---
title: Ассортимент сервер
slug: erp-uh/ассортимент-сервер
---


## ВидыЦенИзмененияАссортиментаСоответствуютПравилам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция проверяет, соответствует ли реквизит "ЦенаВключаетНДС"
// у всех видов цен в табличной части "Товары" документа "ИзменениеАссортимента"
// и у вида цен, указанного в объекте планирования этого документа.
// В случае нахождения расхождений выводит информационное сообщение
// Вызывается ПЕРЕД записью соответствующего документа-объекта.
//
// Параметры:
//  ДокументОбъект - ДокументОбъект.ИзменениеАссортимента
//
// Возвращаемое значение:
//  Булево - если реквизит "ЦенаВключаетНДС" все виды цен совпадает, возвращается Истина, иначе Ложь.
//
Функция ВидыЦенИзмененияАссортиментаСоответствуютПравилам(ДокументОбъект) Экспорт
```

Пример вызова
```bsl
Результат = АссортиментСервер.ВидыЦенИзмененияАссортиментаСоответствуютПравилам(ДокументОбъект) 
```
</details>

## ОбъектПланирования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает значение текущего объекта планирования ассортимента в зависимости от настроек.
//
// Параметры:
//  ОбъектПроверки  - СправочникСсылка.Склады, СправочникСсылка.ФорматыМагазинов - Склад или формат для которого
//                                                                                 определяется объект планирования
//  НаДату  - Дата - Дата на которую определяется текущий объект планирования.
//
// Возвращаемое значение:
//   СправочникСсылка.ФорматыМагазинов, СправочникСсылка.Склады   - текущий объект планирования, в зависимости от ФО -
//   формат магазина или склад-магазин.
//
Функция ОбъектПланирования(ОбъектПроверки, Знач НаДату = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = АссортиментСервер.ОбъектПланирования(ОбъектПроверки, НаДату);
```
</details>

## ПроверитьНеобходимостьУстановкиЦенНаОсновании
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура проверяет стадию документа "ИзменениеАссортимента"
// Вызывается при обработке заполнения документа "Установка цен" на основании "ИзменениеАссортимента"
// если документ переводит товары в стадию "ЗапрещеныЗакупкиИПродажи"
// то принудительно вызывается исключение и формируется соответствующий текст ошибки.
//
// Параметры:
// 		ДокументОснование - ДокументСсылка.ИзменениеАссортимента.
Процедура ПроверитьНеобходимостьУстановкиЦенНаОсновании(ДокументОснование) Экспорт
```

Пример вызова
```bsl
АссортиментСервер.ПроверитьНеобходимостьУстановкиЦенНаОсновании(ДокументОснование) 
```
</details>

## РезультатПакетаВидыЦенИТоварыДляУстановкиПоАссортименту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция получает таблицы товаров и видов цен, содержащихся в табличной части документа "ИзменениеАссортимента"
// вызывается при вводе на основании изменения ассортимента документа установки цен.
//
// Параметры:
//  ДокументОснование - ДокументСсылка.ИзменениеАссортимента
//
// Возвращаемое значение:
//  Массив - результат выполнения пакета запросов.
//
Функция РезультатПакетаВидыЦенИТоварыДляУстановкиПоАссортименту(ДокументОснование) Экспорт
```

Пример вызова
```bsl
Результат = АссортиментСервер.РезультатПакетаВидыЦенИТоварыДляУстановкиПоАссортименту(ДокументОснование) 
```
</details>

## КонтролироватьАссортимент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак контроля ассортимента по истории изменений
//
// Параметры:
//  Склад  - СправочникСсылка.Склады - Склад/магазин для которого проверяется контроль ассортимента
//  НаДату  - Дата - Дата на которую производится проверка контроля ассортимента.
//
// Возвращаемое значение:
//   Булево   - Истина, если ассортимент контролируется на складе и Ложь, если нет.
//
Функция КонтролироватьАссортимент(Знач Склад, Знач НаДату = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = АссортиментСервер.КонтролироватьАссортимент(Склад, НаДату);
```
</details>

## ФорматМагазинаПоСкладу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак контроля ассортимента по истории изменений
//
// Параметры:
//  Склад  - СправочникСсылка.Склады - Склад/магазин для которого проверяется контроль ассортимента
//  НаДату  - Дата - Дата на которую производится проверка контроля ассортимента.
//
// Возвращаемое значение:
//   Булево   - Истина, если ассортимент контролируется на складе и Ложь, если нет.
//
Функция ФорматМагазинаПоСкладу(Знач Склад, Знач НаДату = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = АссортиментСервер.ФорматМагазинаПоСкладу(Склад, НаДату);
```
</details>

## ПроверитьАссортиментТаблицыПодобранныхТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура проверяет вхождение в ассортимент магазина на указанную дату товаров в подборе, не входящих в основание
//
// Параметры:
// 	Объект - ДокументОбъект.ЗаказНаПеремещение - объект подбора
// 	       - ДокументОбъект.ЗаказПоставщику - объект подбора
// 	ИмяРеквизитаСклад - Строка - указывает на реквизит склад, ассортимент которого проверяется
// 	ТаблицаТоваров - ТаблицаЗначений - таблица товаров, добавленных в табличную часть документа, для которых нужно выполнить проверку.
Процедура ПроверитьАссортиментТаблицыПодобранныхТоваров(Объект, ИмяРеквизитаСклад, ТаблицаТоваров = Неопределено) Экспорт
```

Пример вызова
```bsl
АссортиментСервер.ПроверитьАссортиментТаблицыПодобранныхТоваров(Объект, ИмяРеквизитаСклад, ТаблицаТоваров);
```
</details>

## ВидыЦенПоАссортименту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив видов цен, которые назначены для объекта планирования на дату
//
// Параметры:
//  ОбъектПланирования - СправочникСсылка.Склады,СправочникСсылка.ФорматыМагазинов
//  Дата			 - Дата
//  ОтборПоРесурсам	 - Структура.
//
// Возвращаемое значение:
//  Массив - Виды цен по ассортименту.
//
Функция ВидыЦенПоАссортименту(ОбъектПланирования, Знач Дата, ОтборПоРесурсам = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = АссортиментСервер.ВидыЦенПоАссортименту(ОбъектПланирования, Дата, ОтборПоРесурсам);
```
</details>

## ПолучитьЦенуПоАссортименту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция получает значение цены продажи
// в соответствии с видом цен, указанным в регистре "Ассортимент",
// для номенклатуры и склада на указанную дату.
//
// Параметры:
//		ПараметрыОтбора - Структура - Параметры отбора для цены.
//
// Возвращаемое значение:
//  Число - Цена
//
Функция ПолучитьЦенуПоАссортименту(ПараметрыОтбора) Экспорт
```

Пример вызова
```bsl
Результат = АссортиментСервер.ПолучитьЦенуПоАссортименту(ПараметрыОтбора) 
```
</details>

## СтруктураСостоянияАссортиментаТовараВФормате
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция получает актуальные значения ресурсов регистра сведений "Ассортимент" на указанную дату
// для товара и формата магазина.
//
// Параметры:
//  Номенклатура - СправочникСсылка.Номенклатура
//  ОбъектПроверки - СправочникСсылка.ФорматыМагазинов, СправочникСсылка.Склады - Склад или формат магазина
//  НаДату - Дата - Дата на которую определяется текущий объект планирования.
//
// Возвращаемое значение:
//  Структура - аналогична выборке всех ресурсов из регистра.
//
Функция СтруктураСостоянияАссортиментаТовараВФормате(Номенклатура, ОбъектПроверки, Знач НаДату) Экспорт
```

Пример вызова
```bsl
Результат = АссортиментСервер.СтруктураСостоянияАссортиментаТовараВФормате(Номенклатура, ОбъектПроверки, НаДату) 
```
</details>

## СтруктураКвотыПоКатегории
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция получает актуальные значения ресурсов регистра сведений "Квоты ассортимента" на указанную дату
// для категории, марки и формата магазина.
//
// Параметры:
//  ОбъектПланирования - СправочникСсылка.ФорматыМагазинов, СправочникСсылка.Склады - Объект по которому получаем квоты
//  ТоварнаяКатегория - СправочникСсылка.ТоварныеКатегории
//  Марка - СправочникСсылка.Марки
//  НаДату - Дата - дата и время
//
// Возвращаемое значение:
// Структура - аналогична выборке всех ресурсов из регистра.
//
Функция СтруктураКвотыПоКатегории(ОбъектПланирования, ТоварнаяКатегория, Марка, Знач НаДату) Экспорт
```

Пример вызова
```bsl
Результат = АссортиментСервер.СтруктураКвотыПоКатегории(ОбъектПланирования, ТоварнаяКатегория, Марка, НаДату) 
```
</details>

## ВключитьОтборПоАссортиментуВСКД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Если в настройках СКД включено использование отбора по ассортименту,
// то процедура устанавливает служебный параметр использования отбора по ассортименту.
//
//	Параметры:
//		КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных - компоновщик настроек СКД.
//
Процедура ВключитьОтборПоАссортиментуВСКД(КомпоновщикНастроек) Экспорт
```

Пример вызова
```bsl
АссортиментСервер.ВключитьОтборПоАссортиментуВСКД(КомпоновщикНастроек) 
```
</details>

## ДополнитьТекстЗапросаЗаполнитьЦенуПродажиПоАссортименту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для получения цены продажи по ассортименту.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - Структура
Процедура ДополнитьТекстЗапросаЗаполнитьЦенуПродажиПоАссортименту(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
АссортиментСервер.ДополнитьТекстЗапросаЗаполнитьЦенуПродажиПоАссортименту(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаПроверитьАссортиментСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для проверки ассортимента строки.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - Структура
Процедура ДополнитьТекстЗапросаПроверитьАссортиментСтроки(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
АссортиментСервер.ДополнитьТекстЗапросаПроверитьАссортиментСтроки(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
