---
title: Бухгалтерская отчетность БРО
slug: erp-uh/бухгалтерская-отчетность-бро
---


## РазделыОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Содержит имена разделов отчета (в терминологии ФСБУ 4 - "отчетов"), реализованные в программе.
//
// Возвращаемое значение:
//  Массив из Строка
//
Функция РазделыОтчета() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.РазделыОтчета() 
```
</details>

## НовыйКонтекстОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор коллекции, описывающей контекст бухгалтерской отчетности в целом
//
// Возвращаемое значение:
//  Структура - см. тело функции
//
Функция НовыйКонтекстОтчета() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.НовыйКонтекстОтчета() 
```
</details>

## НовыйКонтекстЗаполненияОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор коллекции, описывающей контекст заполнения графы отчета - то есть, получения данных за отчетный или за сравнительный период.
//
// Возвращаемое значение:
//  Структура - см. тело функции
//
Функция НовыйКонтекстЗаполненияОтчета() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.НовыйКонтекстЗаполненияОтчета() 
```
</details>

## ТипСумма
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описывает тип суммовых значений, применяемых в отчете.
// Длина суммовых значений предопределена форматом ГИРБО - там N(12) для сумм в тысячах рублей.
//
// Возвращаемое значение:
//  ОписаниеТипов - описание типа сумм.
//
Функция ТипСумма() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.ТипСумма() 
```
</details>

## НайтиРаздел
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. НовоеДеревоДанныхРазделов() в форме отчета

// На основе подходов в формате ГИРБО все показатели отчета делятся на "фиксированные" и "вписываемые".
//
// "Фиксированные" предполагается использовать, когда отчетность организации совпадает с образцом, приведенным в ФСБУ 4.
// Они предполагают фиксированный (предопределенный) состав показателей отчетности, их наименования и коды.
// Для того, чтобы готовить отчетность, отражающую особенности деятельности предприятия, следует использовать "вписываемые строки".
// Последние позволяют включать в отчет несколько показателей (групп показателей) с одинаковым кодом,
// назначать показателям осмысленные наименования.
//
// Сценарий использования методов раздела:
// 1. С помощью НайтиРаздел находим раздел отчета.
// 2. В этом разделе
//     - обеспечиваем нужное количество вписываемых строк с определенным кодом строки (кодом показателя) - см. СоздатьВписываемыеСтроки
//     либо
//     - находим многострочную часть для хранения вписываемых строк - см. НайтиМногострочнуюЧасть
//     либо
//     - используем фиксированные строки.
//     Для работы с фиксированными строками нужно сначала убедиться, что она подходит - позволяет разместить данные.
//     См. ФиксированнаяСтрокаОтчета.
//     Дальнейшая работа с фиксированной строкой аналогична работе со вписываемыми строками - в частности,
//     в большинство методов можно передавать единообразно вписываемую строку или фиксированную.
// 4. При необходимости обеспечиваем (находим) внутри них строки "в т.ч." - с помощью тех же СоздатьВписываемыеСтроки и НайтиМногострочнуюЧасть.
// 5. Добавить нужное количество строк можно и "вручную" - с помощью ДобавитьСтрокуМногострочнойЧасти
// 6. Для безопасного обращения к строкам отчета по порядку (индексу) можно использовать НайтиСтрокиДереваДанных
// 7. Для установки наименования строки можно использовать УстановитьНаименованиеСтроки
// 8. Для установки значений ячеек в составе строк можно использовать УстановитьЗначениеЯчейки

// Находит строку, соответствующую разделу отчета.
//
// Параметры:
//  ДеревоДанныхРазделов - ДеревоЗначений - см. НовоеДеревоДанныхРазделов
//  Раздел - Строка - искомый раздел, см. РазделыОтчета
//
// Возвращаемое значение:
//  СтрокаДереваЗначений - строка коллекции НовоеДеревоДанныхРазделов, содержащая данные раздела отчета
//  Неопределено - подходящая строка отсутствует
//
Функция НайтиРаздел(ДеревоДанныхРазделов, Раздел) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.НайтиРаздел(ДеревоДанныхРазделов, Раздел) 
```
</details>

## НовыйФиксированнаяСтрокаОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор коллекции, представляющей фиксированную строку отчета.
// См. также ЭтоОписаниеФиксированнойСтроки
//
// Для хранения фиксированных строк для удобства разработчика не используется более-менее логичная иерархическая структура:
// они хранятся просто набором показателей, подчиненных непосредственно разделу, то есть, не сгруппированы по строкам отчета.
//
// То есть, в отличие от вписываемых строк, дерево данных не содержит такой строки, которую можно использовать как ссылку на строку в целом.
// Поэтому вводится абстракция, описывающая фиксированную строку.
//
// Возвращаемое значение:
//  Структура - см. тело функции
//
Функция НовыйФиксированнаяСтрокаОтчета() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.НовыйФиксированнаяСтрокаОтчета() 
```
</details>

## ЭтоОписаниеФиксированнойСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, что переданное значение соответствует ссылке на фиксированную строку (соответствующей абстракции).
//
// Параметры:
//  Строка - AnyType - любая из абстракций, соответствующая строке отчета в дереве данных разделов
//
// Возвращаемое значение:
//  Булево - Истина - это фиксированная строка
//         - Ложь - это вписываемая строка
//
Функция ЭтоОписаниеФиксированнойСтроки(Строка) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.ЭтоОписаниеФиксированнойСтроки(Строка) 
```
</details>

## ФиксированнаяСтрокаОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает описание фиксированной строки отчета с заданными свойствами.
// При этом не гарантируется, что такая фиксированная строка может быть использована - см. МожноИспользоватьФиксированнуюСтроку.
//
// Описание можно передавать в методы работы с вписываемыми строками - СоздатьВписываемыеСтроки, НайтиМногострочнуюЧасть, ЯчейкаОтчета и т.п.
//
// Параметры:
//  ОписаниеРаздела -  СтрокаДереваЗначений - см. НайтиРаздел
//  КодСтроки - Строка - код строки (показателя) бухгалтерской отчетности в соответствии с Приложением 10 к ФСБУ 4
//
// Возвращаемое значение:
//  см. НовыйФиксированнаяСтрокаОтчета - абстрактная ссылка на фиксированную строку
//
Функция ФиксированнаяСтрокаОтчета(ОписаниеРаздела, КодСтроки) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.ФиксированнаяСтрокаОтчета(ОписаниеРаздела, КодСтроки) 
```
</details>

## МожноИспользоватьФиксированнуюСтроку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет возможность использования фиксированной строки.
// При невозможности использования следует использовать вписываемые строки.
//
// Параметры:
//  Строка - см. НовыйФиксированнаяСтрокаОтчета - проверяемая строка
//  Наименование - Строка - наименование показателя, для которого проверяется возможность использовать фиксированные строки.
//            Для строк с другими наименованиями следует использовать вписываемые строки.
//  ОбязательныПодчиненныеСтроки - Булево - Ложь, если не предполагается использовать подчиненные строки "в т.ч.".
//            Если строки нужны, а дерево данных не предоставляет возможности их хранить, следует использовать вписываемые строки.
//  Кеш - Неопределено - при использовании в цикле следует передавать неинициализированную переменную, объявленную вне цикла.
//
// Возвращаемое значение:
//  Истина - можно использовать фиксированную строку
//  Ложь   - нет возможности использовать фиксированную строку, следует использовать вписываемую -
//                 см. СоздатьВписываемыеСтроки, УстановитьНаименованиеСтроки
//
Функция МожноИспользоватьФиксированнуюСтроку(Строка, Наименование, ОбязательныПодчиненныеСтроки = Истина, Кеш = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.МожноИспользоватьФиксированнуюСтроку(Строка, Наименование, ОбязательныПодчиненныеСтроки, Кеш);
```
</details>

## СоздатьВписываемыеСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обеспечивает набор вписываемых строк (строк "в том числе") заданного размера -
// тиражирование строк многострочной части для дальнейшего заполнения.
// Недостающие строки будут добавлены, лишние удалены (однако, в любом случае останется одна строка для образца).
// Можно применять для
// 1. многострочной части, подчиненной разделу - обеспечит набор вписываемых строк с конкретным кодом строки
// 2. многострочной части, подчиненной фиксированной или вписываемой строке отчета верхнего уровня (группе показателей) -
//    обеспечит набор строк "в т.ч." (показателей в составе группы)
//
// Параметры:
//  Родитель - СтрокаДереваЗначений - строка коллекции НовоеДеревоДанныхРазделов: раздел или строка вписываемого показателя.
//                      Раздел можно получить с помощью НайтиРаздел, вписываемые показатели - с помощью НайтиМногострочнуюЧасть.
//           - см. НовыйФиксированнаяСтрокаОтчета - абстрактная ссылка на фиксированный показатель.
//                      Ее можно получить с помощью ФиксированнаяСтрокаОтчета
//  Количество - Число - потребное количество строк
//  КодСтрокиРаздела - Строка - код строки бухгалтерской отчетности (передается, если в качестве Родитель передана вписываемая строка раздела)
//
// Возвращаемое значение:
//  Массив из СтрокаДереваЗначений - строки коллекции НовоеДеревоДанныхРазделов (с типом Строка),
//               соответствующие строкам многострочной части, в порядке их следования в дереве.
//               Предполагается, что к строкам можно обращаться по индексу, коррелированному с Количество.
//
Функция СоздатьВписываемыеСтроки(Родитель, Количество, КодСтрокиРаздела = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.СоздатьВписываемыеСтроки(Родитель, Количество, КодСтрокиРаздела);
```
</details>

## НайтиМногострочнуюЧасть
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Находит строку, соответствующую многострочной части следующего уровня дерева данных отчета:
// 1. многострочную часть, подчиненную разделу - она соответствует набору вписываемых строк с конкретным кодом строки
// 2. многострочную часть, подчиненную фиксированной или вписываемой строке отчета верхнего уровня (группе показателей) -
//    она соответствует набору строк "в т.ч." (показателей в составе группы)
//
// Параметры:
//  Родитель - СтрокаДереваЗначений - строка коллекции НовоеДеревоДанныхРазделов: раздел или строка вписываемого показателя.
//                      Раздел можно получить с помощью НайтиРаздел, вписываемые показатели - с помощью НайтиМногострочнуюЧасть для раздела.
//           - см. НовыйФиксированнаяСтрокаОтчета - абстрактная ссылка на фиксированный показатель.
//                      Ее можно получить с помощью ФиксированнаяСтрокаОтчета
//  КодСтрокиРаздела - Строка - код строки бухгалтерской отчетности (передается, если в качестве Родитель передана строка раздела)
//
// Возвращаемое значение:
//  СтрокаДереваЗначений - строка коллекции НовоеДеревоДанныхРазделов, содержащая многострочную часть
//  Неопределено - подходящая строка отсутствует
//
Функция НайтиМногострочнуюЧасть(Родитель, КодСтрокиРаздела = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.НайтиМногострочнуюЧасть(Родитель, КодСтрокиРаздела);
```
</details>

## ДобавитьСтрокуМногострочнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет строку многострочной части.
//
// Параметры:
//  МногострочнаяЧасть - СтрокаДереваЗначений - строка коллекции НовоеДеревоДанныхРазделов с типом МногострочнаяЧасть
//
// Возвращаемое значение:
//  СтрокаДереваЗначений - строка коллекции НовоеДеревоДанныхРазделов с типом Строка, готовая к использованию методов работы с ячейками.
//
Функция ДобавитьСтрокуМногострочнойЧасти(МногострочнаяЧасть) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.ДобавитьСтрокуМногострочнойЧасти(МногострочнаяЧасть) 
```
</details>

## НайтиСтрокиДереваДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Находит все подстроки дерева данных, соответствующие отбору, в том порядке, в котором они содержатся в дереве.
// Метод следует использовать, когда предполагается несколько строк, соответствующих отбору, и их порядок важен для дальнейшей обработки.
//
// Параметры:
//  ЯчейкаЗначения - СтрокаДереваЗначений - строка коллекции НовоеДеревоДанныхРазделов
//  Отбор - Структура - отбор строк; Ключи - колонки дерева
//
// Возвращаемое значение:
//  Массив из СтрокаДереваЗначений - найденные строки коллекции НовоеДеревоДанныхРазделов
//
Функция НайтиСтрокиДереваДанных(Родитель, Отбор) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.НайтиСтрокиДереваДанных(Родитель, Отбор));
```
</details>

## УстановитьНаименованиеСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает наименование вписываемой строки отчета или строки "в т.ч.".
// Для фиксированной строки можно вызвать, но она ничего не делает.
//
// Параметры:
//  Строка - СтрокаДереваЗначений - из НовоеДеревоДанныхРазделов, с типом Строка.
//           Получить можно с помощью ДобавитьСтрокуМногострочнойЧасти, СоздатьВписываемыеСтроки
//           - см. НовыйФиксированнаяСтрокаОтчета - абстрактная ссылка на фиксированный показатель.
//           Получить можно с помощью ФиксированнаяСтрокаОтчета
//  Наименование - Строка - устанавливаемое наименование
//
Процедура УстановитьНаименованиеСтроки(Строка, Наименование) Экспорт
```

Пример вызова
```bsl
БухгалтерскаяОтчетностьБРО.УстановитьНаименованиеСтроки(Строка, Наименование) 
```
</details>

## УстановитьЗначениеЯчейки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает значение ячейки в дерево данных отчета, с защитой от изменения типа значения ячейки.
//
// Параметры:
//  ЯчейкаЗначения - СтрокаДереваЗначений - строка коллекции НовоеДеревоДанныхРазделов, предположительно соответствующая заполняемой ячейке отчета.
//                                          Допускается передавать результат ЯчейкаОтчета.
//  Значение - Произвольный - значение для помещения в ячейку, например, результат автозаполнения
//
Процедура УстановитьЗначениеЯчейки(ЯчейкаЗначения, Значение) Экспорт
```

Пример вызова
```bsl
БухгалтерскаяОтчетностьБРО.УстановитьЗначениеЯчейки(ЯчейкаЗначения, Значение) 
```
</details>

## ОчиститьЗначениеЯчейки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Очищает (приводит к значению по умолчанию установленного типа) значение ячейки.
//
// Параметры:
//  ЯчейкаЗначения - СтрокаДереваЗначений - строка коллекции НовоеДеревоДанныхРазделов, соответствующая заполняемой ячейке отчета. См. ЯчейкаОтчета
//
Процедура ОчиститьЗначениеЯчейки(ЯчейкаЗначения) Экспорт
```

Пример вызова
```bsl
БухгалтерскаяОтчетностьБРО.ОчиститьЗначениеЯчейки(ЯчейкаЗначения) 
```
</details>

## ЯчейкаОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Находит ячейку отчета - строку дерева данных типа Показатель, предназначенную для хранения выводимого в отчет значения.
//
// Параметры:
//  Строка - СтрокаДереваЗначений - из НовоеДеревоДанныхРазделов, с типом Строка.
//           Получить можно с помощью ДобавитьСтрокуМногострочнойЧасти, СоздатьВписываемыеСтроки
//           - см. НовыйФиксированнаяСтрокаОтчета - абстрактная ссылка на фиксированный показатель.
//           Получить можно с помощью ФиксированнаяСтрокаОтчета
//  НомерГрафы - Строка - номер графы отчета
//
// Возвращаемое значение:
//  СтрокаДереваЗначений - найденная ячейка;
//                         для работы с ней можно использовать УстановитьЗначениеЯчейки, ОчиститьЗначениеЯчейки, УстановитьНаименованиеСтроки
//  Неопределено - ячейка не найдена
//
Функция ЯчейкаОтчета(Строка, НомерГрафы) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.ЯчейкаОтчета(Строка, НомерГрафы) 
```
</details>

## СформироватьПоказателиСтрокиМногострочнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует показатели строки многострочной части (ячейки, хранящие данные отчета).
//
// Параметры:
//  Родитель - СтрокаДереваЗначений - строка коллекции НовоеДеревоДанныхРазделов с типом Строка,
//                                    принадлежащая строке с типом МногострочнаяЧасть
//
Процедура СформироватьПоказателиСтрокиМногострочнойЧасти(Строка) Экспорт
```

Пример вызова
```bsl
БухгалтерскаяОтчетностьБРО.СформироватьПоказателиСтрокиМногострочнойЧасти(Строка) 
```
</details>

## НаименованиеКодаСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет наименование строки (показателя), приведенное в Приложении 10 к ФСБУ 4.
//
// Параметры:
//  КодСтроки - Строка - код строки (показателя)
//  Кеш - Неопределено - при использовании в цикле следует передавать неинициализированную переменную, объявленную вне цикла.
//
// Возвращаемое значение:
//  Строка - наименование.
//  Для строк, которым приложением не установлено определенное наименование, возвращается пустая строка.
//
Функция НаименованиеКодаСтроки(КодСтроки, Кеш = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.НаименованиеКодаСтроки(КодСтроки, Кеш);
```
</details>

## НаименованияКодовСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Содержит наименования строк (показателей), приведенные в Приложении 10 к ФСБУ 4.
//
// Параметры:
//  КодСтроки - Строка - код строки (показателя)
//
// Возвращаемое значение:
//  Соответствие - Ключ - Код строки; Значение - наименование показателя.
//  Содержит коды и наименования строк, которым Приложением установлено определенное наименование.
//
Функция НаименованияКодовСтрок() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.НаименованияКодовСтрок() 
```
</details>

## НовыйЗаполняемыеПоказатели
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор коллекции, описывающей возможности прикладного решения по заполнению бухгалтерской отчетности.
//
// Возвращаемое значение:
//  Структура - см. тело функции
//
Функция НовыйЗаполняемыеПоказатели() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.НовыйЗаполняемыеПоказатели() 
```
</details>

## НовыйЗаполняемыеПоказателиРаздела
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор коллекции, описывающей возможности прикладного решения по заполнению раздела бухгалтерской отчетности.
// Методы работы с коллекцией см. в области ЗаполняемыеПоказателиРаздела программного интерфейса
//
// Возвращаемое значение:
//  Структура - см. тело функции
//
Функция НовыйЗаполняемыеПоказателиРаздела() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.НовыйЗаполняемыеПоказателиРаздела() 
```
</details>

## НовыйАлгоритмЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор описания алгоритма заполнения.
//
// Возвращаемое значение:
//  Структура - см. тело функции
//
Функция НовыйАлгоритмЗаполнения() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.НовыйАлгоритмЗаполнения() 
```
</details>

## НовыйРезультатЗаполненияРазделаОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор коллекции, в которое прикладное решение поместит результат заполнения раздела отчета
//
// Возвращаемое значение:
//  Структура - см. тело функции
//
Функция НовыйРезультатЗаполненияРазделаОтчета() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.НовыйРезультатЗаполненияРазделаОтчета() 
```
</details>

## НовыйЗначенияЗаполненияОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор коллекции, в которое прикладное решение поместит данные заполнения раздела отчета (числовые значения ячеек отчета).
// Эта коллекция при заполнении должна быть синхронизирована по индексам строк с НовыйЗаполняемыеПоказателиРаздела.
//
// Возвращаемое значение:
//  ТаблицаЗначений - см. тело функции.
//
Функция НовыйЗначенияЗаполненияОтчета() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.НовыйЗначенияЗаполненияОтчета() 
```
</details>

## ПолучитьЗаполняемыеПоказателиРаздела
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает из временного хранилища коллекцию, содержащую заполняемые показатели раздела.
// Для использования в форме настроек прикладного решения.
// Временное хранилище может содержать и другие сведения, не подлежащие использованию в форме настроек.
//
// Параметры:
//  АдресВФорме - Строка - Адрес во временном хранилище
//  Раздел - Строка - Имя раздела по РазделыОтчета
//
// Возвращаемое значение:
//  см. НовыйЗаполняемыеПоказателиРаздела
//
Функция ПолучитьЗаполняемыеПоказателиРаздела(АдресВФорме, Раздел) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.ПолучитьЗаполняемыеПоказателиРаздела(АдресВФорме, Раздел) 
```
</details>

## ПоместитьЗаполняемыеПоказателиРаздела
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает сведения о заполняемых показателях раздела во временное хранилище для передачи из формы настроек прикладного решения
// в форму отчета БРО.
//
// Параметры:
//  АдресВФорме - Строка - Адрес во временном хранилище
//  Раздел - Строка - Имя раздела по РазделыОтчета
//  ЗаполняемыеПоказатели - см. НовыйЗаполняемыеПоказателиРаздела - помещаемое значение
//
Процедура ПоместитьЗаполняемыеПоказателиРаздела(АдресВФорме, Раздел, ЗаполняемыеПоказатели) Экспорт
```

Пример вызова
```bsl
БухгалтерскаяОтчетностьБРО.ПоместитьЗаполняемыеПоказателиРаздела(АдресВФорме, Раздел, ЗаполняемыеПоказатели) 
```
</details>

## НаименованиеГруппыПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Универсальные методы для работы с НовыйЗаполняемыеПоказателиРаздела

Функция НаименованиеГруппыПоказателей(ГруппаПоказателей) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.НаименованиеГруппыПоказателей(ГруппаПоказателей) 
```
</details>

## СоставГруппыПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СоставГруппыПоказателей(ГруппаПоказателей) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.СоставГруппыПоказателей(ГруппаПоказателей) 
```
</details>

## ВыводимыеПоказатели
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ВыводимыеПоказатели(Группа) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.ВыводимыеПоказатели(Группа) 
```
</details>

## ТипНаименованиеПоказателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТипНаименованиеПоказателя() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.ТипНаименованиеПоказателя());
```
</details>

## ТипКодСтрокиГИРБО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТипКодСтрокиГИРБО() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскаяОтчетностьБРО.ТипКодСтрокиГИРБО());
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
