---
title: Бухгалтерские отчеты расшифровка
slug: erp-uh/бухгалтерские-отчеты-расшифровка
---


## НастройкиРасшифровки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает настройки расшифровки отчета, которые могут быть открыты любым стандартным отчетом.
//
// Параметры:
//  АдресРасшифровки		 - Строка - Адрес данных расшифровки во временном хранилище.
//  ИдентификаторРасшифровки - ИдентификаторРасшифровкиКомпоновкиДанных - Указатель на элемент данных расшифровки для которого строится расшифровка.
//  ИмяИсходногоОтчета		 - Строка - Имя менеджера отчета из которого вызвана расшифровка.
//  РеквизитыРасшифровки	 - Структура - значения реквизитов из контекста расшифровываемой ячейки.
//
// Возвращаемое значение:
//   - Структура см. БухгалтерскиеОтчетыКлиентСервер.НовыйУниверсальныеНастройки - настройки расшифровки пригодные для чтения стандартным отчетом.
//
Функция НастройкиРасшифровки(АдресРасшифровки, ИдентификаторРасшифровки, ИмяИсходногоОтчета, РеквизитыРасшифровки) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскиеОтчетыРасшифровка.НастройкиРасшифровки(АдресРасшифровки, ИдентификаторРасшифровки, ИмяИсходногоОтчета, РеквизитыРасшифровки) 
```
</details>

## ЗаполнитьНастройкиРасшифровкиПоДаннымСтандартногоОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет настройки расшифровки отчета.
//
// Параметры:
//  Настройки				 - Структура								 - Настройки расшифровки отчета, которые нужно заполнить (см. БухгалтерскиеОтчетыКлиентСервер.НовыйУниверсальныеНастройки).
//  ДанныеРасшифровки		 - ДанныеРасшифровкиКомпоновкиДанных		 - Данные расшифровки отчета.
//  ИдентификаторРасшифровки - ИдентификаторРасшифровкиКомпоновкиДанных  - Идентификатор расшифровки из ячейки для которой вызвана расшифровка.
//  Объект					 - ОтчетОбъект								 - Отчет из данных которого нужно собрать универсальные настройки.
//  РеквизитыРасшифровки	 - Структура								 - Реквизиты отчета полученные из контекста расшифровываемой ячейки.
//
Процедура ЗаполнитьНастройкиРасшифровкиПоДаннымСтандартногоОтчета(Настройки, ДанныеРасшифровки, ИдентификаторРасшифровки, Объект, РеквизитыРасшифровки) Экспорт
```

Пример вызова
```bsl
БухгалтерскиеОтчетыРасшифровка.ЗаполнитьНастройкиРасшифровкиПоДаннымСтандартногоОтчета(Настройки, ДанныеРасшифровки, ИдентификаторРасшифровки, Объект, РеквизитыРасшифровки) 
```
</details>

## РасшифровочныеОтчеты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, какими отчетами можно расшифровать ячейку отчета.
//
// Параметры:
//  ИмяОтчета					 - Строка									 - Имя отчета для которого определяются возможные расшифровки.
//  ДанныеРасшифровки			 - ДанныеРасшифровкиКомпоновкиДанных		 - Данные расшифровки исходного отчета, содержит данный для всех ячеек отчета.
//  ИдентификаторРасшифровки	 - ИдентификаторРасшифровкиКомпоновкиДанных	 - Идентификатор связывающий ячейку отчета с элементом данных расшифровки.
//  ИмяОтчета                	 - Строка									 - Отбор по имени расшифровочного отчета, позволяет сократить вычисления и проверить возможность расшифровки только указанным отчетом.
//
// Возвращаемое значение:
//  ТаблицаЗначений см. НовыйПравилаРасшифровки() - Содержит имена отчетов и реквизиты, требуемые для этих отчетов, правилами расшифровки (см. БухгалтерскиеОтчетыРасшифровка.НовыйПравилаРасшифровки()).
//
Функция РасшифровочныеОтчеты(ДанныеРасшифровки, ИдентификаторРасшифровки, ИмяОтчета) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскиеОтчетыРасшифровка.РасшифровочныеОтчеты(ДанныеРасшифровки, ИдентификаторРасшифровки, ИмяОтчета) 
```
</details>

## ДобавитьТребуемыйРеквизитРасшифровки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет реквизит, требующийся для корректного открытия расшифровочного отчета, в коллекцию требуемых реквизитов правил расшифровки.
//
// Параметры:
//  ТребуемыеРеквизиты	 - ТаблицаЗначений	 - См. НовыйТребуемыеРеквизитыРасшифровки().
//  ИмяРеквизита		 - Строка			 - Имя реквизита.
//  Источники			 - Строка			 - Имена источников для заполнения значения реквизита, разделенные запятыми.
//  Значение			 - Неопределено		 - Значение реквизита которое будет подставлено если не будет найдено ни одного источника.
//
Процедура ДобавитьТребуемыйРеквизитРасшифровки(ТребуемыеРеквизиты, ИмяРеквизита, Источники, Значение = Неопределено) Экспорт
```

Пример вызова
```bsl
БухгалтерскиеОтчетыРасшифровка.ДобавитьТребуемыйРеквизитРасшифровки(ТребуемыеРеквизиты, ИмяРеквизита, Источники, Значение);
```
</details>

## НовыйПравилаРасшифровки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает и инициализирует новую таблицу правил расшифровки отчета.
// При помощи правил расшифровки определяется список расшифровочных отчетов для конкретного отчета источника.
// Одна строка правил описывает один отчет, который может быть использован как расшифровка.
//
// Возвращаемое значение:
//   ТаблицаЗначений - Правила расшифровки.
//
Функция НовыйПравилаРасшифровки() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскиеОтчетыРасшифровка.НовыйПравилаРасшифровки() 
```
</details>

## ДобавитьВНастройкиДанныеРасшифровки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Читает данные расшифровки и добавляет их в настройки
//
// Параметры:
//  ДанныеРасшифровки		 - ДанныеРасшифровкиКомпоновкиДанных		 - Данные расшифровки, из которых будут получены значения настроек
//  ИдентификаторРасшифровки - ИдентификаторРасшифровкиКомпоновкиДанных	 - Идентификатор расшифровки из ячейки для которой вызвана расшифровка
//  Настройки				 - Структура								 - Универсальные настройки, которые нужно дополнить из данных расшифровки
//  РеквизитыРасшифровки	 - Структура								 - Реквизиты отчета, полученные из данных расшифровки, которыми нужно дополнить настройки.
//
Процедура ДобавитьВНастройкиДанныеРасшифровки(ДанныеРасшифровки, ИдентификаторРасшифровки, Настройки, РеквизитыРасшифровки) Экспорт
```

Пример вызова
```bsl
БухгалтерскиеОтчетыРасшифровка.ДобавитьВНастройкиДанныеРасшифровки(ДанныеРасшифровки, ИдентификаторРасшифровки, Настройки, РеквизитыРасшифровки) 
```
</details>

## ДобавитьВНастройкиДанныеОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Читает данные отчета и добавляет их в настройки.
//
// Параметры:
//  Настройки	 - Структура	 - Универсальные настройки, которые нужно дополнить данными отчета.
//  Отчет		 - ОтчетОбъект	 - Отчет, из которого нужно взять данные.
//
Процедура ДобавитьВНастройкиДанныеОтчета(Настройки, Отчет) Экспорт
```

Пример вызова
```bsl
БухгалтерскиеОтчетыРасшифровка.ДобавитьВНастройкиДанныеОтчета(Настройки, Отчет) 
```
</details>

## ПоменятьНумерациюСубконтоВОтборе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет замену левых значений отбора (для отборов по субконто), когда у нового счета другой состав и/или порядок субконто.
//
// Параметры:
//  Настройки			 - Структура				 - Настройки в отборе которых нужно осуществить замену, см. НовыйПравилаРасшифровки().
//  НовыйСчет			 - ПланыСчетов.Хозрасчетный	 - Новый счет.
//	КартаВидовСубконто	 - Соответствие				 - Содержит соответствие старых и новых номеров субконто см. КартаПереходаСубконтоМеждуСчетами.
//
Процедура ПоменятьНумерациюСубконтоВОтборе(Настройки, НовыйСчет, КартаВидовСубконто) Экспорт
```

Пример вызова
```bsl
БухгалтерскиеОтчетыРасшифровка.ПоменятьНумерациюСубконтоВОтборе(Настройки, НовыйСчет, КартаВидовСубконто) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
