---
title: Бухгалтерский учет
slug: erp-uh/бухгалтерский-учет
---


## ПереключитьАктивностьПроводокБУ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Снимает/устанавливает активность проводок документа (бух. учет).
//
// Параметры:
//	Документ - ДокументСсылка.* - Ссылка на документ, для которого меняется активность проводок.
//
Процедура ПереключитьАктивностьПроводокБУ(Документ) Экспорт
```

Пример вызова
```bsl
БухгалтерскийУчет.ПереключитьАктивностьПроводокБУ(Документ) 
```
</details>

## УстановитьСубконто
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает субконто на счете. Если такое субконто на счете
// отсутствует, то ничего не делается.
//
// Параметры:
//	Счет         - ПланСчетовСсылка.Хозрасчетный - Счет, к которому относится субконто.
//  Субконто     - РегистрБухгалтерииСубконто.Хозрасчетный - Набор субконто.
//	ИмяСубконто  - Строка, Число - Номер, имя или вид устанавливаемого субконто.
//  ЗначениеСубконто - Произвольный - Значение устанавливаемого субконто.
//
Процедура УстановитьСубконто(Счет, Субконто, ИмяСубконто, ЗначениеСубконто) Экспорт
```

Пример вызова
```bsl
БухгалтерскийУчет.УстановитьСубконто(Счет, Субконто, ИмяСубконто, ЗначениеСубконто) 
```
</details>

## УстановитьПодразделениеПроводки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает в проводке подразделение на счете, если по нему ведется учет по подразделениям.
//
// Параметры:
//	Проводка - РегистрБухгалтерииЗапись.Хозрасчетный - Проводка, в которой нужно установить подразделение.
//  Подразделение - СправочникСсылка.ПодразделенияОрганизаций - Устанавливаемое подразделение.
//	ДтКт - Строка - Если "Дт", подразделение устанавливается по дебету проводки, иначе по кредиту.
//
Процедура УстановитьПодразделениеПроводки(Проводка, Подразделение, ДтКт = "Дт") Экспорт
```

Пример вызова
```bsl
БухгалтерскийУчет.УстановитьПодразделениеПроводки(Проводка, Подразделение, ДтКт);
```
</details>

## УстановитьПодразделенияПроводки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает в проводке подразделения, если по счетам дебета и кредита ведется учет по подразделениям.
//
// Параметры:
//	Проводка - РегистрБухгалтерииЗапись.Хозрасчетный - Проводка, в которой нужно установить подразделения.
// 	ПодразделениеДт - СправочникСсылка.ПодразделенияОрганизаций - Устанавливаемое подразделение по дебету.
// 	ПодразделениеКт - СправочникСсылка.ПодразделенияОрганизаций - Устанавливаемое подразделение по кредиту.
//
Процедура УстановитьПодразделенияПроводки(Проводка, ПодразделениеДт, ПодразделениеКт) Экспорт
```

Пример вызова
```bsl
БухгалтерскийУчет.УстановитьПодразделенияПроводки(Проводка, ПодразделениеДт, ПодразделениеКт) 
```
</details>

## СформироватьМассивСубсчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет переданные счета их субсчетами. После первого вызова запоминает субсчета
// и при последующих вызовах не обращается к СУБД.
//
// Параметры:
//  МассивСчетов - Массив - список счетов, которые нужно дополнить субсчетами.
//
// Возвращаемое значение:
//   Массив      - список исходных счетов плюс их субсчета.
//
Функция СформироватьМассивСубсчетов(МассивСчетов) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскийУчет.СформироватьМассивСубсчетов(МассивСчетов) 
```
</details>

## МаксимальноеКоличествоСубконто
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает максимальное количество субконто на счете.
//
// Возвращаемое значение:
//	Число - Максимальное количество субконто.
//
Функция МаксимальноеКоличествоСубконто() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскийУчет.МаксимальноеКоличествоСубконто() 
```
</details>

## НачалоОтчетногоГода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет дату начала отчетного года для составления финансовой отчетности в соответствии с Законом "О БУХГАЛТЕРСКОМ
// УЧЕТЕ" N 402-ФЗ (6 декабря 2011 года).
//
// Статья 15
// 3. В случае, если государственная регистрация экономического субъекта, за исключением кредитной организации,
// произведена после 30 сентября, первым отчетным годом является, если иное не установлено экономическим субъектом,
// период с даты государственной регистрации по 31 декабря календарного года, следующего за годом его государственной
// регистрации, включительно.
//
// Параметры:
//  Период		 - Дата - любая дата из отчетного года
//  Организация	 - СправочникСсылка.Организации - Организация, начало отчетного года которой нужно получить.
//
// Возвращаемое значение:
//  Дата         - дата начала периода; как правило начало года, но может быть и датой регистрации организации
//  Неопределено - запрошен период ранее даты регистрации организации.
//
Функция НачалоОтчетногоГода(Период, Организация) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскийУчет.НачалоОтчетногоГода(Период, Организация) 
```
</details>

## ВариантРасширенногоПервогоНалоговогоПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет в целом для сеанса работы, может ли потребоваться рассчитывать,
// заполнять и отображать пользователю суммы НУ в проводках.
//
// Обращение к функции следует выполнять через кеш повтоно используемых значений -
// см. БухгалтерскийУчетВызовСервераПовтИсп.ПользователюДоступныСуммыНалогНаПрибыль()
// Она единообразно работает ИС ПР/ВР, ИС НУ.
//
// Возвращаемое значение:
//  ПеречислениеСсылка.ВариантыРасширенногоПервогоНалоговогоПериода
//
Функция ВариантРасширенногоПервогоНалоговогоПериода() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскийУчет.ВариантРасширенногоПервогоНалоговогоПериода() 
```
</details>

## ПользователюДоступныСуммыНУ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет в целом для сеанса работы, может ли потребоваться рассчитывать,
// заполнять и отображать пользователю суммы НУ в проводках.
//
// Обращение к функции следует выполнять через кеш повтоно используемых значений -
// см. БухгалтерскийУчетВызовСервераПовтИсп.ПользователюДоступныСуммыНалогНаПрибыль()
// Она единообразно работает ИС ПР/ВР, ИС НУ.
//
// Возвращаемое значение:
//  Булево - Истина, если может потребоваться использовать суммы НУ в проводках.
//
Функция ПользователюДоступныСуммыНУ() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскийУчет.ПользователюДоступныСуммыНУ() 
```
</details>

## ИспользоватьСуммыНалогНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет в контексте отдельных операций, отчетов и т.п., нужно ли рассчитывать,
// заполнять и отображать пользователю суммы разниц в проводках.
//
// Параметры:
//  Организация - СправочникСсылка.Организации
//  Период      - Дата - дата, на которую проверяется значение настройки;
//                если не заполнена, то проверяется наиболее поздняя
//  ДоступныйВидИспользованияСумм - Строка - максимально возможный.
//                                  См. БухгалтерскийУчетВызовСервераПовтИсп.ПользователюДоступныСуммыНалогНаПрибыль()
//
// Возвращаемое значение:
//   Строка - варианты использования разниц. См. БухгалтерскийУчетВызовСервераПовтИсп.ПользователюДоступныСуммыНалогНаПрибыль()
//
Функция ИспользоватьСуммыНалогНаПрибыль(Организация, Период, ДоступныйВидИспользованияСумм = "") Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскийУчет.ИспользоватьСуммыНалогНаПрибыль(Организация, Период, ДоступныйВидИспользованияСумм);
```
</details>

## НастроитьПоляУчетаРазниц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Настраивает поля учета разниц в форме, отображающей набор записей регистра Хозрасчетный.
//
// Параметры:
//  ПоляНалогНаПрибыль - Соответствие - ключ = поле формы, в том числе - заголовки строк; значение = вид учета НУ/ПР/ВР
//  ПоляЗаголовков - Структура - поля формы, отображающие заголовки колонок, содержащих показатели НУ, ПР, ВР:
//                    * Дт - ПолеФормы, ГруппаФормы -
//                    * Кт - ПолеФормы, ГруппаФормы -
//  Период         - Дата - основной период набора записей
//  Организация    - СправочникСсылка.Организации - организация набора записей
//                 - Неопределено - организация набора записей не может быть определена
//  ВалютаРУ       - СправочникСсылка.Валюты - Валюта регл. учета
//
Процедура НастроитьПоляУчетаРазниц(ПоляНалогНаПрибыль, ПоляЗаголовков, Период, Организация = Неопределено, ВалютаРУ = Неопределено) Экспорт
```

Пример вызова
```bsl
БухгалтерскийУчет.НастроитьПоляУчетаРазниц(ПоляНалогНаПрибыль, ПоляЗаголовков, Период, Организация, ВалютаРУ);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
