---
title: Бухгалтерский учет клиент сервер
slug: erp-uh/бухгалтерский-учет-клиент-сервер
---


## ПриВыбореСчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура установки типа и видимости субконто в зависимости от выбранного счета
//
// Параметры:
//	Счет			 - <План счетов> - Счет, для которого необходимо настроить тип и видимость субконто
//	Форма			 - <Управляемая форма> - Форма, которая содержит ПоляФормы и ЗаголовкиПолей
//	ПоляФормы		 - <Структура> - Ключи, которой Субконто1, Субконто2, Субконто3,
//									 а значения имена соответствующих полей на форме (поля субконто)
//	ЗаголовкиПолей	 - <Структура> ИЛИ <Неопределено> - Ключи, которой Субконто1, Субконто2, Субконто3
//									 а значения имена соответствующих полей на форме (заголовки субконто)
//	ЭтоТаблица		 - <Булево>		 - Признак того, где выполняется настройка субконто.
//	СкрыватьСубконто - <Булево>		 - Признак того, нужно ли для этой формы дополнительно скрывать субконто, влияет на выполнении функции НужноСкрытьСубконто
//
Процедура ПриВыбореСчета(Счет, Форма, ПоляФормы, ЗаголовкиПолей = Неопределено, ЭтоТаблица = Ложь, СкрыватьСубконто = Истина) Экспорт
```

Пример вызова
```bsl
БухгалтерскийУчетКлиентСервер.ПриВыбореСчета(Счет, Форма, ПоляФормы, ЗаголовкиПолей, ЭтоТаблица, СкрыватьСубконто);
```
</details>

## ПриИзмененииСчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура установки типа, значения и доступности субконто в зависимости от выбранного счета.
//
// Параметры:
//	Счет			 - ПланСчетовСсылка.Хозрасчетный - Счет, для которого необходимо настроить тип и видимость субконто.
//	Объект			 - УправляемаяФорма, СтрокаТабличнойЧасти - Объект, который содержит ПоляФормы.
//	ПоляОбъекта		 - Структура - Ключи, которой Субконто1, Субконто2, Субконто3,
//									 а значения имена соответствующих полей на форме (поля субконто).
//	ЭтоТаблица       - Булево  - Признак того, что Объект является таблицей.
//	ЗначенияСубконто - Соответствие, Неопределено - Значения субконто, где ключ Вид субконто, а значение - значение для подстановки.
//	СкрыватьСубконто - Булево  - Признак того, нужно ли для этой формы дополнительно скрывать субконто, влияет на выполнении функции СкрытьСубконто.
//
Процедура ПриИзмененииСчета(Счет, Объект, ПоляОбъекта, ЭтоТаблица = Ложь, ЗначенияСубконто = Неопределено, СкрыватьСубконто = Истина) Экспорт
```

Пример вызова
```bsl
БухгалтерскийУчетКлиентСервер.ПриИзмененииСчета(Счет, Объект, ПоляОбъекта, ЭтоТаблица, ЗначенияСубконто, СкрыватьСубконто);
```
</details>

## УстановитьДоступностьСубконто
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура установки доступности субконто в зависимости от выбранного счета.
//
// Параметры:
//	Счет			 - ПланСчетовСсылка.Хозрасчетный - Счет, для которого необходимо настроить тип и видимость субконто.
//	Объект			 - УправляемаяФорма, СтрокаТабличнойЧасти - Объект, который содержит ПоляФормы.
//	ПоляОбъекта		 - Структура - Ключи, которой Субконто1, Субконто2, Субконто3, а значения имена соответствующих полей на форме (поля субконто).
//	СкрыватьСубконто - Булево - Признак того, нужно ли для этой формы дополнительно скрывать субконто, влияет на выполнении функции НужноСкрытьСубконто.
//
Процедура УстановитьДоступностьСубконто(Счет, Объект, ПоляОбъекта, СкрыватьСубконто = Истина) Экспорт
```

Пример вызова
```bsl
БухгалтерскийУчетКлиентСервер.УстановитьДоступностьСубконто(Счет, Объект, ПоляОбъекта, СкрыватьСубконто);
```
</details>

## ИзменитьПараметрыВыбораПолейСубконто
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура изменяет параметры выбора полей субконто.
//
// Параметры:
//	Форма - УправляемаяФорма - Форма, на которой расположены поля субконто.
//	Объект - ДанныеФормыСтруктура - Объект, форма которого отображается.
//	ШаблонИмяПоляОбъекта - Строка - Шаблон имени поля объекта, содержащего субконто.
//	ШаблонИмяЭлементаФормы - Строка - Шаблон имени поля формы, в который выводится субконто.
//	СписокПараметров - Структура - Содержит ключи со значениями отборов.
//
Процедура ИзменитьПараметрыВыбораПолейСубконто(Форма, Объект, ШаблонИмяПоляОбъекта, ШаблонИмяЭлементаФормы, СписокПараметров) Экспорт
```

Пример вызова
```bsl
БухгалтерскийУчетКлиентСервер.ИзменитьПараметрыВыбораПолейСубконто(Форма, Объект, ШаблонИмяПоляОбъекта, ШаблонИмяЭлементаФормы, СписокПараметров) 
```
</details>

## ИзменитьПараметрыВыбораСчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура изменяет параметры выбора для ПоляВвода управляемой формы.
//
// Параметры:
//	ЭлементФормыСчет - ПолеВвода - Поле, для которого изменяется параметр выбора.
//  МассивСчетов                 - Массив, Неопределено - счета, которыми нужно ограничить список.
//	                                   Если не заполнено - ограничения не будет.
//  ОтборПоПризнакуВалютный      - Булево, Неопределено - Значение для установки соответствующего параметра выбора.
//                                     Если неопределено, параметр выбора не устанавливается.
//  ОтборПоПризнакуЗабалансовый   - Булево, Неопределено - Значение для установки соответствующего параметра выбора.
//                                     Если неопределено, параметр выбора не устанавливается.
//  ОтборПоПризнакуСчетГруппа    - Булево, Неопределено - Значение для установки соответствующего параметра выбора.
//                                     Если неопределено, параметр выбора не устанавливается.
//
Процедура ИзменитьПараметрыВыбораСчета(ЭлементФормыСчет, МассивСчетов, ОтборПоПризнакуВалютный = Неопределено, ОтборПоПризнакуЗабалансовый = Неопределено, ОтборПоПризнакуСчетГруппа = Ложь) Экспорт
```

Пример вызова
```bsl
БухгалтерскийУчетКлиентСервер.ИзменитьПараметрыВыбораСчета(ЭлементФормыСчет, МассивСчетов, ОтборПоПризнакуВалютный, ОтборПоПризнакуЗабалансовый, ОтборПоПризнакуСчетГруппа);
```
</details>

## ТипСумма
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание типов для суммового показателя.
//
// Возвращаемое значение:
//	ОписаниеТипов - Описание типов для суммового показателя.
//
Функция ТипСумма() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскийУчетКлиентСервер.ТипСумма() 
```
</details>

## РазрядностьДробнойЧастиСумм
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает число знаков после запятой для суммового показателя.
//
// Возвращаемое значение:
//	Число - число знаков после запятой для суммового показателя.
//
Функция РазрядностьДробнойЧастиСумм() Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскийУчетКлиентСервер.РазрядностьДробнойЧастиСумм() 
```
</details>

## ИспользоватьСуммуНУ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет условие использования сумм НУ.
//
// Параметры:
//  ВидИспользованияСумм - Строка - см. БухгалтерскийУчетВызовСервераПовтИсп.ПользователюДоступныСуммыНалогНаПрибыль()
//
// Возвращаемое значение:
//   Булево      - Истина, если суммы НУ используются.
//
Функция ИспользоватьСуммуНУ(ВидИспользованияСумм) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскийУчетКлиентСервер.ИспользоватьСуммуНУ(ВидИспользованияСумм) 
```
</details>

## ИспользоватьСуммыРазниц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет условие использования сумм ВР и ПР.
//
// Параметры:
//  ВидИспользованияСумм - Строка - см. БухгалтерскийУчетВызовСервераПовтИсп.ПользователюДоступныСуммыНалогНаПрибыль()
//
// Возвращаемое значение:
//   Булево      - Истина, если суммы разниц используются.
//
Функция ИспользоватьСуммыРазниц(ВидИспользованияСумм) Экспорт
```

Пример вызова
```bsl
Результат = БухгалтерскийУчетКлиентСервер.ИспользоватьСуммыРазниц(ВидИспользованияСумм) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
