---
title: Бюджетная отчетность клиент сервер
slug: erp-uh/бюджетная-отчетность-клиент-сервер
---


## ПоместитьЭлементВХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает хранилище со стандартной структурой
// элемента бюджетного отчета на основании ссылки или строки
// вида бюджета.
//
// Параметры:
//  Элемент  - ДанныеФормыЭлементДерева, СправочникСсылка.ЭлементыФинансовыхОтчетов - помещаемое значение
//  АдресХранилища - УникальныйИдентификатор - УИД формы вида бюджета.
//
// Возвращаемое значение:
//  Строка - Адрес в хранилище
//
Функция ПоместитьЭлементВХранилище(Элемент, АдресХранилища) Экспорт
```

Пример вызова
```bsl
Результат = БюджетнаяОтчетностьКлиентСервер.ПоместитьЭлементВХранилище(Элемент, АдресХранилища) 
```
</details>

## ПредставлениеПрочейАналитикиБюджетирования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строковое представление пустого измерения (вида аналитики).
//
// Параметры:
//  ИзмерениеВидАналитики - ПланВидовХарактеристикСсылка.АналитикиСтатейБюджетов - Вид аналитики.
//  						- Строка - Измерение. Например "Организация" или "Подразделение".
//  Режим - Строка - Режим получения представления аналитики.
//  				Доступны значения:
//  					"Прочие" - Например, <прочие организации>.
//  					"Все" - Например, <все организации>.
//  					"ДобавляемыеИПрочие" - Например, <добавляемые и прочие организации>.
//  ПредставлениеИзмеренияВидаАналитики - Строка - Строковое представление вида аналитики или измерения.
//  			Для измерения - представление в локализованном формате.
//  			Для вида аналитики - наименование вида аналитики.
//  										- Неопределено - Значение по умолчанию. Представление определяется обращением к базе данных.
//  КэшПредставлений - Соответствие - Соответствие, где ключ - вид аналитики или строка - имя измерения. Значение - представление пустого значения, например <Прочие организации>.
//  					- Неопределено - Кэш представлений не задан.
//  КодЯзыка - Строка - Код языка. По умолчанию пустая строка - соответствует языку текущего пользователя.
//  			Задается при необходимости получения представления для конкретного языка, например, для основного языка конфигурации.
//
// Возвращаемое значение:
//  Строка - представление пустого измерения (вида аналитики), например, "<прочие статьи ДДС>".
//
Функция ПредставлениеПрочейАналитикиБюджетирования(ИзмерениеВидАналитики, Режим, ПредставлениеИзмеренияВидаАналитики = Неопределено, КэшПредставлений = Неопределено, КодЯзыка = "") Экспорт
```

Пример вызова
```bsl
Результат = БюджетнаяОтчетностьКлиентСервер.ПредставлениеПрочейАналитикиБюджетирования(ИзмерениеВидАналитики, Режим, ПредставлениеИзмеренияВидаАналитики, КэшПредставлений, КодЯзыка);
```
</details>

## ПредставлениеИзмеренияБюджетирования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строковое представление измерения.
//
// Параметры:
//  ИмяИзмерения - Строка - Предопределенное имя измерения.
//  КодЯзыка - Строка - Код языка. По умолчанию пустая строка - соответствует языку текущего пользователя.
//  				Задается при необходимости получения представления для конкретного языка, например, для основного языка конфигурации.
//
// Возвращаемое значение:
//  Строка - Строковое представление измерения.
//
Функция ПредставлениеИзмеренияБюджетирования(ИмяИзмерения, КодЯзыка = "") Экспорт
```

Пример вызова
```bsl
Результат = БюджетнаяОтчетностьКлиентСервер.ПредставлениеИзмеренияБюджетирования(ИмяИзмерения, КодЯзыка);
```
</details>

## ПеременныеПериодовБюджетирования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру значений переменных периодов, используемых в бюджетировании.
//
// Параметры:
//  ИсключаяСкобки - Булево - Если истина, то из имени и представления переменной будут исключены ограничивающие квадратные скобки.
//  			Значение по умолчанию Ложь.
//  КодЯзыка - Строка - Код языка. По умолчанию пустая строка - соответствует языку текущего пользователя.
//  			Задается при необходимости получения представления для конкретного языка, например, для основного языка конфигурации.
//
// Возвращаемое значение:
//  Структура  - Структура переменных периодов, используемых в бюджетировании:
//   * НачалоПериодаДанных - Структура - содержит:
//   	** Имя - Строка - Значение переменной. Не локализуется, хранится в базе данных. Например, "[ГраницаФактДанных]".
//   	** Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   * КонецПериодаДанных - Структура - содержит:
//   	** Имя - Строка - Значение переменной. Не локализуется, хранится в базе данных. Например, "[ГраницаФактДанных]".
//   	** Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   * ГраницаФактДанных - Структура - содержит:
//   	** Имя - Строка - Значение переменной. Не локализуется, хранится в базе данных. Например, "[ГраницаФактДанных]".
//   	** Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   * ПериодГруппировки - Структура - содержит:
//   	** Имя - Строка - Значение переменной. Не локализуется, хранится в базе данных. Например, "[ГраницаФактДанных]".
//   	** Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//
Функция ПеременныеПериодовБюджетирования(ИсключаяСкобки = Ложь, КодЯзыка = "") Экспорт
```

Пример вызова
```bsl
Результат = БюджетнаяОтчетностьКлиентСервер.ПеременныеПериодовБюджетирования(ИсключаяСкобки, КодЯзыка);
```
</details>

## ЗначенияПеременныхПериодовПоПредставлению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие представлений переменных периодов и их значений.
//
// Параметры:
//  ИсключаяСкобки - Булево - Если истина, то из имени и представления переменной будут исключены ограничивающие квадратные скобки.
//  			Значение по умолчанию Ложь.
//  КодЯзыка - Строка - Код языка. По умолчанию пустая строка - соответствует языку текущего пользователя.
//  			Задается при необходимости получения представления для конкретного языка, например, для основного языка конфигурации.
//
// Возвращаемое значение:
//  Соответствие из КлючИЗначение - Соответствие представлений переменных периодов и их значений:
//   *Ключ - Строка - пользовательское представление переменной.
//   *Значение - Строка - хранимое не локализуемое значение переменной.
//
Функция ЗначенияПеременныхПериодовПоПредставлению(ИсключаяСкобки = Ложь, КодЯзыка = "") Экспорт
```

Пример вызова
```bsl
Результат = БюджетнаяОтчетностьКлиентСервер.ЗначенияПеременныхПериодовПоПредставлению(ИсключаяСкобки, КодЯзыка);
```
</details>

## ПредставленияПеременныхПериодовПоЗначению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие значений переменных периодов и их представлений.
//
// Параметры:
//  ИсключаяСкобки - Булево - Если истина, то из имени и представления переменной будут исключены ограничивающие квадратные скобки.
//  			Значение по умолчанию Ложь.
//  КодЯзыка - Строка - Код языка. По умолчанию пустая строка - соответствует языку текущего пользователя.
//  			Задается при необходимости получения представления для конкретного языка, например, для основного языка конфигурации.
//
// Возвращаемое значение:
//  Соответствие из КлючИЗначение - Соответствие значений переменных периодов и их представлений:
//   *Ключ - Строка - хранимое не локализуемое значение переменной.
//   *Значение - Строка - пользовательское представление переменной.
//
Функция ПредставленияПеременныхПериодовПоЗначению(ИсключаяСкобки = Ложь, КодЯзыка = "") Экспорт
```

Пример вызова
```bsl
Результат = БюджетнаяОтчетностьКлиентСервер.ПредставленияПеременныхПериодовПоЗначению(ИсключаяСкобки, КодЯзыка);
```
</details>

## ПеременныеБюджетныхОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру значений параметров для подстановки в текстовые поля, используемых в бюджетных отчетах.
//
// Параметры:
//  ИсключаяСкобки - Булево - Если истина, то из имени и представления параметра будут исключены ограничивающие квадратные скобки.
//  			Значение по умолчанию Ложь.
//  КодЯзыка - Строка - Код языка. По умолчанию пустая строка - соответствует языку текущего пользователя.
//  			Задается при необходимости получения представления для конкретного языка, например, для основного языка конфигурации.
//
// Возвращаемое значение:
//  Структура - Структура параметров, используемых в бюджетировании:
//   *ВидОтчета - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     **Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     **Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   *ТекущаяДатаИВремя - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     **Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     **Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   *ПериодОтчетности - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     **Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     **Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   *КонечнаяДатаПериодаОтчета - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     **Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     **Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   *ГраницаФактическихДанных - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     **Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     **Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   *Организация - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     **Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     **Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   *Подразделение - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     **Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     **Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   *Сценарий - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     **Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     **Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   *СтатусДокумента - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     **Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     **Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   *Ответственный - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     **Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     **Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   *Утверждающий - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     **Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     **Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//
Функция ПеременныеБюджетныхОтчетов(ИсключаяСкобки = Ложь, КодЯзыка = "") Экспорт
```

Пример вызова
```bsl
Результат = БюджетнаяОтчетностьКлиентСервер.ПеременныеБюджетныхОтчетов(ИсключаяСкобки, КодЯзыка);
```
</details>

## УпорядоченныеПеременныеБюджетныхОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает упорядоченный массив значений параметров для подстановки в текстовые поля, используемых в бюджетных отчетах.
//
// Параметры:
//  КодЯзыка - Строка - Код языка. По умолчанию пустая строка - соответствует языку текущего пользователя.
//  		Задается при необходимости получения представления для конкретного языка, например, для основного языка конфигурации.
//
// Возвращаемое значение:
//  Массив из Структура -  Упорядоченный массив параметров, параметр представляет структуру с колонками:
//  	*Имя - Строка - Идентификатор переменной.
//  	*Представление - Строка - Представление переменной.
//
Функция УпорядоченныеПеременныеБюджетныхОтчетов(КодЯзыка = "") Экспорт
```

Пример вызова
```bsl
Результат = БюджетнаяОтчетностьКлиентСервер.УпорядоченныеПеременныеБюджетныхОтчетов(КодЯзыка);
```
</details>

## ПолучитьИдентификатор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вычисляет значение идентификатора из строки соответствии с правилами именования переменных.
//
// Параметры:
//  СтрНаименование - Строка - Наименование, строка из которой необходимо получить идентификатор.
//
// Возвращаемое значение:
//  Строка - Идентификатор, соответствующий правилам именования идентификаторов.
//
Функция ПолучитьИдентификатор(СтрНаименование) Экспорт
```

Пример вызова
```bsl
Результат = БюджетнаяОтчетностьКлиентСервер.ПолучитьИдентификатор(СтрНаименование) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
