---
title: Ввод остатков сервер
slug: erp-uh/ввод-остатков-сервер
---


## ОписаниеРазделовВводаОстатков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описания разделов и хозяйственных операций ввода остатков.
//
// Параметры:
// 	УчитыватьФО - Булево - Учет функциональных опций при построении таблицы.
// Возвращаемое значение:
// 	ТаблицаЗначений - таблица значений содержащая описание хозяйственных операций ввода остатков:
// * РазделУчета - Строка  - Текстовое представление раздела учета
// * ХозяйственнаяОперация - ПеречислениеСсылка.ХозяйственныеОперации - Значение хозяйственной операции ввода остатков
// * ПояснениеРазделаУчета - Строка - Текстовое представление описания хозяйственной операции ввода остатков
// * ПорядокВДереве        - Число - Иерархия хозяйственной операции в дереве ввода остатков
// * ДоступностьВвода      - Булево - Разрешает или запрещает ввод документа ввода остатков
// * ДокументВводаОстатков - СправочникСсылка.ИдентификаторыОбъектовМетаданных - Идентификатор документа ввода остатков
// * ШаблонЗаголовкаДокумента - Строка - Шаблон по которому строится представление документа.
//
Функция ОписаниеРазделовВводаОстатков(УчитыватьФО = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ВводОстатковСервер.ОписаниеРазделовВводаОстатков(УчитыватьФО);
```
</details>

## ДоступныеХозяйственныеОперации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив доступных хозяйственных операций.
//
// Параметры:
// 	ПараметрыОтбора - Структура - параметры отбора доступных хозяйственных операций, см. ИнициализироватьПараметрыОтбораДоступныхХозяйственныхОпераций.
// Возвращаемое значение:
// 	Массив - Доступные хозяйственных операций.
//
Функция ДоступныеХозяйственныеОперации(ПараметрыОтбора) Экспорт
```

Пример вызова
```bsl
Результат = ВводОстатковСервер.ДоступныеХозяйственныеОперации(ПараметрыОтбора) 
```
</details>

## ОпределитьДокументПоХозяйственнойОперации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает идентификатор документа ввода остатков.
//
// Параметры:
// 	ХозяйственнаяОперация - ПеречислениеСсылка.ХозяйственныеОперации - Хозяйственная операция ввода начальных остатков.
// Возвращаемое значение:
// 	СправочникСсылка.ИдентификаторыОбъектовМетаданных - Идентификатор документа ввода остатков.
//
Функция ОпределитьДокументПоХозяйственнойОперации(ХозяйственнаяОперация) Экспорт
```

Пример вызова
```bsl
Результат = ВводОстатковСервер.ОпределитьДокументПоХозяйственнойОперации(ХозяйственнаяОперация) 
```
</details>

## ИмяДокументаПоХозяйственнойОперации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает синоним документа определенного по хозяйственной операции.
//
// Параметры:
// 	ХозяйственнаяОперация - ПеречислениеСсылка.ХозяйственныеОперации - Хозяйственная операция для которой определяется документ и синоним документа
// Возвращаемое значение:
// 	Строка - Синоним документа.
//
Функция ИмяДокументаПоХозяйственнойОперации(ХозяйственнаяОперация) Экспорт
```

Пример вызова
```bsl
Результат = ВводОстатковСервер.ИмяДокументаПоХозяйственнойОперации(ХозяйственнаяОперация) 
```
</details>

## ДобавитьОписаниеРазделаВводаОстатков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет описание раздела ввода остатков данными заполнения.
//
// Параметры:
// 	ОписаниеРазделовВводаОстатков - ТаблицаЗначений - Таблица значений инициализированная в процедуре ИнициализироватьОписаниеРазделовВводаОстатков
// 	ДанныеЗаполнения              - Структура - Структура данных заполнения, инициализированная в процедуре ИнициализироватьОписаниеРазделаУчета
//
Процедура ДобавитьОписаниеРазделаВводаОстатков(ОписаниеРазделовВводаОстатков, ДанныеЗаполнения) Экспорт
```

Пример вызова
```bsl
ВводОстатковСервер.ДобавитьОписаниеРазделаВводаОстатков(ОписаниеРазделовВводаОстатков, ДанныеЗаполнения) 
```
</details>

## ИнициализироватьОписаниеРазделаУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует структуру описания раздела учета ввода остатков.
//
// Возвращаемое значение:
// 	Структура - Структура содержащая описание раздела учета ввода остатков:
//       *  ДоступностьВвода - Булево - Определят возможность ввод документа ввода остатков
//       * ПорядокВДереве - Число - Иерархия хозяйственной операции в дереве журнала ввода остатков
//       * ХозяйственныеОперации - ПеречислениеСсылка.ХозяйственныеОперации - Хозяйственная операция ввода остатков
//       * ПояснениеРазделаУчета - Строка - Пояснение раздела учета ввода остатков.
//
Функция ИнициализироватьОписаниеРазделаУчета() Экспорт
```

Пример вызова
```bsl
Результат = ВводОстатковСервер.ИнициализироватьОписаниеРазделаУчета() 
```
</details>

## ИнициализироватьЗначенияЗаполненияДокументаВводОстатков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Значения реквизитов для заполнения документа ввода остатков.
//
// Возвращаемое значение:
// 	Структура - Структура содержащая имена реквизитов документа ввода остатков и значения их заполнения:
//       * Комментарий                                - Строка - Комментарий, который будет установлен создаваемого документа
//       * ДатаДокумента                             - Дата - Дата, которая будет установлена создаваемому документу
//       * ОтражатьВУУ                                - Булево - Признак отражения в управленческом учете
//       * ОтражатьВБУиНУ - Булево        - Признак отражения в регламентированном и налоговом учете
//       * ОтражатьВОперативномУчете - Булево - Признак отражения в оперативном учете
//       * Организация                                 - СправочникСсылка.Организации - Организация, для которой вводится остатки
//       * ХозяйственнаяОперация            - ПеречислениеСсылка.ХозяйственныеОперации - Хозяйственная операция ввода остатков.
//
Функция ИнициализироватьЗначенияЗаполненияДокументаВводОстатков() Экспорт
```

Пример вызова
```bsl
Результат = ВводОстатковСервер.ИнициализироватьЗначенияЗаполненияДокументаВводОстатков() 
```
</details>

## ИнициализироватьОписаниеХозяйственнойОперацииВводаОстатков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует структуру описания хозяйственной операции ввода остатков.
//
// Возвращаемое значение:
// 	ТаблицаЗначений - Описание:
//       * ХозяйственнаяОперация - ПеречислениеСсылка.ХозяйственныеОперации - Хозяйственная операция ввода остатков
//       * ШаблонЗаголовкаДокумента - Строка - Шаблон заголовка документа ввода остатков
//       * ДокументВводаОстатков - СправочникСсылка.ИдентификаторыОбъектовМетаданных - Идентификатор документа ввода остатков.
//       * ПорядокВДереве - Число - Порядок для сортировки
Функция ИнициализироватьОписаниеХозяйственнойОперацииВводаОстатков() Экспорт
```

Пример вызова
```bsl
Результат = ВводОстатковСервер.ИнициализироватьОписаниеХозяйственнойОперацииВводаОстатков() 
```
</details>

## ИнициализироватьПараметрыОтбораДоступныхХозяйственныхОпераций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры для отбора доступных хозяйственных операций.
//
// Возвращаемое значение:
// 	Структура - Описание:
//        * РазделУчета - Строка - Раздел учета ввода начальных остатков
//        * ДокументВводаОстатков - СправочникСсылка.ИдентификаторОбъектаМетаданных - Идентификатор документа ввода остатков.
//        * ДоступностьВвода - Строка - Доступность ввода
//
Функция ИнициализироватьПараметрыОтбораДоступныхХозяйственныхОпераций() Экспорт
```

Пример вызова
```bsl
Результат = ВводОстатковСервер.ИнициализироватьПараметрыОтбораДоступныхХозяйственныхОпераций() 
```
</details>

## СформироватьДокументыВводаОстатковПоДаннымОперативногоУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура по данным оперативного учета формирует документы ввода остатков отражаемые в регламентированном учете.
//
// Параметры:
// 	Параметры - Структура - Структура, содержащая параметры создания новых документов
// 	АдресХранилища - Строка - Адрес временного хранилища, в который помещается массив созданных документов.
//
Процедура СформироватьДокументыВводаОстатковПоДаннымОперативногоУчета(Параметры, АдресХранилища) Экспорт
```

Пример вызова
```bsl
ВводОстатковСервер.СформироватьДокументыВводаОстатковПоДаннымОперативногоУчета(Параметры, АдресХранилища) 
```
</details>

## ДоступныеТипыВводаОстатков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает доступные типы документов ввода остатков
//
// Возвращаемое значение:
// 	Массив - Доступные типы документов ввода остатков
//
Функция ДоступныеТипыВводаОстатков() Экспорт
```

Пример вызова
```bsl
Результат = ВводОстатковСервер.ДоступныеТипыВводаОстатков() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
