---
title: Взаиморасчеты сервер
slug: erp-uh/взаиморасчеты-сервер
---


## ЗаполнитьДанныеВыбораОбъектаРасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполнение данных выбора объекта расчетов.
//
// Параметры:
//		ДанныеВыбора - СписокЗначений из СправочникСсылка.ОбъектыРасчетов - Заполняемые данные выбора.
//		СтруктураОтбора - см. ВзаиморасчетыКлиентСервер.СтруктураОтбораДанныхВыбора
//		ВводПоСтроке - Булево - Признак того, что происходит ввод по строке.
//		ЭтоУИП - Булево - Уиникальный идентификатор платежа
//
Процедура ЗаполнитьДанныеВыбораОбъектаРасчетов(ДанныеВыбора, СтруктураОтбора, ВводПоСтроке = Истина, ЭтоУИП = Ложь) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьДанныеВыбораОбъектаРасчетов(ДанныеВыбора, СтруктураОтбора, ВводПоСтроке, ЭтоУИП);
```
</details>

## ЗаполнитьДанныеВыбораОснованияПлатежа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполнение данных выбора основания платежа.
//
// Параметры:
//		ДанныеВыбора - СписокЗначений из ДокументСсылка - Заполняемые данные выбора.
//		СтруктураОтбора - см. ВзаиморасчетыКлиентСервер.СтруктураОтбораДанныхВыбора
//		ВводПоСтроке - Булево - Признак того, что происходит ввод по строке.
//		ЭтоУИП - Булево - Уиникальный идентификатор платежа
//
Процедура ЗаполнитьДанныеВыбораОснованияПлатежа(ДанныеВыбора, СтруктураОтбора, ВводПоСтроке = Истина, ЭтоУИП = Ложь) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьДанныеВыбораОснованияПлатежа(ДанныеВыбора, СтруктураОтбора, ВводПоСтроке, ЭтоУИП);
```
</details>

## ЗаполнитьДанныеВыбораУИП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполнение данных выбора идентификатора платежа.
//
// Параметры:
//		ДанныеВыбора - СписокЗначений из СправочникСсылка.ОбъектыРасчетов - Заполняемые данные выбора.
//		СтруктураОтбора - см. ВзаиморасчетыКлиентСервер.СтруктураОтбораДанныхВыбора
//		ВводПоСтроке - Булево - Признак того, что происходит ввод по строке.
//
Процедура ЗаполнитьДанныеВыбораУИП(ДанныеВыбора, СтруктураОтбора, ВводПоСтроке = Истина) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьДанныеВыбораУИП(ДанныеВыбора, СтруктураОтбора, ВводПоСтроке);
```
</details>

## ЗаполнитьРасшифровкуПлатежаПоЗаказуКлиента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполнения табличной части "РасшифровкаПлатежа" по заказу клиента.
//
// Параметры:
//	ПараметрыЗаполнения - См. ВзаиморасчетыСервер.ПараметрыЗаполненияРасшифровкиПлатежаПоЗаказу.
//	РасшифровкаПлатежа - ТабличнаяЧасть, ТаблицаЗначений - Табличная часть документа, выгрузка колонок табличной части по документу.
//	СуммаКОплате - Число - Сумма к оплате, если известна.
//	Организация - СправочникСсылка.Организации - Организация, осуществляющая продажу.
//	ХозяйственнаяОперация - ПеречислениеСсылка.ХозяйственныеОперации - вид операции платежного документа.
//
Процедура ЗаполнитьРасшифровкуПлатежаПоЗаказуКлиента(ПараметрыЗаполнения, РасшифровкаПлатежа, СуммаКОплате = 0, Организация = Неопределено, ХозяйственнаяОперация = Неопределено) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьРасшифровкуПлатежаПоЗаказуКлиента(ПараметрыЗаполнения, РасшифровкаПлатежа, СуммаКОплате, Организация, ХозяйственнаяОперация);
```
</details>

## ЗаполнитьРасшифровкуПлатежаПоСчетуНаОплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполнения табличной части "РасшифровкаПлатежа" по счету на оплату.
//
// Параметры:
//	СчетНаОплату - ДокументСсылка.СчетНаОплатуКлиенту - Документ - основание.
//	Организация - СправочникСсылка.Организации - Документ - основание.
//	ЗаказКлиента - ДокументСсылка.ЗаказКлиента - Заказ.
//	ВалютаДокумента - СправочникСсылка.Валюты - Валюта документа поступления денежных средств.
//	РасшифровкаПлатежа - ТабличнаяЧасть - Табличная часть документа.
//
Процедура ЗаполнитьРасшифровкуПлатежаПоСчетуНаОплату(СчетНаОплату, Организация, ЗаказКлиента, ВалютаДокумента, РасшифровкаПлатежа) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьРасшифровкуПлатежаПоСчетуНаОплату(СчетНаОплату, Организация, ЗаказКлиента, ВалютаДокумента, РасшифровкаПлатежа) 
```
</details>

## ЗаполнитьРасшифровкуПлатежаПоВозвратуТоваровОтКлиента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполнения табличной части "РасшифровкаПлатежа" по возврату товаров от клиента.
//
// Параметры:
//	Объекты - ДокументСсылка, Массив из ДокументСсылка - Документ основание.
//	Организация - СправочникСсылка.Организации - Организация документа.
//	ВалютаДокумента - СправочникСсылка.Валюты - Валюта документа поступления денежных средств.
//	СуммаДокумента - Число - Сумма документа - основания.
//	Партнер - СправочникСсылка.Партнеры - Партнер документа - основания.
//	РасшифровкаПлатежа - ТабличнаяЧасть - Табличная часть документа.
//
Процедура ЗаполнитьРасшифровкуПлатежаПоВозвратуТоваровОтКлиента(Объекты, Организация, ВалютаДокумента, СуммаДокумента, Партнер, РасшифровкаПлатежа) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьРасшифровкуПлатежаПоВозвратуТоваровОтКлиента(Объекты, Организация, ВалютаДокумента, СуммаДокумента, Партнер, РасшифровкаПлатежа) 
```
</details>

## ЗаполнитьРасшифровкуПлатежаПоЗаказуПоставщику
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполнения табличной части "РасшифровкаПлатежа" по заказу поставщику.
//
// Параметры:
//	ЗаказПоставщику - ДокументСсылка.ЗаказПоставщику - Документ - основание.
//	Договор - СправочникСсылка.ДоговорыКонтрагентов - Договор для заполнения.
//	ВалютаДокумента - СправочникСсылка.Валюты - Валюта документа поступления денежных средств.
//	СуммаКОплате - Число - Сумма к оплате поставщику.
//	РасшифровкаПлатежа - ТабличнаяЧасть - Табличная часть документа.
//	ЖелательнаяДатаПлатежа - Дата - Дата платежа по графику.
//  Организация - СправочникСсылка.Организации - Организация, осуществляющая закупку.
//
Процедура ЗаполнитьРасшифровкуПлатежаПоЗаказуПоставщику(ЗаказПоставщику, Договор, ВалютаДокумента, Знач СуммаКОплате, РасшифровкаПлатежа, ЖелательнаяДатаПлатежа = Неопределено, Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьРасшифровкуПлатежаПоЗаказуПоставщику(ЗаказПоставщику, Договор, ВалютаДокумента, СуммаКОплате, РасшифровкаПлатежа, ЖелательнаяДатаПлатежа, Организация);
```
</details>

## ЗаполнитьРасшифровкуПлатежаПоВозвратуПоставщику
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполнения табличной части "РасшифровкаПлатежа" по возврату поставщику.
//
// Параметры:
//	Объекты - ДокументСсылка, Массив из ДокументСсылка - Документ основание.
//	Организация - СправочникСсылка.Организации - Организация документа.
//	ВалютаДокумента - СправочникСсылка.Валюты - Валюта документа поступления денежных средств.
//	СуммаДокумента - Число - Сумма документа - основания.
//	Партнер - СправочникСсылка.Партнеры - Партнер документа - основания.
//	РасшифровкаПлатежа - ТабличнаяЧасть - Табличная часть документа.
//
Процедура ЗаполнитьРасшифровкуПлатежаПоВозвратуПоставщику(Объекты, Организация, ВалютаДокумента, СуммаДокумента, Партнер, РасшифровкаПлатежа) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьРасшифровкуПлатежаПоВозвратуПоставщику(Объекты, Организация, ВалютаДокумента, СуммаДокумента, Партнер, РасшифровкаПлатежа) 
```
</details>

## ЗаполнитьРасшифровкуПлатежаПоДоговоруСПоставщиком
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполнения табличной части "РасшифровкаПлатежа" по договору.
//
// Параметры:
//		Договор - СправочникСсылка.ДоговорыКонтрагентов - Договор для получения остатков.
//		ВалютаДокумента - СправочникСсылка.Валюты - Валюта документа.
//		РасшифровкаПлатежа - ТаблицаЗначений - Таблица для заполнения.
//		Организация - СправочникСсылка.Организации - Необязательное, организация для получения остатков расчетов.
//
Процедура ЗаполнитьРасшифровкуПлатежаПоДоговоруСПоставщиком(Договор, ВалютаДокумента, РасшифровкаПлатежа, Организация) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьРасшифровкуПлатежаПоДоговоруСПоставщиком(Договор, ВалютаДокумента, РасшифровкаПлатежа, Организация) 
```
</details>

## ЗаполнитьЗадолженностьПоОстаткам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура получает результат запроса по остаткам расчетов с партнером.
//
// Параметры:
//	Организация - СправочникСсылка.Организации - Организация документа.
//	Контрагент - СправочникСсылка.Контрагенты - Контрагент, выбранный в документе.
//	ТипЗадолженности - ПеречислениеСсылка.ТипыЗадолженности - Тип задолженности.
//	ТипРасчетов - ПеречислениеСсылка.ТипыРасчетовСПартнерами - Тип расчетов.
//	Дата - Дата - Дата документа.
//	Валюта - СправочникСсылка.Валюты - Валюта документа.
//	Задолженность - ТаблицаЗначений - Расшифровка платежа документа.
//
Процедура ЗаполнитьЗадолженностьПоОстаткам(Организация, Контрагент, ТипЗадолженности, ТипРасчетов, Дата, Валюта, Задолженность) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьЗадолженностьПоОстаткам(Организация, Контрагент, ТипЗадолженности, ТипРасчетов, Дата, Валюта, Задолженность) 
```
</details>

## ЗаполнитьЗадолженностьПоОстаткамВзаиморасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура получает результат запроса по остаткам расчетов с партнером по документам.
//
// Параметры:
//	Организация - СправочникСсылка.Организации - Организация документа.
//	Контрагент - СправочникСсылка.Контрагенты - Контрагент, выбранный в документе.
//	ТипЗадолженности - ПеречислениеСсылка.ТипыЗадолженности - Тип задолженности.
//	ТипРасчетов - ПеречислениеСсылка.ТипыРасчетовСПартнерами - Тип расчетов.
//	Дата - Дата - Дата документа.
//	Валюта - СправочникСсылка.Валюты - Валюта документа.
//	Задолженность - ДанныеФормыКоллекция - Табличная часть документа.
//
Процедура ЗаполнитьЗадолженностьПоОстаткамВзаиморасчетов(Организация, Контрагент, ТипЗадолженности, ТипРасчетов, Дата, Валюта, Задолженность) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьЗадолженностьПоОстаткамВзаиморасчетов(Организация, Контрагент, ТипЗадолженности, ТипРасчетов, Дата, Валюта, Задолженность) 
```
</details>

## ПересчитатьСуммыВВалютуРасшифровкаПлатежа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает суммы расшифровки платежа в выбранную валюту.
//
// Параметры:
//		Объект - ДокументОбъект - Документ для пересчета суммы.
//		СуммаВсего - Число - Сумма документа.
//
Процедура ПересчитатьСуммыВВалютуРасшифровкаПлатежа(Объект, СуммаВсего) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПересчитатьСуммыВВалютуРасшифровкаПлатежа(Объект, СуммаВсего) 
```
</details>

## ПолучитьОплатуВВалютеПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция определяет порядок оплаты в иностранной валюте.
//
// Параметры:
//  ВалютаОплаты - СправочникСсылка.Валюты - Необязательное, валюта предполагаемой оплаты.
//  Организация - СправочникСсылка.Организации - Необязательное, определяет валюту регламентированного учета.
//
// Возвращаемое значение:
//  Булево - оплата производится в иностранной валюте.
//
Функция ПолучитьОплатуВВалютеПоУмолчанию(Знач ВалютаОплаты = Неопределено, Знач Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ПолучитьОплатуВВалютеПоУмолчанию(ВалютаОплаты, Организация);
```
</details>

## ЗаполнитьСуммуВзаиморасчетовВТабличнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет сумму взаиморасчетов в табличной части "Расшифровка платежка"
// в документах движения денежных средств.
//
// Параметры:
//	Валюта - СправочникСсылка.Валюты - Валюта, указанная в документе.
//	Дата - Дата - Дата документа.
//	ТабличнаяЧасть - ТабличнаяЧасть - Табличная часть документа.
//	Организация - СправочникСсылка.Организации - Организация документа. Определяет базовую валюту получения курсов.
Процедура ЗаполнитьСуммуВзаиморасчетовВТабличнойЧасти(Валюта, Дата, ТабличнаяЧасть, Организация) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьСуммуВзаиморасчетовВТабличнойЧасти(Валюта, Дата, ТабличнаяЧасть, Организация) 
```
</details>

## ЗаполнитьСуммуВзаиморасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
// Процедура заполняет сумму взаиморасчетов в шапке документа.
//
// Параметры:
//	ДокументОбъект - ДокументОбъект - Текущий документ
//	ИмяТЧ - Строка - Необязательный, имя табличной части для расчета суммы документа
//	СтруктураКурса - Структура - Необязательный, параметры курса документа:
//       * КурсЧислитель - Число - Курс числитель валюты.
//       * КурсЗнаменатель - Число - Курс знаменатель валюты.
//	Дата - Дата - Дата, на которую будет получен курс, если не задана структура курса.
//
Процедура ЗаполнитьСуммуВзаиморасчетов(ДокументОбъект, ИмяТЧ = "", СтруктураКурса = Неопределено, Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьСуммуВзаиморасчетов(ДокументОбъект, ИмяТЧ, СтруктураКурса, Дата);
```
</details>

## ЗаполнитьСуммуВзаиморасчетовВПоступлении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
// Процедура заполняет сумму взаиморасчетов в шапке документа.
//
// Параметры:
// ДокументОбъект - ДокументОбъект - Текущий документ
// ИмяТЧ - Строка - Необязательный, имя табличной части, где рассчитывается сумма взаиморасчетов
// СтруктураКурса - Структура - Необязательный, параметры курса документа:
//       * КурсЧислитель   - Число - Курс числитель валюты
//       * КурсЗнаменатель - Число - Курс знаменатель валюты
//
Процедура ЗаполнитьСуммуВзаиморасчетовВПоступлении(ДокументОбъект, ИмяТЧ = "Товары", СтруктураКурса = Неопределено) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьСуммуВзаиморасчетовВПоступлении(ДокументОбъект, ИмяТЧ, СтруктураКурса);
```
</details>

## ЗаполнитьСуммуНДСВзаиморасчетовВТабличнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
// Процедура заполняет сумму НДС взаиморасчетов в табличной части документа.
//
// Параметры:
//	Документ - ДокументОбъект - Текущий документ.
//	ИмяТабличнойЧасти - Строка - Имя табличной части документа для заполнения.
//
Процедура ЗаполнитьСуммуНДСВзаиморасчетовВТабличнойЧасти(Документ, ИмяТабличнойЧасти) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьСуммуНДСВзаиморасчетовВТабличнойЧасти(Документ, ИмяТабличнойЧасти) 
```
</details>

## ЗаполнитьСуммуРасшифровкиПлатежаПоСуммеДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет сумму расшифровки платежа в соответствии с суммой документа.
//
// Параметры:
//		СуммаДокумента - Число - Сумма документа для заполнения.
//		РасшифровкаПлатежа - ТаблицаЗначений - Таблица для заполнения.
//		ВалютаВзаиморасчетов - СправочникСсылка.Валюты - Валюта по умолчанию.
//
Процедура ЗаполнитьСуммуРасшифровкиПлатежаПоСуммеДокумента(Знач СуммаДокумента, РасшифровкаПлатежа, ВалютаВзаиморасчетов = Неопределено) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьСуммуРасшифровкиПлатежаПоСуммеДокумента(СуммаДокумента, РасшифровкаПлатежа, ВалютаВзаиморасчетов);
```
</details>

## ЗаполнитьСуммыРасшифровкиНакладной
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет или очищает табличную часть расшифровка платежа накладной при расчетах по накладным.
//
// Параметры:
//	СуммаДокумента		- Число - Сумма текущего документа.
//	СуммаВзаиморасчетов - Число - Сумма взаиморасчетов документа.
//	РасшифровкаПлатежа	- ТаблицаЗначений - Расшифровка платежа накладной для заполнения:
//		* СуммаВзаиморасчетов	- Число - Сумма взаиморасчетов по строке.
//		* Сумма					- Число - Сумма в валюте документа.
//		* ОбъектРасчетов		- СправочникСсылка.ОбъектыРасчетов - Ссылки на объекты расчетов зачтенных платежи/самого документа.
//	ОбъектРасчетов		- СправочникСсылка.ОбъектыРасчетов - Ссылка на объект расчетов документа владельца расшифровки.
//
Процедура ЗаполнитьСуммыРасшифровкиНакладной(Знач СуммаДокумента, ЗНАЧ СуммаВзаиморасчетов, РасшифровкаПлатежа, ОбъектРасчетов) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьСуммыРасшифровкиНакладной(СуммаДокумента, ЗНАЧ СуммаВзаиморасчетов, РасшифровкаПлатежа, ОбъектРасчетов) 
```
</details>

## РассчитатьДатыПлатежаКлиента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
// В менеджер временных таблиц помещает таблицу "ТаблицаОстатковКлиентов",
// содержащую в себе даты платежа. Строится по регистру "Расчеты с клиентами по документам".
//
// Параметры:
//		МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - Текущий менеджер временных таблиц для помещения таблиц.
//		ДатаОстатков - Дата - Дата остатков.
//
Процедура РассчитатьДатыПлатежаКлиента(МенеджерВременныхТаблиц, ДатаОстатков) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.РассчитатьДатыПлатежаКлиента(МенеджерВременныхТаблиц, ДатаОстатков) 
```
</details>

## РассчитатьДатыПлатежаПоставщика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В менеджер временных таблиц помещает таблицу "ТаблицаОстатковПоставщиков",
// содержащую в себе даты платежа. Строится по регистру "Расчеты с поставщиками по документам".
//
// Параметры:
//		МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - Текущий менеджер временных таблиц для помещения таблиц.
//		ДатаОстатков - Дата - Дата остатков.
//
Процедура РассчитатьДатыПлатежаПоставщика(МенеджерВременныхТаблиц, ДатаОстатков) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.РассчитатьДатыПлатежаПоставщика(МенеджерВременныхТаблиц, ДатаОстатков) 
```
</details>

## РассчитатьОперативныеДатыПлатежаКлиента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В менеджер временных таблиц помещает таблицу содержащую в себе даты платежа.
// Строится по регистру "Расчеты с клиентами".
// Параметры:
//	ВременныеТаблицы - МенеджерВременныхТаблиц - Менеджер временных таблиц, в который будет помещен результат расчета.
//	ДатаОстатков - Дата - Период на который выполняется расчет дат платежа.
Процедура РассчитатьОперативныеДатыПлатежаКлиента(ВременныеТаблицы, ДатаОстатков) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.РассчитатьОперативныеДатыПлатежаКлиента(ВременныеТаблицы, ДатаОстатков) 
```
</details>

## РассчитатьОперативныеДатыПлатежаПоставщика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В менеджер временных таблиц помещает таблицу содержащую в себе даты платежа.
// Строится по регистру "Расчеты с поставщиками".
// Параметры:
//	ВременныеТаблицы - МенеджерВременныхТаблиц - Менеджер временных таблиц, в который будет помещен результат расчета.
//	ДатаОстатков - Дата - Период на который выполняется расчет дат платежа.
Процедура РассчитатьОперативныеДатыПлатежаПоставщика(ВременныеТаблицы, ДатаОстатков) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.РассчитатьОперативныеДатыПлатежаПоставщика(ВременныеТаблицы, ДатаОстатков) 
```
</details>

## ПорядокРасчетовПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
// Возвращает порядок расчетов по соглашению/договору, указанным в объекте.
//
// Параметры:
//	Объект - ДокументОбъект, Структура - Документ, по которому надо получить порядок расчетов.
//
// Возвращаемое значение:
//	ПеречислениеСсылка.ПорядокРасчетов - Порядок расчетов по умолчанию.
//
Функция ПорядокРасчетовПоУмолчанию(Объект) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ПорядокРасчетовПоУмолчанию(Объект) 
```
</details>

## ДоступныеПорядкиРасчетовПоДокументу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет какие порядки расчетов можно использовать в выбранном документе.
//
// Параметры:
//	ЗначениеВДокументе - ПеречислениеСсылка.ПорядокРасчетов - Порядок расчетов, выбранный в документе.
//	ЗначениеПоУмолчанию - ПеречислениеСсылка.ПорядокРасчетов - Порядок расчетов, определяемый по соглашению/договору документа.
//	ПоЗаказу - Булево - Документ введен по заказу.
//	ЭтоЗаказ - Булево - Это заказ.
//	ЗаказКакСчет - Булево - это заказ и включена ФО заказ как счет.
//
// Возвращаемое значение:
//	СписокЗначений - Список доступных порядков расчета.
//
Функция ДоступныеПорядкиРасчетовПоДокументу(ЗначениеВДокументе, ЗначениеПоУмолчанию, ПоЗаказу = Ложь, ЭтоЗаказ = Ложь, ЗаказКакСчет = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ДоступныеПорядкиРасчетовПоДокументу(ЗначениеВДокументе, ЗначениеПоУмолчанию, ПоЗаказу, ЭтоЗаказ, ЗаказКакСчет);
```
</details>

## ПорядокРасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает порядок расчетов по переданным параметрам.
//
// Параметры:
//    ЭтоЗаказ - Булево - Истина, если это заказ.
//    ЗаказОснование - ДокументСсылка - Необязательный, заказ, по которому введен документ.
//    Соглашение - СправочникСсылка.СоглашенияСКлиентами, СправочникСсылка.СоглашенияСПоставщиками - Необязательный, соглашение документа.
//    Договор - СправочникСсылка.ДоговорыКонтрагентов - Необязательный, договор документа.
//
// Возвращаемое значение:
//    ПеречислениеСсылка.ПорядокРасчетов - Порядок расчетов.
//
Функция ПорядокРасчетов(ЭтоЗаказ, ЗаказОснование = Неопределено, Соглашение = Неопределено, Договор = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ПорядокРасчетов(ЭтоЗаказ, ЗаказОснование, Соглашение, Договор);
```
</details>

## ВидДоговораКонтрагента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция определяет вид договора контрагента для обмена
//	с конфигурацией "Бухгалтерия предприятия".
//
// Параметры:
//		ДокументРасчетов - ДокументСсылка - Документ расчетов, по которому нужно определить вид договора.
//		Соглашение - СправочникСсылка.СоглашенияСПоставщиками,СправочникСсылка.СоглашенияСКлиентами - Соглашение документа.
//		ХозяйственнаяОперация - ПеречислениеСсылка.ХозяйственныеОперации - Хозяйственная операция документа.
//
// Возвращаемое значение:
// 		Строка - Вид договора, например, "СПокупателем".
Функция ВидДоговораКонтрагента(ДокументРасчетов, Соглашение, ХозяйственнаяОперация) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ВидДоговораКонтрагента(ДокументРасчетов, Соглашение, ХозяйственнаяОперация) 
```
</details>

## ЗаменитьДокументыРасчетовСКлиентами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заменяет документы расчетов при вызове отчетов по взаиморасчетов из реализации.
// Если реализация по заказу клиента - документом расчетов является заказ клиента.
//
// Параметры:
// Параметры - ДанныеФормыСтруктура - Параметры отчета.
//
Процедура ЗаменитьДокументыРасчетовСКлиентами(Параметры) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаменитьДокументыРасчетовСКлиентами(Параметры) 
```
</details>

## ЗаменитьДокументыРасчетовСПоставщиками
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заменяет документы расчетов при вызове отчетов по взаиморасчетов из поступления.
// Если поступление по заказу поставщику - документом расчетов является заказ поставщику.
//
// Параметры:
// Параметры - ДанныеФормыСтруктура - Параметры отчета.
//
Процедура ЗаменитьДокументыРасчетовСПоставщиками(Параметры) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаменитьДокументыРасчетовСПоставщиками(Параметры) 
```
</details>

## ПроверкаИСообщениеВариантовКлассификацииЗадолженности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает результат проверки количества вариантов классификации при отключенной опции "ИспользоватьНесколькоКлассификацийЗадолженности".
//
// Параметры:
// Количество - Число - количество элементов в справочнике "ВариантыКлассификацииЗадолженности".
// Форма - ФормаКлиентскогоПриложения - форма, источник проверки.
//
// Возвращаемое значение:
// Булево - Ложь, если проверка пройдена, Истина, если проверка не пройдена, выдать сообщение об ошибке.
//
Функция ПроверкаИСообщениеВариантовКлассификацииЗадолженности(Количество, Форма) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ПроверкаИСообщениеВариантовКлассификацииЗадолженности(Количество, Форма) 
```
</details>

## СтруктураОтборовОтчетовРасчетыСКлиентами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует структуру отборов по партнеру и организации для контекстно вызываемых отчетов
//   по расчетам с клиентом.
//
// Параметры:
//  МассивДокументов  - Массив - массив документов, которыми параметризуется отчет.
//  ИмяОтчета         - Строка - имя вызываемого отчета.
//  ИмяКоманды        - Строка - имя команды, при помощи которой вызывается отчет.вызываемого отчета.
//  Типы              - Массив - Массив типов параметра команды вызывающей отчет.
//
// Возвращаемое значение:
//   Структура   - сформированная структура отбора, где:
//      * Партнер - Массив из СправочникСсылка.Партнеры.
//      * Организация - Массив из СправочникСсылка.Организации.
//
Функция СтруктураОтборовОтчетовРасчетыСКлиентами(МассивДокументов, ИмяОтчета, ИмяКоманды, Типы = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.СтруктураОтборовОтчетовРасчетыСКлиентами(МассивДокументов, ИмяОтчета, ИмяКоманды, Типы);
```
</details>

## СписатьСумму
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяется возможная сумма списания с текущего остатка - весь остаток или только часть остатка равная сумме списания.
// При этом уменьшается текущий остаток на сумму списания и сама сумма списания.
//
// Параметры:
//  СуммаОстатка - Число - Текущий остаток с которого необходимо списать сумму.
//  СуммаКСписанию - Число - Сумма которую необходимо списать.
//  ПоследняяЧасть - Булево - если истина, то списать весь остаток.
//
// Возвращаемое значение:
//  Число - сумма которую необходимо списать или весь остаток целиком в случае если он меньше заданной суммы или
//          ПоследняяЧасть = Истина.
//
Функция СписатьСумму(СуммаОстатка, СуммаКСписанию, ПоследняяЧасть = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.СписатьСумму(СуммаОстатка, СуммаКСписанию, ПоследняяЧасть);
```
</details>

## СписатьСуммуПропорционально
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяется возможная сумма списания с текущего остатка одного показателя,
// пропорционально уже списанной по другому показателю.
// При этом уменьшается текущий остаток.
//
// Параметры:
//	СуммаОстатка - Число - Текущий остаток с которого необходимо списать сумму.
//	СуммаСписано - Число - Сумма которая уже списана с другого показателя.
//	СуммаВсего - Число - Сумма по другому показателю до списания.
//
// Возвращаемое значение:
//	Число - сумма которую необходимо списать.
//
Функция СписатьСуммуПропорционально(СуммаОстатка, СуммаСписано, СуммаВсего) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.СписатьСуммуПропорционально(СуммаОстатка, СуммаСписано, СуммаВсего) 
```
</details>

## ПараметрыЗаполненияРасшифровкиПлатежаПоЗаказу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция - конструктор процедуры ВзаиморасчетыСервер.ЗаполнитьРасшифровкуПлатежаПоЗаказуКлиента.
//
// Возвращаемое значение:
//	Структура - Структура параметров:
//		* Партнер          - СправочникСсылка.Партнеры - Партнер документа-инициатора.
//		* Договор          - СправочникСсылка.ДоговорыКонтрагентов - Договор объекта расчетов.
//		* ЗаказКлиента     - ДокументСсылка.ЗаказКлиента - Объект расчетов.
//		* ВалютаДокумента  - СправочникСсылка.Валюты - Валюта документа поступления денежных средств.
//		* ОснованиеПлатежа - ДокументСсылка - Документ-основание.
//
Функция ПараметрыЗаполненияРасшифровкиПлатежаПоЗаказу() Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ПараметрыЗаполненияРасшифровкиПлатежаПоЗаказу() 
```
</details>

## ПолучитьМаксимальнуюДатуВКоллекцииДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает максимальную дату из временной таблицы, которая содержит перечень документов.
//
// Параметры:
//	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - Содержит временную таблицу ТаблицаДанныхДокументов,
//														с перечнем документов одного типа.
// Возвращаемое значение:
// 	Дата - Максимальная дата в коллекци документов.
Функция ПолучитьМаксимальнуюДатуВКоллекцииДокументов(МенеджерВременныхТаблиц) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ПолучитьМаксимальнуюДатуВКоллекцииДокументов(МенеджерВременныхТаблиц) 
```
</details>

## ОтразитьЗаданияКРаспределениюРасчетовСКлиентами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура формирует записи в регистре сведений "Задания к распределению расчетов с клиентами",
// если текущий документ изменяет записи в регистре "Расчеты с клиентами".
// Параметры:
//	Документ - ДокументСсылка - Ссылка на документ-регистратор
//	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - Содержит временную таблицу изменений.
Процедура ОтразитьЗаданияКРаспределениюРасчетовСКлиентами(Документ, МенеджерВременныхТаблиц) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ОтразитьЗаданияКРаспределениюРасчетовСКлиентами(Документ, МенеджерВременныхТаблиц) 
```
</details>

## ОтразитьЗаданияКРаспределениюРасчетовСПоставщиками
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура формирует записи в регистре сведений "Задания к распределению расчетов с поставщиками",
// если текущий документ изменяет записи в регистре "Расчеты с поставщиками".
//
// Параметры:
//  Документ - ДокументСсылка - Ссылка на документ-регистратор
//  МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - Содержит временную таблицу изменений.
//
Процедура ОтразитьЗаданияКРаспределениюРасчетовСПоставщиками(Документ, МенеджерВременныхТаблиц) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ОтразитьЗаданияКРаспределениюРасчетовСПоставщиками(Документ, МенеджерВременныхТаблиц) 
```
</details>

## ХозяйственнаяОперацияИнтеркампани
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
// Функция определяет, является ли переданная хозяйственная операция операцией интеркампани.
//
// Параметры:
//	ХозяйственнаяОперация - ПеречислениеСсылка.ХозяйственныеОперации - Хозяйственная операция для проверки.
//
// Возвращаемое значение:
//	Булево - Истина, если является операцией интеркампани.
//
Функция ХозяйственнаяОперацияИнтеркампани(ХозяйственнаяОперация) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ХозяйственнаяОперацияИнтеркампани(ХозяйственнаяОперация) 
```
</details>

## ХозяйственнаяОперацияСКлиентом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
// Функция определяет, является ли переданная хозяйственная операция операцией с клиентом.
//
// Параметры:
//	ХозяйственнаяОперация - ПеречислениеСсылка.ХозяйственныеОперации - Хозяйственная операция для проверки.
//
// Возвращаемое значение:
//	Булево - Истина, если является операцией с клиентом.
//
Функция ХозяйственнаяОперацияСКлиентом(ХозяйственнаяОперация) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ХозяйственнаяОперацияСКлиентом(ХозяйственнаяОперация) 
```
</details>

## ХозяйственнаяОперацияСПоставщиком
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
// Функция определяет, является ли переданная хозяйственная операция операцией с поставщиком.
//
// Параметры:
//	ХозяйственнаяОперация - ПеречислениеСсылка.ХозяйственныеОперации - Хозяйственная операция для проверки.
//
// Возвращаемое значение:
//	Булево - Истина, если является операцией с поставщиком.
//
Функция ХозяйственнаяОперацияСПоставщиком(ХозяйственнаяОперация) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ХозяйственнаяОперацияСПоставщиком(ХозяйственнаяОперация) 
```
</details>

## ХозяйственнаяОперацияВозвратДенежныхСредств
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
// Функция определяет, является ли переданная хозяйственная операция операцией возврата денежных средств.
//
// Параметры:
//	ХозяйственнаяОперация - ПеречислениеСсылка.ХозяйственныеОперации - Хозяйственная операция для проверки.
//
// Возвращаемое значение:
//	Булево - Истина, если является операцией возврата денежных средств.
//
Функция ХозяйственнаяОперацияВозвратДенежныхСредств(ХозяйственнаяОперация) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ХозяйственнаяОперацияВозвратДенежныхСредств(ХозяйственнаяОперация) 
```
</details>

## ПолучитьКонтрагентовПоСделкам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получение списка контрагентов по сделкам для отправки приглашений.
//
// Параметры:
//  Организация			 - СправочникСсылка - ссылка на организацию, от которой производится приглашение.
//  РежимЗаполнения		 - Строка - режим заполнения контрагентов: "ЗаполнитьПоПоставкам", "ЗаполнитьПоЗакупкам", "ЗаполнитьПоВсемСделкам".
//  НачалоПериода		 - Дата - начало периода заполнения.
//  СписокКонтрагентов	 - ТаблицаЗначений - список контрагентов:
//    * Ссылка - СправочникСсылка - контрагент.
//    * ЭлектроннаяПочта - Строка - адрес электронной почты.
//
Процедура ПолучитьКонтрагентовПоСделкам(Организация, РежимЗаполнения, НачалоПериода, СписокКонтрагентов) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПолучитьКонтрагентовПоСделкам(Организация, РежимЗаполнения, НачалоПериода, СписокКонтрагентов) 
```
</details>

## ЗаполнитьШтрихкодыДляВыгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// ЭлектронноеВзаимодействие.ТорговыеПредложения
// Заполнение штрихкодов для выгрузки.
//
// Параметры:
//  Организации	 - Массив - Список организация, для которых производится выгрузка.
//  РежимПоставщика - Булево - Выгружать только данные по продажам.
//  РежимПокупателя - Булево - Выгружать только данные по покупкам.
//  Штрихкоды	 - ТаблицаЗначений - данные по штрихкодам,
//                 см. ТорговыеПредложения.ОбновитьПодсказкиТорговыеПредложения:
//    * Штрихкод - Строка - штрихкод товара.
//    * Наименование - Строка - Наименование товара
//    * РежимПоставщика - Булево - признак использования штрихкода в продажах.
//    * РежимПокупателя - Булево - признак использования штрихкода в закупках.
//
Процедура ЗаполнитьШтрихкодыДляВыгрузки(Знач Организации, Знач РежимПоставщика, Знач РежимПокупателя, Штрихкоды) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьШтрихкодыДляВыгрузки(Организации, РежимПоставщика, РежимПокупателя, Штрихкоды) 
```
</details>

## ВзаиморасчетыВВалюте
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
// Конец ЭлектронноеВзаимодействие.ТорговыеПредложения

// Функция определяет ведутся взаиморасчеты в иностранной валюте или в национальной
//
// Параметры:
//		ВалютаВзаиморасчетов - СправочникСсылка.Валюты - Валюта взаиморасчетов объекта.
//		ВалютаРегламентированногоУчета - СправочникСсылка.Валюты - Валюта регламентированного учета.
//
// Возвращаемое значение:
//		Булево - Истина, если расчеты в иностранной валюте.
//
Функция ВзаиморасчетыВВалюте(ВалютаВзаиморасчетов, ВалютаРегламентированногоУчета) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ВзаиморасчетыВВалюте(ВалютаВзаиморасчетов, ВалютаРегламентированногоУчета) 
```
</details>

## ОбъектРасчетовПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает ссылку на объект расчетов переданной ссылки.
//
// Параметры:
//		ОбъектСсылка - ОпределяемыйТип.ОбъектРасчетов - Документ по которому нужно определить объект расчетов.
//
// Возвращаемое значение:
// 		ОпределяемыйТип.ОбъектРасчетов - Объект расчетов документа..
//
Функция ОбъектРасчетовПоСсылке(ОбъектСсылка) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ОбъектРасчетовПоСсылке(ОбъектСсылка) 
```
</details>

## ДополнитьСоответствияРегистраторовОтчетаОДвижениях
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// см. ОтчетыУТПереопределяемый.ДополнитьСоответствияРегистраторовОтчетаОДвижениях
//
Процедура ДополнитьСоответствияРегистраторовОтчетаОДвижениях(Документ, СоответствиеРегистров) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ДополнитьСоответствияРегистраторовОтчетаОДвижениях(Документ, СоответствиеРегистров) 
```
</details>

## ОтложенноеОбновлениеРегистровВзаиморасчетовЗавершено
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отложенное обновление регистров взаиморасчетов завершено.
//
// Параметры:
//  ТолькоФинансовые - Булево - Только финансовые
//
// Возвращаемое значение:
//  Булево - Отложенное обновление регистров взаиморасчетов завершено
Функция ОтложенноеОбновлениеРегистровВзаиморасчетовЗавершено(ТолькоФинансовые = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ОтложенноеОбновлениеРегистровВзаиморасчетовЗавершено(ТолькоФинансовые);
```
</details>

## ОбновитьСтатусСверкиВзаиморасчетовПриЗаписиСостоянияПоОбъектамУчетаЭДОПриЗаписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ Локализация

// Обработка обновления статуса Сверки взаиморасчетов (2.5.11) при записи регистра сведения Состояния по объектам учета ЭДО.
// Выполняется по подписке на событие ПриЗаписи.
// См. Подписку на событие ПриЗаписиСостоянияПоОбъектамУчетаЭДО.
//
// Параметры:
//  Источник - РегистрСведенийНаборЗаписей.СостоянияПоОбъектамУчетаЭДО - Набор записей регистра сведений
//  Отказ - Булево - Признак отказа от записи
//  Замещение - Булево - Замещение
Процедура ОбновитьСтатусСверкиВзаиморасчетовПриЗаписиСостоянияПоОбъектамУчетаЭДОПриЗаписи(Источник, Отказ, Замещение) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ОбновитьСтатусСверкиВзаиморасчетовПриЗаписиСостоянияПоОбъектамУчетаЭДОПриЗаписи(Источник, Отказ, Замещение) 
```
</details>

## ТекстЗапросаТаблицыДанныхОплатыПартий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
//-- Локализация

// Возвращает текст запроса формирования временной таблицы оплаты партий.
//
// Параметры:
//  ИмяТаблицыВходныхДанные - Строка - Имя таблицы входных данных. Таблица должна содержать колонку Партия.
//  ИмяТаблицыОплат - Строка - Имя результирующей таблицы оплат
//
// Возвращаемое значение:
// 	Строка - Текст запроса, формирующий временную таблицу оплат партий. Таблица содержит колонки: Партия, ДокументОплаты, ДатаОплаты, СуммаОплаты.
//
Функция ТекстЗапросаТаблицыДанныхОплатыПартий(ИмяТаблицыВходныхДанные, ИмяТаблицыОплат) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ТекстЗапросаТаблицыДанныхОплатыПартий(ИмяТаблицыВходныхДанные, ИмяТаблицыОплат) 
```
</details>

## ДополнитьТекстЗапросаЗаданийКЗакрытиюМесяца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет текст запроса механизма формирования заданий закрытия месяца.
//
// Параметры:
// 	Запрос - Запрос - используется для установки параметров запроса.
// 	ТекстЗапроса - Строка - строка с текстом запроса.
// 	ТекстЗапросаВременныхТаблиц - Строка - строка с текстом запроса временных таблиц.
// 	ИменаВременныхТаблиц - Строка - массив имен создаваемых временных таблиц для последующего уничтожения.
Процедура ДополнитьТекстЗапросаЗаданийКЗакрытиюМесяца(Запрос, ТекстЗапроса, ТекстЗапросаВременныхТаблиц, ИменаВременныхТаблиц) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ДополнитьТекстЗапросаЗаданийКЗакрытиюМесяца(Запрос, ТекстЗапроса, ТекстЗапросаВременныхТаблиц, ИменаВременныхТаблиц) 
```
</details>

## ПараметрыМеханизма
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров механизма взаиморасчетов.
// Параметры описываются либо путем к данным объекта, либо фиксированным значением типа Булево, Строка и пр.
// Путь к данным может вести как в шапку документа ("Объект.Организация"), так и в табличную часть ("Объект.РасшифровкаПлатежа.Партнер").
// В одном документе может быть задано несколько структур параметров (пример - ОтчетКомиссионера).
// Для встраивания в документы рекомендуется использовать шаблон в конце метода.
//
// Возвращаемое значение:
// 	Структура - Структура параметров с ключами:
// 		* ЭлементыФормы - Структура - Имена элементов формы, используются для связи элемента с текущими параметрами:
// 			** ЗачетОплаты - Строка - Имя элемента, вызывающего помощник зачета оплат.
// 			** СуммаВзаиморасчетовТЧ - Строка - Имя элемента, отображающего колонку Сумма взаиморасчетов в основной табличной части.
// 			** ГиперссылкаРасшифровкаПлатежа - Строка - Имя элемента, отображающего сумму расшифровки платежа и открывающего ее редактирование.
// 			** РасшифровкаПлатежа - Строка - Имя элемента, отображающего табличную часть Расшифровка платежа на форме.
// 			** ПодборВРасшифровкуПлатежа - Строка - Имя кнопки, вызывающего подбор в расшифровку платежа.
// 			** НадписьВалюты - Строка - Имя гиперссылки, отображающей валюты и курс документа и вызывающего форму их редактирования.
// 			** НадписьЭтапы - Строка - Имя гиперссылки, отображающей график оплаты и открывающий форму редактирования правил оплаты.
// 			** НадписьРасчеты - Строка - Имя гиперссылки, отображающей состояние расчетов и открывающей отчет по взаиморасчетам.
// 			** ОграничениеЗадолженностиТекст - Строка - Имя гиперссылки, отображающей текст ограничения задолженности и открывающей соответствующий отчет.
// 			** ОграничениеЗадолженностиКартинка - Строка - Имя картинки, отображающей восклицательный знак при ограничении задолженности.
// 		* ЭтоЗаказ - Булево - Это документ - заказ, на основании которого будут вводиться накладные.
// 		* ЭтоСправочник - Булево - Это справочник (договоры или претензии).
// 		* ЭтоПродажаЗакупка - Булево - Это документ - накладная.
// 		* ТипРасчетов - ПеречислениеСсылка.ТипыРасчетовСПартнерами - Тип взаиморасчетов.
// 		* ИзменяетПланОплаты - Булево - Уменьшает или увеличивает планы к оплате от клиента или поставщику.
// 		* ИзменяетПланОтгрузкиПоставки - Булево - Уменьшает или увеличивает план отгрузки или поставки.
//
// 		* Дата - Строка - Путь к реквизиту объекта, содержащему дату документа.
// 		* ВалютаДокумента - Строка - Путь к реквизиту объекта, содержащему валюту документа.
// 		* СуммаДокумента - Строка - Путь к реквизиту объекта, содержащему сумму документа в валюте документа.
// 		* Организация - Строка- Путь к реквизиту объекта, содержащему организацию, от лица которой производится хозяйственная операция.
// 		* Партнер - Строка - Путь к реквизиту объекта, содержащему партнера, с которым возникают взаиморасчеты у организации.
// 		* Контрагент - Строка - Путь к реквизиту объекта, содержащему контрагента или организацию, с которой возникают взаиморасчеты у организации.
//
// 		* ВалютаВзаиморасчетов - Строка - Путь к реквизиту объекта, содержащему валюту, по который ведутся взаиморасчеты организации с контрагентом.
// 		* СуммаВзаиморасчетов - Строка - Путь к реквизиту объекта, содержащему общую сумму взаиморасчетов документа, без учета залога за тару.
// 		* СуммаНДСВзаиморасчетов - Строка - Путь к реквизиту объекта, содержащему сумму НДС в валюте взаиморасчетов.
// 		* СуммаВзаиморасчетовПоТаре - Строка - Путь к реквизиту объекта, содержащему общую сумму залога за тару.
//
// 		* Договор - Строка - Путь к реквизиту объекта, содержащему договор организации с контрагентом, в рамках которого возникают взаиморасчеты.
// 		* НаправлениеДеятельности - Строка - Путь к реквизиту объекта, содержащему направление деятельности организации, в рамках которой следует отражать взаиморасчеты.
// 		* ПорядокРасчетов - Строка - Путь к реквизиту объекта, содержащему порядок расчетов документа.
// 		* СуммаДокументаФорма - Строка - Путь к реквизиту формы, содержащему сумму документа с учетом залоговой тары.
//
// 		* ПутьКДаннымТЧ - Строка - Путь к реквизиту объекта, содержащему основную табличную часть документа.
// 		* ИмяРеквизитаТЧСуммаСНДС - Строка - Имя реквизита табличной части, содержащего сумму строки с ндс в валюте документа.
// 		* ИмяРеквизитаТЧСуммаСНДС - Строка - Имя реквизита табличной части, содержащего заказ, по которому производится отгрузка/поставка.
//
// 		* ПутьКДаннымТЧРасшифровкаПлатежа - Строка - Путь к реквизиту объекта, содержащему табличную часть "Расшифровка платежа" документа.
// 		* Соглашение - Строка - Путь к реквизиту объекта, содержащему соглашение с клиентом или поставщиком.
// 		* БанковскийСчетОрганизации - Строка - Путь к реквизиту объекта, содержащему банковский счет организации.
// 		* БанковскийСчетКонтрагента - Строка - Путь к реквизиту объекта, содержащему банковский счет контрагента.
// 		* Касса - Строка - Путь к реквизиту объекта, содержащему кассу.
// 		* ФормаОплаты - Строка - Путь к реквизиту объекта, содержащему форму оплаты.
// 		* ОплатаВВалюте - Строка - Путь к реквизиту объекта, содержащему признак "Оплата в валюте".
// 		* ИдентификаторПлатежа - Строка - Путь к реквизиту объекта, содержащему идентификатор платежа.
// 		* ГруппаФинансовогоУчета - Строка - Путь к реквизиту объекта, содержащему группу финансового учета расчетов.
// 		* ОбъектРасчетов - Строка - Пусть к реквизиту объекта или колонке ТЧ, хранящей ссылку /ссылки на справочник Объекты расчетов.
// 		* Ссылка - Строка - Пусть к реквизиту Ссылка, которая будет являться объектом расчетов при расчетах по накладным.
// 		* Подразделение - Строка - Путь к реквизиту объекта, содержащему подразделение.
// 		* Менеджер - Строка - Путь к реквизиту объекта, содержащему ответственного менеджера.
// 		* НомерВходящегоДокумента - Строка - Путь к реквизиту объекта, содержащему номер входящего документа.
// 		* ДатаВходящегоДокумента - Строка - Путь к реквизиту объекта, содержащему дату входящего документа.
// 		* НаименованиеПервичногоДокумента - Строка - Путь к реквизиту объекта, содержащему наименование первичного документа.
//
// 		* НакладнаяПоЗаказам - Строка - Путь к реквизиту объекта, содержащему признак того, что документ введен по заказу.
// 		* ЗаказОснование - Строка - Путь к реквизиту объекта, содержащему заказ, по которому введен документ.
// 		* ПартнерПрочиеОтношения - Булево - Истина, если подбирать следует только по партнерам с признаком "Прочие отношения".
// 		* ПодборДебиторскойЗадолженности - Булево - Истина, если подбирается дебиторская задолженность.
// 		* ПодборТолькоБезусловнойЗадолженности - Булево - Истина, если подбирается только фактическая задолженность.
//
// 		* КурсЧислитель - Строка - Путь к реквизиту объекта, содержащему курс-числитель валюты документа относительно валюты взаиморасчетов.
// 		* КурсЗнаменатель - Строка - Путь к реквизиту объекта, содержащему курс-знаменатель валюты документа относительно валюты взаиморасчетов.
// 		* ВалютыИКурсДокументаТолькоПросмотр - Булево - Истина, если в форме редактирования валют и курсов документа ничего нельзя менять.
// 		* ВалютаДокументаТолькоПросмотр - Булево - Истина, если в форме редактирования валют и курсов документа нельзя менять валюту документа.
// 		* ВалютаВзаиморасчетовТолькоПросмотр - Булево - Истина, если в форме редактирования валют и курсов документа  нельзя менять валюту взаиморасчетов.
// 		* НеПоказыватьРасчеты - Булево - Истина, если в форме редактирования валют и курсов документа нужно скрыть валюту и сумму взаиморасчетов.
// 		* НеПересчитыватьСуммуДокумента - Булево - Истина, если в форме редактирования валют и курсов документа не нужно предлагать пересчитывать сумму документа.
//
// 		* ПутьКДаннымТЧЭтапыОплаты - Строка - Путь к реквизиту объекта, содержащему табличную часть этапов графика оплаты.
// 		* ДатаПлатежа - Строка - Путь к реквизиту объекта, содержащему дату планового платежа по документу.
// 		* ГрафикОплаты - Строка - Путь к реквизиту объекта, содержащему шаблон графика оплаты документа.
// 		* ДатаСогласования - Строка - Путь к реквизиту объекта, содержащему дату, от которой следует считать этапы графика оплаты с отсчетом от даты согласования.
// 		* ДатаОтгрузки - Строка - Путь к реквизиту объекта, содержащему дату, от которой следует считать этапы графика оплаты с отсчетом от/до даты отгрузки и от даты перехода права собственности.
//
// 		* СуммаЗалогаЗаТаруФорма - Строка - Путь к реквизиту формы, содержащему сумму залога за тару в валюте документа.
// 		* ЭтапыОплатыТолькоПросмотр - Булево - Признак Только просмотр для открываемой формы редактирования правил оплаты.
// 		* ВозможнаНакладнаяПоНесколькимЗаказам - Булево - Истина, если накладная может быть введена по нескольким заказам.
// 		* ИсточникСуммТабличнаяЧасть - Булево - Истина, если объект предоставляет интерфейс ПоместитьСуммыПоЗаказамВоВременноеХранилище() для сложного расчета сумм документа
//
// 		* ДоговорКомиссионера - Строка - Путь к реквизиту объекта, содержащему договор с комиссионероом для определения реквизитов ГФУ, ПорядокРасчетов, ВалютаВзаиморасчетов, ОплатаВВалюте при учете продаж.
// 		* ВестиРасчетыЧерезКонечныхПокупателей - Булево - Признак, что взаиморасчеты по комиссионным продажам идут через конечного покупателя.
//
Функция ПараметрыМеханизма() Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ПараметрыМеханизма() 
```
</details>

## ДополненныеПараметрыМеханизма
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет структуру/ массив структур данными настроек ИБ, задает соответствие элементов формы индексам элементов массива параметров.
//
// Параметры:
// 	Объект - ДокументОбъект, СправочникОбъект, ФормаКлиентскогоПриложения - Объект, по которому требуется дополнить параметры.
// 	ПараметрыМеханизма - Массив из см. ВзаиморасчетыСервер.ПараметрыМеханизма, Структура см. ВзаиморасчетыСервер.ПараметрыМеханизма - Параметры для дополнения.
//
// Возвращаемое значение:
// 	Структура - Описание:
// * МассивПараметров - Массив из Структура см. ВзаиморасчетыСервер.ПараметрыМеханизма - Включает массив структур параметров и общие данные.
//
Функция ДополненныеПараметрыМеханизма(Объект, ПараметрыМеханизма = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ДополненныеПараметрыМеханизма(Объект, ПараметрыМеханизма);
```
</details>

## ОбработкаЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Выполняет первоначальное заполнение валют, порядка расчетов, оплата в валюте, этапов графика оплат, курса и кратности
//значениями по умолчанию, если значения еще не заполнены.
//
// Параметры:
// 	Объект - ДокументОбъект, СправочникОбъект - обрабатываемый объект.
// 	ДанныеЗаполнения - Структура, ДокументОбъект - ДанныеЗаполнения из обработки заполнения документа.
//
Процедура ОбработкаЗаполнения(Объект, ДанныеЗаполнения) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ОбработкаЗаполнения(Объект, ДанныеЗаполнения) 
```
</details>

## ПриКопировании
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Выполняет очистку реквизитов при копировании документов.
//В продажах и закупках чистится расшифровка платежа, этапы графика оплат, суммы взаиморасчетов.
//
// Параметры:
// 	Объект - ДокументОбъект, СправочникОбъект - обрабатываемый объект.
//
Процедура ПриКопировании(Объект) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПриКопировании(Объект) 
```
</details>

## ПередЗаписью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Проверяет и заполняет необходимые данные механизма и документа:
//	Сумму взаиморасчетов документа;
//	Сумму взаиморасчетов в основных табличных частях документа;
//	Порядок расчетов;
//	Оплату в валюте;
//	Расшифровку платежа;
//	Этапы графика оплат.
//
// Параметры:
// 	Объект - ДокументОбъект, СправочникОбъект - обрабатываемый объект.
// 	Отказ - Булево - Флаг отказ из обработчика документа ПередЗаписью.
// 	РежимЗаписи - РежимЗаписиДокумента - Режим записи документа.
//
Процедура ПередЗаписью(Объект, Отказ, ЗНАЧ РежимЗаписи = Неопределено) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПередЗаписью(Объект, Отказ, ЗНАЧ РежимЗаписи);
```
</details>

## ПередЗаписьюНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Перед записью на сервере.
//
// Параметры:
//  Форма Форма
//  ТекущийОбъект Текущий объект
Процедура ПередЗаписьюНаСервере(Форма, ТекущийОбъект) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПередЗаписьюНаСервере(Форма, ТекущийОбъект) 
```
</details>

## ПриИзмененииДатыСогласования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// При изменении даты согласования очищает этапы графика оплаты.
//
// Параметры:
//  Объект - ДокументОбъект, СправочникОбъект - обрабатываемый объект.
Процедура ПриИзмененииДатыСогласования(Объект) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПриИзмененииДатыСогласования(Объект) 
```
</details>

## ФормаПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Выполняет дополнение и кэширование параметров механизма в реквизит формы, обновляет тексты гиперссылок
//и устанавливает видимость команды "Зачет оплаты" для новых документов.
//
// Параметры:
// 	Форма - РасширениеУправляемойФормыДляДокумента - Форма документа/справочника.
//
Процедура ФормаПриСозданииНаСервере(Форма) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ФормаПриСозданииНаСервере(Форма) 
```
</details>

## ФормаПриЧтенииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Выполняет кэширование параметров механизма в реквизит формы, обновляет тексты гиперссылок
//и устанавливает видимость команды "Зачет оплаты" для существующих документов.
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма документа/справочника.
//
Процедура ФормаПриЧтенииНаСервере(Форма) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ФормаПриЧтенииНаСервере(Форма) 
```
</details>

## ФормаПослеЗаписиНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Обновляет тексты гиперссылок после записи и устанавливает значения параметров механизма Взаиморасчеты по оповещению
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма документа/справочника.
// 	ДополнительныеСвойства - Структура - Дополнительные свойства записаннного объекта
//
Процедура ФормаПослеЗаписиНаСервере(Форма, ДополнительныеСвойства = Неопределено) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ФормаПослеЗаписиНаСервере(Форма, ДополнительныеСвойства);
```
</details>

## ФормаПриИзмененииРеквизитов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Выполняет необходимые действия при изменении ключевых реквизитов документа/справочника.
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма документа/справочника.
// 	ИзмененныеРеквизиты - Массив - Перечень имен измененных реквизитов в терминах документа.
// 	ЭтоИзмененияМеханизма - Булево - Флаг того, что вызов производит сам механизм.
//
// Возвращаемое значение:
// 	Структура - Структура измененных реквизитов документа после обработки, где:
// 		* Ключ - Строка - Имя реквизита.
// 		* Значение - Произвольный - значение реквизита до изменения.
//
Функция ФормаПриИзмененииРеквизитов(Форма, ИзмененныеРеквизиты, ЭтоИзмененияМеханизма = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ФормаПриИзмененииРеквизитов(Форма, ИзмененныеРеквизиты, ЭтоИзмененияМеханизма);
```
</details>

## ПриИзмененииПараметровМеханизма
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Обновляет тексты гиперссылок, видимость команды "Зачет оплаты".
//Очищает все реквизиты взаиморасчетов, если документ более не изменяет взаиморасчеты.
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма документа/справочника.
//
Процедура ПриИзмененииПараметровМеханизма(Форма) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПриИзмененииПараметровМеханизма(Форма) 
```
</details>

## ОбработкаОповещения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Используется для обработке оповещений, связанных с механизмами взаиморасчетов.
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения
// 	 * Объект - ДанныеФормы
// 	  ** Ссылка - ДокументСсылка, СправочникСсылка
// 	ИмяСобытия - Строка - Имя события.
// 	Параметр - Произвольный - Параметр события.
Процедура ОбработкаОповещения(Форма, ИмяСобытия, Параметр) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ОбработкаОповещения(Форма, ИмяСобытия, Параметр) 
```
</details>

## КурсыВалютДляПересчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция - Курсы валют для пересчета
//
// Параметры:
//  Форма			 - ФормаКлиентскогоПриложения	 - Форма документа/справочника.
//  СтараяВалюта	 - СправочникСсылка.Валюты	 - валюта из которой нужно пересчитать
//  НоваяВалюта		 - СправочникСсылка.Валюты	 - валюта в которую нужно пересчитать
//  БазоваяВалюта	 - СправочникСсылка.Валюты	 - базовая валюта курсов
//  ДатаДокумента	 - Дата	 - дата получения курсов
//
// Возвращаемое значение:
//  Структура:
//   *СтруктураКурсовСтаройВалюты - см. РаботаСКурсамиВалютУТ.ПолучитьКурсВалюты
//   *СтруктураКурсовНовойВалюты - см. РаботаСКурсамиВалютУТ.ПолучитьКурсВалюты
//
Функция КурсыВалютДляПересчета(Форма, СтараяВалюта, НоваяВалюта, БазоваяВалюта, ДатаДокумента) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.КурсыВалютДляПересчета(Форма, СтараяВалюта, НоваяВалюта, БазоваяВалюта, ДатаДокумента) 
```
</details>

## ПроверитьЗаполнитьЭтапыГрафикаОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Выполняет заполнение/очистку/перераспределение этапов графика оплат
//
// Параметры:
// 	Объект - ДокументОбъект, СправочникОбъект, ФормаКлиентскогоПриложения - обрабатываемый объект.
// 	ДополненныеПараметрыМеханизма - см. ВзаиморасчетыСервер.ДополненныеПараметрыМеханизма
// 	ТаблицаЭтаповГрафикаОплаты - ТаблицаЗначений - Выгрузка табличной части ЭтапыГрафикаОплаты
//
Процедура ПроверитьЗаполнитьЭтапыГрафикаОплаты(Объект, ЗНАЧ ДополненныеПараметрыМеханизма = Неопределено, ТаблицаЭтаповГрафикаОплаты = Неопределено) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПроверитьЗаполнитьЭтапыГрафикаОплаты(Объект, ЗНАЧ ДополненныеПараметрыМеханизма, ТаблицаЭтаповГрафикаОплаты);
```
</details>

## ПоместитьЭтапыОплатыВоВременноеХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПоместитьЭтапыОплатыВоВременноеХранилище(Форма, ИмяЭлемента) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПоместитьЭтапыОплатыВоВременноеХранилище(Форма, ИмяЭлемента) 
```
</details>

## ЗагрузитьЭтапыОплатыИзВременногоХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗагрузитьЭтапыОплатыИзВременногоХранилища(Форма) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗагрузитьЭтапыОплатыИзВременногоХранилища(Форма) 
```
</details>

## ОбновитьТекстГиперссылкиЭтапыОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
// Служебная процедура, заполняет текст гиперссылки правил оплаты
//
// Параметры:
//	Форма       - ФормаКлиентскогоПриложения - Договор, указанный в документе:
//	 * Элементы - ЭлементыФормы - элементы вызывающей формы
//	СтруктураПараметров - см. ВзаиморасчетыСервер.ПараметрыМеханизма
//	СистемныеНастройки  - Структура - Системные настройки из дополненных параметров, если уже получены.
//
Процедура ОбновитьТекстГиперссылкиЭтапыОплаты(Форма, СтруктураПараметров = Неопределено, СистемныеНастройки = Неопределено) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ОбновитьТекстГиперссылкиЭтапыОплаты(Форма, СтруктураПараметров, СистемныеНастройки);
```
</details>

## ВедомостьРасчетовСКлиентами_ДобавитьКомандуОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду отчета "Ведомость расчетов с клиентами" в список команд.
//
// Параметры:
//   КомандыОтчетов - см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
//
// Возвращаемое значение:
// 	- СтрокаТаблицыЗначений: см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов.
// 	- Неопределено - Если нет прав на просмотр отчета.
//
Функция ВедомостьРасчетовСКлиентами_ДобавитьКомандуОтчета(КомандыОтчетов) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ВедомостьРасчетовСКлиентами_ДобавитьКомандуОтчета(КомандыОтчетов) 
```
</details>

## ВедомостьРасчетовМеждуОрганизациями_ДобавитьКомандуОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду отчета "Ведомость расчетов между организациями" в список команд.
//
// Параметры:
//   КомандыОтчетов - см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
//
// Возвращаемое значение:
// 	- СтрокаТаблицыЗначений: см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов.
// 	- Неопределено - Если нет прав на просмотр отчета.
//
Функция ВедомостьРасчетовМеждуОрганизациями_ДобавитьКомандуОтчета(КомандыОтчетов) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ВедомостьРасчетовМеждуОрганизациями_ДобавитьКомандуОтчета(КомандыОтчетов) 
```
</details>

## ВедомостьРасчетовСПартнерами_ДобавитьКомандуОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду отчета "Ведомость расчетов с партнерами" в список команд.
//
// Параметры:
//   КомандыОтчетов - см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
//
// Возвращаемое значение:
// 	- СтрокаТаблицыЗначений: см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов.
// 	- Неопределено - Если нет прав на просмотр отчета.
//
Функция ВедомостьРасчетовСПартнерами_ДобавитьКомандуОтчета(КомандыОтчетов) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ВедомостьРасчетовСПартнерами_ДобавитьКомандуОтчета(КомандыОтчетов) 
```
</details>

## ВедомостьРасчетовСПоставщиками_ДобавитьКомандуОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду отчета "Ведомость расчетов с поставщиками" в список команд.
//
// Параметры:
//   КомандыОтчетов - см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
//
// Возвращаемое значение:
// 	- СтрокаТаблицыЗначений: см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов.
// 	- Неопределено - Если нет прав на просмотр отчета.
//
Функция ВедомостьРасчетовСПоставщиками_ДобавитьКомандуОтчета(КомандыОтчетов) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ВедомостьРасчетовСПоставщиками_ДобавитьКомандуОтчета(КомандыОтчетов) 
```
</details>

## ЗадолженностьКлиентов_ДобавитьКомандуОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду отчета "Задолженность клиентов" в стандартном виде в список команд.
// Отчет группируется по партнерам.
//
// Параметры:
//   КомандыОтчетов - см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
//
// Возвращаемое значение:
// 	- СтрокаТаблицыЗначений: см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов.
// 	- Неопределено - Если нет прав на просмотр отчета.
//
Функция ЗадолженностьКлиентов_ДобавитьКомандуОтчета(КомандыОтчетов) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ЗадолженностьКлиентов_ДобавитьКомандуОтчета(КомандыОтчетов) 
```
</details>

## ЗадолженностьКлиентов_ДобавитьКомандуОтчетаПоДокументам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду отчета "Задолженность клиентов" в список команд.
// Отчет группируется по объекту расчетов.
//
// Параметры:
//   КомандыОтчетов - см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
//
// Возвращаемое значение:
// 	- СтрокаТаблицыЗначений: см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов.
// 	- Неопределено - Если нет прав на просмотр отчета.
//
Функция ЗадолженностьКлиентов_ДобавитьКомандуОтчетаПоДокументам(КомандыОтчетов) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ЗадолженностьКлиентов_ДобавитьКомандуОтчетаПоДокументам(КомандыОтчетов) 
```
</details>

## КарточкаРасчетовСКлиентом_ДобавитьКомандуОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду отчета "Карточка расчетов с клиентом" в список команд.
// Группировка по партнеру/контрагенту
//
// Параметры:
//   КомандыОтчетов - см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
//
// Возвращаемое значение:
// 	- СтрокаТаблицыЗначений: см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов.
// 	- Неопределено - Если нет прав на просмотр отчета.
//
Функция КарточкаРасчетовСКлиентом_ДобавитьКомандуОтчета(КомандыОтчетов) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.КарточкаРасчетовСКлиентом_ДобавитьКомандуОтчета(КомандыОтчетов) 
```
</details>

## КарточкаРасчетовСКлиентом_ДобавитьКомандуОтчетаПоДокументам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду отчета "Карточка расчетов с клиентом" в список команд.
// Группировка по объекту расчетов.
//
// Параметры:
//   КомандыОтчетов - см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
//
// Возвращаемое значение:
// 	- СтрокаТаблицыЗначений: см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов.
// 	- Неопределено - Если нет прав на просмотр отчета.
//
Функция КарточкаРасчетовСКлиентом_ДобавитьКомандуОтчетаПоДокументам(КомандыОтчетов) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.КарточкаРасчетовСКлиентом_ДобавитьКомандуОтчетаПоДокументам(КомандыОтчетов) 
```
</details>

## ЗадолженностьПоставщикам_ДобавитьКомандуОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду отчета "Задолженность поставщикам" в стандартном виде в список команд.
// Отчет группируется по партнерам.
//
// Параметры:
//   КомандыОтчетов - см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
//
// Возвращаемое значение:
// 	- СтрокаТаблицыЗначений: см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов.
// 	- Неопределено - Если нет прав на просмотр отчета.
//
Функция ЗадолженностьПоставщикам_ДобавитьКомандуОтчета(КомандыОтчетов) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ЗадолженностьПоставщикам_ДобавитьКомандуОтчета(КомандыОтчетов) 
```
</details>

## ЗадолженностьПоставщикам_ДобавитьКомандуОтчетаПоДокументам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду отчета "Задолженность поставщикам" в список команд.
// Отчет группируется по объекту расчетов.
//
// Параметры:
//   КомандыОтчетов - см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
//
// Возвращаемое значение:
// 	- СтрокаТаблицыЗначений: см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов.
// 	- Неопределено - Если нет прав на просмотр отчета.
//
Функция ЗадолженностьПоставщикам_ДобавитьКомандуОтчетаПоДокументам(КомандыОтчетов) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ЗадолженностьПоставщикам_ДобавитьКомандуОтчетаПоДокументам(КомандыОтчетов) 
```
</details>

## КарточкаРасчетовСПоставщиком_ДобавитьКомандуОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду отчета "Карточка расчетов с поставщиком" в список команд.
// Группировка по партнеру/контрагенту.
//
// Параметры:
//   КомандыОтчетов - см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
//
// Возвращаемое значение:
// 	- СтрокаТаблицыЗначений: см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов.
// 	- Неопределено - Если нет прав на просмотр отчета.
//
Функция КарточкаРасчетовСПоставщиком_ДобавитьКомандуОтчета(КомандыОтчетов) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.КарточкаРасчетовСПоставщиком_ДобавитьКомандуОтчета(КомандыОтчетов) 
```
</details>

## КарточкаРасчетовСПоставщиком_ДобавитьКомандуОтчетаПоДокументам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду отчета "Карточка расчетов с поставщиком" в список команд.
// Группировка по объекту расчетов.
//
// Параметры:
//   КомандыОтчетов - см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
//
// Возвращаемое значение:
// 	- СтрокаТаблицыЗначений: см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов.
// 	- Неопределено - Если нет прав на просмотр отчета.
//
Функция КарточкаРасчетовСПоставщиком_ДобавитьКомандуОтчетаПоДокументам(КомандыОтчетов) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.КарточкаРасчетовСПоставщиком_ДобавитьКомандуОтчетаПоДокументам(КомандыОтчетов) 
```
</details>

## ЗаполнитьРасшифровкуПлатежаОстатками
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Заполняет табличные части "Расшифровка платежа" остатками задолженности.
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма документа/справочника.
// 	РасшифровкаПлатежа - ТаблицаЗначений - таблица для заполнения
//
Процедура ЗаполнитьРасшифровкуПлатежаОстатками(Форма, РасшифровкаПлатежа) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаполнитьРасшифровкуПлатежаОстатками(Форма, РасшифровкаПлатежа) 
```
</details>

## ПоместитьРасшифровкуПлатежаВоВременноеХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Помещает табличную часть Расшифровка платежа во временное хранилище и записывает ссылку на него в структуру параметров взаиморасчетов.
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма документа/справочника.
// 	ИмяЭлемента - Строка - Имя элемента, по которому можно определить для какой структуры параметров взаиморасчетов помещается расшифровка.
//
Процедура ПоместитьРасшифровкуПлатежаВоВременноеХранилище(Форма, ИмяЭлемента = Неопределено) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПоместитьРасшифровкуПлатежаВоВременноеХранилище(Форма, ИмяЭлемента);
```
</details>

## ЗагрузитьРасшифровкуПлатежаИзВременногоХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗагрузитьРасшифровкуПлатежаИзВременногоХранилища(Форма) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗагрузитьРасшифровкуПлатежаИзВременногоХранилища(Форма) 
```
</details>

## ОбновитьРаспределеннуюСуммаРасшифровки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьРаспределеннуюСуммаРасшифровки(Форма) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ОбновитьРаспределеннуюСуммаРасшифровки(Форма) 
```
</details>

## ЗаблокироватьОбъектыРасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаблокироватьОбъектыРасчетов(Форма) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ЗаблокироватьОбъектыРасчетов(Форма) 
```
</details>

## ОбновитьТекстГиперссылкиСостояниеРасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описание
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения -
Процедура ОбновитьТекстГиперссылкиСостояниеРасчетов(Форма) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ОбновитьТекстГиперссылкиСостояниеРасчетов(Форма) 
```
</details>

## ПроверитьЗаполнитьСуммыВзаиморасчетовВТабличнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура проверяет и заполняет суммы взаиморасчетов в табличной части объекта
//
// Параметры:
//  Объект - ДокументОбъект, СправочникОбъект, ФормаКлиентскогоПриложения - Проверяемый объект
//  СтруктураПараметров - см. ПараметрыМеханизма
Процедура ПроверитьЗаполнитьСуммыВзаиморасчетовВТабличнойЧасти(Объект, СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПроверитьЗаполнитьСуммыВзаиморасчетовВТабличнойЧасти(Объект, СтруктураПараметров) 
```
</details>

## ИнициализироватьПараметрыПоискаОснованийИДокументовОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает структуру параметров поиска оснований оплаты и документов оплаты
//
// Параметры:
// 	РежимПоиска - Число - соответствие коду режима поиска:
// 		1 - Поиск документов оплаты;
// 		2 - Поиск оснований (объектов) платежа.
//
// Возвращаемое значение:
// 	Структура - содержит:
// 	* РежимПоиска - Число - соответствие коду режима поиска:
// 		1 - Поиск документов оплаты;
// 		2 - Поиск оснований (объектов) платежа.
// 	* Организации - СправочникСсылка.Организации, Массив Из СправочникСсылка.Организации -
// 	* Документы   - Массив Из ДокументСсылка - документы, по которым производится поиск платежей.
// 	* НаДату      - Дата - для среза найденных документов на дату
// 	* ТолькоАвансы - Булево - Если "Истина", будут возвращены только авансовые платежи
// 	* ОграничитьТипыДокументовОплаты - Булево - Если "Истина", платежные документы будут ограничены возможными типами
// 	                                                входящих и исходящих документов оплат.
// 	* ОграничитьТипыОснованийОплаты  - Булево - Если "Истина", основания платежа будут ограничены возможными типами
// 	                                                входящих и исходящих документов.
// 	* ПараметрыОтбораПоТаблицеДокументов - Структура - Для отбора по временной таблице с документами, где:
//  	** ИмяПоля - Строка - Имя поля, в котором содержится документ
//  	** ИмяТаблицыОтбора - Строка - имя временной таблицы, где содержится документ
//
Функция ИнициализироватьПараметрыПоискаОснованийИДокументовОплаты(РежимПоиска = 1) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ИнициализироватьПараметрыПоискаОснованийИДокументовОплаты(РежимПоиска);
```
</details>

## ПодготовитьВТ_РасчетыСКлиентами_ОснованияИДокументыОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготовить временную таблицу "РасчетыСКлиентами_ОснованияИДокументыОплаты"
// Создает временную таблицу с колонками:
// 	  Организация;
// 	  ДокументОплаты - платежный документ;
// 	  ОснованиеОплаты - оплачиваемый документ;
// 	  АналитикаУчетаПоПартнерам;
// 	  ОбъектРасчетов;
// 	  НаправлениеДеятельности;
// 	  Контрагент;
// 	  Договор;
// 	  СуммаОплаты;
// 	  СуммаОплатыУпр;
// 	  СуммаОплатыРегл.
//
// Параметры:
// 	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц -
// 	ПараметрыПоиска         - см. ИнициализироватьПараметрыПоискаОснованийИДокументовОплаты
Процедура ПодготовитьВТ_РасчетыСКлиентами_ОснованияИДокументыОплаты(МенеджерВременныхТаблиц, ПараметрыПоиска) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПодготовитьВТ_РасчетыСКлиентами_ОснованияИДокументыОплаты(МенеджерВременныхТаблиц, ПараметрыПоиска) 
```
</details>

## ПодготовитьВТ_РасчетыСПоставщиками_ОснованияИДокументыОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготовить временную таблицу "РасчетыСПоставщиками_ОснованияИДокументыОплаты"
// Создает временную таблицу с колонками:
// 	  Организация;
// 	  ДокументОплаты - платежный документ;
// 	  ОснованиеОплаты - оплачиваемый документ;
// 	  АналитикаУчетаПоПартнерам;
// 	  ОбъектРасчетов;
// 	  НаправлениеДеятельности;
// 	  Контрагент;
// 	  Договор;
// 	  СуммаОплаты;
// 	  СуммаОплатыУпр;
// 	  СуммаОплатыРегл.
//
// Параметры:
// 	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц -
// 	ПараметрыПоиска         - см. ИнициализироватьПараметрыПоискаОснованийИДокументовОплаты
Процедура ПодготовитьВТ_РасчетыСПоставщиками_ОснованияИДокументыОплаты(МенеджерВременныхТаблиц, ПараметрыПоиска) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПодготовитьВТ_РасчетыСПоставщиками_ОснованияИДокументыОплаты(МенеджерВременныхТаблиц, ПараметрыПоиска) 
```
</details>

## ИнициализироватьПараметрыПодготовкиРасчетовАвансов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает структуру параметров для подготовки временных таблиц с расчетами
//
// Параметры:
//  ИсходныеПараметры - Неопределено, Структура - произвольная структура с заполненными значениями
//
// Возвращаемое значение:
// 	Структура - Описание:
//   * ДатаНачала                    - Дата -
//   * ДатаОкончания                 - Дата -
//   * Организации                   - Неопределено, СправочникСсылка.Организации, Массив из СправочникСсылка.Организации -
//   * РасчетныйДокумент             - Неопределено, ДокументСсылка - дополнительный фильтр по расчетному документу
//   * СоздатьПустуюТаблицу          - Булево - позволяет создать каркас временной таблицы без данных
//   * НоваяАрхитектураВзаиморасчетов - Булево - взаиморасчеты "онлайн"/"офлайн"
//   * ВключитьОтборПоОрганизациям - Булево - применять отбор по организации
//   * ПоляИндексовВручную           - Массив из Строка - возможность переопределения полей индексов результата
//   * УчестьРезервированиеАвансов   - Булево - если "Истина", зачтенные авансы,
//                                     которые ранее были зарезервированы, не попадут в выборку.
//   * ПараметрыОтбораПоРасчетномуДокументу - Структура - Для отбора по временной таблице с расчетными документами, где:
//   	** ИмяПоля - Строка - Имя поля, в котором содержится документ
//   	** ИмяТаблицыОтбора - Строка - имя временной таблицы, где содержится документ
//   * ПравилоОтбораАвансов          - ПеречислениеСсылка.ПорядокРегистрацииСчетовФактурНаАванс - правило отбора авансов.
//
Функция ИнициализироватьПараметрыПодготовкиРасчетовАвансов(ИсходныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ВзаиморасчетыСервер.ИнициализироватьПараметрыПодготовкиРасчетовАвансов(ИсходныеПараметры);
```
</details>

## ПодготовитьВТ_РасчетыСКлиентами_Авансы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготовить временную таблицу "РасчетыСКлиентами_Авансы"
// Создает временную таблицу с колонками:
// 	  РасчетныйДокумент;
// 	  ДокументРегистратор;
// 	  Организация;
// 	  АналитикаУчетаПоПартнерам;
// 	  ОбъектРасчетов;
// 	  НаправлениеДеятельности;
// 	  Контрагент;
// 	  Договор;
// 	  ДатаАванса;
// 	  ВалютаДокумента;
// 	  СуммаАвансаВал - сумма в валюте документа;
// 	  СуммаАванса;
// 	  СуммаАвансаУпр;
// 	  СуммаАвансаРегл.
//
// Параметры:
//  МенеджерВременныхТаблиц - МенеджерВременныхТаблиц -
//  ПараметрыРасчета        - см. ИнициализироватьПараметрыПодготовкиРасчетовАвансов
Процедура ПодготовитьВТ_РасчетыСКлиентами_Авансы(МенеджерВременныхТаблиц, ПараметрыРасчета) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПодготовитьВТ_РасчетыСКлиентами_Авансы(МенеджерВременныхТаблиц, ПараметрыРасчета) 
```
</details>

## ПодготовитьВТ_РасчетыСКлиентами_ПогашенияАвансов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготовить временную таблицу "РасчетыСКлиентами_ПогашенияАвансов"
// Создает временную таблицу с колонками:
// 	  РасчетныйДокумент;
// 	  Организация;
// 	  АналитикаУчетаПоПартнерам;
// 	  ОбъектРасчетов;
// 	  ДокументРегистратор;
// 	  Контрагент;
// 	  Договор;
// 	  НаправлениеДеятельности;
// 	  ИсхКонтрагент - контрагент, по которому возник аванс;
// 	  ИсхДоговор    - договор, по которому возник аванс;
// 	  ИсхНаправлениеДеятельности - направление, по которому возник аванс;
// 	  КорАналитикаУчетаПоПартнерам;
// 	  ИсходнаяАналитикаУчетаПоПартнерам - аналитика, по которой образовался аванс;
// 	  КорОбъектРасчетов;
// 	  ИсходныйОбъектРасчетов - объект расчетов, по которому образовался аванс;
// 	  ДатаАванса;
// 	  ДатаПогашения;
// 	  СобытиеЗнак - Если погашение произошло по причине зачета аванса, тогда СобытиеЗнак >= 0,
// 	                Если погашение произошло по причине возврата/списания задолженности, тогда СобытиеЗнак < 0;
// 	  ВидСобытия - событие, в связи с которым произошло погашение аванса. Возможные события:
// 	         - Перечисление.ХозяйственныеОперации.СписаниеКредиторскойЗадолженности,
// 	         - Перечисление.ХозяйственныеОперации.ВозвратОплатыКлиенту,
// 	         - Перечисление.ХозяйственныеОперации.ЗачетАвансаКлиенту;
// 	  ВалютаДокумента;
// 	  СуммаПогашения;
// 	  СуммаПогашенияВал - сумма в валюте документа;
// 	  СуммаПогашенияУпр;
// 	  СуммаПогашенияРегл.
//
// Параметры:
//  МенеджерВременныхТаблиц - МенеджерВременныхТаблиц -
//  ПараметрыРасчета        - см. ИнициализироватьПараметрыПодготовкиРасчетовАвансов
Процедура ПодготовитьВТ_РасчетыСКлиентами_ПогашенияАвансов(МенеджерВременныхТаблиц, ПараметрыРасчета) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПодготовитьВТ_РасчетыСКлиентами_ПогашенияАвансов(МенеджерВременныхТаблиц, ПараметрыРасчета) 
```
</details>

## ПодготовитьВТ_РасчетыСКлиентами_ПереносыАвансов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготовить временную таблицу "РасчетыСКлиентами_Переносы"
// Создает временную таблицу с колонками:
// 	  Организация;
// 	  ДокументОплаты;
// 	  ДокументПереноса;
// 	  АналитикаУчетаПоПартнерам;
// 	  ОбъектРасчетов;
// 	  Контрагент;
// 	  НаправлениеДеятельности;
// 	  Подразделение;
// 	  КорАналитикаУчетаПоПартнерам;
// 	  КорОбъектРасчетов;
// 	  КорКонтрагент;
// 	  КорНаправлениеДеятельности;
// 	  КорПодразделение;
// 	  Период;
// 	  НастройкаХозяйственнойОперации
// 	  ИдентификаторФинЗаписи;
// 	  Валюта;
// 	  Предоплата;
// 	  ПредоплатаРегл;
// 	  ПредоплатаУпр.
//
// Параметры:
//  МенеджерВременныхТаблиц - МенеджерВременныхТаблиц -
//  ПараметрыРасчета        - см. ИнициализироватьПараметрыПодготовкиРасчетовАвансов
Процедура ПодготовитьВТ_РасчетыСКлиентами_ПереносыАвансов(МенеджерВременныхТаблиц, ПараметрыРасчета) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПодготовитьВТ_РасчетыСКлиентами_ПереносыАвансов(МенеджерВременныхТаблиц, ПараметрыРасчета) 
```
</details>

## ПодготовитьВТ_ПолученныеАвансыВРазрезеПогашенийИОстатков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготовить временную таблицу "ПолученныеАвансыВРазрезеПогашенийИОстатков"
// Создает временную таблицу с колонками:
//   Организация;
//   НаправлениеДеятельности;
//   Контрагент;
//   Договор;
//   ИсхНаправлениеДеятельности - направление, по которому возник аванс;
//   ИсхКонтрагент - контрагент, по которому возник аванс;
//   ИсхДоговор    - договор, по которому возник аванс;
//   РасчетныйДокумент;
//   ИсходнаяАналитикаУчетаПоПартнерам - аналитика, по которой образовался аванс;
//   ИсходныйОбъектРасчетов - объект расчетов, по которому образовался аванс;
//   ДатаАванса;
//   ДатаПогашения - если пустая, значит это остаток;
//   ВалютаДокумента;
//   ДокументРегистратор;
//   СуммаВал - сумма в валюте документа;
//   СуммаУпр;
//   СуммаРегл;
//   Сумма.
//
// Параметры:
//  МенеджерВременныхТаблиц - МенеджерВременныхТаблиц -
//  ПараметрыРасчета        - см. ИнициализироватьПараметрыПодготовкиРасчетовАвансов
Процедура ПодготовитьВТ_ПолученныеАвансыВРазрезеПогашенийИОстатков(МенеджерВременныхТаблиц, ПараметрыРасчета) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПодготовитьВТ_ПолученныеАвансыВРазрезеПогашенийИОстатков(МенеджерВременныхТаблиц, ПараметрыРасчета) 
```
</details>

## ПодготовитьВТ_РасчетыСПоставщиками_Авансы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготовить временную таблицу "РасчетыСПоставщиками_Авансы"
// Создает временную таблицу с колонками:
// 	  РасчетныйДокумент;
// 	  ДокументРегистратор;
// 	  Организация;
// 	  АналитикаУчетаПоПартнерам;
// 	  ОбъектРасчетов;
// 	  НаправлениеДеятельности;
// 	  Контрагент;
// 	  Договор;
// 	  ДатаАванса;
// 	  ВалютаДокумента;
// 	  СуммаАвансаВал - сумма в валюте документа;
// 	  СуммаАванса;
// 	  СуммаАвансаУпр;
// 	  СуммаАвансаРегл.
//
// Параметры:
//  МенеджерВременныхТаблиц - МенеджерВременныхТаблиц -
//  ПараметрыРасчета        - см. ИнициализироватьПараметрыПодготовкиРасчетовАвансов
Процедура ПодготовитьВТ_РасчетыСПоставщиками_Авансы(МенеджерВременныхТаблиц, ПараметрыРасчета) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПодготовитьВТ_РасчетыСПоставщиками_Авансы(МенеджерВременныхТаблиц, ПараметрыРасчета) 
```
</details>

## ПодготовитьВТ_РасчетыСПоставщиками_ПогашенияАвансов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготовить временную таблицу "РасчетыСПоставщиками_ПогашенияАвансов"
// Создает временную таблицу с колонками:
// 	  РасчетныйДокумент;
// 	  Организация;
// 	  АналитикаУчетаПоПартнерам;
// 	  ОбъектРасчетов;
// 	  ДокументРегистратор;
// 	  Контрагент;
// 	  Договор;
// 	  НаправлениеДеятельности;
// 	  ИсхКонтрагент - контрагент, по которому возник аванс;
// 	  ИсхДоговор    - договор, по которому возник аванс;
// 	  ИсхНаправлениеДеятельности - направление, по которому возник аванс;
// 	  КорАналитикаУчетаПоПартнерам;
// 	  ИсходнаяАналитикаУчетаПоПартнерам - аналитика, по которой образовался аванс;
// 	  КорОбъектРасчетов;
// 	  ИсходныйОбъектРасчетов - объект расчетов, по которому образовался аванс;
// 	  ДатаАванса;
// 	  ДатаПогашения;
// 	  СобытиеЗнак - Если погашение произошло по причине зачета аванса, тогда СобытиеЗнак >= 0,
// 	                Если погашение произошло по причине возврата/списания задолженности, тогда СобытиеЗнак < 0;
// 	  ВидСобытия - событие, в связи с которым произошло погашение аванса. Возможные события:
// 	         - Перечисление.ХозяйственныеОперации.ВозвратДенежныхСредствОтПоставщика,
// 	         - Перечисление.ХозяйственныеОперации.ЗачетАвансаПоставщику;
// 	  ВалютаДокумента;
// 	  СуммаПогашения;
// 	  СуммаПогашенияВал - сумма в валюте документа;
// 	  СуммаПогашенияУпр;
// 	  СуммаПогашенияРегл.
//
// Параметры:
//  МенеджерВременныхТаблиц - МенеджерВременныхТаблиц -
//  ПараметрыРасчета        - см. ИнициализироватьПараметрыПодготовкиРасчетовАвансов
Процедура ПодготовитьВТ_РасчетыСПоставщиками_ПогашенияАвансов(МенеджерВременныхТаблиц, ПараметрыРасчета) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПодготовитьВТ_РасчетыСПоставщиками_ПогашенияАвансов(МенеджерВременныхТаблиц, ПараметрыРасчета) 
```
</details>

## ПодготовитьВТ_РасчетыСПоставщиками_ПереносыАвансов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготовить временную таблицу "РасчетыСПоставщиками_ПереносыАвансов"
// Создает временную таблицу с колонками:
// 	  Организация;
// 	  ДокументОплаты;
// 	  ДокументПереноса;
// 	  АналитикаУчетаПоПартнерам;
// 	  ОбъектРасчетов;
// 	  Контрагент;
// 	  НаправлениеДеятельности;
// 	  Подразделение;
// 	  КорАналитикаУчетаПоПартнерам;
// 	  КорОбъектРасчетов;
// 	  КорКонтрагент;
// 	  КорНаправлениеДеятельности;
// 	  КорПодразделение;
// 	  Период;
// 	  НастройкаХозяйственнойОперации
// 	  ИдентификаторФинЗаписи;
// 	  Валюта;
// 	  Предоплата;
// 	  ПредоплатаРегл;
// 	  ПредоплатаУпр.
//
// Параметры:
//  МенеджерВременныхТаблиц - МенеджерВременныхТаблиц -
//  ПараметрыРасчета        - см. ИнициализироватьПараметрыПодготовкиРасчетовАвансов
Процедура ПодготовитьВТ_РасчетыСПоставщиками_ПереносыАвансов(МенеджерВременныхТаблиц, ПараметрыРасчета) Экспорт
```

Пример вызова
```bsl
ВзаиморасчетыСервер.ПодготовитьВТ_РасчетыСПоставщиками_ПереносыАвансов(МенеджерВременныхТаблиц, ПараметрыРасчета) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
