---
title: Внеоборотные активы клиент сервер
slug: erp-uh/внеоборотные-активы-клиент-сервер
---


## ПредставлениеКоличестваМесяцевСтрокой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует представление количества месяцев в виде строки "Х лет Х месяцев".
//
// Параметры:
//  КоличествоМесяцев	- Число		- Количество месяцев.
//  ЗаключитьВСкобки	- Булево	- Истина, если срок нужно заключить в скобки.
//
// Возвращаемое значение:
//  Строка - расшифровка срока полезного использования в годах и месяцах.
//
Функция ПредставлениеКоличестваМесяцевСтрокой(КоличествоМесяцев, ЗаключитьВСкобки = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ВнеоборотныеАктивыКлиентСервер.ПредставлениеКоличестваМесяцевСтрокой(КоличествоМесяцев, ЗаключитьВСкобки);
```
</details>

## ПредставлениеСрокаСтрокой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует представление срока в виде строки "Х лет Х месяцев Х дней".
//
// Параметры:
// 	КоличествоЛет - Число -
// 	КоличествоМесяцев - Число -
// 	КоличествоДней - Число -
// Возвращаемое значение:
// 	Строка -
Функция ПредставлениеСрокаСтрокой(Знач КоличествоЛет, Знач КоличествоМесяцев, Знач КоличествоДней) Экспорт
```

Пример вызова
```bsl
Результат = ВнеоборотныеАктивыКлиентСервер.ПредставлениеСрокаСтрокой(КоличествоЛет, КоличествоМесяцев, КоличествоДней) 
```
</details>

## ПредставлениеСрокаФорматированнойСтрокой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует представление срока в виде строки "с 01.01.2020 по 31.12.2020 (Х лет Х месяцев Х дней)".
//
// Параметры:
// 	КоличествоЛет - Число -
// 	КоличествоМесяцев - Число -
// 	КоличествоДней - Число -
// 	ДатаНачала - Дата -
// 	ТолькоПросмотр - Булево -
// Возвращаемое значение:
// 	ФорматированнаяСтрока -
Функция ПредставлениеСрокаФорматированнойСтрокой(Знач КоличествоЛет, Знач КоличествоМесяцев, Знач КоличествоДней, Знач ДатаНачала, Знач ТолькоПросмотр) Экспорт
```

Пример вызова
```bsl
Результат = ВнеоборотныеАктивыКлиентСервер.ПредставлениеСрокаФорматированнойСтрокой(КоличествоЛет, КоличествоМесяцев, КоличествоДней, ДатаНачала, ТолькоПросмотр) 
```
</details>

## ДатаОкончанияПоСроку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Расчитывает дату окончания по сроку.
//
// Параметры:
// 	ДатаНачала - Дата -
// 	СрокЛет - Число -
// 	СрокМес - Число -
// 	СрокДней - Число -
// 	ПроверитьСрок - Булево -
//
// Возвращаемое значение:
// 	Дата - Дата окончания.
Функция ДатаОкончанияПоСроку(ДатаНачала, СрокЛет, СрокМес, СрокДней, ПроверитьСрок = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ВнеоборотныеАктивыКлиентСервер.ДатаОкончанияПоСроку(ДатаНачала, СрокЛет, СрокМес, СрокДней, ПроверитьСрок);
```
</details>

## РассчитатьСрокПоПериоду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает срок по периоду.
// Считается, что между 01.01.2021 и 02.01.2021 срок равен двум дням.
//
// Параметры:
// 	ДатаНачала - Дата -
// 	ДатаОкончания - Дата -
// 	СрокЛет - Число -
// 	СрокМес - Число -
// 	СрокДней - Число -
//
Процедура РассчитатьСрокПоПериоду(ДатаНачала, ДатаОкончания, СрокЛет, СрокМес, СрокДней) Экспорт
```

Пример вызова
```bsl
ВнеоборотныеАктивыКлиентСервер.РассчитатьСрокПоПериоду(ДатаНачала, ДатаОкончания, СрокЛет, СрокМес, СрокДней) 
```
</details>

## ФорматированнаяСтрока
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Форматирует строку в соответствии с заданным шаблоном.
// Возможные значения тегов в шаблоне:
// - <b> Строка </b> - выделяет строку жирным шрифтом.
// - <a href = "Ссылка"> Строка </a> - добавляет гиперссылку.
// Например, "Минимальная версия программы <b>1.1</b>. <a href = "Обновление">Обновите</a> программу.".
//
// Параметры:
//  СтрокаСТегами - Строка - строка, содержащая теги форматирования.
//
// Возвращаемое значение:
//  ФорматированнаяСтрока - преобразованная строка.
//
Функция ФорматированнаяСтрока(Знач СтрокаСТегами) Экспорт
```

Пример вызова
```bsl
Результат = ВнеоборотныеАктивыКлиентСервер.ФорматированнаяСтрока(СтрокаСТегами) 
```
</details>

## ДоступныеВариантыРаспределенияРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет доступные варианты распределения расходов на основании порядка учета.
//
// Параметры:
//  ПорядокУчета - ПеречислениеСсылка.ПорядокПогашенияСтоимостиОС,
//  			ПеречислениеСсылка.ПорядокУчетаСтоимостиВнеоборотныхАктивов	 - Порядок учета.
//
// Возвращаемое значение:
//  Массив из ПеречислениеСсылка.ВариантыРаспределенияРасходов - Доступные варианты распределения расходов
Функция ДоступныеВариантыРаспределенияРасходов(ПорядокУчета) Экспорт
```

Пример вызова
```bsl
Результат = ВнеоборотныеАктивыКлиентСервер.ДоступныеВариантыРаспределенияРасходов(ПорядокУчета) 
```
</details>

## ДоступныеВариантыРаспределенияРасходовПриСписании
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Доступные варианты распределения расходов при списании.
//
// Возвращаемое значение:
//  Массив из ПеречислениеСсылка.ВариантыРаспределенияРасходов -  Доступные варианты распределения расходов при списании
Функция ДоступныеВариантыРаспределенияРасходовПриСписании() Экспорт
```

Пример вызова
```bsl
Результат = ВнеоборотныеАктивыКлиентСервер.ДоступныеВариантыРаспределенияРасходовПриСписании() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
