---
title: Внутренняя переработка сервер
slug: erp-uh/внутренняя-переработка-сервер
---


## ЗаполнитьВладелецИзделияДоступенВТаблице
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет признак ВладелецИзделияДоступен в строках таблицы
//
//	Параметры:
//		Форма   - ФормаКлиентскогоПриложения - форма владелец обрабатываемой таблицы
//		Таблица - ДанныеФормыКоллекция       - обрабатываемая таблица
//		Строки  - Массив, Неопределено       - массив обрабатываемых строк
//
Процедура ЗаполнитьВладелецИзделияДоступенВТаблице(Форма, Таблица, Строки = Неопределено) Экспорт
```

Пример вызова
```bsl
ВнутренняяПереработкаСервер.ЗаполнитьВладелецИзделияДоступенВТаблице(Форма, Таблица, Строки);
```
</details>

## ЗаполнитьВладелецИзделияДоступен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет служебный реквизит "ВладелецИзделияДоступен" в строке по данным указанного назначение
//
// Параметры:
//  ТекущиеДанные		 - Структура - данные обрабатываемой строки.
//  СтруктураДействий	 - Структура - описывает действия, где Ключ - наименование действия,
//  														   Значение - Структура - параметры действия.
//  КэшированныеЗначения - Структура - сохраненные значения параметров, используемых при обработке.
//
Процедура ЗаполнитьВладелецИзделияДоступен(ТекущиеДанные, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ВнутренняяПереработкаСервер.ЗаполнитьВладелецИзделияДоступен(ТекущиеДанные, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## УстановитьУсловноеОформлениеПоляВладелецИзделия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает условное оформление поля "Владелец изделия"
//
// Параметры:
//  Форма          - ФормаКлиентскогоПриложения - форма, для которой настраивается условное оформление
//	ИмяОбъекта     - Строка           - имя объекта
//  ИмяТЧ          - Строка           - имя таблицы формы
//  ПутиКДанным    - Структура        - имя таблицы формы
//
Процедура УстановитьУсловноеОформлениеПоляВладелецИзделия(Форма, ИмяОбъекта, ИмяТЧ, ПутиКДанным = Неопределено) Экспорт
```

Пример вызова
```bsl
ВнутренняяПереработкаСервер.УстановитьУсловноеОформлениеПоляВладелецИзделия(Форма, ИмяОбъекта, ИмяТЧ, ПутиКДанным);
```
</details>

## УстановитьУсловноеОформлениеПоляВладелецИзделияОтмененныхСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает условное оформление для "Владелец изделия" для отменных строк
//
// Параметры:
//  Форма          - ФормаКлиентскогоПриложения - форма, для которой настраивается условное оформление
//	ИмяОбъекта     - Строка           - имя объекта
//  ИмяТЧ          - Строка           - имя таблицы формы
//  ПутьКЭлементам - Строка           - путь к элементам формы
//
Процедура УстановитьУсловноеОформлениеПоляВладелецИзделияОтмененныхСтрок( Экспорт
```

Пример вызова
```bsl
ВнутренняяПереработкаСервер.УстановитьУсловноеОформлениеПоляВладелецИзделияОтмененныхСтрок();
```
</details>

## ДобавитьЭтап_ОстаткиКОформлениюОтчетовДавальцам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет этап в таблицу этапов закрытия месяца.
// Элементы данной таблицы являются элементами второго уровня в дереве этапов в форме закрытия месяца.
//
// Параметры:
// 	ТаблицаЭтапов - см. Обработки.ОперацииЗакрытияМесяца.ЗаполнитьОписаниеЭтаповЗакрытияМесяца
// 	ТекущийРодитель - Строка - идентификатор группы.
//
Процедура ДобавитьЭтап_ОстаткиКОформлениюОтчетовДавальцам(ТаблицаЭтапов,ТекущийРодитель) Экспорт
```

Пример вызова
```bsl
ВнутренняяПереработкаСервер.ДобавитьЭтап_ОстаткиКОформлениюОтчетовДавальцам(ТаблицаЭтапов, ТекущийРодитель) 
```
</details>

## Использование_ОстаткиКОформлениюОтчетовДавальцам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчики этапа
//
// Параметры:
// 	ПараметрыОбработчика - см. ЗакрытиеМесяцаСервер.ИнициализироватьПараметрыОбработчикаЭтапаЗакрытияМесяцаДляПроверки
//
Процедура Использование_ОстаткиКОформлениюОтчетовДавальцам(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
ВнутренняяПереработкаСервер.Использование_ОстаткиКОформлениюОтчетовДавальцам(ПараметрыОбработчика) 
```
</details>

## Оформление_ОстаткиКОформлениюОтчетовДавальцам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Оформляет этап закрытия месяца.
//
// Параметры:
// 	ПараметрыОбработчика - см. ЗакрытиеМесяцаСервер.ИнициализироватьПараметрыОбработчикаЭтапаЗакрытияМесяцаДляПроверки
//
Процедура Оформление_ОстаткиКОформлениюОтчетовДавальцам(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
ВнутренняяПереработкаСервер.Оформление_ОстаткиКОформлениюОтчетовДавальцам(ПараметрыОбработчика) 
```
</details>

## ОписаниеПроверок_ОстаткиКОформлениюОтчетовДавальцам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверки состояния системы, относящиеся к этапу.
//
// Параметры:
// 	ТаблицаПроверок - см. АудитСостоянияСистемы.ТаблицаПроверокСостоянияСистемы
//
Процедура ОписаниеПроверок_ОстаткиКОформлениюОтчетовДавальцам(ТаблицаПроверок) Экспорт
```

Пример вызова
```bsl
ВнутренняяПереработкаСервер.ОписаниеПроверок_ОстаткиКОформлениюОтчетовДавальцам(ТаблицаПроверок) 
```
</details>

## ПроверкаОстаткиКОформлениюОтчетовДавальцам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрация ошибок.
//
// Параметры:
// 	ПараметрыПроверки - см. АудитСостоянияСистемы.ИнициализироватьПараметрыПроверки
//
Процедура ПроверкаОстаткиКОформлениюОтчетовДавальцам(ПараметрыПроверки) Экспорт
```

Пример вызова
```bsl
ВнутренняяПереработкаСервер.ПроверкаОстаткиКОформлениюОтчетовДавальцам(ПараметрыПроверки) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
