---
title: Выбор периода клиент
slug: erp-uh/выбор-периода-клиент
---


## ВидПериодаПриИзменении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает значения периода и его представление.
//
// Параметры:
//  Элемент      - ПолеФормы - элемент формы, с которым связано событие.
//  ВидПериода   - ПеречислениеСсылка.ДоступныеПериодыОтчета - кратность периода.
//  НачалоПериода - Дата - нижняя граница периода.
//  КонецПериода - Дата - верхняя граница периода.
//  Период       - см. ВыборПериодаКлиентСервер.ПолучитьПредставлениеПериодаОтчета.
//
Процедура ВидПериодаПриИзменении(Элемент, Знач ВидПериода, НачалоПериода, КонецПериода, Период) Экспорт
```

Пример вызова
```bsl
ВыборПериодаКлиент.ВидПериодаПриИзменении(Элемент, ВидПериода, НачалоПериода, КонецПериода, Период) 
```
</details>

## ПериодПриИзменении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает значения периода при изменении представления.
//
// Параметры:
//  Элемент      - ПолеФормы - элемент формы, с которым связано событие.
//  Период       - см. ВыборПериодаКлиентСервер.ПолучитьПредставлениеПериодаОтчета.
//  НачалоПериода - Дата - нижняя граница периода.
//  КонецПериода - Дата - верхняя граница периода.
//
Процедура ПериодПриИзменении(Элемент, Знач Период, НачалоПериода, КонецПериода) Экспорт
```

Пример вызова
```bsl
ВыборПериодаКлиент.ПериодПриИзменении(Элемент, Период, НачалоПериода, КонецПериода) 
```
</details>

## ПериодНачалоВыбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отображает выбор периода из выпадающего списка.
//
// Параметры:
//  Форма        - ФормаКлиентскогоПриложения - где происходит выбор.
//  Элемент      - ПолеФормы - элемент формы, с которым связано событие.
//  СтандартнаяОбработка - Булево - признак стандартной (системной) обработки события.
//  ВидПериода   - ПеречислениеСсылка.ДоступныеПериодыОтчета - кратность периода.
//  НачалоПериода - Дата - нижняя граница периода.
//	ВыполняемоеОповещение - ОписаниеОповещения - Действие, выполняемое после выбора периода пользователем.
//
Процедура ПериодНачалоВыбора(Форма, Элемент, СтандартнаяОбработка, ВидПериода, НачалоПериода, ВыполняемоеОповещение) Экспорт
```

Пример вызова
```bsl
ВыборПериодаКлиент.ПериодНачалоВыбора(Форма, Элемент, СтандартнаяОбработка, ВидПериода, НачалоПериода, ВыполняемоеОповещение) 
```
</details>

## ПериодОбработкаВыбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает значения периода.
//
// Параметры:
//  Элемент      - ПолеФормы - элемент формы, с которым связано событие.
//  ВыбранноеЗначение - Дата - начало выбранного периода.
//  СтандартнаяОбработка - Булево - признак стандартной (системной) обработки события.
//  ВидПериода   - ПеречислениеСсылка.ДоступныеПериодыОтчета - кратность периода.
//  Период       - см. ВыборПериодаКлиентСервер.ПолучитьПредставлениеПериодаОтчета.
//  НачалоПериода - Дата - нижняя граница периода.
//  КонецПериода - Дата - верхняя граница периода.
//
Процедура ПериодОбработкаВыбора(Элемент, ВыбранноеЗначение, СтандартнаяОбработка, ВидПериода, Период, НачалоПериода, КонецПериода) Экспорт
```

Пример вызова
```bsl
ВыборПериодаКлиент.ПериодОбработкаВыбора(Элемент, ВыбранноеЗначение, СтандартнаяОбработка, ВидПериода, Период, НачалоПериода, КонецПериода) 
```
</details>

## ПериодАвтоПодбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подбор при изменении представления периода.
//
// Параметры:
//  Элемент      - ПолеФормы - элемент формы, с которым связано событие.
//  Текст        - Строка - Строка текста, введенная в поле ввода.
//  ДанныеВыбора - СписокЗначений - значения, из которых происходил выбор.
//  Ожидание     - Число - Интервал в секундах после ввода текста. "0" означает формирование списка быстрого выбора.
//  СтандартнаяОбработка - Булево - признак стандартной (системной) обработки события.
//  ВидПериода   - ПеречислениеСсылка.ДоступныеПериодыОтчета - кратность периода.
//  Период       - см. ВыборПериодаКлиентСервер.ПолучитьПредставлениеПериодаОтчета.
//  НачалоПериода - Дата - нижняя граница периода.
//  КонецПериода - Дата - верхняя граница периода.
//
Процедура ПериодАвтоПодбор(Элемент, Текст, ДанныеВыбора, Ожидание, СтандартнаяОбработка, ВидПериода, Период, НачалоПериода, КонецПериода) Экспорт
```

Пример вызова
```bsl
ВыборПериодаКлиент.ПериодАвтоПодбор(Элемент, Текст, ДанныеВыбора, Ожидание, СтандартнаяОбработка, ВидПериода, Период, НачалоПериода, КонецПериода) 
```
</details>

## ПериодОкончаниеВводаТекста
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подбор при изменении представления периода.
//
// Параметры:
//  Элемент      - ПолеФормы - элемент формы, с которым связано событие.
//  Текст        - Строка - Строка текста, введенная в поле ввода.
//  ДанныеВыбора - СписокЗначений - значения, из которых происходил выбор.
//  СтандартнаяОбработка - Булево - признак стандартной (системной) обработки события.
//  ВидПериода   - ПеречислениеСсылка.ДоступныеПериодыОтчета - кратность периода.
//  Период       - см. ВыборПериодаКлиентСервер.ПолучитьПредставлениеПериодаОтчета.
//  НачалоПериода - Дата - нижняя граница периода.
//  КонецПериода - Дата - верхняя граница периода.
//
Процедура ПериодОкончаниеВводаТекста(Элемент, Текст, ДанныеВыбора, СтандартнаяОбработка, ВидПериода, Период, НачалоПериода, КонецПериода) Экспорт
```

Пример вызова
```bsl
ВыборПериодаКлиент.ПериодОкончаниеВводаТекста(Элемент, Текст, ДанныеВыбора, СтандартнаяОбработка, ВидПериода, Период, НачалоПериода, КонецПериода) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
