---
title: Выбор периода клиент сервер
slug: erp-uh/выбор-периода-клиент-сервер
---


## ЗаполнитьСписокВыбораВидПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет переданный в параметрах список выбора.
//
// Параметры:
// 	МинимальныйПериод   - ПеречислениеСсылка.ДоступныеПериодыОтчета - минимальный вид периода,
//                       начиная с которого необходимо включать остальные виды периода по возрастанию.
// 	СписокВыбора        - СписокЗначений - в списке возвращаются заполненный список выбора
// 	ЗначениеПоУмолчанию - ПеречислениеСсылка.ДоступныеПериодыОтчета - в параметре возвращает вид периода по умолчанию.
//
Процедура ЗаполнитьСписокВыбораВидПериода(Знач МинимальныйПериод, СписокВыбора, ЗначениеПоУмолчанию = Неопределено) Экспорт
```

Пример вызова
```bsl
ВыборПериодаКлиентСервер.ЗаполнитьСписокВыбораВидПериода(МинимальныйПериод, СписокВыбора, ЗначениеПоУмолчанию);
```
</details>

## НачалоПериодаОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дату начала переданного вида периода, сам период определяется по переданной дате.
//
// Параметры:
// 	ВидПериода - ПеречислениеСсылка.ДоступныеПериодыОтчета - Вид периода.
//  ДатаПериода - Дата - Дата, принадлежащая периоду.
//
// Возвращаемое значение:
//   Дата - Дата начала периода.
//
Функция НачалоПериодаОтчета(ВидПериода, ДатаПериода) Экспорт
```

Пример вызова
```bsl
Результат = ВыборПериодаКлиентСервер.НачалоПериодаОтчета(ВидПериода, ДатаПериода) 
```
</details>

## КонецПериодаОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дату окончания переданного вида периода, сам период определяется по переданной дате.
//
// Параметры:
//   ВидПериода - ПеречислениеСсылка.ДоступныеПериодыОтчета - Вид периода.
//   ДатаПериода - Дата - Дата, принадлежащая периоду.
//
// Возвращаемое значение:
//   Дата - Дата окончания периода.
//
Функция КонецПериодаОтчета(ВидПериода, ДатаПериода) Экспорт
```

Пример вызова
```bsl
Результат = ВыборПериодаКлиентСервер.КонецПериодаОтчета(ВидПериода, ДатаПериода) 
```
</details>

## ПолучитьСписокПериодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список периодов, список определяется по переданной дате и виду периода.
//
// Параметры:
//   НачалоПериода - Дата - Дата начала периода.
//   ВидПериода    - ПеречислениеСсылка.ДоступныеПериодыОтчета - Вид периода.
//
// Возвращаемое значение:
//   СписокЗначений - Список возможных периодов.
//
Функция ПолучитьСписокПериодов(Знач НачалоПериода, Знач ВидПериода) Экспорт
```

Пример вызова
```bsl
Результат = ВыборПериодаКлиентСервер.ПолучитьСписокПериодов(НачалоПериода, ВидПериода) 
```
</details>

## ПолучитьВидПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает вид периода по переданным датам начала и окончания этого периода.
//
// Параметры:
// 	НачалоПериода - Дата - Дата начала периода.
//  КонецПериода  - Дата - Дата окончания периода.
//	МинимальныйВидПериода - ПеречислениеСсылка.ДоступныеПериодыОтчета - Наименьший доступный вид периода.
//
// Возвращаемое значение:
//   ПеречислениеСсылка.ДоступныеПериодыОтчета - Вид периода.
//
Функция ПолучитьВидПериода(Знач НачалоПериода, Знач КонецПериода, Знач МинимальныйВидПериода = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ВыборПериодаКлиентСервер.ПолучитьВидПериода(НачалоПериода, КонецПериода, МинимальныйВидПериода);
```
</details>

## ПолучитьПредставлениеПериодаОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление периода.
//
// Параметры:
//   ВидПериода    - ПеречислениеСсылка.ДоступныеПериодыОтчета - Вид периода.
//   НачалоПериода - Дата - Дата начала периода.
//   КонецПериода  - Дата - Дата окончания периода.
//
// Возвращаемое значение:
//   Строка - Текстовое представление периода.
//
Функция ПолучитьПредставлениеПериодаОтчета(ВидПериода, Знач НачалоПериода, Знач КонецПериода) Экспорт
```

Пример вызова
```bsl
Результат = ВыборПериодаКлиентСервер.ПолучитьПредставлениеПериодаОтчета(ВидПериода, НачалоПериода, КонецПериода) 
```
</details>

## ПодобратьПериодОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подбирает период отчета по виду периода и текущим датам отчетов.
//
// Параметры:
//	ВидПериода    - ПеречислениеСсылка.ДоступныеПериодыОтчета - Вид периода.
//	Текст         - Строка - Текстовое описание периода.
//	ДатаНачала    - Дата - Дата начала периода.
//	ДатаОкончания - Дата - Дата окончания периода.
//
// Возвращаемое значение:
//	СписокЗначений - Список возможных периодов:
//		* Значение - Дата - Дата начала периода.
//		* Представление - Строка - Текстовое описание периода.
//
Функция ПодобратьПериодОтчета(ВидПериода, Текст, ДатаНачала, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
Результат = ВыборПериодаКлиентСервер.ПодобратьПериодОтчета(ВидПериода, Текст, ДатаНачала, ДатаОкончания) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
