---
title: Групповая обработка штрихкодов ИС
slug: erp-uh/групповая-обработка-штрихкодов-ис
---


## РезультатЗагрузкиШтрихкодовИзТСД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Результат серверной обработки полученных из ТСД штрихкодов.
//
// Параметры:
//   ИдентификаторСтроки - Число - идентификатор текущей проверяемой упаковки формы проверки и подбора.
//
// Возвращаемое значение:
//   Структура - результат обработки:
//    * ТребуетсяАвторизация      - Булево - обработка не выполнена: требуется авторизация во внешнем сервисе
//    * ТребуетсяАвторизацияИСМПРозница - Булево - Если Истина, то обработка не выполнена: требуется авторизация розничным токеном
//    * ОтсутствуютCDNПлощадки    - Булево - Если Истина, то обработка не выполнена: отсутствуют CDN-площадки для обращения розничным токеном
//    * ШтрихкодыДляСопоставления - Массив - Если заполнен, то обработка не выполнена: обнаружены неизвестные штрихкоды номенклатуры
//    * ЕстьОшибкиВДереве         - Булево - Если Истина, то обработка не выполнена: модуль штрихкодирования вернул эту ошибку
//    * АдресДереваУпаковок                 - Строка - адрес дерева упаковок для отображения ошибки
//    * АдресУточнениеКоэффициентовУпаковок - Строка - адрес параметров открытия формы уточнения коэффициентов упаковок
//    * ОбщаяОшибка               - Булево - Если Истина, то обработка не выполнена: модуль штрихкодирования вернул эту ошибку
//    * ТекстОбщейОшибки          - Строка - Расшифровка общей ошибки
//
//    * ПараметрыСканирования    - См. ШтрихкодированиеИС.ПараметрыСканирования - кэшированные параметры сканирования
//    * АгрегатТСД               - Строка - служебная упаковка пакета загрузки
//    * ТребуетсяУточнениеДанных - Булево - загружаемые штрихкодв требуют уточнения данных
//    * Счетчик      - Число  - Количество штрихкодов обработанных на сервере
//    * ШтрихкодыТСД - Массив из Структура - Штрихкоды требующие обработки
//
//    * ПредложитьЗагрузитьВУпаковке - Булево - предложить пользователю загрузить данные ТСД в одной упаковке
//    * ТекстПредложенияОЗагрузке    - Строка - доступная распознанная структура иерархии
//    * ПроверяемаяУпаковка          - Число, Неопределено - открытая до начала групповой обработки упаковка (идентификатор).
//
//    * ДобавленныеСтроки         - Массив - Добавленные строки документа
//    * ИзмененныеСтроки          - Массив - Измененные строки документа
//
//    * ЭтоВосстановлениеВложенностиУпаковок - Булево - режим пересчета детализации для формы проверки
//    * ДанныеДляВосстановлениеВложенности - Неопределено - режим пересчета детализации для формы проверки
//    * ПересчитыватьИтогиВДеревеМаркированнойПродукции - Булево - режим пересчета детализации для формы проверки
//
//    * ПредложитьИзменитьДетализацию - Булево - предложить пользователю загрузить данные ТСД в другой детализации
//    * ОписаниеРекомендацииСменыДетализации - Строка - текстовое представление описания смены детализации
//    * РекомендуемыеДетализации - Неопределено, Массив - рекомендуемые детализации
//
Функция РезультатЗагрузкиШтрихкодовИзТСД(ИдентификаторСтроки = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ГрупповаяОбработкаШтрихкодовИС.РезультатЗагрузкиШтрихкодовИзТСД(ИдентификаторСтроки);
```
</details>

## ЗагрузкаШтрихкодовПрервана
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загрузка штрихкодов прервана.
//
// Параметры:
//  ЗагрузкаДанныхТСД - См. РезультатЗагрузкиШтрихкодовИзТСД
//
// Возвращаемое значение:
//  Булево - признак незавершенной обработки пакета данных
Функция ЗагрузкаШтрихкодовПрервана(ЗагрузкаДанныхТСД) Экспорт
```

Пример вызова
```bsl
Результат = ГрупповаяОбработкаШтрихкодовИС.ЗагрузкаШтрихкодовПрервана(ЗагрузкаДанныхТСД) 
```
</details>

## ЭтоАгрегатТСД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Это служебный штрихкод сеанса загрузки данных из ТСД.
//   В качестве служебного штрихкода используется нулевой короб SSCC
//
// Параметры:
//  ЗначениеШтрихкода - Строка - Значение штрихкода
//
// Возвращаемое значение:
//  Булево - Это служебный штрихкод порции данных ТСД
Функция ЭтоАгрегатТСД(ЗначениеШтрихкода) Экспорт
```

Пример вызова
```bsl
Результат = ГрупповаяОбработкаШтрихкодовИС.ЭтоАгрегатТСД(ЗначениеШтрихкода) 
```
</details>

## ОставитьНеобработанныеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет из массива штрихкодов обработанные для уменьшения объема данных к передаче на клиент
//
// Параметры:
// 	РезультатЗагрузки - См. РезультатЗагрузкиШтрихкодовИзТСД
Процедура ОставитьНеобработанныеДанные(РезультатЗагрузки) Экспорт
```

Пример вызова
```bsl
ГрупповаяОбработкаШтрихкодовИС.ОставитьНеобработанныеДанные(РезультатЗагрузки) 
```
</details>

## ОбработатьПолученныеДанныеТСДВДокументе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Серверная часть обработки штрихкодов при их загрузке из ТСД в формы документов (без иерархической проверки)
//
// Параметры:
//   Форма                 - ФормаКлиентскогоПриложения - источник вызова
//   ШтрихкодыТСД          - Массив Из Структура - данные ТСД с преобразованными в Base64 штрихкодами
//   ПараметрыСканирования - См. ШтрихкодированиеОбщегоНазначенияИС.ПараметрыСканирования
//   ТолькоКодыМаркировки  - Булево - признак обработки только кодов маркировки (без штрихкодов номенклатуры)
//
// Возвращаемое значение:
//   См. РезультатЗагрузкиШтрихкодовИзТСД
Функция ОбработатьПолученныеДанныеТСДВДокументе(Форма, ШтрихкодыТСД, ПараметрыСканирования, ТолькоКодыМаркировки = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ГрупповаяОбработкаШтрихкодовИС.ОбработатьПолученныеДанныеТСДВДокументе(Форма, ШтрихкодыТСД, ПараметрыСканирования, ТолькоКодыМаркировки);
```
</details>

## ОбработатьШтрихкоды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработать штрихкоды.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма из которой выполняется операция загрузки штрихкодов
//  Результат - См. РезультатЗагрузкиШтрихкодовИзТСД
Процедура ОбработатьШтрихкоды(Форма, Результат) Экспорт
```

Пример вызова
```bsl
ГрупповаяОбработкаШтрихкодовИС.ОбработатьШтрихкоды(Форма, Результат) 
```
</details>

## ОбработатьДанныеКОпределениюВидаУпаковки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОбработатьДанныеКОпределениюВидаУпаковки(КОпределениюВидаУпаковки) Экспорт
```

Пример вызова
```bsl
Результат = ГрупповаяОбработкаШтрихкодовИС.ОбработатьДанныеКОпределениюВидаУпаковки(КОпределениюВидаУпаковки) 
```
</details>

## ПодготовитьДанныеКОпределениюВидаУпаковки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПодготовитьДанныеКОпределениюВидаУпаковки(ДанныеДляТСД, ВидМаркируемойПродукции, КешДанныхРазбора, Экспорт
```

Пример вызова
```bsl
Результат = ГрупповаяОбработкаШтрихкодовИС.ПодготовитьДанныеКОпределениюВидаУпаковки(ДанныеДляТСД, ВидМаркируемойПродукции, КешДанныхРазбора, );
```
</details>

## ВидУпаковкиИПредставлениеШтрихкодаУпрощенныйРазбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ВидУпаковкиИПредставлениеШтрихкодаУпрощенныйРазбор(Знач Штрихкод, ВидПродукции, КешДанныхРазбора = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ГрупповаяОбработкаШтрихкодовИС.ВидУпаковкиИПредставлениеШтрихкодаУпрощенныйРазбор(Штрихкод, ВидПродукции, КешДанныхРазбора, );
```
</details>

## ВидУпаковкиИПредставлениеШтрихкода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ВидУпаковкиИПредставлениеШтрихкода(Знач Штрихкод, ВидПродукции, КешДанныхРазбора = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ГрупповаяОбработкаШтрихкодовИС.ВидУпаковкиИПредставлениеШтрихкода(Штрихкод, ВидПродукции, КешДанныхРазбора, );
```
</details>

## ПодготовитьДополнительныеВариантыСопоставленияНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготовливает параметр сканирования ДополнительныеВариантыСопоставленияНоменклатуры
//
// Параметры:
//  ПараметрыСканирования - См. ШтрихкодированиеОбщегоНазначенияИС.ПараметрыСканирования
//  ПодобраннаяМаркируемаяПродукция - ДанныеФормыКоллекция Из ДанныеФормыСтруктура - Таблица ПодобраннаяМаркируемаяПродукция из формы проверки и подбора:
//    * GTIN - Строка - GTIN
//    * Номенклатура - ОпределяемыйТип.Номенклатура - Номенклатура
//    * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - Характеристика номенклатуры
//    * Серия - ОпределяемыйТип.СерияНоменклатуры - Серия номенклатуры
//
Процедура ПодготовитьДополнительныеВариантыСопоставленияНоменклатуры(ПараметрыСканирования, ПодобраннаяМаркируемаяПродукция) Экспорт
```

Пример вызова
```bsl
ГрупповаяОбработкаШтрихкодовИС.ПодготовитьДополнительныеВариантыСопоставленияНоменклатуры(ПараметрыСканирования, ПодобраннаяМаркируемаяПродукция) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
