---
title: Денежные средства клиент сервер локализация
slug: erp-uh/денежные-средства-клиент-сервер-локализация
---


## ПроверитьКорректностьНомераСчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверка корректности банковского счета
//
// Параметры:
//  Номер        - Строка - Номер банковского счета.
//  ВалютныйСчет - Булево - Признак, является ли счет валютным.
//  ТекстОшибки  - Строка - Текст сообщения о найденных ошибках.
//
// Возвращаемое значение:
//  Булево - Истина - контрольный ключ верен, Ложь - контрольный ключ не верен.
//
Функция ПроверитьКорректностьНомераСчета(Знач Номер, ВалютныйСчет = Ложь, ТекстОшибки = "") Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваКлиентСерверЛокализация.ПроверитьКорректностьНомераСчета(Номер, ВалютныйСчет, ТекстОшибки);
```
</details>

## ЭтоКазначейскийСчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, что переданный номер счета является казначейским.
//
// Параметры:
//  НомерСчета - Строка
//
// Возвращаемое значение:
//  Булево
//
Функция ЭтоКазначейскийСчет(НомерСчета) Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваКлиентСерверЛокализация.ЭтоКазначейскийСчет(НомерСчета) 
```
</details>

## ЭтоБИКТОФК
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, что переданный БИК является кодом Территориального органа Федерального казначейства.
//
// Параметры:
//  КодБанка - Строка
//
// Возвращаемое значение:
//  Булево
//
Функция ЭтоБИКТОФК(КодБанка) Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваКлиентСерверЛокализация.ЭтоБИКТОФК(КодБанка) 
```
</details>

## ЭтоЕдиныйКазначейскийСчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, что переданный номер счета является единым казначейским счетом.
//
// Параметры:
//  НомерСчета - Строка
//
// Возвращаемое значение:
//  Булево
///
Функция ЭтоЕдиныйКазначейскийСчет(НомерСчета) Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваКлиентСерверЛокализация.ЭтоЕдиныйКазначейскийСчет(НомерСчета) 
```
</details>

## ПрименяетсяВалютныйКонтроль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ Локализация

// Возращает признак возможного применения валютного контроля.
//
// Параметры:
//  ЮрФизЛицо - ПеречислениеСсылка.ЮрФизЛицо - вид контрагента.
//  Валюта - СправочникСсылка.Валюты - текущая валюта.
//  ВалютаРеглУчета - СправочникСсылка.Валюты - валюта регламентированного учета.
//  ОплатаВВалюте - Булево - признак оплаты в валюте.
//
// Возвращаемое значение:
//   Булево - признак применения валютного контроля.
//
Функция ПрименяетсяВалютныйКонтроль(ЮрФизЛицо, Валюта, ВалютаРеглУчета, ОплатаВВалюте) Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваКлиентСерверЛокализация.ПрименяетсяВалютныйКонтроль(ЮрФизЛицо, Валюта, ВалютаРеглУчета, ОплатаВВалюте) 
```
</details>

## ПроверитьУникальныйНомерВалютногоКонтракта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет корректность уникального номера валютного контракта.
//  1 – 2: две последние цифры года, в котором контракту присвоен уникальный номер;
//  3 – 4: месяц, в котором контракту присвоен уникальный номер (числа от 01 до 12);
//  5 – 8: порядковый номер (от 0001 до 9999) контракта, принятого на учет с присвоением уникального номера банком УК в течение календарного месяца, по виду контракта, код которого указан в четвертой части уникального номера контракта.
//  Если банком УК является головной офис уполномоченного банка:
//  9 – 12: регистрационный номер кредитной организации в соответствии с КГРКО.
//  13 – 16: нули.
//  Если банком УК является филиал уполномоченного банка:
//  9 – 12: регистрационный номер кредитной организации.
//  13 – 16: порядковый номер филиала в соответствии с КГРКО.
//  17: код вида контракта.
//  18: признак резидента, являющегося стороной по контракту:
//    •	1 - юридическое лицо или его филиал;
//    •	2 - физическое лицо - индивидуальный предприниматель;
//    •	3 - физическое лицо, занимающееся в установленном законодательством Российской Федерации порядке частной практикой.
//
// Параметры:
//  Объект - СправочникОбъект.ДоговорыКонтрагентов, СправочникОбъект.ДоговорыКредитовИДепозитов,
//  СправочникОбъект.ДоговорыАренды, СправочникСсылка.ДоговорыКонтрагентов, СправочникСсылка.ДоговорыКредитовИДепозитов,
//   СправочникСсылка.ДоговорыАренды - ключ данных.
//  НомерКонтракта - Строка - проверяемый номер контракта.
//  Отказ - Булево - признак ошибки.
//
Процедура ПроверитьУникальныйНомерВалютногоКонтракта(Объект, НомерКонтракта, Отказ = Ложь) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваКлиентСерверЛокализация.ПроверитьУникальныйНомерВалютногоКонтракта(Объект, НомерКонтракта, Отказ);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
