---
title: Денежные средства сервер локализация
slug: erp-uh/денежные-средства-сервер-локализация
---


## ОплатитьСтрокиГрафика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает платежные документы, либо формирует данные заполнения для создания одного платежного документа.
//
// Параметры:
//    СтрокиГрафика - Массив - Ключи записей графика платежей
//    ТипДокумента - Строка - Тип создаваемых документов. Если не задан, будет определен автоматически.
//
// Возвращаемое значение:
//    Структура:
//        ОткрыватьФормуПомощника - Булево - Признак необходимости открытия формы помощника создания документов
//        ДокументКСозданию - Структура - Данные заполнения единственного документа
//        ДлительнаяОперация - Структура - Длительная операция создания нескольких документов
//        АдресСтрокГрафика - Строка - Адрес временного хранилища, в котором содержатся оплачиваемые строки графика.
//
Функция ОплатитьСтрокиГрафика(СтрокиГрафика, ТипДокумента) Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.ОплатитьСтрокиГрафика(СтрокиГрафика, ТипДокумента) 
```
</details>

## НаименованиеОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует варианты наименования юридического лица в соответствии с его организационно-правовой формой.
//
// Параметры:
//    Наименование - Строка - Наименование юр. лица.
//
// Возвращаемое значение:
//    Структура - Наименование, РабочееНаименование, ПолноеНаименование.
//
Функция НаименованиеОрганизации(Знач Наименование) Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.НаименованиеОрганизации(Наименование) 
```
</details>

## ПолучитьВалютуПоНомеруСчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция получает валюту, соответствующую номеру банковского счета.
// 6-8 разряды номера банковского счета соответствуют коду валюты.
// Для рублей используется код 810.
//
// Параметры:
//	НомерСчета - Число - Номер банковского счета.
//
// Возвращаемое значение:
//	СправочникСсылка.Валюты - Валюта банковского счета.
//
Функция ПолучитьВалютуПоНомеруСчета(НомерСчета) Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.ПолучитьВалютуПоНомеруСчета(НомерСчета) 
```
</details>

## ЗадатьОписаниеЗаполняемыхРеквизитовПоСтатистике
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует описание реквизитов объекта, заполняемых по статистике их использования.
//
// Параметры:
//  ОписаниеРеквизитов - см. ЗаполнениеОбъектовПоСтатистике.ДобавитьОписаниеЗаполняемыхРеквизитов.
//
Процедура ЗадатьОписаниеЗаполняемыхРеквизитовПоСтатистике(ОписаниеРеквизитов) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ЗадатьОписаниеЗаполняемыхРеквизитовПоСтатистике(ОписаниеРеквизитов) 
```
</details>

## ЗадатьОписаниеЗаполняемыхРеквизитовПриобретенияПоСтатистике
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует описание реквизитов объекта, заполняемых по статистике их использования.
//
// Параметры:
//  ОписаниеРеквизитов - см. ЗаполнениеОбъектовПоСтатистике.ДобавитьОписаниеЗаполняемыхРеквизитов.
//
Процедура ЗадатьОписаниеЗаполняемыхРеквизитовПриобретенияПоСтатистике(ОписаниеРеквизитов) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ЗадатьОписаниеЗаполняемыхРеквизитовПриобретенияПоСтатистике(ОписаниеРеквизитов) 
```
</details>

## МассивОперацийПеречисленияВБюджет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция формирует массив хозяйственных операций, для которых доступно перечисление в бюджет.
//
// Возвращаемое значение:
//	Массив - массив хозяйственных операций.
//
Функция МассивОперацийПеречисленияВБюджет() Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.МассивОперацийПеречисленияВБюджет() 
```
</details>

## УстановитьВидимостьОперацииПеречислениеТаможне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает видимость выбора операции оплаты таможенного платежа в форме.
//
// Параметры:
//	Поле - ПолеФормы - Поле формы для выбора хозяйственной операции.
//
Процедура УстановитьВидимостьОперацииПеречислениеТаможне(Поле) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.УстановитьВидимостьОперацииПеречислениеТаможне(Поле) 
```
</details>

## УстановитьВидимостьОперацийЗаймамСотрудникам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает видимость выбора операций выдачи и погашения займов сотрудникам в форме.
//
// Параметры:
//	Поле - ПолеФормы - Поле формы для выбора хозяйственной операции.
//
Процедура УстановитьВидимостьОперацийЗаймамСотрудникам(Поле) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.УстановитьВидимостьОперацийЗаймамСотрудникам(Поле) 
```
</details>

## УстановитьПрефиксКассовойКнигиНомеруДокументаПриУстановкеНовогоНомера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подмена префикса организации префиксом кассовой книги
//
// Параметры:
//    Источник - ДокументОбъект - ПКО, РКО, Кассовая книга
//    СтандартнаяОбработка - Булево - флаг стандартной обработки подписки
//    Префикс - Строка - префикс объекта, который нужно изменить.
//
Процедура УстановитьПрефиксКассовойКнигиНомеруДокументаПриУстановкеНовогоНомера(Источник, СтандартнаяОбработка, Префикс) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.УстановитьПрефиксКассовойКнигиНомеруДокументаПриУстановкеНовогоНомера(Источник, СтандартнаяОбработка, Префикс) 
```
</details>

## ПроверитьНомерДокументаПоДатеОрганизацииКассовойКнигеПередЗаписью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сброс номера документа при необходимости его изменения
//
// Параметры:
//    Источник - ДокументОбъект - ПКО, РКО, Кассовая книга
//    Отказ - Булево - флаг отказа
//    РежимЗаписи - РежимЗаписиДокумента - Режим записи
//    РежимПроведения - РежимПроведенияДокумента - Режим проведения.
//
Процедура ПроверитьНомерДокументаПоДатеОрганизацииКассовойКнигеПередЗаписью(Источник, Отказ, РежимЗаписи, РежимПроведения) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ПроверитьНомерДокументаПоДатеОрганизацииКассовойКнигеПередЗаписью(Источник, Отказ, РежимЗаписи, РежимПроведения) 
```
</details>

## УстановитьПараметрыВыбораДоговораСЗаказчиком
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает параметры выбора договора с заказчиком в рамках кооперации ГОЗ
//
// Параметры:
//    Элемент - ПолеФормы - Поле ввода договора.
//    ДополнительныеПараметры - Структура - Набор дополнительных параметров
//
Процедура УстановитьПараметрыВыбораДоговораСЗаказчиком(Элемент, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.УстановитьПараметрыВыбораДоговораСЗаказчиком(Элемент, ДополнительныеПараметры);
```
</details>

## ЗаполнитьПоВедомостямКОплате
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТ

// Процедура заполняет таблицу на основании ведомостей различных типов оплаты в соответствии с отборами.
//
// Параметры:
//	ТаблицаВедомостей - ТаблицаЗначений, ТабличнаяЧасть - Заполняемая таблица
//	СтруктураПараметров - Структура - Структура отборов
//	ТаблицаРаботников - ТаблицаЗначений, ТабличнаяЧасть - Таблица, в которую помещаются работники первой ведомости.
//
Процедура ЗаполнитьПоВедомостямКОплате(ТаблицаВедомостей, СтруктураПараметров, ТаблицаРаботников = Неопределено) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ЗаполнитьПоВедомостямКОплате(ТаблицаВедомостей, СтруктураПараметров, ТаблицаРаботников);
```
</details>

## ЗаполнитьПоВедомостямИЗаявкамКОплате
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет таблицу на основании ведомостей на основании заявок на расходование денежных средств.
//
// Параметры:
//	ТаблицаВедомостей - ТаблицаЗначений, ТабличнаяЧасть - Заполняемая таблица
//	СтруктураПараметров - Структура - Структура отборов.
//
Процедура ЗаполнитьПоВедомостямИЗаявкамКОплате(ТаблицаВедомостей, СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ЗаполнитьПоВедомостямИЗаявкамКОплате(ТаблицаВедомостей, СтруктураПараметров) 
```
</details>

## ДанныеРаботниковПоВедомостям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу значений с данными о работниках и сумме выплаты по ведомости.
// Параметры:
//	СтруктураПараметров - Структура - Структура отборов;
//	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - для передачи таблицы в другой запрос.
//
// Возвращаемое значение:
//	ТаблицаЗначений - данные о работниках и суммах их начисления по ведомостям.
//
Функция ДанныеРаботниковПоВедомостям(СтруктураПараметров, МенеджерВременныхТаблиц = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.ДанныеРаботниковПоВедомостям(СтруктураПараметров, МенеджерВременныхТаблиц);
```
</details>

## ЗаполнитьПоДоговоруЗаймаСотруднику
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура формирует данные для заполнения и расшифровку платежа платежного документа по договору займа сотруднику.
//
// Параметры:
//	Договор - ДокументСсылка.ДоговорЗаймаСотруднику - Договор займа, по которому формируется платежный документ.
//	ДанныеЗаполнения - Структура - Структура основания для заполнения документа.
//	РасшифровкаПлатежа - ТаблицаЗначений, ТабличнаяЧасть - Расшифровка платежа платежного документа.
//	ЭтоПоступление - Булево - Признак, определяющий направление движение денежных средств.
//	ТипДокумента - Строка - Тип формируемого документа. Применяется для поиска образца при заполнении расшифровки платежа.
//
Процедура ЗаполнитьПоДоговоруЗаймаСотруднику(Знач Договор, ДанныеЗаполнения, РасшифровкаПлатежа, Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ЗаполнитьПоДоговоруЗаймаСотруднику(Договор, ДанныеЗаполнения, РасшифровкаПлатежа, );
```
</details>

## ДанныеРасшифровкиПлатежаДокументаДДСПоДоговоруЗаймаСотруднику
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает данные расшифровки платежа платежного документа по договору займа сотруднику.
//
// Параметры:
//	ДанныеЗаполнения - Структура - Структура основания для заполнения документа.
//	ЭтоПоступление - Булево - Признак, определяющий направление движение денежных средств.
//	ДокументИсключение - ДокументСсылка.РасходныйКассовыйОрдер,
//                       ДокументСсылка.СписаниеБезналичныхДенежныхСредств,
//                       ДокументСсылка.ПриходныйКассовыйОрдер,
//                       ДокументСсылка.ПоступлениеБезналичныхДенежныхСредств - Документ, движения которого следует исключить.
//	ТипДокумента - Строка - Тип формируемого документа. Применяется для поиска образца при заполнении расшифровки платежа.
//
// Возвращаемое значение:
//	ТаблицаЗначений - Данные заполнения расшифровки платежа.
Функция ДанныеРасшифровкиПлатежаДокументаДДСПоДоговоруЗаймаСотруднику(ДанныеЗаполнения, ЭтоПоступление = Ложь, Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.ДанныеРасшифровкиПлатежаДокументаДДСПоДоговоруЗаймаСотруднику(ДанныеЗаполнения, ЭтоПоступление, );
```
</details>

## СтатьиДДСЗаймовСотрудникуПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает структуру статей ДДС для заполнения платежного документа. Поиск статьи ДДС
// выполняется по хозяйственной операции и типу документа.
//
// Параметры:
//    ДатаАктуальности - Дата - Дата, на которую требуется получить статьи ДДС.
//    ДокументИсключение - ДокументСсылка.РасходныйКассовыйОрдер,
//                       ДокументСсылка.СписаниеБезналичныхДенежныхСредств,
//                       ДокументСсылка.ПриходныйКассовыйОрдер,
//                       ДокументСсылка.ПоступлениеБезналичныхДенежныхСредств - Документ, движения которого следует исключить.
//    ТипДокумента - Строка - Тип формируемого документа. Применяется для поиска образца при заполнении расшифровки платежа.
//
// Возвращаемое значение:
//    Структура - Структура статей ДДС.
Функция СтатьиДДСЗаймовСотрудникуПоУмолчанию(ДатаАктуальности, ДокументИсключение = Неопределено, ТипДокумента = "ПриходныйКассовыйОрдер") Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.СтатьиДДСЗаймовСотрудникуПоУмолчанию(ДатаАктуальности, ДокументИсключение, ТипДокумента);
```
</details>

## ЗаполнитьДокументПоУведомлениюОЗачисленииВалюты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//-- НЕ УТ

// Процедура заполняет документ на основании уведомления о зачислении валюты
//
// Параметры:
//	ДокументОснование - ДокументСсылка.УведомлениеОЗачисленииВалюты - Документ - основание
//	ДокументОбъект - ДокументОбъект - Текущий документ
//	ДанныеЗаполнения - Структура - Данные заполнения.
//
Процедура ЗаполнитьДокументПоУведомлениюОЗачисленииВалюты(Знач ДокументОснование, ДокументОбъект, ДанныеЗаполнения) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ЗаполнитьДокументПоУведомлениюОЗачисленииВалюты(ДокументОснование, ДокументОбъект, ДанныеЗаполнения) 
```
</details>

## ПодтверждающиеДокументыФЗ275
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТ

// Помещает во временное хранилище таблицу подтверждающих документов
//
// Параметры:
//    ТипПлатежаФЗ275 - СправочникСсылка.ТипыПлатежейФЗ275 - Тип платежа ФЗ275
//    ИдентификаторВладельца - УникальныйИдентификатор - Идентификатор формы для помещения результата
//    Договор - СправочникСсылка.ДоговорыКонтрагентов, СправочникСсылка.ДоговорыМеждуОрганизациями, СправочникСсылка.ДоговорыКредитовИДепозитов - Договор по госконтракту
//
// Возвращаемое значение:
//    Строка -Адрес во временном хранилище, по которому содержатся ссылки на подтверждающие документы
//
Функция ПодтверждающиеДокументыФЗ275(ТипПлатежаФЗ275, ИдентификаторВладельца, Договор = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.ПодтверждающиеДокументыФЗ275(ТипПлатежаФЗ275, ИдентификаторВладельца, Договор);
```
</details>

## ПриИзмененииПравилПлатежейВБюджет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
//-- НЕ УТ

// Очищает реквизиты платежей в бюджет после проверки даты применения Приказа 107н
//
// Параметры:
//	Объект - ДокументОбъект - Документ оплаты.
//	ПредыдущийПериод - Дата - исходный период (до изменения)
//	НовыйПериод - Дата - новый период.
//
Процедура ПриИзмененииПравилПлатежейВБюджет(Объект, ПредыдущийПериод, НовыйПериод) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ПриИзмененииПравилПлатежейВБюджет(Объект, ПредыдущийПериод, НовыйПериод) 
```
</details>

## СписокКППОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выбирает перечень КПП подразделений организации
//
// Параметры:
//    Организация - СправочникСсылка.Организации - Организация, для которой определяет перечень КПП.
//
// Возвращаемое значение:
//    Массив из Структура - содержит:
//     * КПП - Строка - КПП филиала
//     * Подразделение - СправочникСсылка.СтруктураПредприятия - Филиал, имеющий регистрацию в налоговом органе
//     * РегистрацияСсылка - СправочникСсылка.РегистрацииВНалоговомОргане - Регистрация филиала
//
Функция СписокКППОрганизации(Организация) Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.СписокКППОрганизации(Организация) 
```
</details>

## РазобратьВыпискуБанка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает электронную выписку банка
//
// Параметры:
//     ЭлектроннаяВыпискаБанка - Ссылка - Электронная выписка банка
//
Процедура РазобратьВыпискуБанка(ЭлектроннаяВыпискаБанка) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.РазобратьВыпискуБанка(ЭлектроннаяВыпискаБанка) 
```
</details>

## ЗаполнитьПоОстаткамДД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет таблицу остатками денежных документов
//
// Параметры:
//	Отбор - Структура - Параметры отбора остатков ДД:
//		* Организация		- СправочникСсылка.Организации 				- Организация, в которой хранятся ДД
//		* Подразделение		- СправочникСсылка.СтруктураПредприятия 	- Подразделение, в котором хранятся ДД
//		* МОЛ 				- СправочникСсылка.ФизическиеЛица 			- МОЛ, у которого хранятся ДД
//		* Ссылка			- ДокументСсылка.ВыбытиеДенежныхДокументов 	- Документ, движения которого должны быть исключены из расчета остатков
//		* ДенежныеДокументы	- Массив 									- отбор по денежным документам
//	Таблица - ТаблицаЗначений - таблица, в которую будет помещен результат получения остатков ДД.
//
Процедура ЗаполнитьПоОстаткамДД(Отбор, Таблица) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ЗаполнитьПоОстаткамДД(Отбор, Таблица) 
```
</details>

## ПроверитьЗаполнениеНалоговыхРеквизитов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет корректность заполнения налоговых реквизитов
//
// Параметры:
//	Объект - ДокументОбъект - Документ оплаты.
//	Отказ - Булево - Признак отказа от продолжения работы
//	НепроверяемыеРеквизиты - Массив - Непроверяемые реквизиты документа
//	ФлагОбменСБанками - Булево - используется обмен с банком
//	ОшибкиЗаполнения - Строка - Накопленное описание ошибок.
//
Процедура ПроверитьЗаполнениеНалоговыхРеквизитов(Объект, Отказ, НепроверяемыеРеквизиты, ФлагОбменСБанками = Ложь, ОшибкиЗаполнения = Неопределено) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ПроверитьЗаполнениеНалоговыхРеквизитов(Объект, Отказ, НепроверяемыеРеквизиты, ФлагОбменСБанками, ОшибкиЗаполнения);
```
</details>

## ПроверитьИННиКППНаСоответствие148н
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет корректность заполнения реквизитов платежа в бюджет согласно 148н
//
// Параметры:
//	Объект - ДокументОбъект - Документ оплаты.
//	Отказ - Булево - Признак отказа от продолжения работы.
//
Процедура ПроверитьИННиКППНаСоответствие148н(Объект, Отказ) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ПроверитьИННиКППНаСоответствие148н(Объект, Отказ) 
```
</details>

## НазначениеПлатежаФЗ275
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирование текста назначения платежа для операций с использованием отдельных счетов
// Назначение платежа состоит из 4 частей:
//		1. Аванс / Оплата (необязательный) - Контроль необходимости указания подтверждающих исполнение документов
//		2. Предмет платежа - Контроль платежа по параметрам контракта (перечень товаров и услуг по тарифным ценам)
//		3. Блок автоматической обработки (необязательный) - Контроль состава приложенных обосновывающих документов
//		4. НДС (необязательный) - Указание в сумме платежа ставки и суммы платежа.
//
Функция НазначениеПлатежаФЗ275(Объект, Действие = "") Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.НазначениеПлатежаФЗ275(Объект, Действие);
```
</details>

## ОчиститьНеиспользуемыеРеквизитыОплатыЗаСчетСредствГОЗ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура очищает неиспользуемые реквизиты оплаты за счет средств ГОЗ
//
// Параметры:
//    ДокументОбъект - ДокументОбъект - Текущий документ.
//
Процедура ОчиститьНеиспользуемыеРеквизитыОплатыЗаСчетСредствГОЗ(ДокументОбъект) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ОчиститьНеиспользуемыеРеквизитыОплатыЗаСчетСредствГОЗ(ДокументОбъект) 
```
</details>

## УстановитьПараметрыВыбораСтатьиЦелевыхСредств
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает параметры выбора для статьи целевых средств
//
// Параметры:
//	Объект - ДанныеФормыСтруктура - Текущий объект
//	ЭлементСтатья - ПолеФормы - Поле для ввода статьи целевых средств.
//
Процедура УстановитьПараметрыВыбораСтатьиЦелевыхСредств(Объект, ЭлементСтатья) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.УстановитьПараметрыВыбораСтатьиЦелевыхСредств(Объект, ЭлементСтатья) 
```
</details>

## КонтрольДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет переданный документ на соответствие требованиям федеральных законов 275-ФЗ и 3729-У.
//
// Параметры:
//   Ссылка - ДокументСсылка.ЗаявкаНаРасходованиеДенежныхСредств, ДокументСсылка.СписаниеБезналичныхДенежныхСредств -
//            проверяемый документ
//   ДанныеДокументовДляКонтроля - Массив - массив результатов запросов для контроля документов за исключением временных
//                                          таблиц и удалений временных таблиц.
//
// Возвращаемое значение:
//   РезультатыПроверок - Структура - результаты проверок
//       ВсеКонтролиПройдены - Булево
//       ОписанияРезультатов - ТаблицаЗначений - результаты проверки каждого правила
//           ИмяОбработчикаКонтроля - Строка - имя процедуры, проверяющей условия одного пункта контроля
//           КонтрольПройден - Булево - результат проверки одного пункта контроля
//           Описание - Строка - развернутое описания причин прохождения или непрохождения одного пункта контроля.
//
Функция КонтрольДокумента(Ссылка, ДанныеДокументовДляКонтроля = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.КонтрольДокумента(Ссылка, ДанныеДокументовДляКонтроля);
```
</details>

## ДанныеДокументовДляКонтроля
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует таблицу данных для пакетной проверки документов
//
// Параметры:
//   МассивСсылок - ДокументСсылка.ЗаявкаНаРасходованиеДенежныхСредств,
//                  ДокументСсылка.СписаниеБезналичныхДенежныхСредств - проверяемые документы.
//
// Возвращаемое значение:
//   ДанныеДокументовДляКонтроля - Массив - массив результатов запросов для контроля документов за исключением временных
//                                          таблиц и удалений временных таблиц.
//
Функция ДанныеДокументовДляКонтроля(МассивСсылок) Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.ДанныеДокументовДляКонтроля(МассивСсылок) 
```
</details>

## ТекстЗапросаПроверкиОтдельногоСчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// По имени поля возвращает шаблон замены для запросах, где используется контроль отдельного банковского счета.
//
// Параметры:
//   ИсточникБанковскогоСчета - Строка - название поля банковского счета в запросе.
//
// Возвращаемое значение:
//   Строка - Текст запроса
//
Функция ТекстЗапросаПроверкиОтдельногоСчета(ИсточникБанковскогоСчета) Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.ТекстЗапросаПроверкиОтдельногоСчета(ИсточникБанковскогоСчета) 
```
</details>

## ОбработкаПроверкиЗаполненияПодтверждающиеДокументы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет корректность заполнения подтверждающих документов
//
// Параметры:
//	Объект - СправочникОбъект.ДоговорыКонтрагентов, ДокументОбъект.ЗаявкаНаРасходованиеДенежныхСредств - проверяемый объект
//	Отказ - Булево - Признак отказа от продолжения работы
//	ПроверяемыеРеквизиты - Массив - Проверяемые реквизиты документа
//	Ошибки - Строка - Накопленное описание ошибок.
//
Процедура ОбработкаПроверкиЗаполненияПодтверждающиеДокументы(Объект, Отказ, ПроверяемыеРеквизиты, Ошибки) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ОбработкаПроверкиЗаполненияПодтверждающиеДокументы(Объект, Отказ, ПроверяемыеРеквизиты, Ошибки) 
```
</details>

## ПроверитьЗаполнениеРеквизитовПлатежаГОЗ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет корректность заполнения подтверждающих документов
//
// Параметры:
//    Объект - СправочникОбъект.ДоговорыКонтрагентов, ДокументОбъект.ЗаявкаНаРасходованиеДенежныхСредств - проверяемый объект
//    Отказ - Булево - Признак отказа от продолжения работы.
//
Процедура ПроверитьЗаполнениеРеквизитовПлатежаГОЗ(Объект, Отказ) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ПроверитьЗаполнениеРеквизитовПлатежаГОЗ(Объект, Отказ) 
```
</details>

## НастроитьЭлементыОперацииССамозанятым
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменяет свойства элементов, связанных с операцией с самозанятыми, в документах "Приобретение товаров и услуг"
// и "Приобретение услуг и прочих активов".
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма, в которой изменяется отображение.
//
Процедура НастроитьЭлементыОперацииССамозанятым(Форма, ЕстьПривязкаЧека = Истина) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.НастроитьЭлементыОперацииССамозанятым(Форма, ЕстьПривязкаЧека);
```
</details>

## ЗаполнитьПризнакЗакупкиУСамозанятого
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отключает флаг закупки у самозанятого в документах приобретения: "Приобретение товаров и услуг"
// и "Приобретение услуг и прочих активов".
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа приобретения.
//
Процедура ЗаполнитьПризнакЗакупкиУСамозанятого(Форма) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ЗаполнитьПризнакЗакупкиУСамозанятого(Форма) 
```
</details>

## ОперацияССамозанятымПриИзменении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет документ при изменении флага "Операция с самозанятым".
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа.
//
Процедура ОперацияССамозанятымПриИзменении(Форма, ЕстьПривязкаЧека = Истина) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ОперацияССамозанятымПриИзменении(Форма, ЕстьПривязкаЧека);
```
</details>

## УстановитьСтатусЗагрузкиЧеков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает статус загрузки чеков в форме документов приобретения: "Приобретение товаров и услуг"
// и "Приобретение услуг и прочих активов".
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа приобретения.
//
Процедура УстановитьСтатусЗагрузкиЧеков(Форма) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.УстановитьСтатусЗагрузкиЧеков(Форма) 
```
</details>

## СохранитьЧекСамозанятого
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ Локализация

// Сохраняет чек самозанятого в присоединенных файлах документа.
//
// Параметры:
//  Документ - ДокументСсылка.ПриобретениеТоваровУслуг, ДокументСсылка.ПриобретениеУслугПрочихАктивов - будущий
//             документ, владелец файла.
//  ДанныеЧека - Структура - Данные чека:
// * НомерЧека - Строка - номер чека.
// * СсылкаНаЧек - Строка - ссылка на чек.
// * ЧекСамозанятого - ДвоичныеДанные - файл чека в виде двоичных данных.
Процедура СохранитьЧекСамозанятого(Документ, ДанныеЧека) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.СохранитьЧекСамозанятого(Документ, ДанныеЧека) 
```
</details>

## ДобавитьЧекСамозанятогоИзИнтернета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает ссылку на скаченный файл чека самозанятого по переданной ссылке
//
// Параметры:
//  СсылкаНаЧек - Строка - URL на чек самозанятого на сайте ФНС
//  Документ - ДокументСсылка.ПриобретениеТоваровУслуг, ДокументСсылка.ПриобретениеУслугПрочихАктивов - Ссылка на
//             документ, к которому присоединяется файл.
//
Процедура ДобавитьЧекСамозанятогоИзИнтернета(СсылкаНаЧек, Документ) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ДобавитьЧекСамозанятогоИзИнтернета(СсылкаНаЧек, Документ) 
```
</details>

## НомерЧекаИзСсылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает номер чека из ссылки на чек на сайте ФНС
//
// Параметры:
//  СсылкаНаЧек - Строка - URL на чек самозанятого на сайте ФНС
//
// Возвращаемое значение:
//  Строка - Номер чека
//
Функция НомерЧекаИзСсылки(СсылкаНаЧек) Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.НомерЧекаИзСсылки(СсылкаНаЧек) 
```
</details>

## ИННИзСсылкиНаЧек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает ИНН контрагента из ссылки на чек самозанятого.
//
// Параметры:
//  МассивЧастейСсылки - Массив из Строка - Массив, полученный в результате разделения ссылки на чек по символу "/".
//
// Возвращаемое значение:
//  Строка - ИНН
//
Функция ИННИзСсылкиНаЧек(МассивЧастейСсылки) Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.ИННИзСсылкиНаЧек(МассивЧастейСсылки) 
```
</details>

## АдресСервисаФНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает адрес сервиса ФНС с чеками
//
// Возвращаемое значение:
//   Строка - адрес страницы
//
Функция АдресСервисаФНС() Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.АдресСервисаФНС() 
```
</details>

## ЭтоСчетСбербанка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак, что счет открыт в Сбербанке
//
// Параметры:
//  БанковскийСчет - СправочникСсылка.БанковскиеСчетаОрганизаций - Ссылка на банковский счет, который стоит проверить.
//
// Возвращаемое значение:
//   Булево - Истина, если счет открыт в Сбербанке
//
Функция ЭтоСчетСбербанка(БанковскийСчет) Экспорт
```

Пример вызова
```bsl
Результат = ДенежныеСредстваСерверЛокализация.ЭтоСчетСбербанка(БанковскийСчет) 
```
</details>

## ОчиститьНеиспользуемыеРеквизитыОплатыСамозанятым
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Очищает неиспользуемые реквизиты при оплате самозанятым.
//
// Параметры:
//  ДокументОбъект - ДокументОбъект.ЗаявкаНаРасходованиеДенежныхСредств,
//                   ДокументОбъект.СписаниеБезналичныхДенежныхСредств - текущий объект.
//
Процедура ОчиститьНеиспользуемыеРеквизитыОплатыСамозанятым(ДокументОбъект) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.ОчиститьНеиспользуемыеРеквизитыОплатыСамозанятым(ДокументОбъект) 
```
</details>

## УстановитьПараметрыВыбораБанковскихСчетаСпискаКонтрагентов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает параметры выбора для счета для списка контрагентов
//
// Параметры:
//	Объект - ДанныеФормыСтруктура - Текущий объект
//	Элемент - ПолеФормы - Поле для ввода банковского счета.
//
Процедура УстановитьПараметрыВыбораБанковскихСчетаСпискаКонтрагентов(Объект, Элемент) Экспорт
```

Пример вызова
```bsl
ДенежныеСредстваСерверЛокализация.УстановитьПараметрыВыбораБанковскихСчетаСпискаКонтрагентов(Объект, Элемент) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
