---
title: Документооборот с минобороны служебный вызов сервера
slug: erp-uh/документооборот-с-минобороны-служебный-вызов-сервера
---


## ПолучитьСвойстваСертификата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает отдельные свойства сертификата в формате X.509 в соответствие с https://tools.ietf.org/html/rfc5280.
//
// Параметры:
//   ДанныеСертификата - ДвоичныеДанные, Строка - файл (двоичные данные, адрес во временном хранилище или строка Base64
//                                                при Настройки.ЭтоСтрокаBase64 = Истина) в формате X.509.
//   Настройки - Неопределено - настройки по умолчанию.
//             - Структура:
//     ЭтоЭлектроннаяПодписьВМоделиСервиса - Булево - по умолчанию Истина, влияет на имя события при записи в журнал регистрации.
//     ЭтоСтрокаBase64                     - Булево - по умолчанию Ложь, при Истина ДанныеСертификата задает строку Base64.
//     ВозможенФорматBase64                - Булево - по умолчанию Ложь, при Истина двоичные данные в ДанныеСертификата
//                                                    могут быть в формате Base64, в том числе с заголовками сертификата,
//                                                    корректность чтения определяется по прочитанному алгоритму
//     ВозвращатьИсключения                - Булево - по умолчанию Истина, генерировать исключения при неверной структуре данных.
//
// Возвращаемое значение:
//   Структура - свойства криптосообщения.
//     Размер                  - Число - размер файла в байтах.
//     Версия                  - Число - версия формата сертификата, 0 - v1, 1 - v2, 2 - v3.
//     СерийныйНомер           - ДвоичныеДанные - серийный номер сертификата.
//     АлгоритмПубличногоКлюча - Строка - "GOST R 34.10-2001", "GOST R 34.10-2012-256", "GOST R 34.10-2012-512"
//                                        или OID нераспознанного алгоритма.
//
Функция ПолучитьСвойстваСертификата(Знач ДанныеСертификата, Настройки = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотСМинобороныСлужебныйВызовСервера.ПолучитьСвойстваСертификата(ДанныеСертификата, Настройки);
```
</details>

## ИзвлечьКриптопровайдер
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИзвлечьКриптопровайдер(Сертификат) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотСМинобороныСлужебныйВызовСервера.ИзвлечьКриптопровайдер(Сертификат) 
```
</details>

## ПрочитатьAlgorithmIdentifier
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПрочитатьAlgorithmIdentifier(ЧтениеДанных, СвойстваКриптосообщения, Свойства = Неопределено, ПроверитьТип = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотСМинобороныСлужебныйВызовСервера.ПрочитатьAlgorithmIdentifier(ЧтениеДанных, СвойстваКриптосообщения, Свойства, ПроверитьТип);
```
</details>

## ПрочитатьДвоичныеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПрочитатьДвоичныеДанные(ЧтениеДанных, Свойства) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотСМинобороныСлужебныйВызовСервера.ПрочитатьДвоичныеДанные(ЧтениеДанных, Свойства));
```
</details>

## ПрочитатьЦелоеЧисло
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПрочитатьЦелоеЧисло(ЧтениеДанных, Свойства) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотСМинобороныСлужебныйВызовСервера.ПрочитатьЦелоеЧисло(ЧтениеДанных, Свойства));
```
</details>

## ПрочитатьОбъектныйИдентификатор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПрочитатьОбъектныйИдентификатор(ЧтениеДанных, Свойства) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотСМинобороныСлужебныйВызовСервера.ПрочитатьОбъектныйИдентификатор(ЧтениеДанных, Свойства));
```
</details>

## ПрочитатьСоставляющуюОбъектногоИдентификатора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПрочитатьСоставляющуюОбъектногоИдентификатора(Буфер, ТекущийБайт) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотСМинобороныСлужебныйВызовСервера.ПрочитатьСоставляющуюОбъектногоИдентификатора(Буфер, ТекущийБайт));
```
</details>

## КлассТегаБлока
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КлассТегаБлока(Байт) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотСМинобороныСлужебныйВызовСервера.КлассТегаБлока(Байт));
```
</details>

## ТегБлока
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТегБлока(Байт) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотСМинобороныСлужебныйВызовСервера.ТегБлока(Байт));
```
</details>

## ПрочитатьСвойстваБлока
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПрочитатьСвойстваБлока(ЧтениеДанных, РазмерДанных) Экспорт
```

Пример вызова
```bsl
Результат = ДокументооборотСМинобороныСлужебныйВызовСервера.ПрочитатьСвойстваБлока(ЧтениеДанных, РазмерДанных));
```
</details>

## ПропуститьБлок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПропуститьБлок(ЧтениеДанных, СколькоБайт) Экспорт
```

Пример вызова
```bsl
ДокументооборотСМинобороныСлужебныйВызовСервера.ПропуститьБлок(ЧтениеДанных, СколькоБайт));
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
