---
title: Доходы и расходы сервер
slug: erp-uh/доходы-и-расходы-сервер
---


## ПараметрыВыбораСтатьиИАналитики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров выбора статьи и аналитики
//
// Возвращаемое значение:
// 	Структура - Параметры выбора:
// 		* ПутьКДанным - Строка - Путь к объекту, в которым хранится статья.
// 		                         Например, "Объект" (если статья - реквизит объекта) или "Объект.Товары" (если статья - реквизит табличной части).
// 		* Статья - Строка - Имя реквизита статьи. Например "СтатьяРасходов"
// 		* ЗначениеПоУмолчанию - ПланВидовХарактеристикСсылка.СтатьиРасходов,
// 		                        ПланВидовХарактеристикСсылка.СтатьиДоходов
// 		                        ПланВидовХарактеристикСсылка.СтатьиАктивовПассивов - Ссылка на элемент соответствующего типа (в том числе пустая ссылка).
// 		* ДоступностьПоОперации - Булево, Неопределено - Признак доступности выбора статьи по текущей хозяйственной операции документа.
// 		                                   Если Ложь, то элементы выбора статьи и аналитики на форме скрываются.
// 		                                   Если значение Неопределено, то механизм не управляет доступностью статьи. Задача решается на стороне документа.
// 		* СкрыватьСтатьюНедоступнуюПоОперации - Булево - Если Истина, то поля скрываются. Если Ложь, то делаются недоступными. Значение по умолчанию Истина.
// 		* ОбязательностьЗаполнения - Булево - Если Истина, то устанавливается отметака незаполненного и проверяется заполнение.
// 		                                      Если Ложь, то отметка незаполненного не устанавливается и проверка заполнения не выполняется.
//
// 		* ВыборСтатьиРасходов - Булево - Определяет возможность выбора в качестве значения Статьи расходов. Значение по умолчанию Ложь.
// 		* АналитикаРасходов - Строка - Имя реквизита аналитики расходов (Тип реквизита Характеристика.СтатьиРасходов).
// 		* ОтборСтатейРасходов - Структура - Структура параметров дополнительного отбора статей расходов:
// 		                                * Ключ - Строка - Имя параметра отбора
// 		                                * Значение - Произвольный - Значение параметра отбора.
//
// 		* ВыборСтатьиДоходов - Булево - Определяет возможность выбора в качестве значения Статьи доходов. Значение по умолчанию Ложь.
// 		* АналитикаДоходов - Строка - Имя реквизита аналитики доходов (Тип реквизита Характеристика.СтатьиДоходов).
//
// 		* ВыборСтатьиАктивовПассивов - Булево - Определяет возможность выбора в качестве значения Статьи активов/пассивов. Значение по умолчанию Ложь.
// 		* АналитикаАктивовПассивов - Строка - Имя реквизита аналитики активов / пассивов (Тип реквизита Характеристика.СтатьиАктивовПассивов).
//
// 		* ЭлементыФормы - Структура - Структура с ключами:
// 			* Статья - Массив - Имена элементов формы для выбора статьи (Например, ТоварыСтатьяРасходов, СтатьяРасходовБезРазбиения)
// 			* АналитикаРасходов - Массив - Имена элементов формы для выбора аналитики статьи расходов.
// 			* АналитикаДоходов - Массив - Имена элементов формы для выбора аналитики статьи доходов.
// 			* АналитикаАктивовПассивов - Массив - Имена элементов формы для выбора аналитики статьи активов/пассивов.
//
// 		* ТипСтатьи - Строка - Имя служебного реквизита формы, в котором хранится числовое значение типа статьи. Значение по умолчанию Ложь.
// 		                               Реквизит может принимать значения:
// 		                                0 - Статья имеет значение Неопределено;
// 		                                1 - если статья имеет тип ПланВидовХарактеристикСсылка.СтатьиРасходов;
// 		                                2 - если статья имеет тип ПланВидовХарактеристикСсылка.СтатьиДоходов;
// 		                                3 - если статья имеет тип ПланВидовХарактеристикСсылка.СтатьиАктивовПассивов.
//
// 		* УсловияДоступностиСтатьиВСтроках - Структура - Дополнительные условия доступности статьи в строках таблицы. Если условий несколько, то доступность определяется по "И".
// 		                                            В элементах структуры:
// 		                                             * Ключ - Строка - Имя реквизита таблицы, определяющее доступность статьи.
// 		                                             * Значение - Булево, ЛюбаяСсылка, Массив, СписокЗначений - Значение реквизита, при котором выбор статьи доступен.
// 		* СкрыватьНедоступныеСтатьиВСтроках - Булево - Если Истина, то недоступные в строках статьи и аналитики скрываются.
// 		                                               Если Ложь, то для ячеек устанавливается оформление ТолькоПросмотр. Значение по умолчанию Ложь.
//
Функция ПараметрыВыбораСтатьиИАналитики() Экспорт
```

Пример вызова
```bsl
Результат = ДоходыИРасходыСервер.ПараметрыВыбораСтатьиИАналитики() 
```
</details>

## ОбработкаЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует пустые значения статей значением по умолчанию.
// Вызывается в соответствующем обработчике событий объекта.
//
// Параметры:
// 	Объект - ДокументОбъектИмяДокумента - Объект
// 	ПараметрыВыбора - Структура, Массив - Параметры выбора статьей (См. ДоходыИРасходыСервер.ПараметрыВыбораСтатьиИАналитики)
// 	                                      Если в объекте несколько статей, то передается массив параметров.
//
Процедура ОбработкаЗаполнения(Объект, Знач ПараметрыВыбора) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ОбработкаЗаполнения(Объект, ПараметрыВыбора) 
```
</details>

## ПередЗаписью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует пустые значения статей значением по умолчанию.
// Вызывается в соответствующем обработчике событий объекта.
//
// Параметры:
// 	Объект - ДокументОбъект - Объект
// 	ПараметрыВыбора - Структура, Массив - Параметры выбора статьей (См. ДоходыИРасходыСервер.ПараметрыВыбораСтатьиИАналитики)
// 	                                      Если в объекте несколько статей, то передается массив параметров.
//
Процедура ПередЗаписью(Объект, Знач ПараметрыВыбора) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ПередЗаписью(Объект, ПараметрыВыбора) 
```
</details>

## ОбработкаПроверкиЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку заполнение статей и аналитик в объекте.
// Вызывается в соответствующем обработчике событий объекта.
//
// Параметры:
// 	Объект - ДокументОбъект - Объект
// 	Отказ - Булево - Флаг отказа записи.
// 	ПроверяемыеРеквизиты - Массив - Массив проверяемых реквизитов объекта.
// 	ПараметрыВыбора - Структура, Массив - Параметры выбора статьей (См. ДоходыИРасходыСервер.ПараметрыВыбораСтатьиИАналитики)
// 	                                      Если в объекте несколько статей, то передается массив параметров.
//
Процедура ОбработкаПроверкиЗаполнения(Объект, Отказ, ПроверяемыеРеквизиты, Знач ПараметрыВыбора) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ОбработкаПроверкиЗаполнения(Объект, Отказ, ПроверяемыеРеквизиты, ПараметрыВыбора) 
```
</details>

## ПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Настраивает форму объекта для выбора статей и аналитики при создании формы не сервере.
// Вызывается в соответствующем обработчике событий формы.
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма объекта:
// 		* Объект - ДокументОбъект - Объект формы
// 	ПараметрыВыбора - Структура, Массив - Параметры выбора статьей (См. ДоходыИРасходыСервер.ПараметрыВыбораСтатьиИАналитики)
// 	                                      Если в объекте несколько статей, то передается массив параметров.
//
Процедура ПриСозданииНаСервере(Форма, Знач ПараметрыВыбора) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ПриСозданииНаСервере(Форма, ПараметрыВыбора) 
```
</details>

## ПриЧтенииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Настраивает форму объекта для выбора статей и аналитики при чтении объекта на сервере.
// Вызывается в соответствующем обработчике событий формы.
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма объекта
// 	ПараметрыВыбора - Структура, Массив - Параметры выбора статьей (См. ДоходыИРасходыСервер.ПараметрыВыбораСтатьиИАналитики)
// 	                                      Если в объекте несколько статей, то передается массив параметров.
//
Процедура ПриЧтенииНаСервере(Форма, Знач ПараметрыВыбора) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ПриЧтенииНаСервере(Форма, ПараметрыВыбора) 
```
</details>

## ПослеЗаписиНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет служебные реквизиты выбора статей и аналитик после записи на сервере.
// Вызывается в соответствующем обработчике событий формы.
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма объекта
//
Процедура ПослеЗаписиНаСервере(Форма) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ПослеЗаписиНаСервере(Форма) 
```
</details>

## ОбновитьСлужебныеРеквизиты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет служебные реквизиты выбора статей и аналитик
// Вызывается при необходимости (например после преобразования объекта в реквизит формы).
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма объекта
//
Процедура ОбновитьСлужебныеРеквизиты(Форма) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ОбновитьСлужебныеРеквизиты(Форма) 
```
</details>

## ПриИзмененииПараметровВыбораСтатей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет соответствие выбранных статей и аналитик переданным параметрам выбора.
// Выполняет настройку формы под новые параметры выбора.
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма объекта
// 	ПараметрыВыбора - Структура, Массив - Параметры выбора статьей (См. ДоходыИРасходыСервер.ПараметрыВыбораСтатьиИАналитики)
// 	                                      Если в объекте несколько статей, то передается массив параметров.
//
Процедура ПриИзмененииПараметровВыбораСтатей(Форма, Знач ПараметрыВыбора) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ПриИзмененииПараметровВыбораСтатей(Форма, ПараметрыВыбора) 
```
</details>

## ЗаполнитьСтатьюИАналитикуРасходовНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет в строке табличный части статью и аналитику расходов списания номенклатуры по статистике.
// Вызывается из механизма ОбработкаТабличнойЧасти.
//
// Параметры:
// 	ТекущаяСтрока - Структура - Данные строки.
// 	Номенклатура - СправочникСсылка.Номенклатура - Номенклатура, для которой необходимо заполнить статью и аналитику расходов.
// 	ПараметрыДействия - Структура - Параметры действия. (См. ДоходыИРасходыКлиентСервер.ВставитьДействиеЗаполнитьСтатьюАналитикуРасходовНоменклатуры)
//
Процедура ЗаполнитьСтатьюИАналитикуРасходовНоменклатуры(ТекущаяСтрока, ПараметрыДействия) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ЗаполнитьСтатьюИАналитикуРасходовНоменклатуры(ТекущаяСтрока, ПараметрыДействия) 
```
</details>

## ЗаполнитьСтатьюИАналитикуРасходовНоменклатурыПакетно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет в строке табличный части статью и аналитику расходов списания номенклатуры по статистике.
// Вызывается из механизма пакетной обработке строк табличных частей.
//
// Параметры:
// 	ТекущаяСтрока - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.ТекущаяСтрока
// 	ПараметрыДействия - Структура - Параметры действия. (См. ДоходыИРасходыКлиентСервер.ВставитьДействиеЗаполнитьСтатьюАналитикуРасходовНоменклатуры)
// 	КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ЗаполнитьСтатьюИАналитикуРасходовНоменклатурыПакетно(ТекущаяСтрока, ПараметрыДействия, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ЗаполнитьСтатьюИАналитикуРасходовНоменклатурыПакетно(ТекущаяСтрока, ПараметрыДействия, КэшированныеЗначения) 
```
</details>

## ОчиститьСтатьюАналитикуРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Очищает в строке табличный части статью и аналитику расходов.
// Вызывается из механизма ОбработкаТабличнойЧасти.
//
// Параметры:
// 	ТекущаяСтрока - Структура - Данные строки.
// 	ПараметрыДействия - Структура - Параметры действия. (См. ДоходыИРасходыКлиентСервер.ВставитьДействиеОчиститьСтатьюИАналитикуРасходов)
//
Процедура ОчиститьСтатьюАналитикуРасходов(ТекущаяСтрока, ПараметрыДействия) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ОчиститьСтатьюАналитикуРасходов(ТекущаяСтрока, ПараметрыДействия) 
```
</details>

## ОчиститьСтатьюАналитикуРасходовПакетно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Очищает в строке табличной части статью и аналитику расходов. Вызывается из механизма пакетной обработки строк
// табличных частей.
//
// Параметры:
// 	ТекущаяСтрока - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.ТекущаяСтрока
// 	ПараметрыДействия - Структура - Параметры действия. (См. ДоходыИРасходыКлиентСервер.ВставитьДействиеОчиститьСтатьюИАналитикуРасходов)
// 	КэшированныеДанные - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ОчиститьСтатьюАналитикуРасходовПакетно(ТекущаяСтрока, ПараметрыДействия, КэшированныеДанные) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ОчиститьСтатьюАналитикуРасходовПакетно(ТекущаяСтрока, ПараметрыДействия, КэшированныеДанные) 
```
</details>

## ИнициализироватьСтатьюИАналитикуПослеДобавленияСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует строку после добавления.
// Вызывается из механизма ОбработкаТабличнойЧасти.
//
// Параметры:
// 	ТекущаяСтрока - Структура - Данные строки.
// 	ПараметрыДействия - Структура - Параметры действия. (См. ДоходыИРасходыКлиентСервер.ВставитьДействиеИнициализироватьСтатьюИАналитикуПослеДобавленияСтроки)
//
Процедура ИнициализироватьСтатьюИАналитикуПослеДобавленияСтроки(ТекущаяСтрока, ПараметрыДействия) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ИнициализироватьСтатьюИАналитикуПослеДобавленияСтроки(ТекущаяСтрока, ПараметрыДействия) 
```
</details>

## ИнициализироватьСтатьюИАналитикуПослеДобавленияСтрокиПакетно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует строку табличной части после добавления. Вызывается из механизма пакетной обработки табличной части.
//
// Параметры:
// 	ТекущаяСтрока - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.ТекущаяСтрока
// 	ПараметрыДействия - Структура - Параметры действия. (См. ДоходыИРасходыКлиентСервер.ВставитьДействиеИнициализироватьСтатьюИАналитикуПослеДобавленияСтроки)
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ИнициализироватьСтатьюИАналитикуПослеДобавленияСтрокиПакетно(ТекущаяСтрока, ПараметрыДействия, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ИнициализироватьСтатьюИАналитикуПослеДобавленияСтрокиПакетно(ТекущаяСтрока, ПараметрыДействия, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаСтатьяАналитикаРасходовПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения статьи аналитики расходов
// при обработке строк табличной части. Возвращается последние использованные в документах статьи и аналитики расходов.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаСтатьяАналитикаРасходовПоУмолчанию(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ДополнитьТекстЗапросаСтатьяАналитикаРасходовПоУмолчанию(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаЗначенияРеквизитовСтатьи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения реквизитов по статье
// расходов/доходов при обработке строк табличной части.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаЗначенияРеквизитовСтатьи(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ДополнитьТекстЗапросаЗначенияРеквизитовСтатьи(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаПризнакПринимаетсяКНУ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения поля ПринятиеКНалоговомуУчету
// при обработке строк табличной части.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаПризнакПринимаетсяКНУ(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.ДополнитьТекстЗапросаПризнакПринимаетсяКНУ(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## СтатьяАналитикаРасходовПоУмолчаниюПакетно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция получает последние использованные в документах статью и аналитику расходов.
//
// Параметры:
//	КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
// Возвращаемое значение:
//	СтрокаТаблицыЗначений - Статья и аналитика расходов.
//
Функция СтатьяАналитикаРасходовПоУмолчаниюПакетно(КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
Результат = ДоходыИРасходыСервер.СтатьяАналитикаРасходовПоУмолчаниюПакетно(КэшированныеЗначения) 
```
</details>

## ПолучитьВалютуУправленческогоУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает валюту управленческого учета
// Если переданная в качестве параметра валюта уже заполнена - возвращает ее.
// Если валюта не передана в качестве параметра или передан пустой,
// валюту УУ. Если валюта УУ не заполнена - возвращает пустую ссылку на валюту.
//
// Параметры:
//	Валюта - СправочникСсылка.Валюты - Валюта, которую нужно заполнить.
//
// Возвращаемое значение:
//	СправочникСсылка.Валюты - валюта управленческого учета.
//
Функция ПолучитьВалютуУправленческогоУчета(Знач Валюта = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ДоходыИРасходыСервер.ПолучитьВалютуУправленческогоУчета(Валюта);
```
</details>

## ПолучитьКонтрагентаИзОснования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает контрагента из документа основания
//
// Параметры:
//  ДокументОснование - ДокументСсылка - документ, для которого нужно получить контрагента.
//
// Возвращаемое значение:
//	СправочникСсылка.Контрагенты - ссылка на контрагента.
//
Функция ПолучитьКонтрагентаИзОснования(ДокументОснование) Экспорт
```

Пример вызова
```bsl
Результат = ДоходыИРасходыСервер.ПолучитьКонтрагентаИзОснования(ДокументОснование) 
```
</details>

## РаспределитьРасходыНаСебестоимостьТоваровПоБазе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура выполняет распределение расходов на себестоимость товаров
// по рассчитанной базе распределения.
//
// Параметры:
//	ДокументОбъект - ДокументОбъект - документ, которым отражены расходы, распределяемые на себестоимость товаров.
//	СтруктураДополнительныеСвойства - Структура - дополнительные свойства документа:
//		* ТаблицыДляДвижений - Структура - Таблицы для движений:
//			** ТаблицаРасходов - ТаблицаЗначений - Таблица с колонками:
//				*** НомерСтроки - Число - Номер строки таблицы
//	Движения - КоллекцияДвижений - наборы записей регистров.
//	Отказ - Булево - признак отказа от проведения документа.
//
Процедура РаспределитьРасходыНаСебестоимостьТоваровПоБазе(ДокументОбъект, СтруктураДополнительныеСвойства, Движения, Отказ) Экспорт
```

Пример вызова
```bsl
ДоходыИРасходыСервер.РаспределитьРасходыНаСебестоимостьТоваровПоБазе(ДокументОбъект, СтруктураДополнительныеСвойства, Движения, Отказ) 
```
</details>

## РаспределениеРасходовНаСебестоимостьТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция формирует таблицу с данными распределения расходов на себестоимость товаров.
//
// Параметры:
//	ДокументСсылка - ДокументСсылка - документ, которым отражены расходы, распределяемые на себестоимость товаров.
//
// Возвращаемое значение:
//	ТаблицаЗначений - Таблица распределения расходов.
//
Функция РаспределениеРасходовНаСебестоимостьТоваров(ДокументСсылка) Экспорт
```

Пример вызова
```bsl
Результат = ДоходыИРасходыСервер.РаспределениеРасходовНаСебестоимостьТоваров(ДокументСсылка) 
```
</details>

## ДополнитьТекстЗапросаТаблицаОтражениеДокументовВРеглУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТ

// Формирует текст запроса дополнения таблицы "ТаблицаОтражениеДокументовВРеглУчете".
//
// Параметры:
// 	ЕстьВтПартииПрочихРасходов - Булево - Признак наличия временной таблицы;
// 	ИмяПериода - Строка - имя периода параметра "Период" в принимаемом запросе, должно устанавливаться в методе
// 		модуля менеджера документа "ЗаполнитьПараметрыИнициализации". По умолчанию - "Период".
//
// Возвращаемое значение:
// 	Строка - Текст запроса
Функция ДополнитьТекстЗапросаТаблицаОтражениеДокументовВРеглУчете(ЕстьВтПартииПрочихРасходов = Истина, ИмяПериода = "Период") Экспорт
```

Пример вызова
```bsl
Результат = ДоходыИРасходыСервер.ДополнитьТекстЗапросаТаблицаОтражениеДокументовВРеглУчете(ЕстьВтПартииПрочихРасходов, ИмяПериода);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
