---
title: Заказы сервер
slug: erp-uh/заказы-сервер
---


## УстановитьКлючВСтрокахТабличнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает ключ в строках табличной части
//
// Параметры:
//  Объект							 - ДокументОбъект - Изменяемый документ
//  ИмяТабличнойЧасти				 - Строка - Название табличной части
//  РеквизитМаксимальныйКодСтроки	 - Строка - Имя реквизита максимального кода строки объекта
//  ИмяРеквизитаТЧ					 - Строка - Имя реквизита кода строки в ТЧ объекта
//
Процедура УстановитьКлючВСтрокахТабличнойЧасти(Объект, Экспорт
```

Пример вызова
```bsl
ЗаказыСервер.УстановитьКлючВСтрокахТабличнойЧасти(Объект, );
```
</details>

## ПолучитьМинимальнуюДатуОтгрузкиЗаказа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает минимальную дату отгрузки по неоформленным строкам заказа. Используется в событии обработка заполнения,
// для заполнения даты документа.
//
// Параметры:
//  ЗаказИлиМассивЗаказов - ДокументСсылка - заказ, дату отгрузки которого необходимо получить.
//  ИмяРегистра - Строка - Имя регистра накопления, содержащего сведения о неоформленных строках заказа.
//  ИмяРаспоряжения - Строка - Имя измерения регистра накопления, содержащего распоряжение (заказ).
//
// Возвращаемое значение:
// Дата - Минимальная дата отгрузки по неоформленным строкам заказа.
//
Функция ПолучитьМинимальнуюДатуОтгрузкиЗаказа(ЗаказИлиМассивЗаказов, ИмяРегистра = "ЗаказыКлиентов", ИмяРаспоряжения = "ЗаказКлиента") Экспорт
```

Пример вызова
```bsl
Результат = ЗаказыСервер.ПолучитьМинимальнуюДатуОтгрузкиЗаказа(ЗаказИлиМассивЗаказов, ИмяРегистра, ИмяРаспоряжения);
```
</details>

## ПолучитьМинимальнуюДатуОтгрузкиОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает минимальную дату отгрузки Документа.
//
// Параметры:
//  Объект - ДокументОбъект - ЗаказКлиента, ЗаявкаНаВозвратКлиента.
//  ИмяТабличнойЧасти - Строка - Имя табличной части. Значение по-умолчанию - "Товары".
//
// Возвращаемое значение:
//  Дата - Минимальная дата отгрузки документа.
Функция ПолучитьМинимальнуюДатуОтгрузкиОбъекта(Объект, ИмяТабличнойЧасти = "Товары") Экспорт
```

Пример вызова
```bsl
Результат = ЗаказыСервер.ПолучитьМинимальнуюДатуОтгрузкиОбъекта(Объект, ИмяТабличнойЧасти);
```
</details>

## ПолучитьМаксимальнуюДатуОтгрузкиЗаказа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает максимальную дату отгрузки по неоформленным строкам заказа. Используется в событии обработка заполнения,
// для заполнения даты документа.
//
// Параметры:
//  ЗаказИлиМассивЗаказов - ДокументСсылка - заказ, дату отгрузки которого необходимо получить.
//  ИмяРегистра - Строка - Имя регистра накопления, содержащего сведения о неоформленных строках заказа.
//  ИмяРаспоряжения - Строка - Имя измерения регистра накопления, содержащего распоряжение (заказ).
//
// Возвращаемое значение:
// Дата - Максимальная дата отгрузки по неоформленным строкам заказа.
//
Функция ПолучитьМаксимальнуюДатуОтгрузкиЗаказа(ЗаказИлиМассивЗаказов, ИмяРегистра = "ЗаказыКлиентов", ИмяРаспоряжения = "ЗаказКлиента") Экспорт
```

Пример вызова
```bsl
Результат = ЗаказыСервер.ПолучитьМаксимальнуюДатуОтгрузкиЗаказа(ЗаказИлиМассивЗаказов, ИмяРегистра, ИмяРаспоряжения);
```
</details>

## ПараметрыОбновленияИнформацииПоЗаказамВФорме
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция-конструктор параметров обновления информации по заказам в форме
//
// Возвращаемое значение:
// Структура - Структура параметров для определения счета:
//      * ИмяРеквизитаСписокЗаказов         - Строка - Имя реквизита формы содержащего список заказов, например, "СписокЗаказов".
//      * ПутьЗаказаВШапке                  - Строка - Путь к заказу шапки, например, для вызова из формы документа "Объект.ЗаказКлиента",
//                                                     или "ЗаказКлиента" для вызова из формы подбора.
//      * ИмяНадписиЗаголовка               - Строка - Имя реквизита формы для вывода надписи "Всего заказов" или "Заказ
//                                                     ...".
//      * ИмяГруппыКолонокВТабличнойЧасти   - Строка - Имя группы колонок заказа клиента и кода строки в ТЧ
//                                                          документа для установки группировки.
//      * ИмяЗаказаВТабличнойЧасти          - Строка - Имя колонки ТЧ с заказами (например "ЗаказКлиента").
//      * ИспользоватьЗаказыВТабличнойЧасти - Булево - Значение функциональной опции использовать несколько заказов.
//      * НадписьВсегоЗаказов               - Строка - Необязательный, префикс надписи заказа.
//      * ИспользоватьЗаказы                - Неопределено, Булево - используются заказы.
//
Функция ПараметрыОбновленияИнформацииПоЗаказамВФорме() Экспорт
```

Пример вызова
```bsl
Результат = ЗаказыСервер.ПараметрыОбновленияИнформацииПоЗаказамВФорме() 
```
</details>

## ОбновитьИнформациюПоЗаказамВФорме
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет информацию по заказам в форме
//
// Параметры:
// 	 Форма - ФормаКлиентскогоПриложения - форма, для которой обновляется информация по заказам
// 	 ТабличнаяЧасть - ДанныеФормыКоллекция - ТаблицаЗначений, Табличная часть, используемая для заполнения списка заказов.
// 	 ПараметрыОбновления - см. ЗаказыСервер.ПараметрыОбновленияИнформацииПоЗаказамВФорме
//
Процедура ОбновитьИнформациюПоЗаказамВФорме(Форма, ТабличнаяЧасть, ПараметрыОбновления) Экспорт
```

Пример вызова
```bsl
ЗаказыСервер.ОбновитьИнформациюПоЗаказамВФорме(Форма, ТабличнаяЧасть, ПараметрыОбновления) 
```
</details>

## ЗаполнитьЗаказВШапкеПоЗаказамВТабличнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет заказ в шапке накладной если в табличной части указан только один заказ.
//
// Параметры:
//  ЗаказВШапке - ДокументСсылка - поле, которое необходимо заполнить.
//  ТабличнаяЧасть - ТабличнаяЧасть - табличная часть накладной, по которой необходимо заполнить заказ в шапке.
//  ИмяЗаказаВТабличнойЧасти - Строка - имя реквизита в табличной части, где хранится ссылка на заказ.
//
Процедура ЗаполнитьЗаказВШапкеПоЗаказамВТабличнойЧасти(ЗаказВШапке, Знач ТабличнаяЧасть, Знач ИмяЗаказаВТабличнойЧасти) Экспорт
```

Пример вызова
```bsl
ЗаказыСервер.ЗаполнитьЗаказВШапкеПоЗаказамВТабличнойЧасти(ЗаказВШапке, ТабличнаяЧасть, ИмяЗаказаВТабличнойЧасти) 
```
</details>

## ЗаполнитьРеквизитыШапкиПоТабличнымЧастям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет реквизиты шапки по табличным частям
//
// Параметры:
//  СоответствиеРеквизитов	- Соответствие - Соответствие реквизитов шапки и реквизитов табличных частей (ключ - реквизит шапки, значение - реквизит ТЧ)
//  ТабличныеЧасти			- Строка - Список табличных частей из которых нужно получить значения
//  Объект					- ДокументОбъект, ДанныеФормыСтруктура - Объект в котором нужно заполнить реквизиты.
//
Процедура ЗаполнитьРеквизитыШапкиПоТабличнымЧастям(СоответствиеРеквизитов, ТабличныеЧасти, Объект) Экспорт
```

Пример вызова
```bsl
ЗаказыСервер.ЗаполнитьРеквизитыШапкиПоТабличнымЧастям(СоответствиеРеквизитов, ТабличныеЧасти, Объект) 
```
</details>

## УстановитьПризнакиПрисутствияСтрокиВДокументе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает признак присутствия строки в документе относительно распоряжения по кодам строк.
//
// Параметры:
//  ТаблицаТовары            - ТаблицаЗначений - таблица, в которой необходимо установить признак.
//  ИмяЗаказаВТабличнойЧасти - Строка - имя реквизита Заказ в таблице для сопоставления.
//  МассивКодовСтрок         - Массив - коды строк заказов, с которыми осуществляется сопоставление.
//  ИмяРеквизитаКодСтроки    - Строка - имя реквизита КодСтроки заказа в таблице для сопоставления.
//
Процедура УстановитьПризнакиПрисутствияСтрокиВДокументе(ТаблицаТовары, ИмяЗаказаВТабличнойЧасти, МассивКодовСтрок, ИмяРеквизитаКодСтроки = "КодСтроки") Экспорт
```

Пример вызова
```bsl
ЗаказыСервер.УстановитьПризнакиПрисутствияСтрокиВДокументе(ТаблицаТовары, ИмяЗаказаВТабличнойЧасти, МассивКодовСтрок, ИмяРеквизитаКодСтроки);
```
</details>

## УстановитьОформлениеОтмененнойСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает условное оформление отмененной строки ТЧ в форме Заказа
// Параметры:
//	УсловноеОформление - УсловноеОформлениеКомпоновкиДанных - условное оформление формы;
//	ТаблицаФормы - ТаблицаФормы - элемент формы, связанного с ТЧ, в которой отменяются строки;
//	ИмяЭлементаОтменено - Строка - наименование элемента формы, связанного с признаком отмены строки заказа;
//	ИмяЭлементаПричинаОтмены - Строка - наименование элемента формы, связанного с причиной отмены строки заказа.
//	ИмяПоляВводаЦены - Строка - наименование элемента формы, связанного с полем ввода цены
//	ИмяПоляВводаСуммы - Строка - наименование элемента формы, связанного с полем ввода суммы
//
Процедура УстановитьОформлениеОтмененнойСтроки(УсловноеОформление, ТаблицаФормы, ИмяЭлементаОтменено, ИмяЭлементаПричинаОтмены = "", ИмяПоляВводаЦены = "", ИмяПоляВводаСуммы = "") Экспорт
```

Пример вызова
```bsl
ЗаказыСервер.УстановитьОформлениеОтмененнойСтроки(УсловноеОформление, ТаблицаФормы, ИмяЭлементаОтменено, ИмяЭлементаПричинаОтмены, ИмяПоляВводаЦены, ИмяПоляВводаСуммы);
```
</details>

## ПроверитьДублиКодовСтрокВТаблице
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПроверитьДублиКодовСтрокВТаблице(ДокументОбъект, КодСтроки, НомерСтроки, СоответствиеКодовСтрок, Отказ, ИмяТЧ = Неопределено) Экспорт
```

Пример вызова
```bsl
ЗаказыСервер.ПроверитьДублиКодовСтрокВТаблице(ДокументОбъект, КодСтроки, НомерСтроки, СоответствиеКодовСтрок, Отказ, ИмяТЧ);
```
</details>

## ЗаполнитьПризнакРасхождениеЗаказ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет служебный реквизит "РасхождениеЗаказ" в строке
//
// Параметры:
//  ТекущаяСтрока		 - Структура - данные обрабатываемой строки
//  ПараметрыЗаполнения  - см. ЗаказыКлиентСервер.ПараметрыЗаполненияПризнакРасхождениеЗаказ
//  КэшированныеЗначения - Структура - сохраненные значения параметров, используемых при обработке
//
Процедура ЗаполнитьПризнакРасхождениеЗаказ(ТекущаяСтрока, ПараметрыЗаполнения, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ЗаказыСервер.ЗаполнитьПризнакРасхождениеЗаказ(ТекущаяСтрока, ПараметрыЗаполнения, КэшированныеЗначения) 
```
</details>

## ЗаполнитьПризнакРасхождениеЗаказВТаблице
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет признак "РасхождениеЗаказ" в строках таблицы
//
//	Параметры:
//   ПараметрыЗаполнения  - см. ЗаказыКлиентСервер.ПараметрыЗаполненияПризнакРасхождениеЗаказ
//	 Таблица              - ДанныеФормыКоллекция - обрабатываемая таблица
//	 Строки               - Массив, Неопределено - массив обрабатываемых строк
//
Процедура ЗаполнитьПризнакРасхождениеЗаказВТаблице(ПараметрыЗаполнения, Таблица, Строки = Неопределено) Экспорт
```

Пример вызова
```bsl
ЗаказыСервер.ЗаполнитьПризнакРасхождениеЗаказВТаблице(ПараметрыЗаполнения, Таблица, Строки);
```
</details>

## ОтвязатьСтрокиОтЗаказов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отвязывает строки в таблице от заказов, сбрасывая значение реквизита "КодСтроки" в 0
//
//	Параметры:
//   ПараметрыЗаполнения - см. ЗаказыКлиентСервер.ПараметрыЗаполненияПризнакРасхождениеЗаказ
//	 Таблица             - ДанныеФормыКоллекция - обрабатываемая таблица
//	 Строки              - Массив, Неопределено - массив обрабатываемых строк
//
Процедура ОтвязатьСтрокиОтЗаказов(ПараметрыЗаполнения, Таблица, Строки = Неопределено) Экспорт
```

Пример вызова
```bsl
ЗаказыСервер.ОтвязатьСтрокиОтЗаказов(ПараметрыЗаполнения, Таблица, Строки);
```
</details>

## СтруктураКорректировкиСтрокЗаказа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция-конструктор структуры корректировки строк заказа
//
// Возвращаемое значение:
//  Структура - Структура параметров для корректировки строк заказа:
//      * ДокументОбъект - ДокументОбъект - Заказ, в котором требуется скорректировать строки.
//      * ИмяДокумента                    - Строка - Имя заказа (объекта метаданных).
//      * ИмяТабличнойЧасти               - Строка - Имя табличной части заказа.
//      * ПричинаОтмены                   - СправочникСсылка.ПричиныОтменыЗаказовКлиентов, СправочникСсылка.ПричиныОтменыЗаказовПоставщикам - Причина отмены строк заказа.
//      * ПроверятьОстатки                - Булево - Требуется ли проверять остатки при корректировке строк.
//      * ОтменитьНеотработанныеСтроки    - Булево - Строки заказа, по которым не оформлена накладная и не
//                                                   осуществлялась приемка/отгрузка будут отменены.
//      * СкорректироватьМерныеТовары     - Булево - Строки заказа, по которым в пределах допустимого отклонения не
//                                                   оформлена накладная и не осуществлялась приемка/отгрузка, будут
//                                                   отменены. Строки заказа, по которым было принято/отгружено и
//                                                   оформлено товара больше, чем в заказе в пределах допустимого
//                                                   отклонения будут увеличены.
//      * СкорректироватьМерныеТоварыПоПриемке - Булево - то же, что СкорректироватьМерныеТовары, но применяется если у документа
//                                                   есть отдельная табличная часть, ориентированная на приемку.
//      * СкорректироватьЦены             - Булево - Цены заказа будут приведены к ценам накладной.
//      * ЗакрыватьЗаказы                 - Булево - Нужно ли предпринять попытку установки статуса Закрыт для заказа.
//
Функция СтруктураКорректировкиСтрокЗаказа() Экспорт
```

Пример вызова
```bsl
Результат = ЗаказыСервер.СтруктураКорректировкиСтрокЗаказа() 
```
</details>

## ПараметрыЗаполненияДляОтменыСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращаемое значение:
// 	Структура - состав:
// * МенеджерРегистра  - РегистрНакопленияМенеджер
// * ОтборПоИзмерениям - Структура
// * ИмяТабличнойЧасти - Строка
// * ПутиКДанным       - Структура
// * ТаблицаЗамен      - Неопределено
//
Функция ПараметрыЗаполненияДляОтменыСтрок() Экспорт
```

Пример вызова
```bsl
Результат = ЗаказыСервер.ПараметрыЗаполненияДляОтменыСтрок() 
```
</details>

## ПараметрыОтменыСтрокЗаказов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращаемое значение:
// 	Структура - состав:
// * ИмяПоляПричинаОтмены        - Строка
// * ПричинаОтмены               - Неопределено
// * УдалятьСтроки               - Булево
// * КорректироватьСумму         - Булево
// * ОтменятьТолькоМерныеТовары  - Булево
// * СкорректироватьМерныеТовары - Булево
//
Функция ПараметрыОтменыСтрокЗаказов() Экспорт
```

Пример вызова
```bsl
Результат = ЗаказыСервер.ПараметрыОтменыСтрокЗаказов() 
```
</details>

## СкорректироватьСтрокиЗаказа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В зависимости от типа заказа вызывает процедуру корректировки строк и процедуры постобработки заказа.
//
// Параметры:
//  ЗаказОбъект                       - ДокументОбъект - Корректируемый заказ.
//  СтруктураДополнительныхПараметров - Структура - Структура корректировки строк заказа.
//
// Возвращаемое значение:
//  Булево - Скорректировать строки заказа
Функция СкорректироватьСтрокиЗаказа(ЗаказОбъект, СтруктураДополнительныхПараметров) Экспорт
```

Пример вызова
```bsl
Результат = ЗаказыСервер.СкорректироватьСтрокиЗаказа(ЗаказОбъект, СтруктураДополнительныхПараметров) 
```
</details>

## ОтменитьНеотработанныеСтрокиПоОтгрузке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры:
// 	ДокументОбъект - ДокументОбъект
// 	ПараметрыЗаполнения - см. ПараметрыЗаполненияДляОтменыСтрок
// 	ПараметрыОтмены - см. ПараметрыОтменыСтрокЗаказов
// Возвращаемое значение:
// 	см. ЗаказыСервер.РезультатОтменыНеотработанныхСтрок
//
Функция ОтменитьНеотработанныеСтрокиПоОтгрузке(ДокументОбъект, ПараметрыЗаполнения, ПараметрыОтмены) Экспорт
```

Пример вызова
```bsl
Результат = ЗаказыСервер.ОтменитьНеотработанныеСтрокиПоОтгрузке(ДокументОбъект, ПараметрыЗаполнения, ПараметрыОтмены) 
```
</details>

## ОтменитьНеотработанныеСтрокиПоПриемке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры:
// 	ДокументОбъект - ДокументОбъект
// 	ПараметрыЗаполнения - см. ПараметрыЗаполненияДляОтменыСтрок
// 	ПараметрыОтмены - см. ПараметрыОтменыСтрокЗаказов
// Возвращаемое значение:
// 	см. ЗаказыСервер.РезультатОтменыНеотработанныхСтрок
//
Функция ОтменитьНеотработанныеСтрокиПоПриемке(ДокументОбъект, ПараметрыЗаполнения, ПараметрыОтмены) Экспорт
```

Пример вызова
```bsl
Результат = ЗаказыСервер.ОтменитьНеотработанныеСтрокиПоПриемке(ДокументОбъект, ПараметрыЗаполнения, ПараметрыОтмены) 
```
</details>

## ПеренестиВТаблицуДокументаОтмененныеСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Описание
//
// Параметры:
// 	ДокументОбъект - ДокументОбъект
// 	ТаблицаДокумента - ТабличнаяЧасть
// 	ТаблицаОтмененныхСтрок - ТаблицаЗначений:
// * Ссылка - ДокументСсылка
// * КодСтроки - Число
// * Номенклатура - СправочникСсылка.Номенклатура
// * Характеристика - СправочникСсылка.ХарактеристикиНоменклатуры
// * Склад - СправочникСсылка.Склады
// * Назначение - СправочникСсылка.Назначения
// * НазначениеСклада - СправочникСсылка.Назначения
// * Идентификатор - Число
// * Количество - Число
// * КоличествоВНакладной - Число
// * КоличествоВОрдере - Число
// * КПоступлению - Число
// 	ПараметрыОтмены - Структура:
// * ПричинаОтмены - Неопределено
// * УдалятьСтроки - Булево
// * КорректироватьСумму - Булево
// * ОтменятьТолькоМерныеТовары - Булево
// * СкорректироватьМерныеТовары - Булево
// 	ТипДвиженияЗапасов - ПеречислениеСсылка.ТипыДвиженияЗапасов
//
// Возвращаемое значение:
// 	Число
Функция ПеренестиВТаблицуДокументаОтмененныеСтроки(ДокументОбъект, ТаблицаДокумента, ТаблицаОтмененныхСтрок, ПараметрыОтмены, ТипДвиженияЗапасов) Экспорт
```

Пример вызова
```bsl
Результат = ЗаказыСервер.ПеренестиВТаблицуДокументаОтмененныеСтроки(ДокументОбъект, ТаблицаДокумента, ТаблицаОтмененныхСтрок, ПараметрыОтмены, ТипДвиженияЗапасов));
```
</details>

## РезультатОтменыНеотработанныхСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текст оповещения об операции отмены строк
//
// Параметры:
//  ОтмененоСтрок      - Число - Количество отмененных строк.
//  Модифицированность - Булево - Одноименный параметр формы, для изменения в процедуре.
//
// Возвращаемое значение:
//  Структура - текст оповещения об операции отмены строк и количество отмененных строк.
//
Функция РезультатОтменыНеотработанныхСтрок(ОтмененоСтрок, Модифицированность = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ЗаказыСервер.РезультатОтменыНеотработанныхСтрок(ОтмененоСтрок, Модифицированность);
```
</details>

## АвтоматическаяКорректировкаСтрокЗаказовМерныхТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Корректирует строки мерных товаров заказов, попавших в регистр ОчередьЗаказовККорректировкеСтрокМерныхТоваров.
// Метод регламентного задания КорректировкаСтрокЗаказовМерныхТоваров.
//
Процедура АвтоматическаяКорректировкаСтрокЗаказовМерныхТоваров() Экспорт
```

Пример вызова
```bsl
ЗаказыСервер.АвтоматическаяКорректировкаСтрокЗаказовМерныхТоваров() 
```
</details>

## ОчиститьОчередьЗаказовККорректировкеСтрокМерныхТоваровПередУдалениемДокументаПередУдалением
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОчиститьОчередьЗаказовККорректировкеСтрокМерныхТоваровПередУдалениемДокументаПередУдалением(Источник, Отказ) Экспорт
```

Пример вызова
```bsl
ЗаказыСервер.ОчиститьОчередьЗаказовККорректировкеСтрокМерныхТоваровПередУдалениемДокументаПередУдалением(Источник, Отказ) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
