---
title: Закупки вызов сервера
slug: erp-uh/закупки-вызов-сервера
---


## ДатаПоступленияПустая
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, есть ли в табличной части строки с незаполненной датой поступления в строках, которые не отменены.
//
// Параметры:
//		Объект - ДанныеФормыСтруктура - проверяемый объект
//		ИмяТЧ - Строка - имя проверяемой ТЧ.
//
// Возвращаемое значение:
//		Булево - признак наличия строк с незаполненной датой поступления.
Функция ДатаПоступленияПустая(Знач Объект, ИмяТЧ) Экспорт
```

Пример вызова
```bsl
Результат = ЗакупкиВызовСервера.ДатаПоступленияПустая(Объект, ИмяТЧ) 
```
</details>

## ТекстЗапросаПоЗаказам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Функция формирует текст запроса по данным заказов
Функция ТекстЗапросаПоЗаказам() Экспорт
```

Пример вызова
```bsl
Результат = ЗакупкиВызовСервера.ТекстЗапросаПоЗаказам());
```
</details>

## ПроверитьСовместимостьЗаказовВОдномДокументе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет возможно ли в одном документе использовать несколько различных заказов
// Если в переданных заказах отличаются реквизиты шапки, выдается сообщение об ошибке.
//
// Параметры:
// 		МассивСсылок   - Массив - заказы поставщикам, которые указаны в документе
// 		ИмяДокумента   - Строка - имя документа в метаданных, для которого осуществляется проверка
//
// Возвращаемое значение:
// 		Булево - Истина, если в переданных заказах отличаются реквизиты шапки и нельзя проводить документ с данными заказами.
//
Функция ПроверитьСовместимостьЗаказовВОдномДокументе(Знач МассивСсылок, ИмяДокумента) Экспорт
```

Пример вызова
```bsl
Результат = ЗакупкиВызовСервера.ПроверитьСовместимостьЗаказовВОдномДокументе(МассивСсылок, ИмяДокумента) 
```
</details>

## СформироватьДанныеЗаполненияПоступления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует структуру для создания поступления по одному или нескольким заказам
// Если в переданных заказах отличаются реквизиты шапки, выдается сообщение об ошибке.
//
// Параметры:
// 		МассивСсылок   - Массив - заказы поставщикам, по которым необходимо ввести поступление
// 		ИмяДокумента   - Строка - имя создаваемого на основании заказа документа в метаданных
// 		РеквизитыШапки - Структура - структура, в которую будут помещены реквизиты шапки из массива заказов
//
// Возвращаемое значение:
// 		Булево - Ложь, если в переданных заказах отличаются реквизиты шапки.
//
Функция СформироватьДанныеЗаполненияПоступления(МассивСсылок, ИмяДокумента, РеквизитыШапки) Экспорт
```

Пример вызова
```bsl
Результат = ЗакупкиВызовСервера.СформироватьДанныеЗаполненияПоступления(МассивСсылок, ИмяДокумента, РеквизитыШапки) 
```
</details>

## ЗаполнитьБанковскиеСчетаПоДоговору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет банковский счета документа по договору.
//
// Параметры:
//		Договор - СправочникСсылка.ДоговорыКонтрагентов - Договор;
//		БанковскийСчетОрганизации - СправочникСсылка.БанковскиеСчетаОрганизаций - Банковский счет организации;
//		БанковскийСчетКонтрагента - СправочникСсылка.БанковскиеСчетаКонтрагентов - Банковский счет контрагента.
//
Процедура ЗаполнитьБанковскиеСчетаПоДоговору(Договор, БанковскийСчетОрганизации = Неопределено, БанковскийСчетКонтрагента = Неопределено) Экспорт
```

Пример вызова
```bsl
ЗакупкиВызовСервера.ЗаполнитьБанковскиеСчетаПоДоговору(Договор, БанковскийСчетОрганизации, БанковскийСчетКонтрагента);
```
</details>

## ПолучитьКоличествоСоглашенийСПоставщиком
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает количество соглашений с указанным поставщиком
//
// Параметры:
//  Партнер           - СправочникСсылка.Партнеры - партнер, для которого необходимо получить количество соглашений.
//  ПараметрыОтбора   - Структура - структура с параметрами отбора соглашений.
//
// Возвращаемое значение:
//  Структура - структура, включающая условия закупок.
//
Функция ПолучитьКоличествоСоглашенийСПоставщиком(Знач Партнер, Экспорт
```

Пример вызова
```bsl
Результат = ЗакупкиВызовСервера.ПолучитьКоличествоСоглашенийСПоставщиком(Партнер, );
```
</details>

## ПолучитьУсловияЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить условия закупок.
//
// Параметры:
//  Соглашение - СправочникСсылка.СоглашенияСПоставщиками - соглашение,по которому необходимо получить стандартные
//                                                          условия закупок.
//  УчитыватьГруппыСкладов - Булево - Учитывать группы складов
//  ИсключитьГруппыСкладовДоступныеВЗаказах - Булево - Исключить группы складов доступные в заказах
//
// Возвращаемое значение:
//  Структура - структура, включающая условия закупок.
Функция ПолучитьУсловияЗакупок(Знач Соглашение,Знач УчитыватьГруппыСкладов = Ложь, Знач ИсключитьГруппыСкладовДоступныеВЗаказах = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ЗакупкиВызовСервера.ПолучитьУсловияЗакупок(Соглашение, УчитыватьГруппыСкладов, ИсключитьГруппыСкладовДоступныеВЗаказах);
```
</details>

## ХозяйственныеОперацииПоОсновной
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив хоз. операций - переданная хоз. операция и операции для использования в схемах "Товары в пути" и
// и "Неотфактурованные поставки".
//
// Параметры:
//  ОсновнаяХозяйственнаяОперация	 - ПеречислениеСсылка.ХозяйственныеОперации	 - основная хозяйственная операция.
//
// Возвращаемое значение:
//  Массив - массив хозяйственных операций включая основную.
//
Функция ХозяйственныеОперацииПоОсновной(ОсновнаяХозяйственнаяОперация) Экспорт
```

Пример вызова
```bsl
Результат = ЗакупкиВызовСервера.ХозяйственныеОперацииПоОсновной(ОсновнаяХозяйственнаяОперация) 
```
</details>

## ЗаполнитьСписокВыбораНомеровГТД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует список значений номеров ГТД номенклатуре, характеристике.
//
// Параметры:
//	Номенклатура - СправочникСсылка.Номенклатура - номенклатура предприятия для подбора номеров ГТД.
//	Характеристика - СправочникСсылка.ХарактеристикиНоменклатуры - характеристика номенклатуры предприятия
//																	для подбора номеров ГТД.
//	СтранаПроисхождения - СправочникСсылка.СтраныМира - страна, для подбора номеров ГТД.
//
// Возвращаемое значение:
//	СписокЗначений Из Структура - список коллекции свойств номеров ГТД со следующими свойствами:
//		* Значение - СправочникСсылка.НомераГТД - номер ГТД.
//		* ПометкаУдаления - Булево - признак пометки номера ГТД к удалению.
//
Функция ЗаполнитьСписокВыбораНомеровГТД(Номенклатура, Характеристика, СтранаПроисхождения) Экспорт
```

Пример вызова
```bsl
Результат = ЗакупкиВызовСервера.ЗаполнитьСписокВыбораНомеровГТД(Номенклатура, Характеристика, СтранаПроисхождения) 
```
</details>

## НомераГТДОбработкаПолученияПредставления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует представление для элементов справочника 'НомераГТД' со значением типа РНПТ комплекта.
//
// Параметры:
//	Данные - Структура- коллекция, содержащая значения полей, из которых формируется представление.
//	Представление - Строка- строка, в которую нужно поместить представление объекта или ссылки.
//	СтандартнаяОбработка -Булево - в данный параметр передается признак формирования стандартного представления объекта
//									или ссылки. Если в теле процедуры-обработчика установить данному параметру
//									значение Ложь, стандартная обработка события производиться не будет.
//
Процедура НомераГТДОбработкаПолученияПредставления(Данные, Представление, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ЗакупкиВызовСервера.НомераГТДОбработкаПолученияПредставления(Данные, Представление, СтандартнаяОбработка) 
```
</details>

## НомераГТДОбработкаПолученияДанныхВыбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует список выбора для поля справочника 'НомераГТД'.
//
// Параметры:
//	ДанныеВыбора - СписокЗначений Из Структура - список выбора данных элемента справочника.
//	Параметры - Структура - настройки обработки получения данных выбора элементов справочника.
//	СтандартнаяОбработка -Булево - в данный параметр передается признак получения данных выбора объекта.
//									Если в теле процедуры-обработчика установить данному параметру
//									значение Ложь, стандартная обработка события производиться не будет.
//
Процедура НомераГТДОбработкаПолученияДанныхВыбора(ДанныеВыбора, Параметры, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ЗакупкиВызовСервера.НомераГТДОбработкаПолученияДанныхВыбора(ДанныеВыбора, Параметры, СтандартнаяОбработка) 
```
</details>

## ПроверитьСопоставленнуюНоменклатуруПоставщика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Проверяет наличие в информационной базе ранее сопоставленной номенклатуры поставщика.
//
// Параметры:
//   Объект - ДанныеФормыКоллекция - документ, в котором необходимо сопоставить номенклатуру поставщика.
//
// Возвращаемое значение:
//   Булево - Истина, если необходимо выводить предупреждение о сопоставлении.
//
Функция ПроверитьСопоставленнуюНоменклатуруПоставщика(Знач Объект) Экспорт
```

Пример вызова
```bsl
Результат = ЗакупкиВызовСервера.ПроверитьСопоставленнуюНоменклатуруПоставщика(Объект) 
```
</details>

## СформироватьСписокВыбораНоменклатурыПоставщика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать см. СопоставлениеНоменклатурыКонтрагентовКлиент.СформироватьСписокВыбораНоменклатурыКонтрагента
// Формирует список значений номенклатуры поставщика по партнеру, номенклатуре, характеристике, упаковке.
//
// Параметры:
//  Партнер        - СправочникСсылка.Партнеры - поставщик, для которого необходимо сформировать список.
//  Номенклатура   - СправочникСсылка.Номенклатура - номенклатура предприятия для фильтрации номенклатуры поставщика.
//  Характеристика - СправочникСсылка.ХарактеристикиНоменклатуры - характеристика номенклатуры предприятия
//                    для фильтрации номенклатуры поставщика.
//  Упаковка       - СправочникСсылка.УпаковкиЕдиницыИзмерения - упаковка номенклатуры предприятия
//                                                                   для фильтрации номенклатуры контрагента.
//
// Возвращаемое значение:
//   Массив - номенклатура поставщика, подходящая под условия фильтрации.
//
Функция СформироватьСписокВыбораНоменклатурыПоставщика(Знач Партнер, Знач Номенклатура, Знач Характеристика) Экспорт
```

Пример вызова
```bsl
Результат = ЗакупкиВызовСервера.СформироватьСписокВыбораНоменклатурыПоставщика(Партнер, Номенклатура, Характеристика) 
```
</details>

## ПроверитьДанныеПоОтборуИПартнеру
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает результат проверки партнера в созданном договоре и документе.
//
//Параметры:
//	Договор - СправочникСсылка.ДоговорыКонтрагентов - созданный договор.
//	ДанныеОтбора - Структура - параметры отбора, зависят от документа.
//	ПартнерДокумента - СправочникСсылка.Партнеры - партнер из документа.
//	СообщениеОбОшибке - Строка - формируемое сообщение об ошибке.
//
//Возвращаемое значение:
//	Булево - признак, что проверка прошла.
//
Функция ПроверитьДанныеПоОтборуИПартнеру(Договор, ДанныеОтбора, ПартнерДокумента, СообщениеОбОшибке = "") Экспорт
```

Пример вызова
```bsl
Результат = ЗакупкиВызовСервера.ПроверитьДанныеПоОтборуИПартнеру(Договор, ДанныеОтбора, ПартнерДокумента, СообщениеОбОшибке);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
