---
title: Заполнение бухгалтерской отчетности переопределяемый
slug: erp-uh/заполнение-бухгалтерской-отчетности-переопределяемый
---


## Счет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет идентичную функцию в общем модуле "ЗаполнениеБухгалтерскойОтчетностиИтоги":
//	описывает счета, отсутствующие в ней, однако использующуюся в текущей конфигурации.
//
//	Параметры:
//		УсловныйКодСчета - Строка - код счета, как правило соответствуют коду счета из плана счетов для соответствующего счета.
//
//	Возвращаемое значение:
//		ПланСчетовСсылка.Хозрасчетный - ссылка на счет бухгалтерского учета, соотвутствующий переданному условному коду.
//			В случае отсутствия соответствия - возвращает пустую ссылку.
//
Функция Счет(УсловныйКодСчета) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.Счет(УсловныйКодСчета) 
```
</details>

## ДобавитьПредопределенныеСчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в таблицу предопределенный счет и его условный код.
//
// Параметры:
//   СчетаСУсловнымиКодами - ТаблицаЗначений
//     * Счет - ПланСчетовСсылка.Хозрасчетный
//     * УсловныйКод - Строка
//
// Пример:
//   НовыйСчет = СчетаСУсловнымиКодами.Добавить();
//   НовыйСчет.УсловныйКод = "83.11";
//   НовыйСчет.Счет = ПланСчетовСсылка.Хозрасчетный.
//
Процедура ДобавитьПредопределенныеСчета(СчетаСУсловнымиКодами) Экспорт
```

Пример вызова
```bsl
ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ДобавитьПредопределенныеСчета(СчетаСУсловнымиКодами) 
```
</details>

## ДобавитьСчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет строку условных кодов счетов счетами, используемыми только в текущей конфигурации по переданным ключам.
//
// Параметры:
//	СчетаСтрокой - Строка - перечисление условных кодов счетов, разделанных запятой (например: "60.01, 60.02");
//	КлючиСчетов - Строка - перечисление ключей счетов (разделенные запятыми), по которым будут добавлены дополнительные счета в первый параметр.
//		(например: "АвансыВыданные, НеотфактурованныеПоставки").
//
Процедура ДобавитьСчета(СчетаСтрокой, КлючиСчетов) Экспорт
```

Пример вызова
```bsl
ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ДобавитьСчета(СчетаСтрокой, КлючиСчетов) 
```
</details>

## ДобавитьСчетаВМассив
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет строку условных кодов счетов счетами, используемыми только в текущей конфигурации по переданным ключам.
//
// Параметры:
//	МассивСчетов - Массив - массив элементов с типом "ПланСчетов.Хозрасчетный";
//	КлючиСчетов - Строка - перечисление ключей счетов (разделенные запятыми), по которым будут добавлены дополнительные счета в первый параметр.
//		(например: "АвансыВыданные, НеотфактурованныеПоставки").
//
Процедура ДобавитьСчетаВМассив(МассивСчетов, КлючиСчетов) Экспорт
```

Пример вызова
```bsl
ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ДобавитьСчетаВМассив(МассивСчетов, КлючиСчетов) 
```
</details>

## ИнициализироватьПереопределяемыеПараметрыЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализация переопределяемых параметров заполнения, на основании которых будут переопределяться значения показателей и расшифровки отчетов.
//
//	Параметры:
//		КонтекстВыполнения - Структура - структура параметров, использующаяся при составлении бух. отчетности. Обязательно должна содержать следующие свойства:
//			* НачалоПериодаОтчета - Дата - начало периода, по данным которого заполняется отчет;
//			* КонецПериодаОтчета - Дата - конец периода, по данным которого заполняется отчет;
//			* Организация - СправочникСсылка.Организации - организация, по данным которой заполяется отчет;
//			* ТаблицаРасшифровки - ТаблицаЗначений - таблица расшифровки значений.
//		ИмяРаздела - Строка - имя раздела, для которого переопределяются параметры;
//		НомерРаздела - Строка - номер раздела, для которого переопределяются параметры;
//		ЭтоИП - Булево - признак того, что организация, для которой происходит заполнение, является индивидуальным предпринимателем;
//		ДатаКонцаПериодаОтчета - Дата, Неопределено - дата для определения заполнения межотчетного периода.
//	Возвращаемое значение:
//		Структура - структура со следующими свойствами:
//			* Показатели - Соответствие - в данном свойстве хранятся значения переопределяемых показателей отчета;
//			* ОбщиеПараметрыРасшифровки - Структура, использующаяся при получении настройки расшифровки переопределяемых показателей, содержит следующие свойства:
//				** Организация - СправочникСсылка.Организации - организация, по данным которой заполяется отчет;
//				** НачалоПериода - Дата - начало периода, по данным которого заполняется отчет;
//				** КонецПериода - Дата - конец периода, по данным которого заполняется отчет;
//			* ТаблицаРасшифровки - ТаблицаЗначений - получается из параметра "КонтекстВыполнения";
//			* ДанныеДляЗаполнения - Структура - содержит расчитанные данные для заполнения отчета, заполняется из параметра "КонтекстВыполнения";
//			* ИмяРаздела - Строка - параметр "ИмяРаздела";
//			* ПараметрыПереопределенияСчетов - Структура - содержит данные, необходимые для переопределения счетов, содержит следующие свойства:
//				** НачалоПериода - Дата - начало периода, по данным которого заполняется отчет;
//				** КонецПериода - Дата - конец периода, по данным которого заполняется отчет;
//				** НомерРаздела - Строка - параметр "НомерРаздела";
//				** ЗаполнятьМОБ - Булево - параметр необходимости исключения межотчетного периода;
//				** ЭтоИП - Булево - параметр "ЭтоИП".
//
Функция ИнициализироватьПереопределяемыеПараметрыЗаполнения(КонтекстВыполнения, ИмяРаздела, НомерРаздела, ЭтоИП = Неопределено, ДатаКонцаПериодаОтчета = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ИнициализироватьПереопределяемыеПараметрыЗаполнения(КонтекстВыполнения, ИмяРаздела, НомерРаздела, ЭтоИП, ДатаКонцаПериодаОтчета);
```
</details>

## ДополнитьЗначениеПоказателяПереопределяемымиПараметрами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет значение показателя отчета переопределяемыми параметрами: когда значение показателя необходимо дополнить данными счетов, используемых только в текущей конфигурации.
//	На основании параметра "НаименованиеСтроки" и свойства "ПараметрыПереопределенияСчетов" параметра "ПараметрыЗаполнения" определяются какими значениями будет дополняться,
//	и если значение ранее еще не было подсчитано оно расчитывается, после чего значение показателя дополняется полученным значением.
//
//	Параметры:
//		ПараметрыЗаполнения - Структура - см. метод "ИнициализироватьПереопределяемыеПараметрыЗаполнения";
//		ЗначениеПоказателя - Число - значение, которое будет дополнено переопределяемыми знвачениями;
//		НаименованиеСтроки - Строка - строка, для которой заполняется значение показателя, на основании переданного значения определяется
//			какими переопределяемыми параметрами будет дополняться значение показателя.
//
Процедура ДополнитьЗначениеПоказателяПереопределяемымиПараметрами(ПараметрыЗаполнения, ЗначениеПоказателя, НаименованиеСтроки) Экспорт
```

Пример вызова
```bsl
ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ДополнитьЗначениеПоказателяПереопределяемымиПараметрами(ПараметрыЗаполнения, ЗначениеПоказателя, НаименованиеСтроки) 
```
</details>

## ДобавитьСтрокуРасшифровкиПереопределяемогоПараметра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет строку расшифровки переопределяемого параметра. Вызывает для каждого переопредяемого значения метод "ДобавитьСтрокуРасшифровки"
//	общего модуля "ЗаполнениеРасшифровкаРегламентированнойОтчетности", перед этим получая все необходимые данные для переопределяемого значения.
//
//	Параметры:
//		ПараметрыЗаполнения - Структура - см. метод "ИнициализироватьПереопределяемыеПараметрыЗаполнения";
//		НаименованиеСтроки - Строка - строка, для которой заполняется значение показателя, на основании переданного значения определяется
//			какими переопределяемыми параметрами будет дополняться значение показателя;
//		ИмяОбластиПоказателя - Строка - имя параметра в макете, по которому будет заполняться расшифровка;
//		НаименованиеПоказателя - Строка - если требуется переопределить наименование.
//
Процедура ДобавитьСтрокуРасшифровкиПереопределяемогоПараметра(ПараметрыЗаполнения, НаименованиеСтроки, ИмяОбластиПоказателя, НаименованиеПоказателя = "") Экспорт
```

Пример вызова
```bsl
ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ДобавитьСтрокуРасшифровкиПереопределяемогоПараметра(ПараметрыЗаполнения, НаименованиеСтроки, ИмяОбластиПоказателя, НаименованиеПоказателя);
```
</details>

## ПредопределенныеСчетаРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает счета расходов, используемые в текущей конфигурации.
//
// Возвращаемое значение:
//  Массив из ПланСчетовСсылка.Хозрасчетный - предопределенные значения счетов расходов
Функция ПредопределенныеСчетаРасходов() Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ПредопределенныеСчетаРасходов() 
```
</details>

## УстановитьПолныйТекстЗапроса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет текст запроса с учетом особенностей текущей конфигурации.
//
//	Параметры:
//		ИсходныйЗапрос - Запрос;
//
Процедура УстановитьПолныйТекстЗапроса(ИсходныйЗапрос) Экспорт
```

Пример вызова
```bsl
ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.УстановитьПолныйТекстЗапроса(ИсходныйЗапрос) 
```
</details>

## ПредопределенныйЭлемент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получение предопределенного элемента. Требует переопределения, так как некоторые предопределенные элементы могут быть недоступны в текущей конфигурации.
//
// Параметры:
//  ИмяПредопределенногоЭлемента - Строка - Имя предопределенного элемента, используемое в функции ОбщегоНазначенияКлиентСервер.ПредопределенныйЭлемент().
//
// Возвращаемое значение:
//  ЛюбаяСсылка, Массив из ПланВидовХарактеристикСсылка, Булево - Любые значения предопределенных элементов.
//
Функция ПредопределенныйЭлемент(ИмяПредопределенногоЭлемента) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ПредопределенныйЭлемент(ИмяПредопределенногоЭлемента) 
```
</details>

## ПереопределитьИсточникиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПереопределитьИсточникиДанных(ТекстЗапроса) Экспорт
```

Пример вызова
```bsl
ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ПереопределитьИсточникиДанных(ТекстЗапроса));
```
</details>

## ПараметрыОбработкиПереопределяемыхСчетовПоНаименованиюСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПараметрыОбработкиПереопределяемыхСчетовПоНаименованиюСтроки(НаименованиеСтроки, Параметры) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ПараметрыОбработкиПереопределяемыхСчетовПоНаименованиюСтроки(НаименованиеСтроки, Параметры));
```
</details>

## ТекстЗапросаВТ_ПрочиеДоходыИРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекстЗапросаВТ_ПрочиеДоходыИРасходы() Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ТекстЗапросаВТ_ПрочиеДоходыИРасходы());
```
</details>

## ТекстЗапросаВТ_ДоговорыКонтрагентов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекстЗапросаВТ_ДоговорыКонтрагентов() Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ТекстЗапросаВТ_ДоговорыКонтрагентов());
```
</details>

## ТекстЗапросаВТ_ПереводыВКраткосрочные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекстЗапросаВТ_ПереводыВКраткосрочные() Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ТекстЗапросаВТ_ПереводыВКраткосрочные());
```
</details>

## ТекстЗапросаВТ_ВсеСФПолученные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекстЗапросаВТ_ВсеСФПолученные(ИсходныйЗапрос) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ТекстЗапросаВТ_ВсеСФПолученные(ИсходныйЗапрос));
```
</details>

## ТекстЗапросаВТ_ВсеСФВыданные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекстЗапросаВТ_ВсеСФВыданные(ИсходныйЗапрос) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ТекстЗапросаВТ_ВсеСФВыданные(ИсходныйЗапрос));
```
</details>

## ТекстЗапросаВТ_РасходыБудущихПериодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекстЗапросаВТ_РасходыБудущихПериодов() Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ТекстЗапросаВТ_РасходыБудущихПериодов() 
```
</details>

## ТекстЗапросаВТ_ДанныеКонтрагентов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекстЗапросаВТ_ДанныеКонтрагентов() Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ТекстЗапросаВТ_ДанныеКонтрагентов());
```
</details>

## ТекстЗапросаВТ_ДокументыМодернизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекстЗапросаВТ_ДокументыМодернизации() Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ТекстЗапросаВТ_ДокументыМодернизации());
```
</details>

## ПереопределитьЗапросСтруктураНДСвДДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПереопределитьЗапросСтруктураНДСвДДС(Запрос) Экспорт
```

Пример вызова
```bsl
ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ПереопределитьЗапросСтруктураНДСвДДС(Запрос) 
```
</details>

## ПереопределитьЗапросСтруктураДДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПереопределитьЗапросСтруктураДДС(Запрос) Экспорт
```

Пример вызова
```bsl
ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ПереопределитьЗапросСтруктураДДС(Запрос) 
```
</details>

## ДополнитьАлгоритмыБО2019Кв1БалансERP
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьАлгоритмыБО2019Кв1БалансERP(Алгоритмы, ПараметрыЗаполнения) Экспорт
```

Пример вызова
```bsl
ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ДополнитьАлгоритмыБО2019Кв1БалансERP(Алгоритмы, ПараметрыЗаполнения));
```
</details>

## ДополнитьАлгоритмыБО2011Кв4БалансERP
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьАлгоритмыБО2011Кв4БалансERP(ПроцессорПоказателя, НаименованиеСтроки, Раздел) Экспорт
```

Пример вызова
```bsl
ЗаполнениеБухгалтерскойОтчетностиПереопределяемый.ДополнитьАлгоритмыБО2011Кв4БалансERP(ПроцессорПоказателя, НаименованиеСтроки, Раздел));
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
