---
title: Заполнение документов ВЕТИС
slug: erp-uh/заполнение-документов-ветис
---


## ПараметрыЗаполненияЗаписейСкладскогоЖурнала
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует параметры, которые используются в функции ЗаполнитьЗаписиСкладскогоЖурнала.
//
// Возвращаемое значение:
//  Структура - Параметры заполнения записей складского журнала:
// * ИмяПоляИдентификаторСтроки - Строка - путь к полю ключа строки
// * ИмяПоляКоличество          - Строка - путь к полю Количество в строке
// * ИмяПоляКоличествоВЕТИС     - Строка - путь к полю Количество ВетИС в строке
// * ЭтоИнвентаризация          - Булево - флаг инвентаризации (особая механика отрицательного количества)
// * ПодбиратьЗаписиСИстекшимСрокомГодности - Булево - возможность указания просроченных записей журнала
Функция ПараметрыЗаполненияЗаписейСкладскогоЖурнала() Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеДокументовВЕТИС.ПараметрыЗаполненияЗаписейСкладскогоЖурнала() 
```
</details>

## ЗаполнитьЗаписиСкладскогоЖурнала
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//  Структура - Содержит свойства:
//  * СообщениеПользователю  - Содержит сообщение о результатах заполнения.
//  * ИзмененныеСтроки  - Массив, в которых не удалось заполнить реквизит.
//

// Заполняет реквизит ЗаписьСкладскогоЖурнала в табличной части документа на основании остатков продукции.
//
// Параметры:
//  Товары               - ТабличнаяЧасть, ДанныеФормыКоллекция        - Табличная часть документа.
//  ХозяйствующийСубъект - СправочникСсылка.ХозяйствующиеСубъектыВЕТИС - Хозяйствующий субъект.
//  Предприятие          - СправочникСсылка.ПредприятияВЕТИС           - Предприятие.
//  СписокСтрок          - Массив Из ДанныеФормыЭлементКоллекции, Неопределено - Строки, в которых надо заполнить реквизиты.
//  ПараметрыЗаполнения  - См. ПараметрыЗаполненияЗаписейСкладскогоЖурнала
//
// Возвращаемое значение:
//  Структура - результат заполнения:
// * ВсегоСтрок - Число - обработано строк
// * ЗаполненоСтрок - Число - строк с заполненными записями
// * ПроблемныхСтрок - Число - строк с незаполненными записями
// * ИзмененныеСтроки - Массив Из ДанныеФормыЭлементКоллекции - измененные строки
// * НоменклатураНеЗаполнена - Число - строк с незаполненной номенклатурой
// * КоличествоНеЗаполнено - Число - строк с незаполненной продукцией ВетИС
// * СообщениеПользователю - Произвольный, Неопределено - описание выполненной обработки
Функция ЗаполнитьЗаписиСкладскогоЖурнала(Товары, ХозяйствующийСубъект, Предприятие, СписокСтрок, ПараметрыЗаполнения) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеДокументовВЕТИС.ЗаполнитьЗаписиСкладскогоЖурнала(Товары, ХозяйствующийСубъект, Предприятие, СписокСтрок, ПараметрыЗаполнения) 
```
</details>

## ДокументОснованиеПоДаннымСвязанныхДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определеяет предполагаемый документ-основание, на основании данных по связанным документам.
//	Сопоставляет данные из ТЗ "СвязанныеДокументы" и ВТ "ДокументыИнформационнойБазы" (см.  ИнтеграцияВЕТИСПереопределяемый.ЗаполнитьВременнуюТаблицуСвязанныхДокументовИнформационнойБазы)
//	по номеру и дате, после чего возвращает первый найденный документ информационной базы, упорядочивая их по полю "ПоказательУпорядочивания"  ВТ "ДокументыИнформационнойБазы"
//	Параметры:
//		СвязанныеДокументы - ТаблицаЗначений - таблица с колонками:
//			* ТипДокумента - ПеречислениеСсылка.ТипыДокументовВЕТИС - тип документа ВЕТИС, служит для определения типа связи с документами ИБ;
//			* Дата - Дата - дата входящего документа, по которой будут сопоставляться данные документов ИБ и данные связанных документов;
//			* Номер - Строка - номер входящего документа, по которому будут сопоставляться данные документов ИБ и данные связанных документов;
//	Возвращаемое значение:
//		ДокументСсылка, Неопределено - возвращает значение неопределено, если по номеру и дате не найдено ни одного документа ИБ, в противном случае - ссылка на найденный документ.
//
Функция ДокументОснованиеПоДаннымСвязанныхДокументов(СвязанныеДокументы) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеДокументовВЕТИС.ДокументОснованиеПоДаннымСвязанныхДокументов(СвязанныеДокументы) 
```
</details>

## ЗаполнитьДатыПоСтатистике
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет один из реквизитов (дату прозводства/срок годности) по другому по полученной статистике
//   * Не изменяет заполненные значения
//   * Срок годности с точностью до часа (скоропорт) устанавливается только по аналогично заполненной второй точности
//
// Параметры:
//   РеквизитыСтрокиТовары - Структура    - реквизиты строки для заполнения статистически взаимозависимых полей
//   Статистика            - См. ЗаполнениеОбъектовПоСтатистикеВЕТИС.СрокГодностиПоПродукции
//
Процедура ЗаполнитьДатыПоСтатистике(РеквизитыСтрокиТовары, Статистика) Экспорт
```

Пример вызова
```bsl
ЗаполнениеДокументовВЕТИС.ЗаполнитьДатыПоСтатистике(РеквизитыСтрокиТовары, Статистика) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
