---
title: Заполнение объектов по статистике
slug: erp-uh/заполнение-объектов-по-статистике
---


## ЗаполнитьРеквизитыОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет реквизиты объекта по статистике их использования.
//
// Параметры:
//  Объект - ДокументОбъект - Объект, реквизиты которого необходимо заполнить:
//  	* ДополнительныеСвойства - Структура - Дополнительные свойства объекта:
//  		** ОтключитьЗаполнениеОбъектаПоСтатистике - Булево - Истина, если необходимо отключить заполнение реквизитов по статистике.
//  		                                                     Например, в сценарии загрузки объектов из другой системы.
//  ДанныеЗаполнения - Произвольный - значение, на основании которого выполняется заполнение объекта.
//  ОписаниеЗаполняемыхРеквизитов - См. ЗаполнениеОбъектовПоСтатистике.ДобавитьОписаниеЗаполняемыхРеквизитов
//      Если параметр не задан, то описание реквизитов будет получено из функции
//      ЗадатьОписаниеЗаполняемыхРеквизитовПоСтатистике() определенной в модуля менеджера объекта.
//
// Возвращаемое значение:
//  Структура - реквизиты объекта, которые были заполнены по статистике,
//      где Ключ - имя реквизита, а Значение - его новое значение.
//
Функция ЗаполнитьРеквизитыОбъекта(Объект, ДанныеЗаполнения, ОписаниеЗаполняемыхРеквизитов = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеОбъектовПоСтатистике.ЗаполнитьРеквизитыОбъекта(Объект, ДанныеЗаполнения, ОписаниеЗаполняемыхРеквизитов);
```
</details>

## ЗаполнитьПодчиненныеРеквизитыОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет реквизиты объекта по статистике их использования,
// которые были подчинены указанному ключевому реквизиту в описании заполняемых реквизитов объекта.
//
// Параметры:
//  Объект - ДокументОбъект - объект, реквизиты которого необходимо заполнить
//  КлючевойРеквизит - Строка - имя реквизита объекта, подчиненные реквизиты которого надо заполнить по статистике.
//  ОписаниеЗаполняемыхРеквизитов - См. ЗаполнениеОбъектовПоСтатистике.ДобавитьОписаниеЗаполняемыхРеквизитов
//      Если параметр не задан, то описание реквизитов будет получено из функции
//      ЗадатьОписаниеЗаполняемыхРеквизитовПоСтатистике() определенной в модуля менеджера объекта.
//
// Возвращаемое значение:
//  Структура - реквизиты объекта, которые были заполнены по статистике,
//      где Ключ - имя реквизита, а Значение - его новое значение.
//
Функция ЗаполнитьПодчиненныеРеквизитыОбъекта(Объект, КлючевойРеквизит, ОписаниеЗаполняемыхРеквизитов = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеОбъектовПоСтатистике.ЗаполнитьПодчиненныеРеквизитыОбъекта(Объект, КлючевойРеквизит, ОписаниеЗаполняемыхРеквизитов);
```
</details>

## ПолучитьЗначенияРеквизитов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает значения реквизитов по статистике их использования в конкретном типе объекта.
//
// Параметры:
//  Ссылка - ЛюбаяСсылка - ссылка на объект определяющий тип, по реквизитам которого необходимо получить значения
//  ОписаниеЗаполняемыхРеквизитов - См. ЗаполнениеОбъектовПоСтатистике.ДобавитьОписаниеЗаполняемыхРеквизитов
//  ДанныеКлючевыхРеквизитов - Структура - значения ключевых реквизитов, в пределах которых собирается статистика.
//
// Возвращаемое значение:
//  Структура - реквизиты, для которых были получены значения по статистике,
//      где Ключ - имя реквизита, а Значение - его значение.
//
Функция ПолучитьЗначенияРеквизитов(Ссылка, ОписаниеЗаполняемыхРеквизитов, ДанныеКлючевыхРеквизитов = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеОбъектовПоСтатистике.ПолучитьЗначенияРеквизитов(Ссылка, ОписаниеЗаполняемыхРеквизитов, ДанныеКлючевыхРеквизитов);
```
</details>

## ПараметрыЗаполняемыхРеквизитов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция-конструктор параметров заполняемых по статистике использования реквизитов объекта.
// Позволяет задать связь заполняемых реквизитов с "ключевыми" реквизитами объекта и, исходя из их значений,
// использовать их как разрезы и/или условия для сбора статистики использования.
//
// Возвращаемое значение:
//  Структура:
//     * РазрезыСбораСтатистики - Структура - список полей, задающих фильтр для получения объектов, по которым будет собираться статистика:
//         * ИспользоватьВсегда - Строка - имена ключевых реквизитов, разделенные запятыми,
//               которые участвуют в отборе объектов для сбора статистики всегда
//         * ИспользоватьТолькоЗаполненные - Строка - имена ключевых реквизитов, разделенные запятыми,
//               которые участвуют в отборе объектов для сбора статистики, только если они заполнены
//     * ЗаполнятьПриУсловии - Структура - список условий, допускающий заполнение реквизитов по статистике
//         * ПоляОбъектаЗаполнены - Строка - имена ключевых реквизитов, разделенные запятыми,
//               которые должны быть заполнены для начала сбора статистики
//         * ПоляОбъектаПусты - Строка - имена ключевых реквизитов, разделенные запятыми,
//               которые должны быть пусты для начала сбора статистики.
//
Функция ПараметрыЗаполняемыхРеквизитов() Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеОбъектовПоСтатистике.ПараметрыЗаполняемыхРеквизитов() 
```
</details>

## ДобавитьОписаниеЗаполняемыхРеквизитов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в структуру описания информацию о заполняемых реквизитах объекта и их связи с ключевыми реквизитами,
// в пределах которых собирается статистика использования.
//
// Параметры:
//  ОписаниеЗаполняемыхРеквизитов - Структура - переменная, в которой хранится описание заполняемых реквизитов
//  ИменаРеквизитов - Строка - имена реквизитов, разделенные запятыми, по которым добавляется описание
//  Параметры - Структура - параметры заполняемых реквизитов
//      (см. ЗаполнениеОбъектовПоСтатистике.ПараметрыЗаполняемыхРеквизитов).
//
Процедура ДобавитьОписаниеЗаполняемыхРеквизитов(ОписаниеЗаполняемыхРеквизитов, ИменаРеквизитов, Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ЗаполнениеОбъектовПоСтатистике.ДобавитьОписаниеЗаполняемыхРеквизитов(ОписаниеЗаполняемыхРеквизитов, ИменаРеквизитов, Параметры);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
