---
title: Заполнение объектов по статистике ВЕТИС
slug: erp-uh/заполнение-объектов-по-статистике-ветис
---


## БлагополучиеМестностиПоПредприятию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает историю поля "Благополучие местности" по предыдущим трем документам "Исходящая транспортная операция ВетИС"
//   * Массив с элементом "Местность благополучна по заразным болезням животных", если не было документов
//   * Массив значений заполнения в иных случаях
//
// Параметры:
//   Предприятие - СправочникСсылка.ПредприятияВЕТИС - грузоотправитель
// Возвращаемое значение:
//   Массив Из Строка - значения заполнения поля "Благополучие местности" в исходящей транспортной операции ВетИС
//     по предыдущим документам площадки
//
Функция БлагополучиеМестностиПоПредприятию(Предприятие) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеОбъектовПоСтатистикеВЕТИС.БлагополучиеМестностиПоПредприятию(Предприятие) 
```
</details>

## ЦелиПоПродукцииИПолучателю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает историю поля "Цель" по предыдущим документам "Исходящая транспортная операция ВетИС" на текущего получателя
//   по группе продукции. Ограничивает доступной продукцией.
//
// Параметры:
//   Продукция                  - СправочникСсылка.ПродукцияВЕТИС             - продукция
//   НизкокачественнаяПродукция - Булево, Неопределено                        - признак низкокачественной продукции
//   ХозяйствующийСубъект       - СправочникСсылка.ХозяйствующиеСубъектыВЕТИС - грузополучатель
//   КешированныеЗначения       - ДеревоЗначений, Неопределено                - кешированные значения допустимых целей
//
// Возвращаемое значение:
//   Массив Из СправочникСсылка.ЦелиВЕТИС - значения заполнения поля "Цель" в исходящей транспортной операции ВетИС
//     по предыдущим документам грузополучателя (либо все доступные цели)
//
Функция ЦелиПоПродукцииИПолучателю(Продукция, НизкокачественнаяПродукция, ХозяйствующийСубъект, КешированныеЗначения) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеОбъектовПоСтатистикеВЕТИС.ЦелиПоПродукцииИПолучателю(Продукция, НизкокачественнаяПродукция, ХозяйствующийСубъект, КешированныеЗначения) 
```
</details>

## СкоропортящаясяПродукцияПоПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает историю поля "Скоропортящаяся продукция" по предыдущим документам "Производственная операция ВетИС"
//   по текущей продукции
//
// Параметры:
//   Продукция - Массив Из СправочникСсылка.ПродукцияВЕТИС - продукция
//
// Возвращаемое значение:
//   Массив Из СправочникСсылка.ПродукцияВЕТИС - скоропортящаяся продукции
//
Функция СкоропортящаясяПродукцияПоПродукции(Продукция) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеОбъектовПоСтатистикеВЕТИС.СкоропортящаясяПродукцияПоПродукции(Продукция) 
```
</details>

## ЭкспертизаПоПользователю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает историю полей "Экспертиза выполнена", "Ветеринарно-санитарная экспертиза" по предыдущим документам
//   "Производственная операция ВетИС" по текущему пользователю
//
// Возвращаемое значение:
//   Структура, Неопределено - значения полей "ЭкспертизаВыполнена" и "ЭкспертизаРезультат" если они совпали
//     в предыдущих документах
//
Функция ЭкспертизаПоПользователю() Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеОбъектовПоСтатистикеВЕТИС.ЭкспертизаПоПользователю() 
```
</details>

## УпаковкиВЕТИСПоПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает упаковку ВетИС по продукции и уровню упаковки по предыдущим документам "Производственная операция ВетИС"
//
// Параметры:
//   ТаблицаУпаковок - ТаблицаЗначений:
//    * Продукция       - СправочникСсылка.ПродукцияВЕТИС - продукция (ключ поиска);
//    * УровеньУпаковки - ПеречислениеСсылка.УровниУпаковокВЕТИС - уровень упаковки (ключ поиска);
//    * ИдентификаторСтроки - Строка - идентификатор заполняемой строки;
//    * УпаковкаВЕТИС - СправочникСсылка.УпаковкиВЕТИС - заполняемая колонка.
Процедура УпаковкиВЕТИСПоПродукции(ТаблицаУпаковок) Экспорт
```

Пример вызова
```bsl
ЗаполнениеОбъектовПоСтатистикеВЕТИС.УпаковкиВЕТИСПоПродукции(ТаблицаУпаковок) 
```
</details>

## СрокГодностиПоПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает срок годности продукции по предыдущим документам "Производственная операция ВетИС"
//
// Параметры:
//   Продукция - Массив Из СправочникСсылка.ПродукцияВЕТИС - продукция
//
// Возвращаемое значение:
//   Соответствие - сроки годности продукции по предыдущим документам:
//    * Ключ     - СправочникСсылка.ПродукцияВЕТИС - продукция
//    * Значение - Структура - точности заполнения даты производства и срока годности, срок годности в часах
//
Функция СрокГодностиПоПродукции(Продукция) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеОбъектовПоСтатистикеВЕТИС.СрокГодностиПоПродукции(Продукция) 
```
</details>

## СрокГодностиПоЗаписиЖурнала
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает срок годности продукции по журналу продукции ВетИС
//
// Параметры:
//   Продукция - Массив Из СправочникСсылка.ПродукцияВЕТИС - продукция
//
// Возвращаемое значение:
//   Соответствие - сроки годности продукции по предыдущим документам:
//    * Ключ     - СправочникСсылка.ПродукцияВЕТИС - продукция
//    * Значение - Структура - точности заполнения даты производства и срока годности, срок годности в часах
//
Функция СрокГодностиПоЗаписиЖурнала(Продукция) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеОбъектовПоСтатистикеВЕТИС.СрокГодностиПоЗаписиЖурнала(Продукция) 
```
</details>

## РеквизитыПеревозкиПоТранспортномуСредству
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает перевозчика и способ хранения при перевозке по реквизитам транспортного средства
//   (при полном совпадении реквизитов с одной из предыдущих перевозок, последней по дате если их несколько)
//
// Параметры:
//   РеквизитыТранспортногоСредства - Структура - реквизиты транспортного средства маршрута:
//     * ТипТранспорта - ПеречислениеСсылка.ТипыТранспортаВЕТИС,
//     * ТранспортноеСредство - ОпределяемыйТип.ТранспортныеСредстваВЕТИС,
//     * НомерТранспортногоСредства - ОпределяемыйТип.СтрокаВЕТИС,
//     * НомерАвтомобильногоПрицепа - ОпределяемыйТип.СтрокаВЕТИС,
//     * НомерАвтомобильногоКонтейнера - ОпределяемыйТип.СтрокаВЕТИС.
//
// Возвращаемое значение:
//   Структура - перевозчик и способ хранения:
//    * СпособХранения     - ПеречислениеСсылка.СпособыХраненияПриТранспортировкеВЕТИС,
//    * ПеревозчикХозяйствующийСубъект - СправочникСсылка.ХозяйствующиеСубъектыВЕТИС.
//
Функция РеквизитыПеревозкиПоТранспортномуСредству(РеквизитыТранспортногоСредства) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеОбъектовПоСтатистикеВЕТИС.РеквизитыПеревозкиПоТранспортномуСредству(РеквизитыТранспортногоСредства) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
