---
title: Заполнение фин отчетности в банки УП
slug: erp-uh/заполнение-фин-отчетности-в-банки-уп
---


## ПодготовитьОписанияСистемНалогообложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает временную таблицу, в которой перечислены системы налогообложения, которые применялись в организациях
// в течение периода.
//
// Параметры:
//   Субъекты    - Массив из СправочникСсылка.Организации - организации, описания систем налогообложения которых нужно подготовить.
//   НачалоПериода - Дата - начало анализируемого периода.
//   КонецПериода - Дата - конец анализируемого периода.
//   ОписанияСистемНалогообложения - МенеджерВременныхТаблиц - после выполнения процедуры должен содержать
//                                    таблицу ВТ_НастройкиСистемыНалогообложения, имеющую следующие колонки:
//     * Период - Дата - начало действия параметров налогообложения.
//     * Субъект - СправочникСсылка.Организации - для кого действуют параметры.
//     * СистемаНалогообложения - ПеречислениеСсылка.СистемыНалогообложения - набор параметров налогообложения.
//     * ПрименяетсяУСНДоходы, ПрименяетсяУСНДоходыМинусРасходы, ПрименяетсяУСНПатент - Булево - флаги вариантов применения УСН.
//     * ПрименяетсяНалогНаПрофессиональныйДоход - флаг учетной политики для самозанятых.
//     * ПлательщикЕНВД, ПлательщикТорговогоСбора - дополнительные флаги учетной политики.
//
Процедура ПодготовитьОписанияСистемНалогообложения(Субъекты, НачалоПериода, КонецПериода, ОписанияСистемНалогообложения) Экспорт
```

Пример вызова
```bsl
ЗаполнениеФинОтчетностиВБанкиУП.ПодготовитьОписанияСистемНалогообложения(Субъекты, НачалоПериода, КонецПериода, ОписанияСистемНалогообложения) 
```
</details>

## ПлательщикНДФЛЗаПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, являлся ли ИП плательщиком НДФЛ.
//
// Параметры:
//  Организация - СправочникСсылка.Организации - проверяемая организация.
//  НачалоПериода - Дата - начало анализируемого периода.
//  КонецПериода - Дата - конец анализируемого периода.
//
// Возвращаемое значение:
//   Булево      - Истина, если ИП хотя бы часть указанного периода был плательщиком НДФЛ.
//
Функция ПлательщикНДФЛЗаПериод(Организация, НачалоПериода, КонецПериода) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеФинОтчетностиВБанкиУП.ПлательщикНДФЛЗаПериод(Организация, НачалоПериода, КонецПериода) 
```
</details>

## ЗаполнитьРеквизитыСубъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет значения основных реквизитов субъекта фин.отчетности.
//
// Параметры:
//  Субъект      - СправочникСсылка - см. реквизит Субъект в таб.части ЭкономическиеСубъекты документа ФинОтчетВБанк.
//  РеквизитыСубъекта - Структура - см. ЗаполнениеФинОтчетностиВБанки.СписокРеквизитовСубъекта()
//
// Заполняет значения основных реквизитов субъекта фин.отчетности.
//
// Параметры:
//  Субъект      - СправочникСсылка - см. реквизит Субъект в таб.части ЭкономическиеСубъекты документа ФинОтчетВБанк.
//  РеквизитыСубъекта - Структура - см. ЗаполнениеФинОтчетностиВБанки.СписокРеквизитовСубъекта()
//
Процедура ЗаполнитьРеквизитыСубъекта(Субъект, РеквизитыСубъекта) Экспорт
```

Пример вызова
```bsl
ЗаполнениеФинОтчетностиВБанкиУП.ЗаполнитьРеквизитыСубъекта(Субъект, РеквизитыСубъекта) 
```
</details>

## ПатентыОрганизацииЗаПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготовливает список применявшихся патентов.
//
// Параметры:
//   Организация - СправочникСсылка.Организации - проверяемая организация.
//   НачалоПериода - Дата - начало анализируемого периода.
//   КонецПериода - Дата - конец анализируемого периода.
//
// Возвращаемое значение:
//   ТаблицаЗначений - содержит колонки:
//    * Ссылка - СправочникСсылка.Патенты - ссылка на патент;
//    * Наименование - Строка(50) - наименование патента в программе;
//    * ДатаНачала - Дата - день начала срока действия патента;
//    * ДатаОкончания - Дата - день окончания срока действия патента;
//    * ПотенциальноВозможныйГодовойДоход - Число - потенциальный годовой доход по патенту. Далее не используется.
//
Функция ПатентыОрганизацииЗаПериод(Организация, НачалоПериода, КонецПериода) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеФинОтчетностиВБанкиУП.ПатентыОрганизацииЗаПериод(Организация, НачалоПериода, КонецПериода) 
```
</details>

## БанковскиеСчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает список из наименований банков для использования в интерфейсе.
//
// Параметры:
//   Субъекты    - Массив из СправочникСсылка.Организации, СправочникСсылка.Контрагенты - владельцы счетов.
//   ИсключаемыеБИК - Массив из Строка - БИК банков, счета которых не должны включаться в список.
//
// Возвращаемое значение:
//   ТаблицаЗначений - список наименований банков, в которых открыты счета у субъектов.
//		* НаименованиеБанка - представление счета.
//
Функция БанковскиеСчета(Субъекты, ИсключаемыеБИК) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеФинОтчетностиВБанкиУП.БанковскиеСчета(Субъекты, ИсключаемыеБИК) 
```
</details>

## Кассы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает список касс организации для использования в интерфейсе.
//
// Параметры:
//   Субъекты    - Массив из СправочникСсылка.Организации, СправочникСсылка.Контрагенты - структурные подразделения, входящие в группу.
//   НачалоПериода - Дата - начало периода, в который счет является действующим.
//   КонецПериода - Дата - конец периода, в который счет является действующим.
//   ПараметрыОтбора - Структура - содержит дополнительные параметры для подбора касс.
//
// Возвращаемое значение:
//   ТаблицаЗначений - список касс с их свойствами:
//     * Организация - СправочникСсылка.Организации - основная организация.
//     * ОрганизацияНаименование - Строка - наименование организации.
//     * Подразделение - СправочникСсылка - обособленное подразделение.
//     * ПодразделениеНаименование - Строка - наименование обособленного подразделения.
//     * ПлатежныйАгент - Булево - признак, что касса относится к платежному агенту.
//
Функция Кассы(Субъекты, НачалоПериода, КонецПериода, ПараметрыОтбора) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеФинОтчетностиВБанкиУП.Кассы(Субъекты, НачалоПериода, КонецПериода, ПараметрыОтбора) 
```
</details>

## НалоговыеОрганы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает список налоговых органов, в которых зарегистрированы подразделения организации, для использования в интерфейсе.
//
// Параметры:
//   Субъекты    - Массив из СправочникСсылка.Организации - структурные подразделения, входящие в группу.
//   НачалоПериода - Дата - начало периода, в который счет является действующим.
//   КонецПериода - Дата - конец периода, в который счет является действующим.
//   ВидНалога   - Строка - имя налога, по которому формируется список налоговых органов: "Имущество" или "ЕНВД".
//
// Возвращаемое значение:
//   СписокЗначений - содержит:
//     * Значение - СправочникСсылка.РегистрацииВНалоговомОргане - налоговый орган.
//     * Представление - Строка - наименование налогового органа.
//
Функция НалоговыеОрганы(Субъекты, НачалоПериода, КонецПериода, ВидНалога) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеФинОтчетностиВБанкиУП.НалоговыеОрганы(Субъекты, НачалоПериода, КонецПериода, ВидНалога) 
```
</details>

## СсылкаНаОбъектПоИННКПП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// По переданным реквизитам подбирает организацию. Если организацию подобрать не удалось, то контрагента.
//
// Параметры:
//  ИНН          - Строка - налоговый идентификатор.
//  КПП          - Строка - налоговый идентификатор организации.
//
// Возвращаемое значение:
//   СправочникСсылка.Организации, СправочникСсылка.Контрагенты - возвращаемый параметр. Приоритет у организации.
//
Функция СсылкаНаОбъектПоИННКПП(ИНН, КПП) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеФинОтчетностиВБанкиУП.СсылкаНаОбъектПоИННКПП(ИНН, КПП) 
```
</details>

## ИмяВариантаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Для переданного отчета подбирает вариант настроек по-умолчанию для включения в пакет отчетов.
//
// Параметры:
//  ИдентификаторОтчета - Строка - имя объекта метаданных-отчета в конфигурации.
//
// Возвращаемое значение:
//  Строка - имя варианта отчета, всегда доступного в конфигурации.
//
Функция ИмяВариантаПоУмолчанию(ИдентификаторОтчета) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеФинОтчетностиВБанкиУП.ИмяВариантаПоУмолчанию(ИдентификаторОтчета) 
```
</details>

## ПодготовитьОтчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Без открытия формы формирует табличный документ отчета.
//
// Параметры:
//  ПараметрыОтчета - Структура - см. ЗаполнениеФинОтчетностиВБанки.ПараметрыОтчетаВедомостьАмортизацииОС()
//  ПараметрыЗаполнения - Структура - см. модуль менеджера документа ФинОтчетВБанк, процедура ЗаполнитьОтчетыВФоне()
//
// Возвращаемое значение:
//  Структура - см. БухгалтерскиеОтчетыВызовСервера.РезультатФормированияОтчета()
//
Функция ПодготовитьОтчет(ПараметрыОтчета, ПараметрыЗаполнения) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеФинОтчетностиВБанкиУП.ПодготовитьОтчет(ПараметрыОтчета, ПараметрыЗаполнения) 
```
</details>

## СформироватьОтчетКассоваяКнига
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует печатную форму "Кассовая книга".
//
// Параметры:
//  ПараметрыОтчета - Структура - см. ЗаполнениеФинОтчетностиВБанки.ПараметрыОтчетаКассоваяКнига()
//  ТипФайла     - Строка - имя значения ТипФайлаПакетаОтображаемыхДокументов.
//
// Возвращаемое значение:
//   Структура - см. ЗаполнениеФинОтчетностиВБанки.НовыйВозвращаемыеПараметры()
//
Функция СформироватьОтчетКассоваяКнига(ПараметрыОтчета, ТипФайла) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеФинОтчетностиВБанкиУП.СформироватьОтчетКассоваяКнига(ПараметрыОтчета, ТипФайла) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
