---
title: Заполнение форм статистики
slug: erp-uh/заполнение-форм-статистики
---


## ЗаполнитьФормуСтатистики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет переданную в виде контейнера структуру данных отчета.
//
// Параметры:
//	- Контейнер         - Структура - модифицируемый параметр; данные отчета которые нужно заполнить.
//	- ИмяОтчета         - Строка    - идентификатор отчета (имя отчета в метаданных).
//	- ИмяРедакцииОтчета - Строка    - идентификатор редакции отчета (имя формы в метаданных).
// 	- ПараметрыОтчета   - Структура - структура параметров отчета, должна содержать ключи:
//		- Организация 						  - СправочникСсылка.Организации.
//		- мДатаНачалаПериодаОтчета 			  - Дата.
//		- мДатаКонцаПериодаОтчета 			  - Дата.
//		- Периодичность			 			  - ПеречислениеСсылка.Периодичность.
//		- АдресВременногоХранилищаРасшифровки - Строка.
//
Процедура ЗаполнитьФормуСтатистики(Контейнер, Знач ИмяОтчета, Знач ИмяРедакцииОтчета, ПараметрыОтчета) Экспорт
```

Пример вызова
```bsl
ЗаполнениеФормСтатистики.ЗаполнитьФормуСтатистики(Контейнер, ИмяОтчета, ИмяРедакцииОтчета, ПараметрыОтчета) 
```
</details>

## НовыйОписаниеПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует коллекцию с описаниями показателей.
// Возвращаемое значение:
//	- ТаблицаЗначений:
//	* ИмяПоля - Строка -Имя поля. Как правило, начинается с символа "П" и содержит 13 знаков.
//	* ОбъектНаблюдения - СправочникСсылка.ОбъектыСтатистическогоНаблюдения -
//		Объект наблюдения источник информации для заполнения показателя.
//	* ИсточникДанных - ПеречислениеСсылка.ИсточникиДанныхСтатистическихПоказателей -
//		Свойство настраиваемого объекта наблюдения.
//	* Характеристика - Строка - Характеристика объекта наблюдения.
//	* ОбщаяНастройка - Строка - Свойство объекта наблюдения, XML-представление настройки (отбора),
//		заданного для объекта наблюдения.
//	* Настройка - Строка - Свойство объекта наблюдения, XML-представление пользовательской настройки.
//	* Детализировать - Булево - Некоторые объекты могут характеризоваться списком показателей.
//	* Аналитика - ТипыКлассификаторов - Значение элемента списка, характеризующего объект.
//	* Организация - СправочникСсылка.Организации - Организация по данным которой предполагается заполнения.
//	* НачалоПериода - Дата - Дата начала периода за который нужно выбирать данные.
//	* КонецПериода - Дата - Дата конца периода за который нужно выбирать данные.
//	* ДополнительныйАлгоритм - ПеречислениеСсылка.ДополнительныеАлгоритмыЗаполненияФормСтатистики -
//		Дополнительный алгоритм который должен быть применен до или после расчета.
//	* Группировка - Булево - Признак того что, значения этого показателя должны быть сгруппированы.
//	* Значение - Число,Строка - Значение показателя.
//	* НаименованиеПоказателя - Строка -Наименование статистического показателя.
//	* ДеревоНастроек - ТаблицаЗначений - Иерархия настроек примененных для получения показателя.
//	* ПримененнаяНастройка - Строка - Итоговая настройка которая была применена.
//	* Используется - Булево - Определяет, используется ли показатель для заполнения.
//	* НастройкаИзДополнительныхАлгоритмов - Строка - Свойство объекта наблюдения, добавленное дополнительным алгоритмом.
//
Функция НовыйОписаниеПоказателей() Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеФормСтатистики.НовыйОписаниеПоказателей() 
```
</details>

## НовыйДеревоНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует коллекцию с описаниями настроек.
//	Возвращаемое значение:
//	ТаблицаЗначений:
//	* ОбъектНаблюдения - СправочникСсылка.ОбъектыСтатистическогоНаблюдения - Объект наблюдения.
//	* Отбор - Строка - XML-представление отбора.
//	* ГруппаНастроек - Число - Определяет группу настроек, в которую будет выведен отбор: 1 - "Настройки заполнения", 2 - "Предопределенные настройки".
//	* Аналитика - СправочникСсылка.КлассификаторВидовЭкономическойДеятельности,
//		СправочникСсылка.КлассификаторПродукцииПоВидамДеятельности,
//		СправочникСсылка.КлассификаторУслугНаселению,
//		Строка - Значение элемента списка, характеризующего объект.
//
Функция НовыйДеревоНастроек() Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеФормСтатистики.НовыйДеревоНастроек() 
```
</details>

## ПоказателиФормыСтатистики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает коллекцию показателей формы статистики.
// Параметры:
//	ИмяОтчета - Строка - Идентификатор регламентированного отчета (например: РегламентированныйОтчетСтатистикаФормаП1).
//	ИмяРедакцииОтчета - Строка- Идентификатор редакции регламентированного отчета отчета (например: ФормаОтчета2016Кв1).
//	Организация - СправочникСсылка.Организации - Организация для которой будут получены настройки показателей.
//	НачалоПериода - Дата - Дата начала периода отчета.
//	КонецПериода - Дата - Дата конца отчетного периода.
//	Периодичность - ПеречислениеСсылка.Периодичность - Периодичность отчета.
// Возвращаемое значение:
// ТаблицаЗначений - Коллекция показателей формы статистики с необходимыми настройками, подробнее см. НовыйОписаниеПоказателей().
//
Функция ПоказателиФормыСтатистики(ИмяОтчета, ИмяРедакцииОтчета, Организация, НачалоПериода, КонецПериода, Периодичность) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеФормСтатистики.ПоказателиФормыСтатистики(ИмяОтчета, ИмяРедакцииОтчета, Организация, НачалоПериода, КонецПериода, Периодичность) 
```
</details>

## РассчитатьЗначенияПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает значения статистических показателей - заполняет колонку Значение в переданной таблице.
//
// Параметры:
//	Показатели 						 	 - ТаблицаЗначений - данные, которые нужно рассчитать.
//              							Структура таблицы описана в НовыйОписаниеПоказателей().
//  ТаблицаРасшифровки					 - заполняется при выполнении алгоритма, предназначена для передачи даннных между разными его частями.
//											Структура таблицы описана в ЗаполнениеРасшифровкаРегламентированнойОтчетности.ДобавитьСтрокуРасшифровки().
//  ПараметрыОтчета						 - Структура - структура параметров отчета.
//  ОтборПоОбособленнымПодразделениям	 - ОтборКомпоновкиДанных или Неопределено - отбор, добавляемый в настройки отбора всех показателей
//
Процедура РассчитатьЗначенияПоказателей(Показатели, ТаблицаРасшифровки, ПараметрыОтчета, ОтборПоОбособленнымПодразделениям = Неопределено) Экспорт
```

Пример вызова
```bsl
ЗаполнениеФормСтатистики.РассчитатьЗначенияПоказателей(Показатели, ТаблицаРасшифровки, ПараметрыОтчета, ОтборПоОбособленнымПодразделениям);
```
</details>

## ЗаполнитьСписокАвтозаполняемыхПолей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет список полей формы, заполняемых автоматически.
//
// Параметры:
// 	ЗаполняемыеПоля   - Структура - коллекция полей в формате БРО (дополняется элементами).
//	ИмяОтчета         - Строка - имя отчета в метаданных.
//  ИмяРедакцииОтчета - Строка - имя формы отчета в метаданных.
//  Период            - Дата - Дата, по которой определяется список "сезонных" полей - тех, которые нужно заполнять не в каждом периоде.
//
Процедура ЗаполнитьСписокАвтозаполняемыхПолей(ЗаполняемыеПоля, Знач ИмяОтчета, ИмяРедакцииОтчета, Период) Экспорт
```

Пример вызова
```bsl
ЗаполнениеФормСтатистики.ЗаполнитьСписокАвтозаполняемыхПолей(ЗаполняемыеПоля, ИмяОтчета, ИмяРедакцииОтчета, Период) 
```
</details>

## НастраиваемыеФормыСтатистики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список форм статистики для которых может быть выполнена настройка заполнения.
// Параметры:
//	Отбор - Структура - Поля отбора форм статистики:
//	* ИмяОтчета - Строка - Имя регламентированного отчета.
//	* ИмяФормы - Строка - Версия формы регламентированного отчета.
// Возвращаемое значение:
//	ТаблицаЗначений:
//	* ИмяРегламентированногоОтчета - Строка - Имя регламентированного отчета.
//	* ФормаСтатистики - СправочникСсылка.ФормыСтатистики - Форма статистики.
//
Функция НастраиваемыеФормыСтатистики(Знач Отбор = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗаполнениеФормСтатистики.НастраиваемыеФормыСтатистики(Отбор);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
