---
title: Заявление о ввозе локализация
slug: erp-uh/заявление-о-ввозе-локализация
---


## ЗаявленияОВвозеТоваровПоОснованию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция находит заявления о ввозе товаров заданного документа-основания.
//
// Параметры:
//	ДокументОснование - ДокументСсылка - Документ, для которого необходимо найти заявление о ввозе товаров.
//	Организация - СправочникСсылка.Организации - Организация, для которой формируется заявление о ввозе товаров.
//	Проведен - Булево - Признак того, что необходимо получить проведенные документы.
//
// Возвращаемое значение:
//	ТаблицаЗначений - Таблица найденных заявлений о ввозе товаров, содержит колонки:
//		* Ссылка - ДокументСсылка.ЗаявлениеОВвозеТоваров - ссылка на документ заявление о ввозе товаров.
//		* Проведен - Булево - признак проведенности документа.
//		* Номер - Строка - номер документа заявления о ввозе товаров.
//		* Дата - Дата - дата документа заявления о ввозе товаров.
//		* Организация - СправочникСсылка.Организации - организация заявления о ввозе товаров.
//		* Контрагент - СправочникСсылка.Контрагенты - контрагент заявления о ввозе товаров.
//		* ДатаПодтвержденияОплаты - Дата - дата, когда была подтверждена оплата налога по данному заявлению.
//		* ДокументОснование - ДокументСсылка.ЗаключениеДоговораАренды, ДокументСсылка.ОтчетПереработчика2_5, ДокументСсылка.ПриобретениеТоваровУслуг, ДокументСсылка.ПриобретениеУслугПрочихАктивов - документ поступления товаров.
//
Функция ЗаявленияОВвозеТоваровПоОснованию(ДокументОснование, Организация = Неопределено, Проведен = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ЗаявлениеОВвозеЛокализация.ЗаявленияОВвозеТоваровПоОснованию(ДокументОснование, Организация, Проведен);
```
</details>

## ОбработкаПроведения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика документа
//
// Параметры:
//  Объект - ДокументОбъект - Обрабатываемый документ.
//  Отказ - Булево - Признак проведения документа.
//                   Если в теле процедуры-обработчика установить данному параметру значение Истина,
//                   то проведение документа выполнено не будет.
//  РежимПроведения - РежимПроведенияДокумента - В данный параметр передается текущий режим проведения.
//
Процедура ОбработкаПроведения(Объект, Отказ, РежимПроведения) Экспорт
```

Пример вызова
```bsl
ЗаявлениеОВвозеЛокализация.ОбработкаПроведения(Объект, Отказ, РежимПроведения) 
```
</details>

## ОбработкаПроверкиЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика документа
//
// Параметры:
//  Объект - ДокументОбъект - Обрабатываемый объект
//  Отказ - Булево - Если в теле процедуры-обработчика установить данному параметру значение Истина,
//                   то будет выполнен отказ от продолжения работы после выполнения проверки заполнения.
//  ПроверяемыеРеквизиты - Массив - Массив путей к реквизитам, для которых будет выполнена проверка заполнения.
//
Процедура ОбработкаПроверкиЗаполнения(Объект, Отказ, ПроверяемыеРеквизиты) Экспорт
```

Пример вызова
```bsl
ЗаявлениеОВвозеЛокализация.ОбработкаПроверкиЗаполнения(Объект, Отказ, ПроверяемыеРеквизиты) 
```
</details>

## ОбработкаЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика документа
//
// Параметры:
//  Объект - ДокументОбъект - Обрабатываемый объект.
//  ДанныеЗаполнения - Произвольный - Значение, которое используется как основание для заполнения.
//  СтандартнаяОбработка - Булево - В данный параметр передается признак выполнения стандартной (системной) обработки события.
//
Процедура ОбработкаЗаполнения(Объект, ДанныеЗаполнения, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ЗаявлениеОВвозеЛокализация.ОбработкаЗаполнения(Объект, ДанныеЗаполнения, СтандартнаяОбработка) 
```
</details>

## ОбработкаУдаленияПроведения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика документа
//
// Параметры:
//  Объект - ДокументОбъект - Обрабатываемый объект
//  Отказ - Булево - Признак отказа от записи.
//                   Если в теле процедуры-обработчика установить данному параметру значение Истина,
//                   то запись выполнена не будет и будет вызвано исключение.
//
Процедура ОбработкаУдаленияПроведения(Объект, Отказ) Экспорт
```

Пример вызова
```bsl
ЗаявлениеОВвозеЛокализация.ОбработкаУдаленияПроведения(Объект, Отказ) 
```
</details>

## ПередЗаписью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика документа
//
// Параметры:
//  Объект - ДокументОбъект - Обрабатываемый объект
//  Отказ - Булево - Признак отказа от записи.
//                   Если в теле процедуры-обработчика установить данному параметру значение Истина,
//                   то запись выполнена не будет и будет вызвано исключение.
//  РежимЗаписи - РежимЗаписиДокумента - В параметр передается текущий режим записи документа. Позволяет определить в теле процедуры режим записи.
//  РежимПроведения - РежимПроведенияДокумента - В данный параметр передается текущий режим проведения.
//
Процедура ПередЗаписью(Объект, Отказ, РежимЗаписи, РежимПроведения) Экспорт
```

Пример вызова
```bsl
ЗаявлениеОВвозеЛокализация.ПередЗаписью(Объект, Отказ, РежимЗаписи, РежимПроведения) 
```
</details>

## ПриЗаписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика документа
//
// Параметры:
//  Объект - ДокументОбъект - Обрабатываемый объект
//  Отказ - Булево - Признак отказа от записи.
//                   Если в теле процедуры-обработчика установить данному параметру значение Истина, то запись выполнена не будет и будет вызвано исключение.
//
Процедура ПриЗаписи(Объект, Отказ) Экспорт
```

Пример вызова
```bsl
ЗаявлениеОВвозеЛокализация.ПриЗаписи(Объект, Отказ) 
```
</details>

## ПриКопировании
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика документа
//
// Параметры:
//  Объект - ДокументОбъект - Обрабатываемый объект
//  ОбъектКопирования - ДокументОбъект - Исходный документ, который является источником копирования.
//
Процедура ПриКопировании(Объект, ОбъектКопирования) Экспорт
```

Пример вызова
```bsl
ЗаявлениеОВвозеЛокализация.ПриКопировании(Объект, ОбъектКопирования) 
```
</details>

## ДобавитьКомандуСоздатьНаОсновании
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду создания документа.
//
// Параметры:
//  КомандыСозданияНаОсновании - см. СозданиеНаОснованииПереопределяемый.ПередДобавлениемКомандСозданияНаОсновании.КомандыСозданияНаОсновании
//
Процедура ДобавитьКомандуСоздатьНаОсновании(КомандыСозданияНаОсновании) Экспорт
```

Пример вызова
```bsl
ЗаявлениеОВвозеЛокализация.ДобавитьКомандуСоздатьНаОсновании(КомандыСозданияНаОсновании) 
```
</details>

## ДобавитьКомандыОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет список команд отчетов.
//
// Параметры:
//   КомандыОтчетов - См. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
//   Параметры - См. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.Параметры
//
Процедура ДобавитьКомандыОтчетов(КомандыОтчетов, Параметры) Экспорт
```

Пример вызова
```bsl
ЗаявлениеОВвозеЛокализация.ДобавитьКомандыОтчетов(КомандыОтчетов, Параметры) 
```
</details>

## ПечатьЗаявленияОВвозеТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ Локализация

// Формирует печатную форму "Заявление о ввозе товаров и уплате косвенных налогов".
//
// Параметры:
//  МассивОбъектов  - Массив Из ДокументСсылка.ЗаявлениеОВвозеТоваров   - ссылки на объекты, которые нужно распечатать;
//  ОбъектыПечати   - СписокЗначений Из ДокументСсылка.ЗаявлениеОВвозеТоваров - значение - ссылка на объект;
//                                            представление - имя области в которой был выведен объект (выходной параметр);
//  ПараметрыВывода       - Структура       - дополнительные параметры сформированных табличных документов (выходной параметр).
//
// Возвращаемое значение:
// ТабличныйДокумент - сформированный табличный документ
//
Функция ПечатьЗаявленияОВвозеТоваров(МассивОбъектов, ОбъектыПечати) Экспорт
```

Пример вызова
```bsl
Результат = ЗаявлениеОВвозеЛокализация.ПечатьЗаявленияОВвозеТоваров(МассивОбъектов, ОбъектыПечати) 
```
</details>

## ПечатьСтатистическойФормыУчетаПеремещенияТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует печатную форму "Статистическая форма учета перемещения товаров".
//
// Параметры:
//  МассивОбъектов  - Массив Из ДокументСсылка.ЗаявлениеОВвозеТоваров   - ссылки на объекты, которые нужно распечатать;
//  ОбъектыПечати   - СписокЗначений Из ДокументСсылка.ЗаявлениеОВвозеТоваров - значение - ссылка на объект;
//                                            представление - имя области в которой был выведен объект (выходной параметр);
//  ПараметрыВывода       - Структура       - дополнительные параметры сформированных табличных документов (выходной параметр).
//
// Возвращаемое значение:
// ТабличныйДокумент - сформированный табличный документ
//
Функция ПечатьСтатистическойФормыУчетаПеремещенияТоваров(МассивОбъектов, ОбъектыПечати) Экспорт
```

Пример вызова
```bsl
Результат = ЗаявлениеОВвозеЛокализация.ПечатьСтатистическойФормыУчетаПеремещенияТоваров(МассивОбъектов, ОбъектыПечати) 
```
</details>

## ПодготовитьТаблицыСтатистическойФормыУчетаПеремещенияТоваровДляВыгрузкиПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует структуру таблиц для выгрузки "Заявление о ввозе товаров и уплате косвенных налогов".
//
// Параметры:
//  МассивДокументов  - Массив Из ДокументСсылка.ЗаявлениеОВвозеТоваров   - ссылки на выгружаемые объекты;
//
// Возвращаемое значение:
// Структура - структура с данными выгрузки, содержит:
// 		* РеквизитыШапка - Структура - данные шапки документа "Заявление о ввозе товаров и уплате косвенных налогов";
//		* ТаблицаДокументы - Структура - данные документов;
//		* ТаблицаТоварыДляВыгрузки - Структура - товары для выгрузки;
//		* ТабДокумент - ТабличныйДокумент - сформированный табличный документ
//
Функция ПодготовитьТаблицыСтатистическойФормыУчетаПеремещенияТоваровДляВыгрузкиПечати(МассивДокументов) Экспорт
```

Пример вызова
```bsl
Результат = ЗаявлениеОВвозеЛокализация.ПодготовитьТаблицыСтатистическойФормыУчетаПеремещенияТоваровДляВыгрузкиПечати(МассивДокументов) 
```
</details>

## СформироватьТекстОтраженияВРеглУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует текст запроса для отражения документа в регламентированном учете.
//
// Параметры:
//	ТекстЗапроса - Строка - Текст запроса формирования проводок
//
Процедура СформироватьТекстОтраженияВРеглУчете(ТекстЗапроса) Экспорт
```

Пример вызова
```bsl
ЗаявлениеОВвозеЛокализация.СформироватьТекстОтраженияВРеглУчете(ТекстЗапроса) 
```
</details>

## СформироватьТекстЗапросаВТОтраженияВРеглУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует текст запроса дополнительных временных таблиц,
// необходимых для отражения в регламентированном учете
//
// Параметры:
//  ТекстЗапроса - Строка - сформированный текст запроса.
Процедура СформироватьТекстЗапросаВТОтраженияВРеглУчете(ТекстЗапроса) Экспорт
```

Пример вызова
```bsl
ЗаявлениеОВвозеЛокализация.СформироватьТекстЗапросаВТОтраженияВРеглУчете(ТекстЗапроса) 
```
</details>

## ВыгрузитьЗаявлениеОВвозеТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует xml-представление печатной формы "Заявление о ввозе товаров и уплате косвенных налогов" и возвращает свойства файла выгрузки.
//
// Параметры:
// УникальныйИдентификатор - Уникальный идентификатор формы выгружаемого заявления.
//	Объект 			- ДокументСсылка.ЗаявлениеОВвозеТоваров - Ссылка на выгружаемый документ.
//	ТолькоПроверка - Булево - признак выгрузки (= Ложь) / проверки возможности выгрузки (= Истина).
//
// Возвращаемое значение:
//	- Неопределено - если не удалось сформировать файл выгрузки.
//	- Массив Из Структура - структуры с данными файлов выгрузки, содержит:
//		* АдресФайлаВыгрузки - Строка - адрес двоичных данных файла выгрузки во временном хранилище (кроме режима только проверки документа).
//		* ИмяФайлаВыгрузки - Строка - короткое имя файла выгрузки (с расширением).
//
Функция ВыгрузитьЗаявлениеОВвозеТоваров(УникальныйИдентификатор, Объект, ТолькоПроверка = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ЗаявлениеОВвозеЛокализация.ВыгрузитьЗаявлениеОВвозеТоваров(УникальныйИдентификатор, Объект, ТолькоПроверка);
```
</details>

## ВыгрузитьУчетПеремещенияТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует xml-представление печатной формы "Статистическая форма учета перемещения товаров" и возвращает свойства файла выгрузки.
//
// Параметры:
// УникальныйИдентификатор - идентификатор формы выгружаемого заявления.
//	Объект - ДокументСсылка.ЗаявлениеОВвозеТоваров - ссылка на выгружаемый документ.
//	ТолькоПроверка - Булево -  признак выгрузки (= Ложь) / проверки возможности выгрузки (= Истина).
//
// Возвращаемое значение:
//	- Неопределено - если не удалось сформировать файл выгрузки.
//	- Массив Из Структура - структуры с данными файлов выгрузки, содержит:
//		* АдресФайлаВыгрузки - Строка - адрес двоичных данных файла выгрузки во временном хранилище (кроме режима только проверки документа).
//		* ИмяФайлаВыгрузки - Строка - короткое имя файла выгрузки (с расширением).
//
Функция ВыгрузитьУчетПеремещенияТоваров(УникальныйИдентификатор, Объект, ТолькоПроверка = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ЗаявлениеОВвозеЛокализация.ВыгрузитьУчетПеремещенияТоваров(УникальныйИдентификатор, Объект, ТолькоПроверка);
```
</details>

## ОбновитьСтруктуруРеквизитовВыгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует состав параметров выгрузки электронного представления заявления.
//
// Параметры:
// СтруктураРеквизитовВыгрузки - Структура - структура параметров выгрузки, состав которой необходимо обновить.
//
Процедура ОбновитьСтруктуруРеквизитовВыгрузки(СтруктураРеквизитовВыгрузки) Экспорт
```

Пример вызова
```bsl
ЗаявлениеОВвозеЛокализация.ОбновитьСтруктуруРеквизитовВыгрузки(СтруктураРеквизитовВыгрузки) 
```
</details>

## ОбновитьДанныеРеквизитовВыгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет данные реквизитов выгрузки заявления о ввозе.
//
// Параметры:
//	СтруктураРеквизитовЗаявления	- Структура - структура реквизитов исходного заявления, содержит:
//		* Ссылка		 - ДокументСсылка.ЗаявлениеОВвозеТоваров - ссылка на выгружаемый документ.
//		* Дата		 	 - Дата - дата заявления.
//		* Организация	 - СправочникСсылка.Организации - организация заявления.
//		* СтруктураРеквизитовВыгрузки - Структура - реквизит формы ЗаявлениеОВвозе.
//
// Возвращаемое значение:
//	- Структура - данные реквизитов выгрузки.
//
Функция ОбновитьДанныеРеквизитовВыгрузки(СтруктураРеквизитовЗаявления) Экспорт
```

Пример вызова
```bsl
Результат = ЗаявлениеОВвозеЛокализация.ОбновитьДанныеРеквизитовВыгрузки(СтруктураРеквизитовЗаявления) 
```
</details>

## ЗаполнитьОтчетностьВФТС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет соответствующий реквизит формы Заявления ранее сохраненным регламентированным отчетом.
//
// Параметры:
// 	ФормаЗаявления			- ФормаКлиентскогоПриложения - форма, из обработчика события которой происходит вызов процедуры.
//
Процедура ЗаполнитьОтчетностьВФТС(ФормаЗаявления) Экспорт
```

Пример вызова
```bsl
ЗаявлениеОВвозеЛокализация.ЗаполнитьОтчетностьВФТС(ФормаЗаявления) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
