---
title: Значение настроек повт исп
slug: erp-uh/значение-настроек-повт-исп
---


## ПолучитьБанковскийСчетКонтрагентаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает банковский счет контрагента, если он один в ИБ
// Если переданный в качестве параметра банковский счет уже заполнен - возвращает его.
// Если банковский счет не передан в качестве параметра или передан пустой,
// возвращает единственный в информационной базе банковский счет. Если банковский счет
// в базе не один - возвращает пустую ссылку на банковский счет
// Возвращает банковский счет, только если переданная форма оплаты безналичная или Неопределено.
//
// Параметры:
//  Контрагент     - СправочникСсылка.Контрагенты - Контрагент, для которой необходимо получить счет
//  ФормаОплаты    - ПеречислениеСсылка.ФормыОплаты - Форма оплаты, по которой определяется необходимость
//                   получения банковского счета.
//  БанковскийСчет - СправочникСсылка.БанковскиеСчетаКонтрагентов - Банковский счет, который нужно заполнить.
//
// Возвращаемое значение:
//  СправочникСсылка.БанковскиеСчетаКонтрагентов - банковский счет контрагента по умолчанию.
//
Функция ПолучитьБанковскийСчетКонтрагентаПоУмолчанию(Знач Контрагент, Знач ФормаОплаты = Неопределено, Знач БанковскийСчет = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПолучитьБанковскийСчетКонтрагентаПоУмолчанию(Контрагент, ФормаОплаты, БанковскийСчет);
```
</details>

## ПолучитьБанковскийСчетОрганизацииПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает банковский счет организации, если он один в ИБ
// Если переданный в качестве параметра банковский счет уже заполнен - возвращает его.
// Если банковский счет не передан в качестве параметра или передан пустой,
// возвращает единственный в информационной базе банковский счет. Если банковский счет
// в базе не один - возвращает пустую ссылку на банковский счет
// Возвращает банковский счет, только если переданная форма оплаты безналичная или не задана.
//
// Параметры:
//   СтруктураПараметров - Структура - Структура параметров для определения счета:
//     * Организация             - СправочникСсылка.Организации - Организация, для которой необходимо получить счет.
//     * ФормаОплаты             - ПеречислениеСсылка.ФормыОплаты - Форма оплаты, по которой определяется необходимость
//                                                                  получения банковского счета.
//     * БанковскийСчет          - СправочникСсылка.БанковскиеСчетаОрганизаций - Банковский счет, который нужно заполнить.
//     * Валюта                  - СправочникСсылка.Валюты - Валюта счета.
//     * НаправлениеДеятельности - СправочникСсылка.НаправленияДеятельности - желательное направление деятельности счета.
//
// Возвращаемое значение:
//   СправочникСсылка.БанковскиеСчетаОрганизаций - банковский счет организации по умолчанию.
//
Функция ПолучитьБанковскийСчетОрганизацииПоУмолчанию(СтруктураПараметров = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПолучитьБанковскийСчетОрганизацииПоУмолчанию(СтруктураПараметров);
```
</details>

## ПолучитьОрганизациюПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает организацию, если она одна в ИБ
// Если переданная в качестве параметра организация уже заполнена - возвращает ее.
// Если организация не передана в качестве параметра или передана пустая,
// возвращает единственную в информационной базе организацию. Если организация
// в базе не одна - возвращает пустую ссылку на организацию.
//
// Параметры:
//   Организация - СправочникСсылка.Организации - Организация, которую нужно заполнить.
//
// Возвращаемое значение:
//   СправочникСсылка.Организации - организация по умолчанию.
//
Функция ПолучитьОрганизациюПоУмолчанию(Знач Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПолучитьОрганизациюПоУмолчанию(Организация);
```
</details>

## ВариантКлассификацииЗадолженностиПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает вариант классификации по умолчанию.
// Если в ИБ есть только один вариант, который не помечен на удаление,
// то будет возвращена ссылка на него, иначе будет возвращена ссылка на первый созданный в справочнике элемент.
//
// Параметры:
//  ТолькоЕслиОдин - Булево - возвращает вариант, только если он один в ИБ.
//
// Возвращаемое значение:
//  СправочникСсылка.ВариантыКлассификацииЗадолженности - ссылка на вариант.
//
Функция ВариантКлассификацииЗадолженностиПоУмолчанию(ТолькоЕслиОдин = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ВариантКлассификацииЗадолженностиПоУмолчанию(ТолькоЕслиОдин);
```
</details>

## ПолучитьПодразделениеДиспетчерПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает подразделение-диспетчер, если оно одно в ИБ
// Если переданный параметр подразделение-диспетчер уже заполнен - возвращает его.
// Если подразделение-диспетчер не передано в качестве параметра или передано пустое,
//	возвращает единственное в информационной базе подразделение-диспетчер.
// Если подразделений-диспетчеров в базе несколько,
//	возвращает подразделение-диспетчер из настроек пользователя.
// Если подразделение-диспетчер не указано в настройках пользователя,
//	возвращает пустое подразделение.
//
// Параметры:
//  Подразделение - СправочникСсылка.СтруктураПредприятия - подразделение, которое нужно заполнить.
//  Пользователь - СправочникСсылка.Пользователи - ссылка на пользователя.
//
// Возвращаемое значение:
//  СправочникСсылка.СтруктураПредприятия - подразделение по умолчанию.
//
Функция ПолучитьПодразделениеДиспетчерПоУмолчанию(Знач Подразделение = Неопределено, Знач Пользователь = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПолучитьПодразделениеДиспетчерПоУмолчанию(Подразделение, Пользователь);
```
</details>

## ПолучитьСтатьюДвиженияДенежныхСредств
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает статью движения денежных средств для выбранной хозяйственной операции.
//
// Параметры:
//	ХозяйственнаяОперация - ПеречислениеСсылка.ХозяйственныеОперации - Хозяйственная операция документа.
//
// Возвращаемое значение:
// 	СправочникСсылка.СтатьиДвиженияДенежныхСредств - Предопределенная статья ДДС.
//
Функция ПолучитьСтатьюДвиженияДенежныхСредств(ХозяйственнаяОперация) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПолучитьСтатьюДвиженияДенежныхСредств(ХозяйственнаяОперация) 
```
</details>

## ПодразделениеПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает подразделение выбранного пользователя.
//
// Параметры:
//	Пользователь - СправочникСсылка.Пользователи - Текущий пользователь.
//	Подразделение - СправочникСсылка.СтруктураПредприятия
//
// Возвращаемое значение:
//	ОпределяемыйТип.Подразделение - Подразделение пользователя.
//
Функция ПодразделениеПользователя(Пользователь, Подразделение = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПодразделениеПользователя(Пользователь, Подразделение);
```
</details>

## ПолучитьОтветственногоПоСкладу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру по ответственному лицу указанного склада
//
// Параметры:
// 		Склад - СправочникСсылка.Склады
//
// Возвращаемое значение:
// 		Структура - Структура с полями:
// 		* Ответственный - СправочникСсылка.ФизическиеЛица
// 		* ОтветственныйДолжность - Строка
//
Функция ПолучитьОтветственногоПоСкладу(Склад) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПолучитьОтветственногоПоСкладу(Склад) 
```
</details>

## ИерархияГрупп
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив ссылок на группы складов, в иерархию которых входит указанный склад.
//
// Параметры:
//  Склад - СправочникСсылка.Склады - склад, для которого нужно получить массив групп.
//
// Возвращаемое значение:
//  Массив - массив ссылок на группы, в иерархию которых входит склад.
//
Функция ИерархияГрупп(Склад) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ИерархияГрупп(Склад) 
```
</details>

## ПолучитьСценарийПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает сценарий по типу плана если он один в ИБ
// Если переданная в качестве параметра Сценарий уже заполнен - возвращает его.
// Если Сценарий не передан в качестве параметра или передан пустой,
// возвращает единственный в информационной базе сценарий. Если Сценарий планирования
// в базе не один - возвращает пустую ссылку на сценарий.
//
// Параметры:
//   ТипПлана - ПеречислениеСсылка.ТипыПланов - Тип плана: план продаж, план закупок и т.д.
//   Сценарий - СправочникСсылка.СценарииТоварногоПланирования - Сценарий, который нужно заполнить.
//
// Возвращаемое значение:
//   СправочникСсылка.СценарииТоварногоПланирования - сценарий планирования по умолчанию.
//
Функция ПолучитьСценарийПоУмолчанию(Знач ТипПлана, Знач Сценарий = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПолучитьСценарийПоУмолчанию(ТипПлана, Сценарий);
```
</details>

## ПолучитьВалютуРегламентированногоУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Возвращает валюту регламентированного учета.
// Если переданная в качестве параметра валюта уже заполнена - возвращает ее.
// Если валюта не передана в качестве параметра или передан пустой,
// валюту РУ. Если валюта РУ не заполнена - возвращает пустую ссылку на валюту.
//
// Параметры:
//   Валюта - СправочникСсылка.Валюты - Валюта, которую нужно заполнить.
//
// Возвращаемое значение:
//   СправочникСсылка.Валюты - валюта по умолчанию.
//
Функция ПолучитьВалютуРегламентированногоУчета(Знач Валюта = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПолучитьВалютуРегламентированногоУчета(Валюта);
```
</details>

## ВалютаРегламентированногоУчетаОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает валюту регламентированного учета, определенную для организации.
//
// Параметры:
//   Организация - СправочникСсылка.Организации - Организация, для которой надо получить валюту регламентированного учета.
//
// Возвращаемое значение:
//   СправочникСсылка.Валюты -
//
Функция ВалютаРегламентированногоУчетаОрганизации(Знач Организация) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ВалютаРегламентированногоУчетаОрганизации(Организация) 
```
</details>

## БазоваяВалютаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает базовую валюту по умолчанию.
//
// Возвращаемое значение:
//   СправочникСсылка.Валюты -
//
Функция БазоваяВалютаПоУмолчанию() Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.БазоваяВалютаПоУмолчанию() 
```
</details>

## ВалютаУправленческогоУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает валюту управленческого учета.
//
// Возвращаемое значение:
//   СправочникСсылка.Валюты -
//
Функция ВалютаУправленческогоУчета() Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ВалютаУправленческогоУчета() 
```
</details>

## ВидЦеныПоставщикаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает вид цены поставщика если он один в ИБ.
//
// Параметры:
// 	Поставщик - СправочникСсылка.Партнеры - партнер, для которого необходимо получить вид цен.
//
// Возвращаемое значение:
// 	СправочникСсылка.ВидыЦенПоставщиков
//
Функция ВидЦеныПоставщикаПоУмолчанию(Поставщик) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ВидЦеныПоставщикаПоУмолчанию(Поставщик) 
```
</details>

## ПолучитьЦеховуюКладовуюПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТ

// Получает цеховую кладовую выбранного подразделения.
//
// Параметры:
//	Подразделение	- СправочникСсылка.СтруктураПредприятия - Подразделение для которого определяется кладовая
//	ЦеховаяКладовая	- СправочникСсылка.Склады - Ранее полученная кладовая.
//
// Возвращаемое значение:
//	СправочникСсылка.Склады - Кладовая подразделения.
//
Функция ПолучитьЦеховуюКладовуюПоУмолчанию(Подразделение, ЦеховаяКладовая = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПолучитьЦеховуюКладовуюПоУмолчанию(Подразделение, ЦеховаяКладовая);
```
</details>

## ВсеРеквизитыНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
//-- НЕ УТ

// Возвращает свойства реквизитов номенклатуры с учетом настроек сделанных
// в метаданных и определенных в модулях менеджера номенклатуры.
//
// Параметры:
//	ТипНоменклатуры - ПеречислениеСсылка.ТипыНоменклатуры - тип номенклатуры.
//	ОсобенностьУчета - ПеречислениеСсылка.ОсобенностиУчетаНоменклатуры - особенность учета номенклатуры.
//	ИспользованиеХарактеристик - ПеречислениеСсылка.ВариантыИспользованияХарактеристикНоменклатуры, Булево - вариант
//		использования номенклатуры или признак использования характеристик.
//	ИспользоватьСрокГодностиСерии - Булево - признак использования срока годности в сериях номенклатуры.
//
// Возвращаемое значение:
//	ФиксированнаяСтруктура - см. Справочники.Номенклатура.ВсеРеквизиты.
//
Функция ВсеРеквизитыНоменклатуры(ТипНоменклатуры, Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ВсеРеквизитыНоменклатуры(ТипНоменклатуры, );
```
</details>

## ВсеРеквизитыНоменклатурыТаблица
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает свойства реквизитов номенклатуры с учетом настроек сделанных
// в метаданных и определенных в модулях менеджера номенклатуры.
//
// Параметры:
//	ТипНоменклатуры - ПеречислениеСсылка.ТипыНоменклатуры - тип номенклатуры.
//	ОсобенностьУчета - ПеречислениеСсылка.ОсобенностиУчетаНоменклатуры - особенность учета номенклатуры.
//	ИспользованиеХарактеристик - ПеречислениеСсылка.ВариантыИспользованияХарактеристикНоменклатуры, Булево - вариант
//		использования номенклатуры или признак использования характеристик.
//	ИспользоватьСрокГодностиСерии - Булево - признак использования срока годности в сериях номенклатуры.
//
// Возвращаемое значение:
//	ТаблицаЗначений - колонки таблицы такие же, как свойства в структуре см. Справочники.Номенклатура.ВсеРеквизиты.
//
Функция ВсеРеквизитыНоменклатурыТаблица(ТипНоменклатуры, Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ВсеРеквизитыНоменклатурыТаблица(ТипНоменклатуры, );
```
</details>

## ВсеРеквизитыХарактеристикНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает свойства реквизитов номенклатуры с учетом настроек сделанных
// в метаданных и определенных в модулях менеджера номенклатуры.
//
// Параметры:
//	ТипНоменклатуры - ПеречислениеСсылка.ТипыНоменклатуры - тип номенклатуры.
//	ОсобенностьУчета - ПеречислениеСсылка.ОсобенностиУчетаНоменклатуры - особенность учета номенклатуры.
//
// Возвращаемое значение:
//	ФиксированнаяСтруктура - см. Справочники.ХарактеристикиНоменклатуры.ВсеРеквизиты.
//
Функция ВсеРеквизитыХарактеристикНоменклатуры(ТипНоменклатуры, ОсобенностьУчета) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ВсеРеквизитыХарактеристикНоменклатуры(ТипНоменклатуры, ОсобенностьУчета) 
```
</details>

## ВсеРеквизитыХарактеристикНоменклатурыТаблица
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает свойства реквизитов номенклатуры с учетом настроек сделанных
// в метаданных и определенных в модулях менеджера номенклатуры.
//
// Параметры:
//	ТипНоменклатуры - ПеречислениеСсылка.ТипыНоменклатуры - тип номенклатуры.
//	ОсобенностьУчета - ПеречислениеСсылка.ОсобенностиУчетаНоменклатуры - особенность учета номенклатуры.
//
// Возвращаемое значение:
//	ТаблицаЗначений - колонки таблицы такие же, как свойства в структуре
//						см. Справочники.ХарактеристикиНоменклатуры.ВсеРеквизиты.
//
Функция ВсеРеквизитыХарактеристикНоменклатурыТаблица(ТипНоменклатуры, ОсобенностьУчета) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ВсеРеквизитыХарактеристикНоменклатурыТаблица(ТипНоменклатуры, ОсобенностьУчета) 
```
</details>

## ВидЗапасовПоОтборам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Кэш для для функции Справочники.ВидыЗапасов.ВидЗапасовПоОтборам
//
// Параметры:
//  Организация - СправочникСсылка.Организации - организация, от имени которой будет оформляться реализация товаров
//  ТипЗапасов - ПеречислениеСсылка.ТипыЗапасов, Массив из ПеречислениеСсылка.ТипыЗапасов - доступные типы запасов товаров.
//  ВладелецТовара - СправочникСсылка.Организации, СправочникСсылка.Партнеры - владелец товаров.
//  Контрагент - СправочникСсылка.Организации, СправочникСсылка.Партнеры - контрагент, с которым заключается договор на реализацию товаров.
//  Соглашение - СправочникСсылка.СоглашенияСПоставщиками - соглашение, в рамках которого оформляется поступление товаров.
//  Договор - СправочникСсылка.ДоговорыКонтрагентов, СправочникСсылка.ДоговорыМеждуОрганизациями, Массив из СправочникСсылка.ДоговорыКонтрагентов, СправочникСсылка.ДоговорыМеждуОрганизациями - договор, в рамках которого оформляется реализация товаров.
//  Валюта - СправочникСсылка.Валюты - валюта, по которой осуществляются взаиморасчеты с владельцем товаров.
//  НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - тип налогообложения реализации товаров, облагаемой налогом на добавленную стоимость.
//  ГруппаФинансовогоУчета - СправочникСсылка.ГруппыФинансовогоУчетаНоменклатуры - группа финансового учета товаров.
//  ГруппаПродукции - СправочникСсылка.ГруппыАналитическогоУчетаНоменклатуры - вид продукции.
//  ВидЦены - СправочникСсылка.ВидыЦенПоставщиков - вид цены, по которой зафиксировано поступление товара.
//
// Возвращаемое значение:
//  СправочникСсылка.ВидыЗапасов
//
Функция ВидЗапасовПоОтборам(Организация, Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ВидЗапасовПоОтборам(Организация, );
```
</details>

## НалогообложениеНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать методы программного интерфейса учета НДС (УчетНДСУП, УчетНДСУПКлиент и т.д.)
//
// Возвращает налогообложение НДС по договору, направлению деятельности, организации и складу на дату.
//
// Параметры:
//	Организация - СправочникСсылка.Организации - Организация, для которой определяется система налогообложения
//	Склад - СправочникСсылка.Склады - Розничный склад, для которого определяется система налогообложения
//	Договор - СправочникСсылка.ДоговорыКонтрагентов, СправочникСсылка.ДоговорыМеждуОрганизациями - Договор, выбранный в документе
//	НаправлениеДеятельности - СправочникСсылка.НаправленияДеятельности - Направление деятельности, выбранное в документе
//	Дата - Дата - Дата определения системы налогообложения по организации и складу.
//
// Возвращаемое значение:
//  ПеречислениеСсылка.ТипыНалогообложенияНДС
//
Функция НалогообложениеНДС(Знач Организация, Знач Склад = Неопределено, Знач Договор = Неопределено, Знач НаправлениеДеятельности = Неопределено, Знач Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.НалогообложениеНДС(Организация, Склад, Договор, НаправлениеДеятельности, Дата);
```
</details>

## ПолучитьСкладПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает склад, если он один в ИБ
// Если переданный в качестве параметра склад уже заполнен - возвращает его.
// Если склад не передан в качестве параметра или передан пустой,
// возвращает единственный в информационной базе склад. Если склад
// в базе не один - возвращает пустую ссылку на склад.
//
// Параметры:
//  Склад - СправочникСсылка.Склады - Склад, который нужно заполнить.
//  УчитыватьГруппыСкладов - Булево
//  ИсключитьГруппыДоступныеВЗаказах - Булево
//
// Возвращаемое значение:
//  СправочникСсылка.Склады - склад по умолчанию.
//
Функция ПолучитьСкладПоУмолчанию(Знач Склад = Неопределено, УчитыватьГруппыСкладов = Ложь, ИсключитьГруппыДоступныеВЗаказах=Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПолучитьСкладПоУмолчанию(Склад, УчитыватьГруппыСкладов, ИсключитьГруппыДоступныеВЗаказах);
```
</details>

## ПолучитьРозничныйСкладПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает склад, если он один в ИБ.
// Если переданный в качестве параметра склад уже заполнен - возвращает его.
// Если склад не передан в качестве параметра или передан пустой,
// возвращает единственный в информационной базе склад. Если склад
// в базе не один - возвращает пустую ссылку на склад.
//
// Параметры:
//   Склад - СправочникСсылка.Склады - Склад, который нужно заполнить.
//
// Возвращаемое значение:
//  СправочникСсылка.Склады - розничный склад по умолчанию.
//
Функция ПолучитьРозничныйСкладПоУмолчанию(Знач Склад = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПолучитьРозничныйСкладПоУмолчанию(Склад);
```
</details>

## ПолучитьКассуОрганизацииПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает кассу организации, если она одна в ИБ.
// Если переданная в качестве параметра касса уже заполнена - возвращает ее.
// Если касса не передана в качестве параметра или передана пустая,
// возвращает единственную в информационной базе кассу. Если касса
// в базе не одна - возвращает пустую ссылку на кассу.
// Возвращает кассу, только если переданная форма оплаты наличная или Неопределено.
//
// Параметры:
//  СтруктураПараметров - Структура - Структура параметров для определения кассы:
//   * Организация - СправочникСсылка.Организации - Организация, для которой необходимо получить счет.
//   * ФормаОплаты - ПеречислениеСсылка.ФормыОплаты - Форма оплаты, по которой определяется необходимость получения кассы.
//   * Касса       - СправочникСсылка.Кассы - Касса, которую нужно заполнить
//   * Валюта      - СправочникСсылка.Валюты - Валюта счета
//   * НаправлениеДеятельности - СправочникСсылка.НаправленияДеятельности - желательное направление деятельности кассы.
//
// Возвращаемое значение:
//   СправочникСсылка.Кассы - касса организации по умолчанию.
//
Функция ПолучитьКассуОрганизацииПоУмолчанию(СтруктураПараметров = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПолучитьКассуОрганизацииПоУмолчанию(СтруктураПараметров);
```
</details>

## ПолучитьКонтактноеЛицоПартнераПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает контактное лицо по умолчанию, если оно одно для указанного партнера
//
// Параметры:
//  Партнер - СправочникСсылка.Партнеры - партнер, для которого необходимо получить контактное лицо.
//
// Возвращаемое значение:
//  СправочникСсылка.КонтактныеЛицаПартнеров - контактное лицо партнера по умолчанию.
//
Функция ПолучитьКонтактноеЛицоПартнераПоУмолчанию(Знач Партнер) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПолучитьКонтактноеЛицоПартнераПоУмолчанию(Партнер) 
```
</details>

## ПолучитьПрефиксыВесовыхШтрихкодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает массив префиксов весовых штрихкодов
//
// Возвращаемое значение:
//   Массив - префиксы весовых штрихкодов.
//
Функция ПолучитьПрефиксыВесовыхШтрихкодов() Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПолучитьПрефиксыВесовыхШтрихкодов() 
```
</details>

## СкладскаяГруппаНоменклатурыПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает складскую группу номенклатуры, если она одна в ИБ
// Если переданная в качестве параметра складская группа уже заполнена - возвращает ее.
// Если складская группа не передана в качестве параметра или передана пустая,
// возвращает единственную в информационной базе складскую группу. Если складская группа
// в базе не одна - возвращает пустую ссылку на складскую группу.
//
// Параметры:
//  СкладскаяГруппаНоменклатуры - СправочникСсылка.СкладскиеГруппыНоменклатуры - складская группа, которую
//                                нужно заполнить.
//
// Возвращаемое значение:
//  СправочникСсылка.СкладскиеГруппыНоменклатуры - складская группа номенклатуры по умолчанию.
//
Функция СкладскаяГруппаНоменклатурыПоУмолчанию(Знач СкладскаяГруппаНоменклатуры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.СкладскаяГруппаНоменклатурыПоУмолчанию(СкладскаяГруппаНоменклатуры);
```
</details>

## СкладскаяГруппаУпаковокПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает складскую группу упаковок, если она одна в ИБ
// Если переданная в качестве параметра складская группа уже заполнена - возвращает ее.
// Если складская группа не передана в качестве параметра или передана пустая,
// возвращает единственную в информационной базе складскую группу. Если складская группа
// в базе не одна - возвращает пустую ссылку на складскую группу.
//
// Параметры:
//  СкладскаяГруппаУпаковок - СправочникСсылка.СкладскиеГруппыУпаковок - складская группа, которую
//                            нужно заполнить.
//
// Возвращаемое значение:
//  СправочникСсылка.СкладскиеГруппыУпаковок - складская группа упаковок по умолчанию.
//
Функция СкладскаяГруппаУпаковокПоУмолчанию(Знач СкладскаяГруппаУпаковок = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.СкладскаяГруппаУпаковокПоУмолчанию(СкладскаяГруппаУпаковок);
```
</details>

## ПолучитьОбъектПланированияПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает формат магазина, если он один в ИБ/
//
// Параметры:
//   ОбъектПланирования - СправочникСсылка.ФорматыМагазинов, СправочникСсылка.Склады - объект планирования, который
//                                                                                     нужно заполнить.
//
// Возвращаемое значение:
//    СправочникСсылка.ФорматыМагазинов, СправочникСсылка.Склады - объект планирования по умолчанию.
//
Функция ПолучитьОбъектПланированияПоУмолчанию(Знач ОбъектПланирования = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПолучитьОбъектПланированияПоУмолчанию(ОбъектПланирования);
```
</details>

## ПараметрыВыбораВидаЦеныПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция-конструктор параметров выбора вида цен по умолчанию
//
// Возвращаемое значение:
// 	Структура - Структура параметров для выбора вида цен:
//      * ВидЦены                                   - СправочникСсылка.ВидыЦен - Вид цены, который нужно заполнить.
//      * ЦенаВключаетНДС                           - Булево - Признак включения НДС в цену.
//      * ИспользоватьПриПродаже                    - Булево - Выбор вида цены для продажи
//      * ИспользоватьПриПередачеМеждуОрганизациями - Булево - Выбор вида цены для передачи между организациями.
//      * ИспользоватьПриПередачеПродукцииДавальцу  - Булево - Выбор вида цены для передачи продукции давальцу.
//
Функция ПараметрыВыбораВидаЦеныПоУмолчанию() Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ПараметрыВыбораВидаЦеныПоУмолчанию() 
```
</details>

## ВидЦеныПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает вид цены, если он один в ИБ.
// Если переданный в качестве параметра вид цены уже заполнен - возвращает его.
// Если вид цены не передан в качестве параметра или передан пустой,
// возвращает единственный в информационной базе вид цены. Если видов цен
// в базе несколько - возвращает пустую ссылку на вид цены.
//
// Параметры:
//   ПараметрыВыбора - Структура - Структура параметров выбора, конструктор ЗначениеНастроекПовтИсп.ПараметрыВыбораВидаЦеныПоУмолчанию.
//
// Возвращаемое значение:
//   СправочникСсылка.ВидыЦен - вид цены по умолчанию.
//
Функция ВидЦеныПоУмолчанию(ПараметрыВыбора) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ВидЦеныПоУмолчанию(ПараметрыВыбора) 
```
</details>

## ДиапазонВесовыхШтрихкодовПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает диапазон весовых штрихкодов по умолчанию.
//
// Возвращаемое значение:
//   Строка - диапазон по умолчанию.
//
Функция ДиапазонВесовыхШтрихкодовПоУмолчанию() Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ДиапазонВесовыхШтрихкодовПоУмолчанию() 
```
</details>

## ДиапазоныВесовыхШтрихкодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив диапазонов весовых штрихкодов.
//
// Возвращаемое значение:
//  Массив - диапазоны штрихкодов.
//
Функция ДиапазоныВесовыхШтрихкодов() Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ДиапазоныВесовыхШтрихкодов() 
```
</details>

## ДиапазоныШтучныхШтрихкодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив диапазонов штучных штрихкодов.
//
// Возвращаемое значение:
//  Массив - диапазоны штрихкодов.
//
Функция ДиапазоныШтучныхШтрихкодов() Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.ДиапазоныШтучныхШтрихкодов() 
```
</details>

## КоличествоИсточниковСкидокНаценок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет сколько скидок (наценок) задействована в объектах ИБ.
//
// Возвращаемое значение:
//  Структура - структура, содержащая количество задействованных скидок (наценок) в объектах ИБ.
//
Функция КоличествоИсточниковСкидокНаценок() Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.КоличествоИсточниковСкидокНаценок() 
```
</details>

## НедоступныеДляРедактированияРеквизитыСправочника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает перечень реквизитов справочника, недоступных для изменения текущему пользователю.
//
// Параметры:
//		ИмяСправочника - Строка - имя справочника как оно задано в метаданных
//		ЭтоГруппа - Булево - проверять реквизиты группы или элемента справочника
//		НепроверяемыеРеквизиты - Строка - перечень реквизитов, которые могут быть "законно" изменены программно, при записи элемента
// Возвращаемое значение:
//		Строка - список недоступных реквизитов, разделенных запятыми.
//
Функция НедоступныеДляРедактированияРеквизитыСправочника(ИмяСправочника, ЭтоГруппа = Ложь, НепроверяемыеРеквизиты = "") Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.НедоступныеДляРедактированияРеквизитыСправочника(ИмяСправочника, ЭтоГруппа, НепроверяемыеРеквизиты);
```
</details>

## РеквизитыСправочника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру реквизитов справочника.
//
// Параметры:
//		ИмяСправочника - Строка - имя справочника как оно задано в метаданных
// Возвращаемое значение:
//		Структура - стандартные и обычные реквизиты справочника.
//
Функция РеквизитыСправочника(ИмяСправочника) Экспорт
```

Пример вызова
```bsl
Результат = ЗначениеНастроекПовтИсп.РеквизитыСправочника(ИмяСправочника) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
