---
title: Интеграция SHARE
slug: erp-uh/интеграция-share
---


## НастройкиСервисаДляПубликации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает настройки сервиса для публикации документа в сервисе 1С:Share.
// Настройки загружаются из общего хранилища настроек авторизованного пользователя.
// В случае, если сохраненных настроек нет в хранилище - выполняется запрос в сервис для получения настроек
// с последующим сохранением в общие настройки авторизованного пользователя.
//
// Параметры:
//  Отказ - Булево - признак наличия ошибок при выполнении запроса в сервисе.
//                   При наличие ошибок выполняется запись в журнал регистрации и вывод сообщения пользователю.
//                   В случае Отказ = Истина рекомендуется ссылаться на запись в журнале регистрацию.
//
// Возвращаемое значение:
//  Неопределено - в случае, если не удалось загрузить настройки.
//  Структура    - настройки сервиса:
//   * МаксимальныйРазмерПакетаВБайтах - Строка - максимальный размер транспортного пакета (zip-архива)
//                                                для публикации документа в байтах.
//
Функция НастройкиСервисаДляПубликации(Отказ) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияShare.НастройкиСервисаДляПубликации(Отказ) 
```
</details>

## ОтметитьВСервисеЗагрузкуДокументаВБазу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет в сервис 1С:Share сведения в какой объект загружен электронный документ в прикладной базе.
// Данные используются при повторной загрузки документа в базу.
//
// Параметры:
//  ПараметрыДокумента - см. ИнтеграцияShareКлиентСервер.НовыеПараметрыДокументаДляОтметкиЗагрузкиВБазу
//  Отказ - Булево - признак наличия ошибок при выполнении запроса.
//                   При наличие ошибок выполняется запись в журнал регистрации и вывод сообщения пользователю.
//
Процедура ОтметитьВСервисеЗагрузкуДокументаВБазу(Знач ПараметрыДокумента, Отказ) Экспорт
```

Пример вызова
```bsl
ИнтеграцияShare.ОтметитьВСервисеЗагрузкуДокументаВБазу(ПараметрыДокумента, Отказ) 
```
</details>

## ЕстьПравоИспользованияСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак наличия прав использования сервиса 1С:Share.
//
// Возвращаемое значение:
//  Булево - признак наличия прав доступа.
//
Функция ЕстьПравоИспользованияСервиса() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияShare.ЕстьПравоИспользованияСервиса() 
```
</details>

## ДобавитьПраваИспользованияСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в профиль роли базовых прав для использования сервиса 1С:Share.
//
// Параметры:
//  ОписаниеПрофиля - см. УправлениеДоступом.НовоеОписаниеПрофиляГруппДоступа.
//
Процедура ДобавитьПраваИспользованияСервиса(ОписаниеПрофиля) Экспорт
```

Пример вызова
```bsl
ИнтеграцияShare.ДобавитьПраваИспользованияСервиса(ОписаниеПрофиля) 
```
</details>

## СпособОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Способ обмена электронного документа через сервис 1С:Share
// для взаимодействия с подсистемой ЭлектронноеВзаимодействие.ОбменСКонтрагентами
//
// Возвращаемое значение:
//  ПеречислениеСсылка.СпособыОбменаЭД - значение "Через1CShare".
Функция СпособОбмена() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияShare.СпособОбмена() 
```
</details>

## НовыйСоставКомандShare
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, состава команд исходящих и входящих документов доступных для обмена в сервисе 1С:Share.
//
// Возвращаемое значение:
//  Структура - состав команд исходящих и входящих документов:
//   * Исходящие - Массив Из Строка - наименование объекта метаданных, которому разрешено отправление из базы через сервис.
//                                    Например: Документ.СчетНаОплатуПокупателю, Справочник.ДоговорыКонтрагентов.
//   * Входящие  - Массив Из Строка - наименование объекта метаданных, которому разрешена загрузка в базу через сервис.
//                                    Например: Документ.СчетНаОплатуПоставщика, Справочник.ДоговорыКонтрагентов.
//
Функция НовыйСоставКомандShare() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияShare.НовыйСоставКомандShare() 
```
</details>

## НовыеПараметрыПубликуемогоДокументаДляВизуализации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор параметров публикуемого документа для формирования визуализации документа.
//
// Возвращаемое значение:
//  Структура - параметры публикуемого документа для формирования визуализации документа:
//   * ОбъектУчета - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО
//   * ДвоичныеДанныеДокумента - ДвоичныеДанные - данные публикуемого документа
//   * ТипДокумента - ПеречислениеСсылка.ТипыДокументовЭДО
//   * СвойстваПредставления - Структура - свойства представления, которые при необходимости можно переопределить
//                                         при использовании стандартной обработки:
//      ** ПараметрыВизуализации  - См. ОбменСКонтрагентамиИнтеграция.НовыеПараметрыВизуализации - параметры визуализации
//                                            для формирования визуализации при стандартной обработки.
//      ** ПредставлениеДокумента  - Строка - представление публикуемого документа, отображаемое пользователю.
//
Функция НовыеПараметрыПубликуемогоДокументаДляВизуализации() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияShare.НовыеПараметрыПубликуемогоДокументаДляВизуализации() 
```
</details>

## НовыеПараметрыДляЗагрузкиДокументаВОбъектУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует параметры для загрузки электронного документа в объект учета.
//
// Возвращаемое значение:
//  Структура - параметры для загрузки документа:
//   * СпособОбмена - См. СпособОбмена
//   * ДанныеОсновногоФайла - Неопределено, См. РаботаСФайламиБЭДКлиентСервер.НовоеОписаниеФайла - данные файла
//              электронного документа.
//   * ДополнительныеФайлыДокумента - Неопределено, См. НовоеОписаниеДополнительныхФайлов
//   * ФайлыВизуализации - Массив из См. НовыйФайлВизуализации() - файлы визуализации документа.
//
Функция НовыеПараметрыДляЗагрузкиДокументаВОбъектУчета() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияShare.НовыеПараметрыДляЗагрузкиДокументаВОбъектУчета() 
```
</details>

## РасширениеФайлаДоступно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак доступности типа файла к отправке в сервис 1С:Share.
// Расширение файла проверяется на запрещенные типы из ИнтеграцияShareКлиентСервер.ЗапрещенныеРасширенияФайла.
//
// Параметры:
//  РасширениеФайла - Строка
//  ДвоичныеДанныеФайла - ДвоичныеДанные
//
// Возвращаемое значение:
//  Булево - признак поддерживаемого расширения
Функция РасширениеФайлаДоступно(Знач РасширениеФайла, Знач ДвоичныеДанныеФайла) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияShare.РасширениеФайлаДоступно(РасширениеФайла, ДвоичныеДанныеФайла) 
```
</details>

## НовыеДанныеПрисоединенногоФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор данных присоединенного файла для выбора к публикации.
//
// Возвращаемое значение:
//  Структура - содержит данные присоединенного файла:
//   * СсылкаНаФайл - ОпределяемыйТип.ПрисоединенныйФайл, Неопределено - ссылка на файл документа к публикации.
//   * Наименование - Строка - наименование файла без расширения.
//   * Расширение   - Строка - расширение файла без точки.
//
Функция НовыеДанныеПрисоединенногоФайла() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияShare.НовыеДанныеПрисоединенногоФайла() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
