---
title: Интеграция SHARE клиент переопределяемый
slug: erp-uh/интеграция-share-клиент-переопределяемый
---


## ПриОпределенииПараметровОтправкиЭлектронногоПисьма
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет содержание электронного письма при его создании с ссылкой для скачивания опубликованного документа.
//
// Параметры:
//  ПараметрыОтправки  - См. РаботаСПочтовымиСообщениямиКлиент.ПараметрыОтправкиПисьма
//  ПараметрыДокумента - Структура из См. ИнтеграцияShareКлиентСервер.НовыеДанныеОпубликованногоДокумента - набор данных электронного документа.
//
Процедура ПриОпределенииПараметровОтправкиЭлектронногоПисьма(ПараметрыОтправки, Знач ПараметрыДокумента) Экспорт
```

Пример вызова
```bsl
ИнтеграцияShareКлиентПереопределяемый.ПриОпределенииПараметровОтправкиЭлектронногоПисьма(ПараметрыОтправки, ПараметрыДокумента) 
```
</details>

## ПриОткрытииФормыВыбораФайловДокументаКПубликации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет форму выбора присоединенных файлов документа перед публикацией.
// При необходимости можно описать вызов своей формы для выбора присоединенных файлов к документу,
// либо не открывать форму для выбора файлов и описать алгоритм подбора за пользователя.
// В ином случае, будет выполнена стандартная обработка с открытием формы для выбора файлов при их наличие.
// Файлы к публикации можно переопределить через метод
// ИнтеграцияShareПереопределяемый.ПриОпределенииФайловДокументаДляВыбораКПубликации.
//
// При описании своей логики необходимо установить параметр СтандартнаяОбработка = Ложь и по завершению продолжить
// выполнение публикации, вызвав обработчик оповещения из параметра "ОповещениеОбработкиРезультатаВыборФайлов"
// с результатом выбранных файлов.
// Ожидается результат с типом "Массив из см. ИнтеграцияShareКлиентСервер.НовыеДанныеФайлаДляВыбораКПубликации".
// В случае возникновения ошибок необходимо описывать самостоятельно.
//
// Рекомендуется отбирать к выбору файлы с разрешенным расширением, используя метод см. ИнтеграцияShare.РасширениеФайлаДоступно.
// Иначе при публикации документа в сервисе возникнет ошибка.
//
// Результат с выбранными файлами к публикации формируется в пакет и проходит проверку на максимальный объем передаваемых данных.
// В случае, если проверка не прошла будет повторно вызван этот же метод, в котором будет заполнен параметр "РезультатПроверкиПакета".
//
// Пример:
//	СтандартнаяОбработка = Ложь;
//
//	Если РезультатПроверкиПакета <> Неопределено
//		И РезультатПроверкиПакета.ПревышенРазмерПакета Тогда
//		// Описание алгоритма для изменения выбранных файлов
//		...
//	Иначе
//		// Описание алгоритма выбора файлов
//		...
//	КонецЕсли
//
//	ВыбранныеФайлы = Новый Массив;
//	ВыбранныйФайл = ИнтеграцияShareКлиентСервер.НовыеДанныеФайлаДляВыбораКПубликации();
//	ВыбранныеФайлы.Добавить(ВыбранныйФайл);
//
//	1) ВыполнитьОбработкуОповещения(ОповещениеОбработкиРезультатаВыборФайлов, ВыбранныеФайлы); // В случае когда форму не требуется открывать
//	2) Передать параметры при закрытии формы: Закрыть(ВыбранныеФайлы); // В случае когда вызвали свою форму
//
// Параметры:
//  ОповещениеОбработкиРезультатаВыборФайлов - ОписаниеОповещения - метод для обработки результата выбора файлов
//              при закрытии формы. В дополнительные параметры необходио передать результат с типом
//              "Массив из см. ИнтеграцияShareКлиентСервер.НовыеДанныеФайлаДляВыбораКПубликации".
//  СсылкаНаДокумент                         - ДокументСсылка, СправочникСсылка - ссылка на документ к публикации.
//  РезультатПроверкиПакета                  - Неопределено, См. ИнтеграцияShareКлиентСервер.НовыйРезультатПроверкиПакета - результат проверки выбранных файлов.
//  СтандартнаяОбработка                     - Булево - признак стандартного выполнения загрузки. По умолчанию Истина.
//
Процедура ПриОткрытииФормыВыбораФайловДокументаКПубликации(ОповещениеОбработкиРезультатаВыборФайлов, Знач СсылкаНаДокумент, Экспорт
```

Пример вызова
```bsl
ИнтеграцияShareКлиентПереопределяемый.ПриОткрытииФормыВыбораФайловДокументаКПубликации(ОповещениеОбработкиРезультатаВыборФайлов, СсылкаНаДокумент, );
```
</details>

## ПриЗагрузкеДокументаПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет загрузку документа по данным электронного документа, полученных по публичной ссылке сервиса 1С:Share.
//
// При необходимости можно описать вызов своей формы для загрузки документа, либо сразу загружать данные документа в учетную базу.
// В случае использования своего алгоритма загрузки необходимо поддержать весь процесс чтения и загрузки электронного
// документа в учетную базу из данных транспортного контейнера. Для этого необходимо установить СтандартнаяОбработка = Ложь.
// При стандартной обработке загрузка выполняется с использованием механизмов ЭДО из подсистемы
// "ЭлектронноеВзаимодействие.ОбменСКонтрагентами", которую требуется поддержать.
// Если документ ранее уже был загружен - открывается учетный документ в базе.
//
// Примеры вариантов использования:
//	СтандартнаяОбработка = Ложь; // Устанавливается при использовании своей логики загрузки документа.
//
//	1) ОткрытьФорму("Обработка.ЗагрузкаДокумента.ОсновнаяФорма", ДанныеДокумента); // Вызываем обработку для загрузки документа.
//	и в ней описываем логику загрузки документа.
//
//	2) //В случае, если документ уже ранее загружался в базу можно открыть документ для просмотра или описать алгоритм перезаполнения документа.
//	// Поиск документа выполняется по типу метаданных и идентификатору документа из свойства ДанныеДокумента.ДанныеЗагрузкиДокумента
//	Если ЗначениеЗаполнено(ДанныеДокумента.ДанныеЗагрузкиДокумента.ОбъектУчета) Тогда
//		ПоказатьЗначение(Неопределено, ДанныеДокумента.ДанныеЗагрузкиДокумента.ОбъектУчета);
//		Возврат;
//	КонецЕсли;
//
//	3) // По своей логике описываем загрузку документа.
//	СсылкаНаОбъект = ОбщийМодульВызовСервера.ЗагрузитьДокументПоСвоейЛогике(ДанныеДокумента);
//	ПоказатьЗначение(Неопределено, СсылкаНаОбъект);
//
// Если документ был загружен в базе успешно необходимо отправить отметку в сервис:
//    ПараметрыДокумента = ИнтеграцияShareКлиентСервер.НовыеПараметрыДокументаДляОтметкиЗагрузкиВБазу();
//    ПараметрыДокумента.ОбъектУчета                        = ДанныеДокумента.ДокументУчета;
//    ПараметрыДокумента.ТипМетаданныхДокументаВладельца    =
//       Метаданные.НайтиПоТипу(ТипЗнч(ДанныеДокумента.ДокументУчета)).ПолноеИмя();
//    ПараметрыДокумента.ИдентификаторЭлектронногоДокумента = ДанныеДокумента.ИдентификаторЭлектронногоДокумента;
//    ИнтеграцияShare.ОтметитьВСервисеЗагрузкуДокументаВБазу(ПараметрыДокумента, Отказ);
//
// Параметры:
//  ДанныеДокумента      - Структура из См. ИнтеграцияShare.НовоеОписаниеДанныхЭлектронногоДокумента - данные загружаемого документа по ссылке.
//  СтандартнаяОбработка - Булево - признак стандартного выполнения загрузки. По умолчанию Истина.
//
Процедура ПриЗагрузкеДокументаПоСсылке(ДанныеДокумента, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ИнтеграцияShareКлиентПереопределяемый.ПриЗагрузкеДокументаПоСсылке(ДанныеДокумента, СтандартнаяОбработка) 
```
</details>

## ПослеЗагрузкиДокументаПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет действия после загрузки документа по ссылке.
//
// При необходимости можно вызвать свою форму для работы с присоединенными файлами после загрузки электронного документа
// в объект учета прикладной базы.
//
// Пример:
//  ОткрытьФорму("Обработка.ВыборФайловКЗагрузке.ОсновнаяФорма", ДанныеДокумента); // Вызываем обработку для отработки
//                                                                        присоединенных файлов и в ней описываем логику.
//
// Параметры:
//  ДанныеДокумента - Структура из См. ИнтеграцияShareКлиентСервер НовыеДанныеЗагруженногоДокумента
Процедура ПослеЗагрузкиДокументаПоСсылке(Знач ДанныеДокумента) Экспорт
```

Пример вызова
```bsl
ИнтеграцияShareКлиентПереопределяемый.ПослеЗагрузкиДокументаПоСсылке(ДанныеДокумента) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
