---
title: Интеграция БЗК
slug: erp-uh/интеграция-бзк
---


## ЗаполнитьСуммуНезачисленныхПлатежейПоПодтверждениюБанка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет итоговую сумму незачисленных платежей по подтверждению банка.
//
// Параметры:
//   Подтверждение - ДокументСсылка - ссылка на подтверждение банка.
//   Сумма - Число - заполняемая сумма незачисленных платежей.
//
Процедура ЗаполнитьСуммуНезачисленныхПлатежейПоПодтверждениюБанка(Подтверждение, Сумма) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБЗК.ЗаполнитьСуммуНезачисленныхПлатежейПоПодтверждениюБанка(Подтверждение, Сумма) 
```
</details>

## СформироватьВозмещениеРасходовПоСоциальномуСтрахованию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура выполняет регистрацию возмещения из ФСС расходов на пособия.
//
// Параметры:
//	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - менеджер, содержащий таблицу ДокументыКОтражению.
//	Объект - ДокументОбъект.ПоступлениеБезналичныхДенежныхСредств - Документ, если регистрация выполняется при проведении документа.
//	Отказ - Булево - Признак отказа от записи движений.
//
Процедура СформироватьВозмещениеРасходовПоСоциальномуСтрахованию(МенеджерВременныхТаблиц = Неопределено, Объект = Неопределено, Отказ = Ложь) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБЗК.СформироватьВозмещениеРасходовПоСоциальномуСтрахованию(МенеджерВременныхТаблиц, Объект, Отказ);
```
</details>

## ПроверитьЗаполнениеПоВозвратуНеперечисленнойЗарплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет заполнение поступления ДС по возврату неперечисленной зарплаты.
//
// Параметры:
// 	Объект - ДокументОбъект.ПоступлениеБезналичныхДенежныхСредств - проверяемый документ.
// 	МассивНепроверяемыхРеквизитов - Массив - массив непроверяемых реквизитов обработки проверки заполнения.
// 	Отказ - Булево - признак отказа.
//
Процедура ПроверитьЗаполнениеПоВозвратуНеперечисленнойЗарплаты(Объект, МассивНепроверяемыхРеквизитов, Отказ) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБЗК.ПроверитьЗаполнениеПоВозвратуНеперечисленнойЗарплаты(Объект, МассивНепроверяемыхРеквизитов, Отказ) 
```
</details>

## ЗаполнитьМесяцНалоговогоПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дату, соответствующую налоговому периоду, за который произведен платеж.
//
// Параметры:
//    МесяцНалоговогоПериода - Дата - заполняемая дата.
//    ПоказательОснования - Строка - Условное обозначение основания налогового платежа
//    ПоказательПериода - Строка - Условное обозначение периода, за который перечисляется налог
Процедура ЗаполнитьМесяцНалоговогоПериода(МесяцНалоговогоПериода, ПоказательОснования, ПоказательПериода) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБЗК.ЗаполнитьМесяцНалоговогоПериода(МесяцНалоговогоПериода, ПоказательОснования, ПоказательПериода) 
```
</details>

## ДанныеВедомостей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция данные ведомостей для заполнения платежных документов.
//
// Параметры:
//   ПараметрыОтбора - Структура - структура с параметрами отбора ведомостей.
//   МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - менеджер временных таблиц.
//
// Возвращаемое значение:
//   Структура   - структура со значениями РеквизитыШапки и МассивОшибок.
//
Функция ДанныеВедомостей(ПараметрыОтбора, МенеджерВременныхТаблиц = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБЗК.ДанныеВедомостей(ПараметрыОтбора, МенеджерВременныхТаблиц);
```
</details>

## ДанныеОбОплатеВедомостей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура формирует временную таблицу физических лиц по ведомостям различных типов в соответствии с параметрами.
//
// Параметры:
//	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - Менеджер временных таблиц
//	Параметры - Структура - Структура параметров.
//
Процедура ДанныеОбОплатеВедомостей(МенеджерВременныхТаблиц, Параметры) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБЗК.ДанныеОбОплатеВедомостей(МенеджерВременныхТаблиц, Параметры) 
```
</details>

## ЗаполнитьКраткийСоставФизЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразовывает переданный массив физических лиц в строку.
// Используется для представления краткого состава документов.
//
// Параметры:
//	ФизическиеЛица - Массив - массив элементов типа СправочникСсылка.ФизическиеЛица,
//	ДатаАктуальности - Дата - дата для получения фамилии, имени и отчества.
//	Состав - Строка - строка вида <Фамилия И.О., Фамилия И.О...>.
//
Процедура ЗаполнитьКраткийСоставФизЛиц(ФизическиеЛица, ДатаАктуальности, Состав) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБЗК.ЗаполнитьКраткийСоставФизЛиц(ФизическиеЛица, ДатаАктуальности, Состав) 
```
</details>

## ЗаполнитьКадровыеДанныеСотрудников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет кадровые данные: тарифную ставку, отработанное время в переданной коллекции.
//
// Параметры:
//  Объект - ДокументОбъект.ВыработкаСотрудников, ДанныеФормыСтруктура - Заполняемый документ.
//  ИмяТЧ - Строка - имя табличной части, в которой требуется заполнить поля.
//  ЗаполняемыеПоля - Структура - структура, содержащая перечень полей к заполнению (см. ИнтеграцияБЗК.ПоляКадровыхДанных).
//  МассивСтрок - Массив - строки, в которых выполняется заполнение (если Неопределено, то поля заполняются во всех
//                         строках табличной части).
//
Процедура ЗаполнитьКадровыеДанныеСотрудников(Объект, ИмяТЧ, ЗаполняемыеПоля, МассивСтрок = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБЗК.ЗаполнитьКадровыеДанныеСотрудников(Объект, ИмяТЧ, ЗаполняемыеПоля, МассивСтрок);
```
</details>

## ЗаполнитьФизическиеЛицаПодразделения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает состав подразделения
//
// Параметры:
// 	МассивФизЛиц - Массив - массив физлиц.
// 	Подразделение - СправочникСсылка.СтруктураПредприятия - подразделение.
// 	Организация - СправочникСсылка.Организации - организация искомого подразделения.
//
Процедура ЗаполнитьФизическиеЛицаПодразделения(МассивФизЛиц, Подразделение, Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБЗК.ЗаполнитьФизическиеЛицаПодразделения(МассивФизЛиц, Подразделение, Организация);
```
</details>

## ЗаполнитьПоДаннымРегистраБухучетВидаРабот
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяется настройки отражения в бух. учете по умолчанию для указанного вида работ.
//
// Параметры:
// 	ДанныеРегистра - Структура - Описание полей см. в ресурсах регистра сведений БухучетРаботСотрудников.
//   ВидРабот - СправочникСсылка.ВидыРаботСотрудников - Вид работ.
//
Процедура ЗаполнитьПоДаннымРегистраБухучетВидаРабот(ДанныеРегистра, ВидРабот) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБЗК.ЗаполнитьПоДаннымРегистраБухучетВидаРабот(ДанныеРегистра, ВидРабот) 
```
</details>

## ПоляКадровыхДанныхСотрудниковКЗаполнению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует структуру полей кадровых данных сотрудников к заполнению
//
// Возвращаемое значение:
//  Структура - поля к заполнению.
//
Функция ПоляКадровыхДанныхСотрудниковКЗаполнению() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБЗК.ПоляКадровыхДанныхСотрудниковКЗаполнению() 
```
</details>

## МестоСотрудникаВСтруктуреПредприятия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ Локализация

// Возвращает элемент справочника СтруктураПредприятия, в котором числится физическое лицо.
//
// Параметры:
//  Организация 	- СправочникСсылка.Организации - организация, в которой работает сотрудник
//  ФизическоеЛицо	- СправочникСсылка.ФизическиеЛица - физическое лицо, подразделение которого требуется получить
//  Период			- Дата - дата, на которую требуется получить данные.
//
// Возвращаемое значение:
//   СправочникСсылка.СтруктураПредприятия   - подразделение организационной структуры.
//
Функция МестоСотрудникаВСтруктуреПредприятия(Организация, ФизическоеЛицо, Период) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБЗК.МестоСотрудникаВСтруктуреПредприятия(Организация, ФизическоеЛицо, Период) 
```
</details>

## ЗаполнитьОсновныхСотрудниковФизическихЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//-- Локализация

// Заполняет таблицу значений содержащую поля ФизическоеЛицо и Сотрудник
//
// Параметры:
//	Таблица				-ТаблицаЗначений - Таблица значений, содержащая поля Сотрудник и соответствующее сотруднику ФизическоеЛицо
//	СписокФизическихЛиц - Массив из СправочникСсылка.ФизическиеЛица, СправочникСсылка.ФизическиеЛица, Неопределено -
//							если передано Неопределено - в таблицу войдут "основные" сотрудники всех
//							физических лиц когда либо работавших в организации.
//	ТолькоРазрешенные	- Булево - признак использования РАЗРЕШЕННЫЕ в запросе.
//	Организация			- СправочникСсылка.Организации - ссылка на организацию.
//	Период				- Дата - дата получения сотрудников.
//
Процедура ЗаполнитьОсновныхСотрудниковФизическихЛиц(Таблица, СписокФизическихЛиц, ТолькоРазрешенные, Организация, Период) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБЗК.ЗаполнитьОсновныхСотрудниковФизическихЛиц(Таблица, СписокФизическихЛиц, ТолькоРазрешенные, Организация, Период) 
```
</details>

## ЗаполнитьТаблицуКадровыеДанныеСотрудников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу значений заполненную данными сотрудников, перечисленными в
// параметре СписокНеобходимыхДанных.
//
// Параметры:
//	Таблица           - ТаблицаЗначений   - Таблица значений, содержащая запрошенные данные.
//	ТолькоРазрешенные - Булево
//  СписокСотрудников - Массив из СправочникСсылка.Сотрудники - ссылки на элементы справочника сотрудники.
//  КадровыеДанные - 	Строка - список полей данных, перечисленных через запятую
//						или Массив строк с полями данных, которые необходимо получить.
//	ДатаПолученияДанных - Дата - дата на которую необходимо получить данные сотрудников,
//						применимо к данным, носящим периодический характер.
//						Если дату не указывать, будут получены самые последние данные.
//  ПоляОтбораПериодическихДанных - Структура - в качестве ключа указывается имя таблицы, содержащей
//									периодические данные (например ФИОФизическихЛиц, ГражданствоФизическихЛиц).
//									В качестве значений коллекция условий отбора,
//									соединяемых по "И" и применяемых к регистру сведений.
//  ФормироватьСПериодичностьДень - Булево - признак формирования таблицы с периодичностью День.
//
Процедура ЗаполнитьТаблицуКадровыеДанныеСотрудников(Таблица, ТолькоРазрешенные, СписокСотрудников, КадровыеДанные, ДатаПолученияДанных = '00010101', ПоляОтбораПериодическихДанных = Неопределено, ФормироватьСПериодичностьДень = Истина) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБЗК.ЗаполнитьТаблицуКадровыеДанныеСотрудников(Таблица, ТолькоРазрешенные, СписокСотрудников, КадровыеДанные, ДатаПолученияДанных, ПоляОтбораПериодическихДанных, ФормироватьСПериодичностьДень);
```
</details>

## ЗаполнитьТипНалогаОперацииПоЗарплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ Локализация

// Заполняет типа налога в зависимости от операции по зарплате.
//
// Параметры:
//   ТипНалога  - ПеречислениеСсылка.ТипыНалогов - "Типы налогов".
//   ВидОперации - ПеречислениеСсылка.ВидыОперацийПоЗарплате - вид операции по зарплате.
//
Процедура ЗаполнитьТипНалогаОперацииПоЗарплаты(ТипНалога, ВидОперации) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБЗК.ЗаполнитьТипНалогаОперацииПоЗарплаты(ТипНалога, ВидОперации) 
```
</details>

## ВключеныПодразделенияНаСчетахУчетаЗарплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак учета по подразделениям на счетах расчетов по оплате труда
//
// Возвращаемое значение:
//   Булево   - признак включения учета по подразделениям.
//
Функция ВключеныПодразделенияНаСчетахУчетаЗарплаты() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБЗК.ВключеныПодразделенияНаСчетахУчетаЗарплаты() 
```
</details>

## ВключеныПодразделенияНаСчетахУчетаНДФЛ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак учета по подразделениям на счетах учета НДФЛ
//
// Возвращаемое значение:
//   Булево   - признак включения учета по подразделениям.
//
Функция ВключеныПодразделенияНаСчетахУчетаНДФЛ() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБЗК.ВключеныПодразделенияНаСчетахУчетаНДФЛ() 
```
</details>

## ТипыНалоговНДФЛИВзносов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив всех типов налогов по НДФЛ и страховым взносам
//
// Возвращаемое значение:
//  Массив из ПеречислениеСсылка.ТипыНалогов - поля к заполнению.
//
Функция ТипыНалоговНДФЛИВзносов() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБЗК.ТипыНалоговНДФЛИВзносов() 
```
</details>

## ПриОпределенииОбработчиковТекущихДел
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//-- Локализация

// См. ТекущиеДелаПереопределяемый.ПриОпределенииОбработчиковТекущихДел.
Процедура ПриОпределенииОбработчиковТекущихДел(Обработчики) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБЗК.ПриОпределенииОбработчиковТекущихДел(Обработчики) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
