---
title: Интеграция БРО ЭДО
slug: erp-uh/интеграция-бро-эдо
---


## ТребуетсяПереизданиеСертификатаЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет необходимость переиздания указанного сертификата для использования в ЭДО.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация для проверки.
//  Сертификат - СертификатКриптографии - сертификат для проверки.
//  ТребуетсяПереиздание - Булево - признак необходимости переиздать сертификат для ЭДО.
//
Процедура ТребуетсяПереизданиеСертификатаЭДО(Знач Организация, Знач Сертификат, ТребуетсяПереиздание) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБРОЭДО.ТребуетсяПереизданиеСертификатаЭДО(Организация, Сертификат, ТребуетсяПереиздание) 
```
</details>

## ИнициализироватьНастройкиПодключенияЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует настройки подключения ЭДО.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация для подключения ЭДО.
//  КодФНС - Строка - код налогового органа организации.
//  Настройки - Строка - инициализированные настройки.
//
Процедура ИнициализироватьНастройкиПодключенияЭДО(Знач Организация, Знач КодФНС, Настройки) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБРОЭДО.ИнициализироватьНастройкиПодключенияЭДО(Организация, КодФНС, Настройки) 
```
</details>

## ИнициализироватьНастройкиПереизданияСертификатаЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует настройки переиздания сертификата криптографии.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация для переиздания сертификата.
//  КодФНС - Строка - код налогового органа организации.
//  Сертификат - СертификатКриптографии - сертификат для переиздания.
//  Настройки - Строка - инициализированные настройки.
//
Процедура ИнициализироватьНастройкиПереизданияСертификатаЭДО(Знач Организация, Знач КодФНС, Знач Сертификат, Настройки) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБРОЭДО.ИнициализироватьНастройкиПереизданияСертификатаЭДО(Организация, КодФНС, Сертификат, Настройки) 
```
</details>

## ПроверитьНастройкиРегистрацииЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет корректность настроек операции ЭДО (подключение ЭДО, переиздание сертификата).
//
// Параметры:
//  Настройки - Строка - настройки для проверки.
//                       См. ИнициализироватьНастройкиПодключенияЭДО.
//                       См. ИнициализироватьНастройкиПереизданияСертификатаЭДО.
//  НастройкиКорректны - Булево - результат проверки настроек.
//
Процедура ПроверитьНастройкиРегистрацииЭДО(Знач Настройки, НастройкиКорректны) Экспорт
```

Пример вызова
```bsl
ИнтеграцияБРОЭДО.ПроверитьНастройкиРегистрацииЭДО(Настройки, НастройкиКорректны) 
```
</details>

## ВыгрузкаДокументовДляПередачиВФНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выгружает электронные документы для предоставления в ФНС.
// Предназначена для использования совместно с библиотекой "Регламентированная отчетность".
//
// Параметры:
//  УчетныеДокументы - Массив - массив ссылок на документы информационной базы.
//  УникальныйИдентификатор - УникальныйИдентификатор - будет использован для помещения файлов выгрузки во временное хранилище.
//
// Возвращаемое значение:
//  Соответствие - соответствие документов ИБ:
//    * Ключ     - ДокументСсылка - ссылка на документ-владелец электронного документа.
//    * Значение - Массив Из Структура - параметры электронных документов, с ключами:
//       * ТипФайла - Строка - возможные значения: "ФайлВыгрузки", "ЭЦП", "ФайлПодтверждения", "ЭЦППодтверждения".
//       * КНД      - Строка - КНД выгружаемого электронного документа, заполняется только для файла выгрузки и файла подтверждения.
//       * ИмяФайла - Строка - имя выгружаемого файла.
//       * АдресВременногоХранилища - Строка - адрес временного хранилища с данными файлов выгрузки.
//
Функция ВыгрузкаДокументовДляПередачиВФНС(УчетныеДокументы, УникальныйИдентификатор) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБРОЭДО.ВыгрузкаДокументовДляПередачиВФНС(УчетныеДокументы, УникальныйИдентификатор) 
```
</details>

## ВыгрузкаНеформализованныхДокументовPDFДляПередачиВФНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выгружает неформализованные электронные документы, подписанные и переданные в формате PDF, для предоставления в ФНС
// в переданное соответствие, исключает выгрузку документов сформированных по стандарту PDF/A-3.
// Предназначена для использования совместно с библиотекой "Регламентированная отчетность".
//
// Параметры:
//  ДанныеФайловПоОбъектамУчета - Соответствие Из КлючИЗначение:
//    * Ключ - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылка на документ-владелец электронного документа
//    * Значение - Массив Из Структура:
//       * Имя - Строка - имя выгружаемого файла
//       * Размер - Число - размер выгружаемого файла в байтах
//       * АдресДанных - Строка - адрес временного хранилища с данными файла выгрузки
//       * ИмяФайлаПодписи - Строка - имя файла подписи выгружаемого файла
//       * АдресФайлаПодписи - Строка - адрес временного хранилища с данными файла подписи
//  УникальныйИдентификатор - УникальныйИдентификатор - будет использован для помещения файлов выгрузки
//                                                      во временное хранилище.
//
Процедура ВыгрузкаНеформализованныхДокументовPDFДляПередачиВФНС(ДанныеФайловПоОбъектамУчета, Экспорт
```

Пример вызова
```bsl
ИнтеграцияБРОЭДО.ВыгрузкаНеформализованныхДокументовPDFДляПередачиВФНС(ДанныеФайловПоОбъектамУчета, );
```
</details>

## СформироватьФайлыВыгрузкиЭДДляФНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выгружает электронные документы для предоставления в ФНС.
//
// Параметры:
//  ЭлектронныеДокументы - Массив из ДокументСсылка.ЭлектронныйДокументВходящийЭДО, ДокументСсылка.ЭлектронныйДокументИсходящийЭДО
//
// Возвращаемое значение:
//  Структура - Структура результатов обработки и соответствия файлов:
//  * РезультатыОбработки - Соответствие Из КлючИЗначение - Результаты обработки документов по организациям:
//   ** Ключ - Строка - Наименование организации
//   ** Значение - См. НовыеРезультатыОбработки
//  * СоответствиеФайлов - Соответствие Из КлючИЗначение:
//   ** Ключ - Строка - Имя файла
//   ** Значение - ДвоичныеДанные - Двоичные данные файла
//  * Ошибки - Массив Из См. НоваяОшибка
Функция СформироватьФайлыВыгрузкиЭДДляФНС(Знач ЭлектронныеДокументы) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБРОЭДО.СформироватьФайлыВыгрузкиЭДДляФНС(ЭлектронныеДокументы) 
```
</details>

## СвойстваОбъектовУчетаЭлектронныхДокументовДляВыгрузкиВФНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает свойства объектов учета, которые будут отражаться в едином списке документов, представляемых по требованию ФНС.
// Для объекта учета должны существовать электронные документы по завершенным обменам, не помеченные на удаление и
// имеющие один из следующих типов:
// УПД, СчетФактура, ТоварнаяНакладная, АктВыполненныхРабот, АктНаПередачуПрав,
// УКД, КорректировочныйСчетФактура, СоглашениеОбИзмененииСтоимости, АктОРасхождениях, ДоговорнойДокумент,
// АктСверкиВзаиморасчетов, АктПриемкиСтроительныхРаботУслуг.
//
// Параметры:
//  ОбъектыУчета - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - массив ссылок на объекты учета электронных документов.
//                       Если параметр указан, требуется заполнить свойства только указанных объектов.
//                       Если параметр не указан или массив пустой, тогда требуется заполнить свойства
//                       для всех объектов учета, по которым ЭДО завершен.
//
// Возвращаемое значение:
//   Соответствие Из КлючИЗначение - Соответствие объектов учета и видов электронных документов:
//    * Ключ     - ДокументСсылка - ссылка на документ учета.
//    * Значение - Строка - тип электронного документа, который следует преобразовать
//                 к строковому представлению определенного формата.
//                 Возможные значения:
//                 ПередачаТоваров, ПередачаУслуг,
//                 УПД, СчетФактура, ТоварнаяНакладнаяТОРГ12, АктПриемкиСдачиРабот, АктНаПередачуПрав,
//                 УКД, КорректировочныйСчетФактура, ДокументОбИзмененииСтоимости, АктОРасхождениях
//                 ДоговорнойДокумент, АктСверкиВзаиморасчетов, АктПриемкиСтроительныхРаботУслуг.
Функция СвойстваОбъектовУчетаЭлектронныхДокументовДляВыгрузкиВФНС(ОбъектыУчета = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБРОЭДО.СвойстваОбъектовУчетаЭлектронныхДокументовДляВыгрузкиВФНС(ОбъектыУчета);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
