---
title: Интеграция БСП БЭД
slug: erp-uh/интеграция-бсп-бэд
---


## ЕстьВозможностьПодключенияОбсуждений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, встроена ли в конфигурацию подсистема БСП "Обсуждения" и не подключена ли еще система "Взаимодействия".
//
// Возвращаемое значение:
// 	Булево - Истина, если обсуждения подключены.
Функция ЕстьВозможностьПодключенияОбсуждений() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.ЕстьВозможностьПодключенияОбсуждений() 
```
</details>

## СведенияОбАдресеПоПредставлению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует представление адреса в структуру полей адреса, используемую в форматах ФНС
//
// Параметры:
//   АдресОрганизации - Строка - Представление адреса
//
// Возвращаемое значение:
//  Структура - структура полей адреса:
// * Индекс          - Строка - индекс
// * Регион          - Строка - Регион
// * КодРегиона      - Строка - КодРегиона
// * Район           - Строка - Район
// * Город           - Строка - Город
// * НаселенныйПункт - Строка - НаселенныйПункт
// * Улица           - Строка - Улица
// * Дом             - Строка - Дом
// * Корпус          - Строка - Корпус
// * Квартира        - Строка - Квартира
//
Функция СведенияОбАдресеПоПредставлению(АдресОрганизации) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.СведенияОбАдресеПоПредставлению(АдресОрганизации) 
```
</details>

## СведенияОбАдресеПоЗначению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует значение адреса  в структуру полей адреса, используемую в форматах ФНС
//
// Параметры:
// 	ЗначениеАдреса - Строка - строка JSON или XML контактной информации, соответствующая XDTO-пакету КонтактнаяИнформация.
// Возвращаемое значение:
//  Структура - структура полей адреса:
// * Индекс          - Строка - индекс
// * Регион          - Строка - Регион
// * КодРегиона      - Строка - КодРегиона
// * Район           - Строка - Район
// * Город           - Строка - Город
// * НаселенныйПункт - Строка - НаселенныйПункт
// * Улица           - Строка - Улица
// * Дом             - Строка - Дом
// * Корпус          - Строка - Корпус
// * Квартира        - Строка - Квартира
Функция СведенияОбАдресеПоЗначению(Знач ЗначениеАдреса) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.СведенияОбАдресеПоЗначению(ЗначениеАдреса) 
```
</details>

## КонтактнаяИнформацияОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает сведения элемента контактной информации переданного объекта.
//
// Параметры:
// 	Объект - ЛюбаяСсылка - ссылка на объект, контактную информацию которого нужно получить.
// 	ТипВидКонтактнойИнформацииСтрокой - Строка - строковый идентификатор типа контактной информации или вида.
// Возвращаемое значение:
//  Структура - сведения элемента контактной информации:
// * Значение - Строка - строка JSON или XML контактной информации, соответствующая XDTO-пакету КонтактнаяИнформация.
// * Представление - Строка - представление элемента контактной информации.
Функция КонтактнаяИнформацияОбъекта(Объект, ТипВидКонтактнойИнформацииСтрокой) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.КонтактнаяИнформацияОбъекта(Объект, ТипВидКонтактнойИнформацииСтрокой) 
```
</details>

## ПользовательНедействителен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, является ли пользователь недействительным.
//
// Параметры:
// 	КонтекстДиагностики - См. ОбработкаНеисправностейБЭД.НовыйКонтекстДиагностики - если передан, в него будет добавлена ошибка.
// Возвращаемое значение:
// 	Булево - Истина, если пользователь является недействительным.
Функция ПользовательНедействителен(КонтекстДиагностики = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.ПользовательНедействителен(КонтекстДиагностики);
```
</details>

## ПустаяСсылкаНаПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает пустую ссылку справочника Пользователи.
//
// Возвращаемое значение:
// 	СправочникСсылка.Пользователи - значение ссылки.
Функция ПустаяСсылкаНаПользователя() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.ПустаяСсылкаНаПользователя() 
```
</details>

## ПустойИдентификаторОбъектаМетаданных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает пустую ссылку справочника ИдентификаторыОбъектовМетаданных.
//
// Возвращаемое значение:
// 	СправочникСсылка.ИдентификаторыОбъектовМетаданных - значение ссылки.
Функция ПустойИдентификаторОбъектаМетаданных() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.ПустойИдентификаторОбъектаМетаданных() 
```
</details>

## ОписаниеТипаИдентификатораОбъектаМетаданных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание типа, в которое включен справочник идентификаторов объектов метаданных.
//
// Возвращаемое значение:
// 	ОписаниеТипов - описание типов.
Функция ОписаниеТипаИдентификатораОбъектаМетаданных() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.ОписаниеТипаИдентификатораОбъектаМетаданных() 
```
</details>

## ПредставлениеНомераОбъектаУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует номер к виду, допустимому для печати.
//
// Параметры:
// 	Номер - Строка - номер в исходном виде.
// Возвращаемое значение:
//  Строка - номер, готовый к печати.
Функция ПредставлениеНомераОбъектаУчета(Номер) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.ПредставлениеНомераОбъектаУчета(Номер) 
```
</details>

## КомандыПечатиСМенеджерамиПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу команд печати, которые имеют менеджеры.
//
// Параметры:
// 	ОбъектМетаданных - ОбъектМетаданных - объект метаданных, по которому нужно получить команды печати.
// Возвращаемое значение:
// 	ТаблицаЗначений - см. УправлениеПечатью.КомандыПечатиОбъекта.
Функция КомандыПечатиСМенеджерамиПечати(ОбъектМетаданных) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.КомандыПечатиСМенеджерамиПечати(ОбъектМетаданных) 
```
</details>

## КомандыПечатиФормыОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Команды печати формы объекта.
//
// Параметры:
//  ОбъектМетаданных - ОбъектМетаданных
//  ИмяФормыОбъекта - Строка - Имя формы объекта, для которой необходимо получить команды печати
//                             Если не заполнена, по получает печатные формы для основной формы объекта
//
// Возвращаемое значение:
//  ТаблицаЗначений -  - см. УправлениеПечатью.КомандыПечатиОбъекта
Функция КомандыПечатиФормыОбъекта(ОбъектМетаданных, ИмяФормыОбъекта) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.КомандыПечатиФормыОбъекта(ОбъектМетаданных, ИмяФормыОбъекта) 
```
</details>

## ДанныеВалютыПоКлассификатору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные валюты по классификатору ОКВ.
//
// Параметры:
// 	КодВалюты - Строка
// Возвращаемое значение:
// 	Структура - данные валюты:
// * КодВалютыЦифровой - Строка
// * КодВалютыБуквенный - Строка
// * Наименование - Строка
//  Неопределено - возвращается в случае, если не удалось получить данные классификатора.
Функция ДанныеВалютыПоКлассификатору(КодВалюты) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.ДанныеВалютыПоКлассификатору(КодВалюты) 
```
</details>

## ИсточникиКомандПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список объектов метаданных, в которых внедрена подсистема Печать.
//
// Возвращаемое значение:
//  Массив - список из элементов типа ОбъектМетаданных.
//
Функция ИсточникиКомандПечати() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.ИсточникиКомандПечати() 
```
</details>

## ДвоичныеДанныеФайлов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает двоичные данные присоединенных файлов.
//
// Параметры:
// 	ПрисоединенныеФайлы - Массив из ОпределяемыйТип.ПрисоединенныйФайл
// 	КонтекстДиагностики - см. ОбработкаНеисправностейБЭД.НовыйКонтекстДиагностики
// Возвращаемое значение:
// 	Соответствие из КлючИЗначение:
// 	  * Ключ - ОпределяемыйТип.ПрисоединенныйФайл
// 	  * Значение - ДвоичныеДанные
Функция ДвоичныеДанныеФайлов(ПрисоединенныеФайлы, КонтекстДиагностики = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.ДвоичныеДанныеФайлов(ПрисоединенныеФайлы, КонтекстДиагностики);
```
</details>

## ЗапросНеполученныхСертификатов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание запроса, в результате которого будут содержаться заказанные, но еще не полученные сертификаты.
// Запрос содержит следующие поля:
//   * Ссылка - СправочникСсылка.СертификатыКлючейЭлектроннойПодписиИШифрования - сертификат.
//   * Организация - ОпределяемыйТип.Организация - организация.
//
// Параметры:
// 	ИмяВременнойТаблицы - Строка - таблица, в которую будет помещен результат запроса
// Возвращаемое значение:
// 	см. ОбщегоНазначенияБЭД.НовоеОписаниеЗапроса
Функция ЗапросНеполученныхСертификатов(ИмяВременнойТаблицы) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.ЗапросНеполученныхСертификатов(ИмяВременнойТаблицы) 
```
</details>

## ЗапросСертификатов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗапросСертификатов(ИмяВременнойТаблицы, ВыбираемыеПоля, ПоляУсловия, Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.ЗапросСертификатов(ИмяВременнойТаблицы, ВыбираемыеПоля, ПоляУсловия, );
```
</details>

## ОписанияПрограммЭлектроннойПодписиИШифрования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описания программ криптографии, добавленные в справочник ПрограммыЭлектроннойПодписиИШифрования.
//
// Возвращаемое значение:
// 	Массив из см. ЭлектроннаяПодпись.НовоеОписаниеПрограммы
Функция ОписанияПрограммЭлектроннойПодписиИШифрования() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.ОписанияПрограммЭлектроннойПодписиИШифрования() 
```
</details>

## УстановленныеПодписиОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает установленные подписи объектов.
//
// Параметры:
//  ПодписанныеОбъекты - ОпределяемыйТип.ПодписанныйОбъект
//
// Возвращаемое значение:
//  Соответствие из КлючИЗначение:
//  * Ключ - ОпределяемыйТип.ПодписанныйОбъект
//  * Значение - Массив из см. КриптографияБЭДКлиентСервер.НовыеСвойстваПодписи
//
Функция УстановленныеПодписиОбъектов(ПодписанныеОбъекты) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.УстановленныеПодписиОбъектов(ПодписанныеОбъекты) 
```
</details>

## ЭтоСертификатыОблачногоСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, являются ли сертификаты облачными.
//
// Параметры:
// 	Сертификаты - Массив из СправочникСсылка.СертификатыКлючейЭлектроннойПодписиИШифрования
// Возвращаемое значение:
// 	Соответствие из КлючИЗначение:
//   * Ключ - СправочникСсылка.СертификатыКлючейЭлектроннойПодписиИШифрования
//   * Значение - Булево - сертификат облачный
Функция ЭтоСертификатыОблачногоСервиса(Сертификаты) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияБСПБЭД.ЭтоСертификатыОблачногоСервиса(Сертификаты) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
