---
title: Интеграция ВЕТИС УТ
slug: erp-uh/интеграция-ветис-ут
---


## КопироватьСвязьСКлассификаторомПродукцииВЕТИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Копирует связь между номенклатурой и продукцией ВЕТИС для новой позиции номенклатуры.
//
// Параметры:
//	Приемник						  - СправочникСсылка.Номенклатура - Номенклатура, для которой копируется связь.
//	Источник						  - СправочникСсылка.Номенклатура - Номенклатура для которой существует связь.
//	СоответствияСкопированныхОбъектов - Соответствие - соответствие характеристик номенклатуры-приемника характеристикам номенклатуры-источника.
//
Процедура КопироватьСвязьСКлассификаторомПродукцииВЕТИС(Приемник, Источник, СоответствияСкопированныхОбъектов) Экспорт
```

Пример вызова
```bsl
ИнтеграцияВЕТИСУТ.КопироватьСвязьСКлассификаторомПродукцииВЕТИС(Приемник, Источник, СоответствияСкопированныхОбъектов) 
```
</details>

## ЕдиницаИзмеренияОКЕИ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает единицу измерения по ОКЕИ.
//
// Параметры:
//	КодОКЕИ - ОпределяемыйТип.СтрокаВЕТИС - Код ОКЕИ.
//
// Возвращаемое значение:
//	СправочникСсылка.УпаковкиЕдиницыИзмерения, Неопределено - Единица измерения по ОКЕИ.
//
Функция ЕдиницаИзмеренияОКЕИ(Знач КодОКЕИ) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияВЕТИСУТ.ЕдиницаИзмеренияОКЕИ(КодОКЕИ) 
```
</details>

## СоздатьЕдиницуИзмеренияПоКлассификаторуОКЕИ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает единицу измерения по ОКЕИ.
//
// Параметры:
//	КодОКЕИ - ОпределяемыйТип.СтрокаВЕТИС - Код ОКЕИ.
//
// Возвращаемое значение:
//	СправочникСсылка.УпаковкиЕдиницыИзмерения, Неопределено - Единица измерения по ОКЕИ.
//
Функция СоздатьЕдиницуИзмеренияПоКлассификаторуОКЕИ(КодОКЕИ) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияВЕТИСУТ.СоздатьЕдиницуИзмеренияПоКлассификаторуОКЕИ(КодОКЕИ) 
```
</details>

## КоэффициентЕдиницыИзмеренияПоВЕТИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о коэффициенте пересчета единицы измерения ВЕТИС.
//
// Параметры:
// ЕдиницаИзмеренияВЕТИС - СправочникСсылка.ЕдиницыИзмеренияВЕТИС - Единица измерения ВЕТИС, коэффициент которой нужно
//                                                                  получить.
// Номенклатура - СправочникСсылка.Номенклатура - Номенклатура для единицы хранения, которой осуществляется
//                                                получение коэффициента пересчета.
// Возвращаемое значение:
// Структура - Структура со свойствами:
//  * КодОшибки      - Число    - Код ошибки получения коэффициента.
//      0 - Нет ошибок;
//      1 - Не заполнена единица измерения в справочнике 'ЕдиницыИзмеренияВЕТИС';
//      2 - В справочнике 'Номенклатура' выключена возможность пересчета количества
//          в соответствующую мерную единицу измерения;
//      3 - Не удалось сопоставить единицу хранения справочника 'Номенклатура'
//          с единицей измерения справочника 'ЕдиницыИзмеренияВЕТИС'.
//  * Коэффициент      - Число  - Коэффициент пересчета единицы измерения ВЕТИС.
//  * КэшироватьДанные - Булево - Истина если требуется кэшировать сведения о коэффициенте пересчета.
//  * ТипИзмеряемойВеличины   - ПеречислениеСсылка.ТипыИзмеряемыхВеличин - Тип измеряемой величины единицы измерения
//                      справочника 'ЕдиницыИзмеренияВЕТИС'.
//  * НужноОкруглятьКоличество      - Булево - Истина если необходимо округление количества при пересчете.
//  * НужноОкруглятьКоличествоВЕТИС - Булево - Истина если необходимо округление количества ВетИС при пересчете.
Функция КоэффициентЕдиницыИзмеренияПоВЕТИС(ЕдиницаИзмеренияВЕТИС, Номенклатура) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияВЕТИСУТ.КоэффициентЕдиницыИзмеренияПоВЕТИС(ЕдиницаИзмеренияВЕТИС, Номенклатура) 
```
</details>

## КоэффициентыЕдиницИзмеренияПоВЕТИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения для пересчета единиц измерения ВЕТИС.
//
// Параметры:
//   ДанныеСтрокВЕТИС - Массив - элементы массива должны содержать свойства Номенклатура и ЕдиницаИзмеренияВЕТИС.
//
// Возвращаемое значение:
//  Соответствие - ключ ссылка на номенклатуру, значение соответствие единица измерения ВЕТИС и структура:
//   * КодОшибки - Число  - Код ошибки получения коэффициента:
//        0 - Нет ошибок;
//        1 - Не заполнена единица измерения в справочнике 'ЕдиницыИзмеренияВЕТИС';
//        2 - В справочнике 'Номенклатура' выключена возможность пересчета количества в соответствующую мерную единицу измерения;
//        3 - Не удалось сопоставить единицу хранения справочника 'Номенклатура' с единицей измерения справочника 'ЕдиницыИзмеренияВЕТИС'.
//   * Коэффициент                   - Число  - Коэффициент пересчета единицы измерения ВЕТИС.
//   * ТипИзмеряемойВеличины         - ПеречислениеСсылка.ТипыИзмеряемыхВеличин - Тип измеряемой величины единицы измерения
//       справочника 'ЕдиницыИзмеренияВЕТИС'.
//   * НужноОкруглятьКоличество      - Булево - Признак необходимости округления количества при пересчете.
//   * НужноОкруглятьКоличествоВЕТИС - Булево - Признак необходимости округления количества ВетИС при пересчете.
Функция КоэффициентыЕдиницИзмеренияПоВЕТИС(ДанныеСтрокВЕТИС) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияВЕТИСУТ.КоэффициентыЕдиницИзмеренияПоВЕТИС(ДанныеСтрокВЕТИС) 
```
</details>

## ОсобенностиУчетаНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив особенностей учета номенклатуры подсистемы
//
// Возвращаемое значение:
//   Массив из ПеречислениеСсылка.ОсобенностиУчетаНоменклатуры
Функция ОсобенностиУчетаНоменклатуры() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияВЕТИСУТ.ОсобенностиУчетаНоменклатуры() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
