---
title: Интеграция ГИСМ клиент сервер
slug: erp-uh/интеграция-гисм-клиент-сервер
---


## СертификатКриптографииИзКонвертаSOAP
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает сертификат криптографии, которым подписано сообщение
//
// Параметры:
//  Сообщение - СправочникСсылка.ГИСМПрисоединенныеФайлы.
//
// Возвращаемое значение:
//  СертификатКриптографии - Сертификат криптографии.
//
Функция СертификатКриптографииИзКонвертаSOAP(КонвертSOAP) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияГИСМКлиентСервер.СертификатКриптографииИзКонвертаSOAP(КонвертSOAP) 
```
</details>

## ПредставлениеПодписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сформировать представление подписи
//
// Параметры:
//  СертификатКриптографии - Сертификат криптографии
//  ПодписьВерна           - Булево - признак валидности подписи
//  ДатаПроверкиПодписи    - Дата - Дата проверки подписи.
//
// Возвращаемое значение:
//  ФорматированнаяСтрока - Представление подписи.
//
Функция ПредставлениеПодписи(СертификатКриптографии, Сообщение, ВыводитьГиперссылки, СтруктураЦветаСтиля) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияГИСМКлиентСервер.ПредставлениеПодписи(СертификатКриптографии, Сообщение, ВыводитьГиперссылки, СтруктураЦветаСтиля) 
```
</details>

## ПараметрыXMLDSig
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует структуру свойств для уточнения данных конверта SOAP и
// алгоритмов подписания и хеширования.
//
// Возвращаемое значение:
// Структура - (См. ЭлектроннаяПодписьКлиентСервер.ПараметрыXMLDSig).
//
Функция ПараметрыXMLDSig() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияГИСМКлиентСервер.ПараметрыXMLDSig() 
```
</details>

## СтруктураСообщенияXML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует пустую структуру сообщения XML
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * ТекстОшибки                 - Строка - Текст ошибки.
//   * Ошибки                      - Соответствие - Описание ошибок.
//   * Описание                    - Строка - Описание для отображения в форме подписания.
//   * ТекстСообщенияXML           - Строка - Текст сообщения XML.
//   * КонвертSOAP                 - Строка - Текст сообщения SOAP.
//   * ТипСообщения                - ПеречислениеСсылка.ТипыСообщенийГИСМ - Тип сообщения.
//   * Организация                 - ОпределяемыйТип.Организации - Организация.
//   * Документ                    - ДокументСсылка - Документ.
//   * Версия                      - Строка - Версия сообщения.
//   * GLN                         - Строка - Регистрационный номер GLN.
//   * СообщениеОснование          - СправочникСсылка.ГИСМПрисоединенныеФайлы - сообщение основание.
//   * ДанныеДляПолученияДокумента - Структура - Данные для получения документа.
//   * Основание                   - ДокументСсылка - Документ основание.
//
Функция СтруктураСообщенияXML() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияГИСМКлиентСервер.СтруктураСообщенияXML() 
```
</details>

## ДобавитьТекстОшибки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в свойство структуры сообщения текст ошибки
//
// Параметры:
//  Сообщение    - Структура - сообщение, в которое добавляется текст ошибки.
//  ТекстОшибки  - Строка - добавляемый текст ошибки.
//
Процедура ДобавитьТекстОшибки(Сообщение, ТекстОшибки) Экспорт
```

Пример вызова
```bsl
ИнтеграцияГИСМКлиентСервер.ДобавитьТекстОшибки(Сообщение, ТекстОшибки) 
```
</details>

## ДобавитьТекстОшибкиНеЗаполненGLNОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в свойство структуры сообщения текст ошибки
//
// Параметры:
//  Сообщение    - Структура - сообщение, в которое добавляется текст ошибки.
//  GLN  - Число - GLN Организации.
//  Организация  - СправочникСсылка.Организация - Организация.
//
Процедура ДобавитьТекстОшибкиНеЗаполненGLNОрганизации(СообщениеXML, GLN, РеквизитыШапки) Экспорт
```

Пример вызова
```bsl
ИнтеграцияГИСМКлиентСервер.ДобавитьТекстОшибкиНеЗаполненGLNОрганизации(СообщениеXML, GLN, РеквизитыШапки) 
```
</details>

## ДобавитьТекстОшибкиУказанНеКорректныйКППОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в свойство структуры сообщения текст ошибки
//
// Параметры:
//  Сообщение    - Структура - сообщение, в которое добавляется текст ошибки.
//  GLN  - Число - GLN Организации.
//  Организация  - СправочникСсылка.Организация - Организация.
//
Процедура ДобавитьТекстОшибкиУказанНеКорректныйКППОрганизации(СообщениеXML, КПП, Организация) Экспорт
```

Пример вызова
```bsl
ИнтеграцияГИСМКлиентСервер.ДобавитьТекстОшибкиУказанНеКорректныйКППОрганизации(СообщениеXML, КПП, Организация) 
```
</details>

## ДобавитьТекстОшибкиНеЗаполненоПолноеНаименованиеКонтрагента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в свойство структуры сообщения текст ошибки
//
// Параметры:
//  Сообщение    - Структура - сообщение, в которое добавляется текст ошибки.
//  GLN  - Число - GLN Организации.
//  Организация  - СправочникСсылка.Организация - Организация.
//
Процедура ДобавитьТекстОшибкиНеЗаполненоПолноеНаименованиеКонтрагента(СообщениеXML, Контрагент) Экспорт
```

Пример вызова
```bsl
ИнтеграцияГИСМКлиентСервер.ДобавитьТекстОшибкиНеЗаполненоПолноеНаименованиеКонтрагента(СообщениеXML, Контрагент) 
```
</details>

## ДобавитьТекстОшибкиНеЗаполненGLNПартнера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в свойство структуры сообщения текст ошибки
//
// Параметры:
//  Сообщение    - Структура - сообщение, в которое добавляется текст ошибки.
//  GLN  - Число - GLN Организации.
//  Организация  - СправочникСсылка.Организация - Организация.
//
Процедура ДобавитьТекстОшибкиНеЗаполненGLNПартнера(СообщениеXML, GLN, Партнер) Экспорт
```

Пример вызова
```bsl
ИнтеграцияГИСМКлиентСервер.ДобавитьТекстОшибкиНеЗаполненGLNПартнера(СообщениеXML, GLN, Партнер) 
```
</details>

## РазложитьПоТипамШтрихкодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Разбирает переданный массив штриховых кодов и формирует структуру массивов.
// Один массив содержит штриховые коды, являющиеся номерами КиЗ, другой прочие штриховые коды.
//
// Параметры:
//  Штрихкоды - Массив - штриховые коды.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * КиЗ     - Массив - номера КиЗ.
//   * БезТипа - Массив - прочие штриховые коды.
//
Функция РазложитьПоТипамШтрихкодов(Штрихкоды) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияГИСМКлиентСервер.РазложитьПоТипамШтрихкодов(Штрихкоды) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
