---
title: Интеграция ЕГАИС
slug: erp-uh/интеграция-егаис
---


## ПередЗаписью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возникает перед выполнением записи документа. Вызывается после начала транзакции записи, но до начала записи документа.
//
// Параметры:
//  ДокументОбъект - ДокументОбъект - записываемый документ,
//  Отказ - Булево - признак отказа от записи,
//  РежимЗаписи - РежимЗаписиДокумента - текущий режим записи документа,
//  РежимПроведения - РежимПроведенияДокумента - текущий режим проведения документа.
Процедура ПередЗаписью(ДокументОбъект, Отказ, РежимЗаписи, РежимПроведения) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ПередЗаписью(ДокументОбъект, Отказ, РежимЗаписи, РежимПроведения) 
```
</details>

## ЗаполнитьТабличнуюЧастьТовары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет табличную часть Товары документа
//
// Параметры:
//  ДокументОбъект   - ДокументОбъект   - заполняемый документ
//  РезультатЗапроса - РезультатЗапроса - результат запроса с расчетом заполнения табличной части
//  ДанныеЗаполнения - ДокументСсылка   - источник заполнения
//  БезСопоставления - Булево           - возможность заполнения не сопоставленной алкогольной продукцией
//
Процедура ЗаполнитьТабличнуюЧастьТовары(ДокументОбъект, РезультатЗапроса, ДанныеЗаполнения, БезСопоставления = Ложь) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ЗаполнитьТабличнуюЧастьТовары(ДокументОбъект, РезультатЗапроса, ДанныеЗаполнения, БезСопоставления);
```
</details>

## ЗаполнитьАлкогольнуюПродукцию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет информацию о сопоставлении алкогольной продукции в табличной части
//
// Параметры:
//  ТабличнаяЧасть	 - ДанныеФормыСтруктура - Табличная часть документа
//
Процедура ЗаполнитьАлкогольнуюПродукцию(ТабличнаяЧасть) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ЗаполнитьАлкогольнуюПродукцию(ТабличнаяЧасть) 
```
</details>

## ЗаполнитьСопоставленнуюПродукцию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет в табличной части сопоставленную номенклатуру и алкогольную продукцию.
//
// Параметры:
//  ТаблицаСопоставления - ТаблицаЗначений, ДанныеФормыКоллекция - таблица для заполнения.
//
Процедура ЗаполнитьСопоставленнуюПродукцию(ТаблицаСопоставления) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ЗаполнитьСопоставленнуюПродукцию(ТаблицаСопоставления) 
```
</details>

## ПодобратьСправки2ДляСписанияИзРегистра1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подбирает справки 2 по остаткам для списания по FIFO.
//
// Параметры:
//  Товары - ТабличнаяЧасть, ДанныеФормыКоллекция, ТаблицаЗначений - табличная часть, содержащая реквизиты:
//                                                                     АлкогольнаяПродукция, Справка2, Количество.
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - организация учета остатков,
//  Период - Дата, Граница - дата получения остатков. Если не указана, то берутся последние.
//  СтруктураПересчетаСуммы - Структура - Структура со свойствами:
//   * Поля - Структура - содержит поля для пересчета суммы в табличной части документа,
//   * Строки - Массив Из ДанныеФормыЭлементКоллекции - ссылки на строки для пересчета сумм,
//   * ИтогКоличество - Число - сумма значений в поле "Количество" в строках переданных в параметре "Строки".
//
Процедура ПодобратьСправки2ДляСписанияИзРегистра1(Товары, ОрганизацияЕГАИС, Период, СтруктураПересчетаСуммы) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ПодобратьСправки2ДляСписанияИзРегистра1(Товары, ОрганизацияЕГАИС, Период, СтруктураПересчетаСуммы) 
```
</details>

## ПодобратьСправки2ДляВозвратаИзРегистра2
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подбирает справки 2 для списания по LIFO.
//
// Параметры:
//  Товары - ТабличнаяЧасть, ДанныеФормыКоллекция, ТаблицаЗначений - табличная часть, содержащая реквизиты:
//                                                                     АлкогольнаяПродукция, Справка2, Количество.
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - организация учета остатков,
//  Период - Дата - дата получения остатков.
//  СтруктураПересчетаСуммы - Структура - Структура со свойствами:
//   * Поля - Структура - содержит поля для пересчета суммы в табличной части документа,
//   * Строки - Массив Из ДанныеФормыЭлементКоллекции - ссылки на строки для пересчета сумм,
//   * ИтогКоличество - Число - сумма значений в поле "Количество" в строках переданных в параметре "Строки".
//
// Возвращаемое значение:
//  Булево - Истина, если все справки заполнены.
//
Функция ПодобратьСправки2ДляВозвратаИзРегистра2(Товары, ОрганизацияЕГАИС, Период, СтруктураПересчетаСуммы) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПодобратьСправки2ДляВозвратаИзРегистра2(Товары, ОрганизацияЕГАИС, Период, СтруктураПересчетаСуммы) 
```
</details>

## УстановитьПометкуУдаленияПрисоединенныхФайловДокументаЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки на событие ПередЗаписью владельца присоединенного файла.
// Помечает на удаление связанные файлы.
//
// Параметры:
//  Источник        - ДокументОбъект - владелец присоединенного файла.
//  Отказ           - Булево - параметр, передаваемый в подписку на событие ПередЗаписью.
//  РежимЗаписи     - Булево - параметр, передаваемый в подписку на событие ПередЗаписью.
//  РежимПроведения - Булево - параметр, передаваемый в подписку на событие ПередЗаписью.
//
Процедура УстановитьПометкуУдаленияПрисоединенныхФайловДокументаЕГАИС(Источник, Отказ, РежимЗаписи, РежимПроведения) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.УстановитьПометкуУдаленияПрисоединенныхФайловДокументаЕГАИС(Источник, Отказ, РежимЗаписи, РежимПроведения) 
```
</details>

## УстановитьПометкуУдаленияПрисоединенныхФайловОрганизацииЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки на событие ПередЗаписью владельца присоединенного файла.
// Помечает на удаление связанные файлы.
//
// Параметры:
//  Источник        - ДокументОбъект - владелец присоединенного файла.
//  Отказ           - Булево - параметр, передаваемый в подписку на событие ПередЗаписью.
//  РежимЗаписи     - Булево - параметр, передаваемый в подписку на событие ПередЗаписью.
//  РежимПроведения - Булево - параметр, передаваемый в подписку на событие ПередЗаписью.
//
Процедура УстановитьПометкуУдаленияПрисоединенныхФайловОрганизацииЕГАИС(Источник, Отказ) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.УстановитьПометкуУдаленияПрисоединенныхФайловОрганизацииЕГАИС(Источник, Отказ) 
```
</details>

## СтатусыЦветТекстаТребуетВниманияЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить статусы ЕГАИС, цвет текста которых "требует внимания ЕГАИС"
//
// Возвращаемое значение:
//  Массив - Статусы ЕГАИС, для которых требуется устанавливать цвет "требует внимания ЕГАИС"
//
Функция СтатусыЦветТекстаТребуетВниманияЕГАИС() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.СтатусыЦветТекстаТребуетВниманияЕГАИС() 
```
</details>

## ПредставлениеСтатусаЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить представление статуса ЕГАИС.
//
// Параметры:
//  СтатусЕГАИС - ПеречислениеСсылка - Статус документа ЕГАИС.
//  ВходящиеДальнейшееДействие - Массив Из ПеречислениеСсылка.ДальнейшиеДействияПоВзаимодействиюЕГАИС - Список разрешенных
//                                                                                                      дальнейших действий.
//                             - ПеречислениеСсылка.ДальнейшиеДействияПоВзаимодействиюЕГАИС -
//  ДопустимыеДействия         - Массив Из ПеречислениеСсылка.ДальнейшиеДействияПоВзаимодействиюЕГАИС - Список допустимых
//                                                                                                      дальнейших действий.
//                             - ПеречислениеСсылка.ДальнейшиеДействияПоВзаимодействиюЕГАИС -
//
// Возвращаемое значение:
//  ФорматированнаяСтрока - Представление статуса ЕГАИС.
Функция ПредставлениеСтатусаЕГАИС(СтатусЕГАИС, ВходящиеДальнейшееДействие, ДопустимыеДействия) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПредставлениеСтатусаЕГАИС(СтатусЕГАИС, ВходящиеДальнейшееДействие, ДопустимыеДействия) 
```
</details>

## ДопустимоеДальнейшееДействие
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, имеется ли выбранное действие в массиве допустимых действий
//
// Параметры:
//  ДальнейшееДействие - ПеречислениеСсылка.ДальнейшиеДействияПоВзаимодействиюЕГАИС - выбранное действие.
//  ДопустимыеДействия - Массив - массив допустимых действий.
//
// Возвращаемое значение:
//  Булево - Истина, если действие допустимо, Ложь в обратном случае.
//
Функция ДопустимоеДальнейшееДействие(ДальнейшееДействие, ДопустимыеДействия) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ДопустимоеДальнейшееДействие(ДальнейшееДействие, ДопустимыеДействия));
```
</details>

## СоздатьСправку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает (или обновляет, если найдена по рег. номеру) справку на основании переданных данных.
//
// Параметры:
//  ДанныеСправки - Структура - заполненная структура, полученная функцией ИнтеграцияЕГАИСКлиентСервер.СтруктураДанныхСправки(1)(2),
//  ВидСправки - ПеречислениеСсылка.ВидыДокументовЕГАИС - вид справки,
//  ДополнительныеПараметры - Произвольный - параметры прикладной конфигурации,
//  ТекстОшибки - Строка - возвращаемый текст ошибки создания справки,
//  ВызыватьОбработчик - Булево - признак вызова обработчика переопределяемого модуля.
//
// Возвращаемое значение:
//   СправочникСсылка.Справки1ЕГАИС, СправочникСсылка.Справки2ЕГАИС - созданная (найденная) справка.
//
Функция СоздатьСправку(ДанныеСправки, ВидСправки) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.СоздатьСправку(ДанныеСправки, ВидСправки) 
```
</details>

## ЗапуститьОбработкуОтветовЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура запуска регламентного задания ОбработкаОтветовЕГАИС.
//
Процедура ЗапуститьОбработкуОтветовЕГАИС() Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ЗапуститьОбработкуОтветовЕГАИС() 
```
</details>

## УстановитьПараметрыСеанса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет установку параметров сеанса. Вызывается из модуля сеанса.
//
// Параметры:
//   ИмяПараметра           - строка - имя параметра сеанса.
//   УстановленныеПараметры - массив - все установленные параметры сеанса.
//
Процедура УстановитьПараметрыСеанса(ИмяПараметра, УстановленныеПараметры) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.УстановитьПараметрыСеанса(ИмяПараметра, УстановленныеПараметры) 
```
</details>

## ПриОпределенииНастроекРегламентныхЗаданий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// см. РегламентныеЗаданияПереопределяемый.ПриОпределенииНастроекРегламентныхЗаданий
Процедура ПриОпределенииНастроекРегламентныхЗаданий(Настройки) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ПриОпределенииНастроекРегламентныхЗаданий(Настройки) 
```
</details>

## ПриПолученииСпискаШаблонов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// см. ОчередьЗаданийПереопределяемый.ПриПолученииСпискаШаблонов
Процедура ПриПолученииСпискаШаблонов(ШаблоныЗаданий) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ПриПолученииСпискаШаблонов(ШаблоныЗаданий) 
```
</details>

## ПриОпределенииПсевдонимовОбработчиков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// см. ОчередьЗаданийПереопределяемый.ПриОпределенииПсевдонимовОбработчиков
Процедура ПриОпределенииПсевдонимовОбработчиков(СоответствиеИменПсевдонимам) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ПриОпределенииПсевдонимовОбработчиков(СоответствиеИменПсевдонимам) 
```
</details>

## ЗначениеОпределяемогоТипаПоНаименованию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение переданного определяемого типа по переданному наименованию.
//
// Параметры:
//  ИмяТипа - Строка - Имя типа
//  Наименование - Строка - Наименование
//  ТочноеСоответствие - Булево - Точное соответствие
//  Родитель - Неопределено - Родитель
//  Владелец - Неопределено - Владелец
//
// Возвращаемое значение:
//  Произвольный, СправочникСсылкаИмяСправочника, Неопределено - Значение определяемого типа по наименованию
Функция ЗначениеОпределяемогоТипаПоНаименованию(ИмяТипа, Наименование, ТочноеСоответствие, Родитель = Неопределено, Владелец = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗначениеОпределяемогоТипаПоНаименованию(ИмяТипа, Наименование, ТочноеСоответствие, Родитель, Владелец);
```
</details>

## ПриОпределенииСправочниковХраненияФайлов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить справочники хранения файлов по типам владельцев.
//
// Параметры:
//  ТипВладелецФайла  - Тип - тип ссылки объекта, к которому добавляется файл.
//
//  ИменаСправочников - Соответствие - содержит в ключах имена справочников.
//                      При вызове содержит стандартное имя одного справочника,
//                      помеченного, как основной (если существует).
//                      Основной справочник используется для интерактивного
//                      взаимодействия с пользователем. Чтобы указать основной
//                      справочник, нужно установить Истина в значение соответствия.
//                      Если установить Истина более одного раза, тогда будет ошибка.
//
Процедура ПриОпределенииСправочниковХраненияФайлов(ТипВладелецФайла, ИменаСправочников) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ПриОпределенииСправочниковХраненияФайлов(ТипВладелецФайла, ИменаСправочников) 
```
</details>

## ПриОпределенииНастроекРаботыСФайлами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриОпределенииНастроекРаботыСФайлами(Настройки) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ПриОпределенииНастроекРаботыСФайлами(Настройки) 
```
</details>

## ТекстЗапросаВТКоэффициентыПересчетаВЕдиницыЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текст запроса для формирования временной таблицы коэффициентов пересчета базовых единиц измерения
// номенклатуры в единицы ЕГАИС:
//   - для упакованного товара: коэффициент пересчета в штуки (бутылки)
//   - для неупакованного товара: коэффициент пересчета в декалитры.
// Временная таблица используется при проведении документов по регистру ОстаткиЕГАИС и при передаче данных в УТМ.
//
// Параметры:
//  ИмяТаблицыТовары - Строка - Имя таблицы с колонками: АлкогольнаяПродукция, Номенклатура, Характеристика, Серия.
//  ИмяВременнойТаблицы - Строка - Имя результирующей временной таблицы.
//  ДобавлятьРазделитель - Булево - Признак добавления разделителя запросов.
//
// Возвращаемое значение:
//  Строка - Текст запроса.
//
Функция ТекстЗапросаВТКоэффициентыПересчетаВЕдиницыЕГАИС(ИмяТаблицыТовары = "ВТТовары", ИмяВременнойТаблицы = "ВТКоэффициентыПересчетаВЕдиницыЕГАИС", ДобавлятьРазделитель = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ТекстЗапросаВТКоэффициентыПересчетаВЕдиницыЕГАИС(ИмяТаблицыТовары, ИмяВременнойТаблицы, ДобавлятьРазделитель);
```
</details>

## ИспользуетсяИнтеграцияВФормеДокументаОснования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИспользуетсяИнтеграцияВФормеДокументаОснования(Форма, Объект) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ИспользуетсяИнтеграцияВФормеДокументаОснования(Форма, Объект) 
```
</details>

## ПредставлениеДокументаАктСписанияЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Возвращает структуру данных описания гиперссылки документа Акт списания ЕГАИС.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * КомандаСоздать - Строка - Текст гиперссылки создания нового документа.
//   * ИмяКомандыСоздать - Строка - Имя команды Создать.
//   * ИмяКомандыОткрыть - Строка - Имя команды Открыть.
//   * ДокументОтсутствуетНетПравНаСоздание - Строка - Текст гиперссылки на создание документа, в случае отсутствия прав.
//   * Представление - Строка - Текст гиперссылки на список документов.
//   * НесколькоДокументовПредставление - Строка - Текст гиперссылки если найдено несколько документов.
//
Функция ПредставлениеДокументаАктСписанияЕГАИС() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПредставлениеДокументаАктСписанияЕГАИС());
```
</details>

## ПредставлениеДокументаАктПостановкиНаБалансЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру данных описания гиперссылки документа Акт списания ЕГАИС.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * КомандаСоздать - Строка - Текст гиперссылки создания нового документа.
//   * ИмяКомандыСоздать - Строка - Имя команды Создать.
//   * ИмяКомандыОткрыть - Строка - Имя команды Открыть.
//   * ДокументОтсутствуетНетПравНаСоздание - Строка - Текст гиперссылки на создание документа, в случае отсутствия прав.
//   * Представление - Строка - Текст гиперссылки на список документов.
//   * НесколькоДокументовПредставление - Строка - Текст гиперссылки если найдено несколько документов.
//
Функция ПредставлениеДокументаАктПостановкиНаБалансЕГАИС() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПредставлениеДокументаАктПостановкиНаБалансЕГАИС());
```
</details>

## ПредставлениеДокументаТТНИсходящаяЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру данных описания гиперссылки документа ТТН ЕГАИС (исходящая).
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * КомандаСоздать - Строка - Текст гиперссылки создания нового документа.
//   * ИмяКомандыСоздать - Строка - Имя команды Создать.
//   * ИмяКомандыОткрыть - Строка - Имя команды Открыть.
//   * ДокументОтсутствуетНетПравНаСоздание - Строка - Текст гиперссылки на создание документа, в случае отсутствия прав.
//   * Представление - Строка - Текст гиперссылки на список документов.
//   * НесколькоДокументовПредставление - Строка - Текст гиперссылки если найдено несколько документов.
//
Функция ПредставлениеДокументаТТНИсходящаяЕГАИС() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПредставлениеДокументаТТНИсходящаяЕГАИС());
```
</details>

## ПредставлениеДокументаТТНВходящаяЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру данных описания гиперссылки документа ТТН ЕГАИС (входящая).
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * КомандаСоздать - Строка - Текст гиперссылки создания нового документа.
//   * ИмяКомандыСоздать - Строка - Имя команды Создать.
//   * ИмяКомандыОткрыть - Строка - Имя команды Открыть.
//   * ДокументОтсутствуетНетПравНаСоздание - Строка - Текст гиперссылки на создание документа, в случае отсутствия прав.
//   * Представление - Строка - Текст гиперссылки на список документов.
//   * НесколькоДокументовПредставление - Строка - Текст гиперссылки если найдено несколько документов.
//
Функция ПредставлениеДокументаТТНВходящаяЕГАИС() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПредставлениеДокументаТТНВходящаяЕГАИС());
```
</details>

## ПредставлениеДокументаЧекЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру данных описания гиперссылки документа Чек ЕГАИС.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * КомандаСоздать - Строка - Текст гиперссылки создания нового документа.
//   * ИмяКомандыСоздать - Строка - Имя команды Создать.
//   * ИмяКомандыОткрыть - Строка - Имя команды Открыть.
//   * ДокументОтсутствуетНетПравНаСоздание - Строка - Текст гиперссылки на создание документа, в случае отсутствия прав.
//   * Представление - Строка - Текст гиперссылки на список документов.
//   * НесколькоДокументовПредставление - Строка - Текст гиперссылки если найдено несколько документов.
//
Функция ПредставлениеДокументаЧекЕГАИС() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПредставлениеДокументаЧекЕГАИС());
```
</details>

## ПредставлениеДокументаЧекЕГАИСВозврат
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру данных описания гиперссылки документа Чек ЕГАИС на возврат.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * КомандаСоздать - Строка - Текст гиперссылки создания нового документа.
//   * ИмяКомандыСоздать - Строка - Имя команды Создать.
//   * ИмяКомандыОткрыть - Строка - Имя команды Открыть.
//   * ДокументОтсутствуетНетПравНаСоздание - Строка - Текст гиперссылки на создание документа, в случае отсутствия прав.
//   * Представление - Строка - Текст гиперссылки на список документов.
//   * НесколькоДокументовПредставление - Строка - Текст гиперссылки если найдено несколько документов.
//
Функция ПредставлениеДокументаЧекЕГАИСВозврат() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПредставлениеДокументаЧекЕГАИСВозврат());
```
</details>

## ПредставлениеДокументаПередачаВРегистр2ЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру данных описания гиперссылки документа Передача в регистр 2.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * КомандаСоздать - Строка - Текст гиперссылки создания нового документа.
//   * ИмяКомандыСоздать - Строка - Имя команды Создать.
//   * ИмяКомандыОткрыть - Строка - Имя команды Открыть.
//   * ДокументОтсутствуетНетПравНаСоздание - Строка - Текст гиперссылки на создание документа, в случае отсутствия прав.
//   * Представление - Строка - Текст гиперссылки на список документов.
//   * НесколькоДокументовПредставление - Строка - Текст гиперссылки если найдено несколько документов.
//
Функция ПредставлениеДокументаПередачаВРегистр2ЕГАИС() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПредставлениеДокументаПередачаВРегистр2ЕГАИС());
```
</details>

## ПредставлениеДокументаВозвратИзРегистра2ЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру данных описания гиперссылки документа Возврат из регистра 2.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * КомандаСоздать - Строка - Текст гиперссылки создания нового документа.
//   * ИмяКомандыСоздать - Строка - Имя команды Создать.
//   * ИмяКомандыОткрыть - Строка - Имя команды Открыть.
//   * ДокументОтсутствуетНетПравНаСоздание - Строка - Текст гиперссылки на создание документа, в случае отсутствия прав.
//   * Представление - Строка - Текст гиперссылки на список документов.
//   * НесколькоДокументовПредставление - Строка - Текст гиперссылки если найдено несколько документов.
//
Функция ПредставлениеДокументаВозвратИзРегистра2ЕГАИС() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПредставлениеДокументаВозвратИзРегистра2ЕГАИС());
```
</details>

## ПредставлениеДокументаУведомлениеОПланируемомИмпортеЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру данных описания гиперссылки документа Уведомление о планируемом импорте.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * КомандаСоздать - Строка - Текст гиперссылки создания нового документа.
//   * ИмяКомандыСоздать - Строка - Имя команды Создать.
//   * ИмяКомандыОткрыть - Строка - Имя команды Открыть.
//   * ДокументОтсутствуетНетПравНаСоздание - Строка - Текст гиперссылки на создание документа, в случае отсутствия прав.
//   * Представление - Строка - Текст гиперссылки на список документов.
//   * НесколькоДокументовПредставление - Строка - Текст гиперссылки если найдено несколько документов.
//
Функция ПредставлениеДокументаУведомлениеОПланируемомИмпортеЕГАИС() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПредставлениеДокументаУведомлениеОПланируемомИмпортеЕГАИС());
```
</details>

## ПредставлениеДокументаОтчетОбИмпортеЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру данных описания гиперссылки документа Отчет об импорте.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * КомандаСоздать - Строка - Текст гиперссылки создания нового документа.
//   * ИмяКомандыСоздать - Строка - Имя команды Создать.
//   * ИмяКомандыОткрыть - Строка - Имя команды Открыть.
//   * ДокументОтсутствуетНетПравНаСоздание - Строка - Текст гиперссылки на создание документа, в случае отсутствия прав.
//   * Представление - Строка - Текст гиперссылки на список документов.
//   * НесколькоДокументовПредставление - Строка - Текст гиперссылки если найдено несколько документов.
//
Функция ПредставлениеДокументаОтчетОбИмпортеЕГАИС() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПредставлениеДокументаОтчетОбИмпортеЕГАИС());
```
</details>

## ПредставлениеДокументаОтчетОПроизводствеЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру данных описания гиперссылки документа Отчет о производстве.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * КомандаСоздать - Строка - Текст гиперссылки создания нового документа.
//   * ИмяКомандыСоздать - Строка - Имя команды Создать.
//   * ИмяКомандыОткрыть - Строка - Имя команды Открыть.
//   * ДокументОтсутствуетНетПравНаСоздание - Строка - Текст гиперссылки на создание документа, в случае отсутствия прав.
//   * Представление - Строка - Текст гиперссылки на список документов.
//   * НесколькоДокументовПредставление - Строка - Текст гиперссылки если найдено несколько документов.
//
Функция ПредставлениеДокументаОтчетОПроизводствеЕГАИС() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПредставлениеДокументаОтчетОПроизводствеЕГАИС());
```
</details>

## ПредставлениеДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить данные для заполнения представления документа.
//
// Параметры:
//  МетаданныеДокумента - ОбъектМетаданных - Метаданные документа.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//  * КомандаСоздать - Строка - Представление документа, если документ требуется создать.
//  * ИмяКомандыСоздать - Строка - Имя команды "Создать".
//  * ИмяКомандыОткрыть - Строка - Имя команды "Открыть".
//  * ДокументОтсутствуетНетПравНаСоздание - Строка - Представление документа, если документ не создан.
//  * Представление - Строка - Представление документа.
//  * НесколькоДокументовПредставление - Строка - Представление документа, если их несколько.
//
Функция ПредставлениеДокумента(МетаданныеДокумента) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПредставлениеДокумента(МетаданныеДокумента) 
```
</details>

## ДанныеДокументаЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить данные документа ЕГАИС
//
// Параметры:
//  МетаданныеДокумента - ОбъектМетаданных - Метаданные документа.
//  ДокументыПоОснованию - Структура - структура со свойствами:
//   * ВозвратИзРегистра2ЕГАИС - Структура - структура со свойствами:
//     ** Ссылка - ДокументСсылка - Документ.
//     ** Статус - ПеречислениеСсылка.СтатусыОбработкиВозвратаИзРегистра2ЕГАИС - Статус документа.
//   * ПередачаВРегистр2ЕГАИС - Структура - Структура со свойствами:
//     ** Ссылка - ДокументСсылка - Документ.
//     ** Статус - ПеречислениеСсылка.СтатусыОбработкиПередачиВРегистр2ЕГАИС - Статус документа.
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * Представление - Строка - Представление документа.
//   * МассивДокументов - Массив - Массив документов.
//   * МетаданныеДокумента - ОбъектМетаданных - Метаданные документа.
//
Функция ДанныеДокументаЕГАИС(МетаданныеДокумента, ДокументыПоОснованию, СтатусыОформления) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ДанныеДокументаЕГАИС(МетаданныеДокумента, ДокументыПоОснованию, СтатусыОформления) 
```
</details>

## ДанныеОформленияДокументовПоПриоритетам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДанныеОформленияДокументовПоПриоритетам(ДокументСсылка) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ДанныеОформленияДокументовПоПриоритетам(ДокументСсылка) 
```
</details>

## РезультатыЗапросаПередачиВРегистры2и3ПоТТНВходящей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РезультатыЗапросаПередачиВРегистры2и3ПоТТНВходящей(ДокументСсылка) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.РезультатыЗапросаПередачиВРегистры2и3ПоТТНВходящей(ДокументСсылка) 
```
</details>

## ЗаполнитьВXDTOОрганизацию_v1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект XDTO, соответствующий переданной организации.
//
Процедура ЗаполнитьВXDTOОрганизацию_v1(ОбъектXDTOРодитель, ИмяПоля, Источник, Префикс = "", СообщениеXML) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ЗаполнитьВXDTOОрганизацию_v1(ОбъектXDTOРодитель, ИмяПоля, Источник, Префикс, СообщениеXML) 
```
</details>

## ЗаполнитьВXDTOОрганизацию_v2
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект XDTO, соответствующий переданной организации.
//
Процедура ЗаполнитьВXDTOОрганизацию_v2(ОбъектXDTOРодитель, ИмяПоля, Источник, Префикс = "", СообщениеXML) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ЗаполнитьВXDTOОрганизацию_v2(ОбъектXDTOРодитель, ИмяПоля, Источник, Префикс, СообщениеXML) 
```
</details>

## ЗаполнитьВXDTOОрганизациюСЮрАдресом_v2
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект XDTO, соответствующий переданной организации.
//
Процедура ЗаполнитьВXDTOОрганизациюСЮрАдресом_v2(ОбъектXDTOРодитель, ИмяПоля, Источник, Префикс = "", СообщениеXML) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ЗаполнитьВXDTOОрганизациюСЮрАдресом_v2(ОбъектXDTOРодитель, ИмяПоля, Источник, Префикс, СообщениеXML) 
```
</details>

## ЗаполнитьВXDTOАлкогольнуюПродукцию_v1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

	// Функция возвращает объект XDTO, соответствующий переданной алкогольной продукции.
//
Процедура ЗаполнитьВXDTOАлкогольнуюПродукцию_v1(ОбъектXDTO, Источник, Префикс = "", СообщениеXML) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ЗаполнитьВXDTOАлкогольнуюПродукцию_v1(ОбъектXDTO, Источник, Префикс, СообщениеXML) 
```
</details>

## ЗаполнитьВXDTOАлкогольнуюПродукцию_v2
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект XDTO, соответствующий переданной алкогольной продукции.
//
Процедура ЗаполнитьВXDTOАлкогольнуюПродукцию_v2(ОбъектXDTO, Источник, Префикс = "", СообщениеXML) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ЗаполнитьВXDTOАлкогольнуюПродукцию_v2(ОбъектXDTO, Источник, Префикс, СообщениеXML) 
```
</details>

## ЗаполнитьВXDTOИностраннуюАлкогольнуюПродукцию_v2
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект XDTO, соответствующий переданной алкогольной продукции.
//
Процедура ЗаполнитьВXDTOИностраннуюАлкогольнуюПродукцию_v2(ОбъектXDTO, Источник, Префикс = "", СообщениеXML) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ЗаполнитьВXDTOИностраннуюАлкогольнуюПродукцию_v2(ОбъектXDTO, Источник, Префикс, СообщениеXML) 
```
</details>

## ЗаполнитьВXDTOТранспортныйРазделТТН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект XDTO, соответствующий транспортному разделу ТТН.
//
// Параметры:
//  ДоставкаXDTO - ОбъектXDTO - Доставка XDTO
//  Источник - Произвольный - Источник
//  СообщениеXML - Структура - Сообщение XML
//
// Возвращаемое значение:
//  Булево - Заполнить ВXDTOТранспортный раздел ТТН
Функция ЗаполнитьВXDTOТранспортныйРазделТТН(ДоставкаXDTO, Источник, СообщениеXML) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗаполнитьВXDTOТранспортныйРазделТТН(ДоставкаXDTO, Источник, СообщениеXML) 
```
</details>

## ЗаполнитьВXDTOТранспортныйРазделТТН_v4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект XDTO, соответствующий транспортному разделу ТТН.
//
// Параметры:
//  ДоставкаXDTO - ОбъектXDTO - Доставка XDTO
//  Источник - Произвольный - Источник
//  СообщениеXML - Структура - Сообщение XML
//
// Возвращаемое значение:
//  Булево - Заполнить ВXDTOТранспортный раздел ТТН v4
Функция ЗаполнитьВXDTOТранспортныйРазделТТН_v4(ДоставкаXDTO, Источник, СообщениеXML) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗаполнитьВXDTOТранспортныйРазделТТН_v4(ДоставкаXDTO, Источник, СообщениеXML) 
```
</details>

## ТипТранспорта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразовывает текстовое представление статуса документа в значение перечисления и наоборот.
//
// Параметры:
//  ЗначениеПоиска - ПеречислениеСсылка.ТипыТранспортаЕГАИС, Строка - значение для перекодировки
//  Формат - Строка - Формат значения
//  ИспользоватьИсключение - Булево - Истина, если требуется вызывать исключение.
//
// Возвращаемое значение:
//  ПеречислениеСсылка.ТипыТранспортаЕГАИС, Строка, Неопределено - статус документа.
Функция ТипТранспорта(Знач ЗначениеПоиска, Формат = "WayBill", ИспользоватьИсключение = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ТипТранспорта(ЗначениеПоиска, Формат, ИспользоватьИсключение);
```
</details>

## ТоварВПутиПринадлежитГрузоотправителю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразовывает текстовое представление флага "Товар в пути принадлежит грузополучателю" в значение перечисления и наоборот.
//
// Параметры:
//  ЗначениеПоиска - Булево, Строка - значение для перекодировки
//
// Возвращаемое значение:
//  Булево, Строка - Товар в пути принадлежит грузополучателю.
Функция ТоварВПутиПринадлежитГрузоотправителю(Знач ЗначениеПоиска) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ТоварВПутиПринадлежитГрузоотправителю(ЗначениеПоиска) 
```
</details>

## ЗаполнитьВXDTOАкцизныеМаркиПоОтбору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект XDTO, соответствующий переданным акцизным маркам.
//
Процедура ЗаполнитьВXDTOАкцизныеМаркиПоОтбору(ОбъектXDTO, ПараметрыОтбора, ИсточникАкцизныеМарки, ИмяПоля, СообщениеXML) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ЗаполнитьВXDTOАкцизныеМаркиПоОтбору(ОбъектXDTO, ПараметрыОтбора, ИсточникАкцизныеМарки, ИмяПоля, СообщениеXML) 
```
</details>

## ЗаполнитьВXDTOАкцизныеМаркиПоСправке2_v2
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект XDTO, соответствующий переданным акцизным маркам.
//
Процедура ЗаполнитьВXDTOАкцизныеМаркиПоСправке2_v2(ОбъектXDTO, Источник, ИсточникАкцизныеМарки, ИмяПоля, СообщениеXML) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ЗаполнитьВXDTOАкцизныеМаркиПоСправке2_v2(ОбъектXDTO, Источник, ИсточникАкцизныеМарки, ИмяПоля, СообщениеXML) 
```
</details>

## ЗаполнитьВXDTOАкцизныеМаркиПоСправке2_v3
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект XDTO, соответствующий переданным акцизным маркам.
//
Процедура ЗаполнитьВXDTOАкцизныеМаркиПоСправке2_v3(ОбъектXDTO, Источник, ИсточникАкцизныеМарки, СообщениеXML) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ЗаполнитьВXDTOАкцизныеМаркиПоСправке2_v3(ОбъектXDTO, Источник, ИсточникАкцизныеМарки, СообщениеXML) 
```
</details>

## ЗаполнитьВXDTOАкцизныеМаркиПоСправке2_v4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает объект XDTO, соответствующий переданным акцизным маркам.
//
Процедура ЗаполнитьВXDTOАкцизныеМаркиПоСправке2_v4(ОбъектXDTO, Источник, ИсточникАкцизныеМарки, СообщениеXML) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ЗаполнитьВXDTOАкцизныеМаркиПоСправке2_v4(ОбъектXDTO, Источник, ИсточникАкцизныеМарки, СообщениеXML) 
```
</details>

## ОбработатьОтветНаЗапросПолученияДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обрабатывает ответ ЕГАИС на запрос о получении документа.
//
// Параметры:
//  ВходящиеДанные - (См. ОбменДаннымиЕГАИСКлиентСервер.СтруктураЗагрузкиВходящегоДокумента).
//  ТаблицаСоответствияДокументовТипамЕГАИС - ТаблицаЗначений - см. функцию Перечисления.ВидыДокументовЕГАИС.ТаблицаСоответствияДокументовТипамЕГАИС().
//
// Возвращаемое значение:
//  Структура:
//   * Результат         - Неопределено, Структура - результат выполнения запроса.
//   * ТекстОшибки       - Строка - текст ошибки, в случае ее возникновения.
//   * ТекстСообщенияXML - Строка - содержит ответ, полученный на запрос.
//   * СтатусОбработки   - ПеречислениеСсылка.СтатусыОбработкиСообщенийЕГАИС - Статус обработки сообщения.
//
Функция ОбработатьОтветНаЗапросПолученияДокумента(ВходящиеДанные, ТаблицаСоответствияДокументовТипамЕГАИС = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ОбработатьОтветНаЗапросПолученияДокумента(ВходящиеДанные, ТаблицаСоответствияДокументовТипамЕГАИС);
```
</details>

## НайтиОбъектПоИдентификатору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НайтиОбъектПоИдентификатору(МетаданныеОбъекта, ИмяРеквизита, Значение, ВидКвитанции = Неопределено, ОрганизацияЕГАИС = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.НайтиОбъектПоИдентификатору(МетаданныеОбъекта, ИмяРеквизита, Значение, ВидКвитанции, ОрганизацияЕГАИС);
```
</details>

## ПараметрыИдентификатораЗапросаV4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПараметрыИдентификатораЗапросаV4(ИдентификаторЗапроса) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПараметрыИдентификатораЗапросаV4(ИдентификаторЗапроса) 
```
</details>

## НайтиОбъектПоИдентификаторуЗапроса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные последнего исходящего запроса по идентификатору.
//
// Параметры:
//  ИдентификаторЗапроса - Строка - идентификатор исходящего запроса.
//
// Возвращаемое значение:
//   Структура - данные последнего исходящего запроса. Неопределено - если запрос не найден.
//
Функция НайтиОбъектПоИдентификаторуЗапроса(ИдентификаторЗапроса, ИскатьДокументОснование = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.НайтиОбъектПоИдентификаторуЗапроса(ИдентификаторЗапроса, ИскатьДокументОснование);
```
</details>

## НайтиОбъектПоИдентификаторуТипаЕГАИСПриЗагрузкеКвитанции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает вид документа и ссылку на документ-основание, выгруженного ранее в ЕГАИС
//
Функция НайтиОбъектПоИдентификаторуТипаЕГАИСПриЗагрузкеКвитанции(Идентификатор, ТипЕГАИС, ВидКвитанции, ОрганизацияЕГАИС = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.НайтиОбъектПоИдентификаторуТипаЕГАИСПриЗагрузкеКвитанции(Идентификатор, ТипЕГАИС, ВидКвитанции, ОрганизацияЕГАИС);
```
</details>

## НайтиУведомлениеОРегистрацииСправок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НайтиУведомлениеОРегистрацииСправок(ДанныеТТН, ДанныеДокументовРегистрацияСправок) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.НайтиУведомлениеОРегистрацииСправок(ДанныеТТН, ДанныеДокументовРегистрацияСправок) 
```
</details>

## НайтиИсториюСправок2ПоТТН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Возвращает историю справок 2 по ТТН из массива полученных историй
//
// Возвращаемое значение:
//   Произвольный - история справок 2
Функция НайтиИсториюСправок2ПоТТН(УведомлениеОРегистрации, ИсторияСправок2ПоТТН) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.НайтиИсториюСправок2ПоТТН(УведомлениеОРегистрации, ИсторияСправок2ПоТТН) 
```
</details>

## ИсходящееСообщение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИсходящееСообщение(ИдентификаторЗапроса) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ИсходящееСообщение(ИдентификаторЗапроса) 
```
</details>

## ЗагрузитьТТНВходящуюЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает ТТН на основании переданных данных.
//
// Параметры:
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьТТНВходящуюЕГАИС(ОрганизацияЕГАИС, ДополнительныеДанные) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьТТНВходящуюЕГАИС(ОрганизацияЕГАИС, ДополнительныеДанные) 
```
</details>

## ЗагрузитьУведомлениеОРегистрацииДвиженияТТН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует новые справки 1 и 2 и заполняет их в табличной части ТТН.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьУведомлениеОРегистрацииДвиженияТТН(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьУведомлениеОРегистрацииДвиженияТТН(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьУведомлениеОРегистрацииДвиженияАктаПостановкиНаБаланс
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует новые справки 1 и 2 и заполняет их в табличной части акта.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьУведомлениеОРегистрацииДвиженияАктаПостановкиНаБаланс(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьУведомлениеОРегистрацииДвиженияАктаПостановкиНаБаланс(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьУведомлениеОРегистрацииДвиженияОтчетаОбИмпортеПроизводстве
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует новые справки 1 и 2 и заполняет их в табличной части акта.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьУведомлениеОРегистрацииДвиженияОтчетаОбИмпортеПроизводстве(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьУведомлениеОРегистрацииДвиженияОтчетаОбИмпортеПроизводстве(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьКвитанциюАктаРасхожденийТТН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет действия при получении подтверждения акта расхождений ТТН.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьКвитанциюАктаРасхожденийТТН(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьКвитанциюАктаРасхожденийТТН(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьКвитанциюЗапросаНаОтменуПроведенияТТН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет действия при получении подтверждения акта расхождений ТТН.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьКвитанциюЗапросаНаОтменуПроведенияТТН(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьКвитанциюЗапросаНаОтменуПроведенияТТН(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьАктПоИсходящейТТНЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет действия при получении акта подтверждения ТТН.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьАктПоИсходящейТТНЕГАИС(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьАктПоИсходящейТТНЕГАИС(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьЗапросНаОтменуПроведенияТТН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет действия при получении запроса на отмену проведения ТТН.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьЗапросНаОтменуПроведенияТТН(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьЗапросНаОтменуПроведенияТТН(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьОтветНаЗапросАлкогольнойПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает список организаций ЕГАИС в базу.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьОтветНаЗапросАлкогольнойПродукции(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьОтветНаЗапросАлкогольнойПродукции(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ПрочитатьОтветНаЗапросПроверкиАкцизныхМарокНаОстаткахОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Читает результат проверки акцизных марок на остатках организации
//
// Параметры:
//  ТекстСообщенияXML - Строка - Текст сообщения XML
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
// Возвращаемое значение:
//  Структура - Описание:
//    * ОтсутствующиеАкцизныеМарки - Массив Из Строка - Отсутствующие акцизные марки
//                                 - Неопределено - Если необходимо анализировать Описание
//    * Описание - Строка - Описание результата
Функция ПрочитатьОтветНаЗапросПроверкиАкцизныхМарокНаОстаткахОрганизации(ТекстСообщенияXML, ОрганизацияЕГАИС) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПрочитатьОтветНаЗапросПроверкиАкцизныхМарокНаОстаткахОрганизации(ТекстСообщенияXML, ОрганизацияЕГАИС) 
```
</details>

## ЗагрузитьОрганизацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Загружает организацию ЕГАИС в базу.
//  * При загрузке запросом из классификатора - безусловно.
//  * При загрузке в составе пакета (например ТТН) - создание новых элементов и обновление контрагентов
//    (флаг "Соответствует организации" установлен в Ложь).
//
//Параметры:
//   ДанныеОрганизацииXDTO - ОбъектXDTO - данные классификатора организаций ЕГАИС
//   ЗагрузкаИзКлассификатора - Булево - признак запроса данных из классификатора
//
//Возвращаемое значение:
//   СправочникСсылка.КлассификаторОрганизацийЕГАИС - найденный или загруженный элемент классификатора.
//
Функция ЗагрузитьОрганизацию(ДанныеОрганизацииXDTO, ЗагрузкаИзКлассификатора = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьОрганизацию(ДанныеОрганизацииXDTO, ЗагрузкаИзКлассификатора);
```
</details>

## ЗагрузитьОтветНаЗапросОстатковВРегистре1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает остатки ЕГАИС по регистру №1 в базу данных.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьОтветНаЗапросОстатковВРегистре1(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьОтветНаЗапросОстатковВРегистре1(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьОтветНаЗапросОстатковВРегистре2
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает остатки ЕГАИС по регистру №2 в базу данных.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьОтветНаЗапросОстатковВРегистре2(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьОтветНаЗапросОстатковВРегистре2(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьОтветНаЗапросАкцизныхМарок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает новые штрихкоды акцизных марок (для замены испорченных) в базу данных.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьОтветНаЗапросАкцизныхМарок(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьОтветНаЗапросАкцизныхМарок(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьОтветНаЗапросОтчетаДвиженияМеждуРегистрами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает данные отчета Движения между регистрами в базу данных.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьОтветНаЗапросОтчетаДвиженияМеждуРегистрами(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьОтветНаЗапросОтчетаДвиженияМеждуРегистрами(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьОтветНаЗапросОтчетаДвиженияПоСправке2
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает данные отчета Движения между регистрами в базу данных.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьОтветНаЗапросОтчетаДвиженияПоСправке2(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьОтветНаЗапросОтчетаДвиженияПоСправке2(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьОтветНаЗапросОтчетаИнформацияОбОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает данные отчета Информация об организации в базу данных.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьОтветНаЗапросОтчетаИнформацияОбОрганизации(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьОтветНаЗапросОтчетаИнформацияОбОрганизации(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьОтветНаЗапросОтчетаНеобработанныеТТН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает данные отчета Необработанные ТТН в базу данных.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьОтветНаЗапросОтчетаНеобработанныеТТН(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьОтветНаЗапросОтчетаНеобработанныеТТН(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьОтветНаЗапросОтчетаОбработанныеЧеки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает данные отчета Обработанные чеки в базу данных.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьОтветНаЗапросОтчетаОбработанныеЧеки(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьОтветНаЗапросОтчетаОбработанныеЧеки(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьОтветНаЗапросОтчетаОстаткиВРегистре1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает данные отчета Остатки в регистре №1 в базу данных.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьОтветНаЗапросОтчетаОстаткиВРегистре1(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьОтветНаЗапросОтчетаОстаткиВРегистре1(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьОтветНаЗапросОтчетаОстаткиВРегистре2
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает данные отчета Остатки в регистре №2 в базу данных.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьОтветНаЗапросОтчетаОстаткиВРегистре2(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьОтветНаЗапросОтчетаОстаткиВРегистре2(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьОтветНаЗапросОтчетаОстаткиВРегистре3
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает данные отчета Остатки в регистре №3 в базу данных.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьОтветНаЗапросОтчетаОстаткиВРегистре3(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьОтветНаЗапросОтчетаОстаткиВРегистре3(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьОтветНаЗапросОтчетаИсторияСправок2
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает данные отчета История справок 2 в базу данных.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьОтветНаЗапросОтчетаИсторияСправок2(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьОтветНаЗапросОтчетаИсторияСправок2(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьИсториюСправок2ПоТТН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает историю справок 2 по ТТН в базу данных.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьИсториюСправок2ПоТТН(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьИсториюСправок2ПоТТН(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьВходящуюТранспортнуюНакладную
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает историю справок 2 по ТТН в базу данных.
//
// Параметры:
//  ЭлементДанных - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьВходящуюТранспортнуюНакладную(ЭлементДанных, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьВходящуюТранспортнуюНакладную(ЭлементДанных, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ЗагрузитьСправку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает справки по формам А и Б в базу данных.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьСправку(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьСправку(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## ОбработатьКвитанциюАСИиУ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обрабатывает квитанцию АСИиУ - только отметка о прочтении для удаления из очереди
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ОбработатьКвитанциюАСИиУ(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ОбработатьКвитанциюАСИиУ(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры) 
```
</details>

## ЗагрузитьКвитанцию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает и обрабатывает квитанцию из ЕГАИС.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//  ДополнительныеПараметры - Неопределено - Дополнительные параметры
//
// Возвращаемое значение:
//  см. ЗагрузитьКвитанциюПолученЕГАИС
Функция ЗагрузитьКвитанцию(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьКвитанцию(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## НеТребуетсяПроведениеЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Не требуется проведение ЕГАИС.
//
// Параметры:
//  Операция - Произвольный - Операция
//
// Возвращаемое значение:
//  Булево - Не требуется проведение ЕГАИС
Функция НеТребуетсяПроведениеЕГАИС(Операция) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.НеТребуетсяПроведениеЕГАИС(Операция));
```
</details>

## ЗагрузитьКвитанциюПолученЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает информацию о фиксации документа в ЕГАИС.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ДанныеОснованияКвитанции - Структура -
//  ИдентификаторЕГАИС - Строка - Идентификатор ЕГАИС
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьКвитанциюПолученЕГАИС(ДанныеДокумента, ДанныеОснованияКвитанции, ИдентификаторЕГАИС, ОрганизацияЕГАИС) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьКвитанциюПолученЕГАИС(ДанныеДокумента, ДанныеОснованияКвитанции, ИдентификаторЕГАИС, ОрганизацияЕГАИС) 
```
</details>

## ЗагрузитьКвитанциюПроведенЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает информацию о проведении документа в ЕГАИС.
//
// Параметры:
//  ДанныеДокумента - Структура - Данные документа
//  ДанныеОснованияКвитанции - Структура -
//  ИдентификаторЕГАИС - Строка - Идентификатор ЕГАИС
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьКвитанциюПроведенЕГАИС(ДанныеДокумента, ДанныеОснованияКвитанции, ИдентификаторЕГАИС, ОрганизацияЕГАИС) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗагрузитьКвитанциюПроведенЕГАИС(ДанныеДокумента, ДанныеОснованияКвитанции, ИдентификаторЕГАИС, ОрганизацияЕГАИС) 
```
</details>

## ДокументСоответствуетТипуЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет соответствие типа ЕГАИС и передаваемого документа.
//
Функция ДокументСоответствуетТипуЕГАИС(ДокументСсылка, ТипЕГАИС) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ДокументСоответствуетТипуЕГАИС(ДокументСсылка, ТипЕГАИС));
```
</details>

## ДанныеСправки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные справок А и Б в виде структуры для последующей загрузки в базу.
//
Функция ДанныеСправки(ДанныеДокумента, ВидСправки) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ДанныеСправки(ДанныеДокумента, ВидСправки));
```
</details>

## ДанныеОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает объект XDTO организации, которую требуется загрузить.
//
Функция ДанныеОрганизации(ДанныеОрганизации) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ДанныеОрганизации(ДанныеОрганизации));
```
</details>

## ТипОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает тип организации ЕГАИС.
//
// Параметры:
//  ДанныеОрганизации - ОбъектXDTO - Данные организации ЕГАИС.
//
// Возвращаемое значение:
//  ПеречислениеСсылка.ТипыОрганизацийЕГАИС - Тип организации ЕГАИС.
//
Функция ТипОрганизации(ДанныеОрганизации) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ТипОрганизации(ДанныеОрганизации));
```
</details>

## СлужебныеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структура данных для удаления запросов из УТМ.
//
// Параметры:
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС.
//  Операция - ПеречислениеСсылка.ВидыДокументовЕГАИС - Операция.
//  АдресЗапроса - Строка - Адрес запроса.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС.
//   * Операция - ПеречислениеСсылка.ВидыДокументовЕГАИС - Операция.
//   * АдресЗапроса - Строка - Адрес запроса.
//
Функция СлужебныеДанные(ОрганизацияЕГАИС, Операция, АдресЗапроса) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.СлужебныеДанные(ОрганизацияЕГАИС, Операция, АдресЗапроса));
```
</details>

## ЗначенияШтрихкодовИзДереваУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет поиск акцизных марок в дереве упаковок.
//
// Параметры:
//  ДеревоУпаковок - ДеревоЗначений - Дерево упаковок.
//  ЗначенияШтрихкодов - Массив - Массив найденных штрихкодов.
//
// Возвращаемое значение:
//  Массив - Найденные штрихкоды.
Функция ЗначенияШтрихкодовИзДереваУпаковок(ДеревоУпаковок, ЗначенияШтрихкодов = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЗначенияШтрихкодовИзДереваУпаковок(ДеревоУпаковок, ЗначенияШтрихкодов);
```
</details>

## ЗаписатьСтатусДокументаЕГАИСПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет начальную запись в регистр "Статусы документов ЕГАИС"
//
Процедура ЗаписатьСтатусДокументаЕГАИСПоУмолчанию(Источник) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ЗаписатьСтатусДокументаЕГАИСПоУмолчанию(Источник) 
```
</details>

## ОтборПоОрганизацииПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОтборПоОрганизацииПриСозданииНаСервере(Форма, Знач ЗначениеПрефиксы = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ОтборПоОрганизацииПриСозданииНаСервере(Форма, ЗначениеПрефиксы);
```
</details>

## НеотображаемыеВДокументахДальнейшиеДействия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует массив дальнейших действий, которые не отображаются при выводе статуса обмена с ЕГАИС в форме документа.
//
// Возвращаемое значение:
//  Массив - содержит неотображаемые дальнейшие действия.
//
Функция НеотображаемыеВДокументахДальнейшиеДействия() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.НеотображаемыеВДокументахДальнейшиеДействия() 
```
</details>

## ЗаполнитьСписокВыбораДальнейшееДействие
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет список дальнейших действий для быстрого отбора динамического списка "Дальнейшее действие"
//
// Параметры:
//  СписокВыбора         - СписокЗначений - формируемый список значений.
//  ВсеТребующиеДействия - Массив - действия, которые необходимо выполнить пользователю.
//  ВсеТребующиеОжидания - Массив - действия, выполнения которых ожидает пользователь.
//
Процедура ЗаполнитьСписокВыбораДальнейшееДействие(СписокВыбора, ВсеТребующиеДействия, ВсеТребующиеОжидания) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ЗаполнитьСписокВыбораДальнейшееДействие(СписокВыбора, ВсеТребующиеДействия, ВсеТребующиеОжидания) 
```
</details>

## УстановитьОтборПоДальнейшемуДействию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает отбор в динамическом списке по полю "Дальнейшее действие".
//
// Параметры:
//  ДинамическийСписок     - ДинамическийСписок - список, в котором устанавливается отбор.
//  ДальнейшееДействиеЕГАИС - Перечисление.ДальнейшееДействиеЕГАИС, Строка - значение устанавливаемого отбора.
//  ВсеТребующиеДействия - Массив - действия, которые необходимо выполнить пользователю.
//  ВсеТребующиеОжидания - Массив - действия, выполнения которых ожидает пользователь.
//
Процедура УстановитьОтборПоДальнейшемуДействию(ДинамическийСписок, ДальнейшееДействие, ВсеТребующиеДействия, ВсеТребующиеОжидания) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.УстановитьОтборПоДальнейшемуДействию(ДинамическийСписок, ДальнейшееДействие, ВсеТребующиеДействия, ВсеТребующиеОжидания) 
```
</details>

## ЕстьДвижения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверить наличие движений в зависимости от статусов.
//
// Параметры:
//  СтатусыДвижений - Массив - Статусы.
//  НовыйСтатус - ПеречислениеСсылка - Новый статус.
//  ПредыдущийСтатус - ПеречислениеСсылка - Новый статус.
//
// Возвращаемое значение:
//  Булево - Истина, если движения есть.
//
Функция ЕстьДвижения(СтатусыДвижений, ПредыдущийСтатус, НовыйСтатус) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ЕстьДвижения(СтатусыДвижений, ПредыдущийСтатус, НовыйСтатус) 
```
</details>

## НетДвижений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверить отсутствие движений в зависимости от статусов.
//
// Параметры:
//  СтатусыДвижений - Массив - Статусы.
//  НовыйСтатус - ПеречислениеСсылка - Новый статус.
//  ПредыдущийСтатус - ПеречислениеСсылка - Новый статус.
//
// Возвращаемое значение:
//  Булево - Истина, если движений нет.
//
Функция НетДвижений(СтатусыДвижений, ПредыдущийСтатус, НовыйСтатус) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.НетДвижений(СтатусыДвижений, ПредыдущийСтатус, НовыйСтатус) 
```
</details>

## СтатусТребуетОбновленияДвижений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитать необходимость обновления движений в зависимости от статуса.
//
// Параметры:
//  СтатусыДвижений - Массив - Статусы.
//  НовыйСтатус - ПеречислениеСсылка - Новый статус.
//  ПредыдущийСтатус - ПеречислениеСсылка - Новый статус.
//
// Возвращаемое значение:
//  Булево - Необходимость обновления движений.
//
Функция СтатусТребуетОбновленияДвижений(СтатусыДвижений, ПредыдущийСтатус, НовыйСтатус) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.СтатусТребуетОбновленияДвижений(СтатусыДвижений, ПредыдущийСтатус, НовыйСтатус) 
```
</details>

## СтатусТребуетДобавленияДвижений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитать необходимость добавления движений в зависимости от статуса.
//
// Параметры:
//  СтатусыДвижений - Массив - Статусы.
//  НовыйСтатус - ПеречислениеСсылка - Новый статус.
//  ПредыдущийСтатус - ПеречислениеСсылка - Новый статус.
//
// Возвращаемое значение:
//  Булево - Необходимость добавления движений.
//
Функция СтатусТребуетДобавленияДвижений(СтатусыДвижений, ПредыдущийСтатус, НовыйСтатус) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.СтатусТребуетДобавленияДвижений(СтатусыДвижений, ПредыдущийСтатус, НовыйСтатус) 
```
</details>

## СтатусТребуетУдаленияДвижений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитать необходимость удаления движений в зависимости от статуса.
//
// Параметры:
//  СтатусыДвижений - Массив - Статусы.
//  НовыйСтатус - ПеречислениеСсылка - Новый статус.
//  ПредыдущийСтатус - ПеречислениеСсылка - Новый статус.
//
// Возвращаемое значение:
//  Булево - Необходимость удаления движений.
//
Функция СтатусТребуетУдаленияДвижений(СтатусыДвижений, ПредыдущийСтатус, НовыйСтатус) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.СтатусТребуетУдаленияДвижений(СтатусыДвижений, ПредыдущийСтатус, НовыйСтатус) 
```
</details>

## НастройкиСопоставленияАлкогольнойПродукцииСНоменклатуройВДокументе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает настройки по умолчанию (имя табличной части и имена колонок табличной части документов)
//   для записи в регистр "СопоставлениеНоменклатурыЕГАИС" из документа, в котором выполнено сопоставление данных.
//
// Параметры:
//   ИмяКолонкиАлкогольнаяПродукция - Строка - имя колонки алкогольной продукции в табличной части документа
// Возвращаемое значение:
//   Структура - параметры сопоставления документа и регистра соответствия:
//   * Колонки - Структура - имена колонок табличной части документа для записи регистра сопоставления.
//       Незаполненное значение означает что колонка не используется / не проверяется:
//    ** АлкогольнаяПродукция  - Строка - имя колонки (обязательно используется),
//    ** Номенклатура          - Строка - имя колонки (обязательно используется),
//    ** Характеристика        - Строка - имя колонки,
//    ** Серия                 - Строка - имя колонки,
//    ** ИдентификаторУпаковки - Строка - имя колонки,
//    ** Справка2              - Строка - имя колонки.
// * ИмяТабличнойЧасти - Строка - имя табличной части документа.
//
Функция НастройкиСопоставленияАлкогольнойПродукцииСНоменклатуройВДокументе(ИмяКолонкиАлкогольнаяПродукция = "АлкогольнаяПродукция") Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.НастройкиСопоставленияАлкогольнойПродукцииСНоменклатуройВДокументе(ИмяКолонкиАлкогольнаяПродукция);
```
</details>

## СопоставитьАлкогольнуюПродукциюСНоменклатурой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет регистр соответствия номенклатуры и алкогольной продукции для дальнейшего использования.
//
// Параметры:
//  Объект - ДокументОбъект - Объект в котором сопоставляется номенклатура.
//  НастройкиСопоставления - (См. НастройкиСопоставленияАлкогольнойПродукцииСНоменклатуройВДокументе)
//
Процедура СопоставитьАлкогольнуюПродукциюСНоменклатурой(Объект, НастройкиСопоставления = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.СопоставитьАлкогольнуюПродукциюСНоменклатурой(Объект, НастройкиСопоставления);
```
</details>

## СверткаРегистраСоответствиеНоменклатурыЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сворачивает остатки по сериям и справкам 2 регистра соответствие номенклатуры ЕГАИС
//
Процедура СверткаРегистраСоответствиеНоменклатурыЕГАИС() Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.СверткаРегистраСоответствиеНоменклатурыЕГАИС() 
```
</details>

## СоответствиеАлкогольнойПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СоответствиеАлкогольнойПродукции(КодыАлкогольнойПродукции) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.СоответствиеАлкогольнойПродукции(КодыАлкогольнойПродукции) 
```
</details>

## ПредставлениеВалютыРегламентированногоУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить представление валюты регламентированного учета.
//
// Возвращаемое значение:
//  Строка - Представление валюты.
//
Функция ПредставлениеВалютыРегламентированногоУчета() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ПредставлениеВалютыРегламентированногоУчета() 
```
</details>

## ПараметрыРаботыКлиентаПриЗапуске
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПараметрыРаботыКлиентаПриЗапуске(Параметры) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИС.ПараметрыРаботыКлиентаПриЗапуске(Параметры) 
```
</details>

## КонтекстЗаполненияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает структуру входящих значений функции ЗаполнитьСгенерироватьСерии
//
// Возвращаемое значение:
//   Структура - Структура с необходимыми свойствами
//
Функция КонтекстЗаполненияСерий() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.КонтекстЗаполненияСерий() 
```
</details>

## ИдентификаторыОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет список значений идентификаторов организаций и их представлений, в формате
//
// Параметры: СписокИдентификаторовОрганизации - СписокЗначений - заполняемый список идентификаторов
//  ВключаяДату - Дата - В состав идентификатора может быть включено представление даты маркировки.
//  ТолькоКодФСРАР - Булево - получение идентификатора только по коду ФСРАР
//
// Возвращаемое значение:
//  СписокЗначений Из Строка - Идентификаторы организации:
//   * Значение - Строка - Идентификатор организации для генерации штрихкода, содержащий символы цифр,
//   * Представление - Строка - Представление идентификатора для отображения пользователю.
Функция ИдентификаторыОрганизации(ВключаяДату, ТолькоКодФСРАР) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияЕГАИС.ИдентификаторыОрганизации(ВключаяДату, ТолькоКодФСРАР) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
