---
title: Интеграция ЕГАИС клиент переопределяемый
slug: erp-uh/интеграция-егаис-клиент-переопределяемый
---


## ПриОпределенииФормыСопоставления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет параметры открытия формы сопоставления номенклатуры и алкогольной продукции.
//
// Параметры:
//  ИмяФормы                    - Строка                           - имя формы сопоставления.
//  ПараметрыФормы              - Структура                        - параметры открываемой формы, содержит:
//   * АлкогольнаяПродукция - СправочникСсылка.КлассификаторАлкогольнойПродукцииЕГАИС - Сопоставляемая алкогольная продукция,
//   * НоменклатураДляВыбора - Массив - массив номенклатуры для быстрого выбора.
//  Владелец                    - ФормаКлиентскогоПриложения, Неопределено   - Форма-владелец.
//  ОписаниеОповещенияОЗакрытии - ОписаниеОповещения, Неопределено - описание оповещения о закрытии формы.
Процедура ПриОпределенииФормыСопоставления(ИмяФормы, ПараметрыФормы, Владелец, ОписаниеОповещенияОЗакрытии) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИСКлиентПереопределяемый.ПриОпределенииФормыСопоставления(ИмяФормы, ПараметрыФормы, Владелец, ОписаниеОповещенияОЗакрытии) 
```
</details>

## ПриОпределенииРеквизитовНоменклатурыДляВыбораАлкогольнойПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет, дополняет реквизиты номенклатуры для выбора алкогольной продукции.
//
// Параметры:
//  Реквизиты   - Структура - значения реквизитов номенклатуры для выбора алкогольной продукции, с полем
//                            "ВидАлкогольнойПродукции", для заполнения.
//  Номенклатура - ОпределяемыйТип.Номенклатура - Номенклатура.
Процедура ПриОпределенииРеквизитовНоменклатурыДляВыбораАлкогольнойПродукции(Реквизиты, Номенклатура) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИСКлиентПереопределяемый.ПриОпределенииРеквизитовНоменклатурыДляВыбораАлкогольнойПродукции(Реквизиты, Номенклатура) 
```
</details>

## ПриОпределенииПараметровСозданияКонтрагента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет параметры заполнения при создании контрагента из классификатора организаций ЕГАИС в структуру с
//  ключами    - реквизитами справочника контрагентов конфигурации и соответствующими
//  значениями - реквизитами справочника "КлассификаторОрганизацийЕГАИС",
//  например, Результат.Вставить("ИНН","ИНН")
// Параметры:
//  Результат - Структура - структура параметров заполнения
Процедура ПриОпределенииПараметровСозданияКонтрагента(Результат) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИСКлиентПереопределяемый.ПриОпределенииПараметровСозданияКонтрагента(Результат) 
```
</details>

## ПриПроверкеСопоставленияКлассификаторов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет обработку проверки сопоставления классификаторов ЕГАИС.
//
// Параметры:
//   * ДокументОснование       - ДокументСсылка     - ссылка на проверяемый документ,
//   * Форма                   - ФормаКлиентскогоПриложения   - форма документа, в которой произошло нажатие на гиперссылку,
//   * ОповещениеПриЗавершении - ОписаниеОповещения - действие после сопоставления классификаторов.
//   * СтандартнаяОбработка    - Булево             - признак стандартной обработки события (установить Ложь при
//            собственной реализации обработчика)
//
Процедура ПриПроверкеСопоставленияКлассификаторов(ДокументОснование, Форма, ОповещениеПриЗавершении, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ИнтеграцияЕГАИСКлиентПереопределяемый.ПриПроверкеСопоставленияКлассификаторов(ДокументОснование, Форма, ОповещениеПриЗавершении, СтандартнаяОбработка) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
