---
title: Интеграция ИС вызов сервера
slug: erp-uh/интеграция-ис-вызов-сервера
---


## КоэффициентВесОбъемУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значения коэффициента, веса, объема упаковок и тип измеряемой величины.
//
// Параметры:
//  ВходящиеДанные - ТаблицаЗначений, ТабличнаяЧасть - Таблица с колонками:
//   * Номенклатура - ОпределяемыйТип.Номенклатура - Ссылка на номенклатуру - обязательно для указания.
//   * Упаковка     - ОпределяемыйТип.Упаковка - Упаковка, данные которой нужно получить - если не указана,
//                                               тогда получаются данные базовой единицы измерения номенклатуры.
//                 - Массив из Структура со свойствами:
//   * Номенклатура - ОпределяемыйТип.Номенклатура - см.ТаблицаЗначений
//   * Упаковка     - ОпределяемыйТип.Упаковка - см.ТаблицаЗначений
//                 - Массив из ОпределяемыйТип.Номенклатура - см.ТаблицаЗначений, Упаковка считается не указанной.
//  ВесОбъемУпаковкиВЕдиницеКонстантИС - Булево - Если ЛОЖЬ, то вес и объем возвращаются в единицах измерения веса и объема,
//                                                иначе - в единицах измерения, указанных в константах:
//                                                ЕдиницаИзмеренияКилограммИС, ЕдиницаИзмеренияЛитрИС.
// Возвращаемое значение:
//  Соответствие - Соответствие из КлючИЗначение:
//   * Ключ - ОпределяемыйТип.Номенклатура,
//   * Значение - Соответствие из КлючИЗначение:
//    * Ключ - ОпределяемыйТип.Упаковка,
//    * Значение - Структура со свойствами:
//     * Коэффициент - Число - Разрядность (15, 3).
//     * Вес         - Число - Разрядность (15, 3).
//     * Объем       - Число - Разрядность (15, 3).
//     * ТипИзмеряемойВеличиныВес   - Булево - Устанавливается в значение Истина, если единица измерения номенклатуры
//                                             или упаковка, является единицой измерения веса.
//     * ТипИзмеряемойВеличиныОбъем - Булево - Устанавливается в значение Истина, если единица измерения номенклатуры
//                                             или упаковка, является единицой измерения объема.
//
Функция КоэффициентВесОбъемУпаковок(ВходящиеДанные, ВесОбъемУпаковкиВЕдиницеКонстантИС = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияИСВызовСервера.КоэффициентВесОбъемУпаковок(ВходящиеДанные, ВесОбъемУпаковкиВЕдиницеКонстантИС);
```
</details>

## КоэффициентВесОбъемУпаковки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает коэффициент упаковки, вес упаковки в килограммах, объем упаковки в литрах и тип измеряемой величины.
//
// Параметры:
//  Номенклатура - ОпределяемыйТип.Номенклатура - Номенклатура
//  Упаковка - ОпределяемыйТип.Упаковка, ОпределяемыйТип.ЕдиницаИзмерения, Неопределено - Упаковка
//  КэшированныеЗначения - Неопределено - кэшированные значения не используются,
//                         Структура - кэшированные значения:
//                          Ключ - "КоэффициентВесОбъемУпаковки", Значение - Соответствие:
//                          Ключ - Номенклатура,                  Значение - Соответствие:
//                          Ключ - Упаковка,                      Значение - Структура:
//                           Ключ - "Коэффициент", Значение - Число,
//                           Ключ - "Вес",         Значение - Число,
//                           Ключ - "Объем",       Значение - Число.
//                           Ключ - "ТипИзмеряемойВеличиныВес"   - Значение - Булево.
//                           Ключ - "ТипИзмеряемойВеличиныОбъем" - Значение - Булево.
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * Коэффициент - Число - Коэффициент упаковки.
//   * Вес         - Число - Вес упаковки в килограммах.
//   * Объем       - Число - Объем упаковки в литрах.
//   * ТипИзмеряемойВеличиныВес   - Булево - Устанавливается в значение Истина, если единица измерения номенклатуры
//                                           или упаковка, является единицой измерения веса.
//   * ТипИзмеряемойВеличиныОбъем - Булево - Устанавливается в значение Истина, если единица измерения номенклатуры
//                                           или упаковка, является единицой измерения объема.
//
Функция КоэффициентВесОбъемУпаковки(Номенклатура, Упаковка = Неопределено, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияИСВызовСервера.КоэффициентВесОбъемУпаковки(Номенклатура, Упаковка, КэшированныеЗначения);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
