---
title: Интеграция ИС переопределяемый
slug: erp-uh/интеграция-ис-переопределяемый
---


## ПередЗаписьюОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределение/дополнение события "Перед записью" библиотечных справочников и документов.
//   Позволяет модифицировать библиотечные объекты при необходимости.
//   * Не вызывается в режиме "ОбменДанными.Загрузка"
//
// Параметры:
//  Объект          - СправочникОбъект, ДокументОбъект - записываемый объект
//  Отказ           - Булево - Отказ
//  РежимЗаписи     - РежимЗаписиДокумента - режим записи (для документов)
//  РежимПроведения - РежимПроведенияДокумента - режим проведения (для документов)
//
Процедура ПередЗаписьюОбъекта(Объект, Отказ, РежимЗаписи = Неопределено, РежимПроведения = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ПередЗаписьюОбъекта(Объект, Отказ, РежимЗаписи, РежимПроведения);
```
</details>

## ОбработкаПроверкиЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается расширением формы при необходимости проверки заполнения реквизитов при записи или при проведении документа в форме,
// а также при выполнении метода ПроверитьЗаполнение.
//
// Параметры:
//  Объект          - СправочникОбъект, ДокументОбъект - записываемый объект
//  Отказ           - Булево - Отказ
//  ПроверяемыеРеквизиты - Массив Из Строка - массив проверяемых реквизитов
//  МассивНепроверяемыхРеквизитов - Массив Из Строка - массив непроверяемых реквизитов (заполнять для отключения проверки)
//
Процедура ОбработкаПроверкиЗаполнения(Объект, Отказ, ПроверяемыеРеквизиты, МассивНепроверяемыхРеквизитов) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ОбработкаПроверкиЗаполнения(Объект, Отказ, ПроверяемыеРеквизиты, МассивНепроверяемыхРеквизитов) 
```
</details>

## ЗаполнитьСлужебныеРеквизитыВКоллекции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет в табличной части служебные реквизиты.
// ТабличнаяЧасть может иметь различный состав колонок.
// В ТабличнаяЧасть обязательно содержится колонка Номенклатура - ОпределяемыйТип.Номенклатура.
// Заполнению подлежат колонки из нижеперечисленного списка, если значения, указываемые в колонке, используются в прикладном решении.
// Например:
// 	В "ТабличнаяЧасть" присутствует колонка "Артикул".
// 	Колонка подлежит заполнению, если в прикладном решении для номенклатуры возможно указание артикула.
// Список колонок для заполнения:
// 	Артикул                    - ОпределяемыйТип.Артикул - артикул номенклатуры.
// 	Код                        - ОпределяемыйТип.УникальныйИдентификаторИС - код номенклатуры.
// 	ХарактеристикиИспользуются - Булево - признак обязательного использования характеристик номенклатуры.
// 	ЕдиницаИзмерения           - ОпределяемыйТип.Упаковка - базовая единица измерения номенклатуры, в которой осуществляется учет и хранение.
// 	ТипНоменклатуры            - ОпределяемыйТип.ТипНоменклатуры - тип номенклатуры.
// 	ТребуетВзвешивания         - Булево - признак, что для номенклатуры маркированные потребительские упаковки имеют индивидуальный вес.
// 	ПроизвольнаяЕдиницаУчета   - Булево - признак, что для номенклатуры базовая единица учета отличается от маркированной потребительской упаковки.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения, Неопределено - Форма.
//  ТабличнаяЧасть - ДанныеФормыКоллекция, ТаблицаЗначений - таблица для заполнения.
Процедура ЗаполнитьСлужебныеРеквизитыВКоллекции(Форма, ТабличнаяЧасть) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЗаполнитьСлужебныеРеквизитыВКоллекции(Форма, ТабличнаяЧасть) 
```
</details>

## ОбработатьСтрокуТабличнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обрабатывает строку табличной части в соостветствии с переданной структурой действий.
//
// Параметры:
//  СтрокаТабличнойЧасти - Структура, СтрокаТабличнойЧасти, ДанныеФормыЭлементКоллекции - обрабатываемая строка.
//  СтруктураДействий - структура - структура выполняемых действий.
Процедура ОбработатьСтрокуТабличнойЧасти(СтрокаТабличнойЧасти, СтруктураДействий) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ОбработатьСтрокуТабличнойЧасти(СтрокаТабличнойЧасти, СтруктураДействий) 
```
</details>

## ПроверитьЗаполнениеХарактеристикВТаблицеЗначений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет заполнение характеристик в таблице значений.
//
// Параметры:
//  ТаблицаТоваров - ТаблицаЗначений - таблица для проверки с колонками: Номенклатура, Характеристика.
//  Отказ - Булево - Истина - характеристики заполнены в требуемых строках, в противном случае - Ложь.
Процедура ПроверитьЗаполнениеХарактеристикВТаблицеЗначений(ТаблицаТоваров, Отказ) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ПроверитьЗаполнениеХарактеристикВТаблицеЗначений(ТаблицаТоваров, Отказ) 
```
</details>

## ПриЗаполненииСертификатовНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Необходимо заполнить информацию о сертификатах номенклатуры в виде соответствия из массива структур со свойствами:
//    "ВидСертификации", "НомерСертификации", "ДатаСертификации", "СрокДействия", "Бессрочный".
// Информацию по сертификатам следует добавить в соответствие
//     "СертификатыНоменклатуры".
//
// Параметры:
//  СписокНоменклатуры - ОпределяемыйТип.Номенклатура - элемент номенклатура.
//  СертификатыНоменклатуры - Соответствие Из Структура
//   * Ключ - ОпределяемыйТип.Номенклатура,
//   * Значение - Массив из структура: см. ИнтеграцияИСМПКлиентСервер.ИнициализироватьДанныеЗаполненияСертификации
Процедура ПриЗаполненииСертификатовНоменклатуры(СписокНоменклатуры, СертификатыНоменклатуры) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ПриЗаполненииСертификатовНоменклатуры(СписокНоменклатуры, СертификатыНоменклатуры) 
```
</details>

## ПравоРегистрацииШтрихкодовНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В функции требуется определить право на регистрацию нового штрихкода для текущего пользователя.
//
// Параметры:
//  ДоступРазрешен - Булево - Истина, если есть право на регистрацию штрихкода. Ложь - в противном случае.
//
Процедура ПравоРегистрацииШтрихкодовНоменклатуры(ДоступРазрешен) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ПравоРегистрацииШтрихкодовНоменклатуры(ДоступРазрешен) 
```
</details>

## ИспользованиеХарактеристик
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре требуется определить признак использования характеристик
//   * для номенклатуры, если передана номенклатура,
//   * в программе, если не передана.
//
// Параметры:
//  Использование - Булево - Признак использования характеристик (для номенклатуры или общий)
//  Номенклатура - ОпределяемыйТип.Номенклатура, Неопределено - Ссылка на элемент номенклатуры.
//
Процедура ИспользованиеХарактеристик(Использование, Номенклатура) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ИспользованиеХарактеристик(Использование, Номенклатура) 
```
</details>

## ИспользованиеЧастичноеВыбытие
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре требуется определить наличие товаров по виду продукции для которых используется механизм частичного выбытия
//
// Параметры:
//  Использование - Булево - Признак использования частичного выбытия (для вида продукции)
//  ВидПродукцииИС - Перечислениессылка.ВидыПродукцииИС - Проверяемый вид продукции.
//
Процедура ИспользованиеЧастичноеВыбытие(Использование, ВидПродукцииИС) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ИспользованиеЧастичноеВыбытие(Использование, ВидПродукцииИС) 
```
</details>

## ИспользованиеСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре требуется определить признак использования серий
//   * для номенклатуры, если передана номенклатура,
//   * в программе, если не передана.
//
// Параметры:
//  Использование - Булево - Признак использования серий (для номенклатуры или общий)
//  Номенклатура - ОпределяемыйТип.Номенклатура, Неопределено - Ссылка на элемент номенклатуры.
//
Процедура ИспользованиеСерий(Использование, Номенклатура) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ИспользованиеСерий(Использование, Номенклатура) 
```
</details>

## ИспользованиеУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре требуется определить признак использования упаковок для номенклатуры.
//   * для номенклатуры, если передана номенклатура,
//   * в программе, если не передана.
//
// Параметры:
//  Использование - Булево - Признак использования упаковок (для номенклатуры или общий)
//  Номенклатура - ОпределяемыйТип.Номенклатура, Неопределено - Ссылка на элемент номенклатуры.
//
Процедура ИспользованиеУпаковок(Использование, Номенклатура) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ИспользованиеУпаковок(Использование, Номенклатура) 
```
</details>

## ИспользованиеВидовНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре требуется определить признак использования видов номенклатуры.
//
// Параметры:
//  Использование - Булево - Признак использования видов номенклатуры в программе.
//
Процедура ИспользованиеВидовНоменклатуры(Использование) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ИспользованиеВидовНоменклатуры(Использование) 
```
</details>

## ОбъемУпаковки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает объем упаковки или единицы измерения в литрах.
//  * Если не задана упаковка, то для единицы учета номенклатуры
//  * Если задана упаковка, то для указанной упаковки
//  * Если задана единица измерения, то для указанной единицы измерения
//
// Параметры:
//  Объем - Число - Объем упаковки (исходящий)
//  Номенклатура - ОпределяемыйТип.Номенклатура, Неопределено - Номенклатура
//  Упаковка - ОпределяемыйТип.Упаковка, ОпределяемыйТип.ЕдиницаИзмерения, Неопределено - Упаковка или единица измерения номенклатуры
//  КэшированныеЗначения - Произвольный - Кэшированные значения
Процедура ОбъемУпаковки(Объем, Знач Номенклатура, Знач Упаковка, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ОбъемУпаковки(Объем, Номенклатура, Упаковка, КэшированныеЗначения) 
```
</details>

## ПриОпределенииКоэффициентовУпаковки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает коэффициенты переданной единицы измерения
//
// Параметры:
//  Упаковка - ОпределяемыйТип.Упаковка, ОпределяемыйТип.ЕдиницаИзмерения - Упаковка или единица измерения
//  Номенклатура - Массив Из ОпределяемыйТип.Номенклатура - Номенклатура
//  КоэффициентыУпаковокНоменклатуры - Соответствие из КлючИЗначение:
//   * Ключ - ОпределяемыйТип.Номенклатура
//   * Значение - структура:
//   * КодОшибки - Число  - Код ошибки получения коэффициента:
//        0 - Нет ошибок;
//        1 - Не заполнена единица измерения в справочнике 'ЕдиницыИзмеренияВЕТИС';
//        2 - В справочнике 'Номенклатура' выключена возможность пересчета количества в соответствующую мерную единицу измерения;
//        3 - Не удалось сопоставить единицу хранения справочника 'Номенклатура' с единицей измерения 'Упаковка'.
//   * Коэффициент - Число  - Коэффициент пересчета единицы измерения из 'Упаковка'.
Процедура ПриОпределенииКоэффициентовУпаковки(Упаковка, Номенклатура, КоэффициентыУпаковокНоменклатуры) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ПриОпределенииКоэффициентовУпаковки(Упаковка, Номенклатура, КоэффициентыУпаковокНоменклатуры) 
```
</details>

## ИспользованиеПроизвольныхЕдиницУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре требуется определить наличие товаров по виду продукции для которых единица учета не совпадает с
//   количеством в потребительском коде маркировки
//
// Параметры:
//  Использование - Булево - Признак использования произвольных единиц учета (для вида продукции) (исходящий)
//  ВидПродукцииИС - Перечислениессылка.ВидыПродукцииИС - Проверяемый вид продукции.
//
Процедура ИспользованиеПроизвольныхЕдиницУчета(Использование, ВидПродукцииИС) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ИспользованиеПроизвольныхЕдиницУчета(Использование, ВидПродукцииИС) 
```
</details>

## ПриЗаполненииТекстаЗапросаПризнакаМаркируемаяПродукцияПоНоменклатуре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриЗаполненииТекстаЗапросаПризнакаМаркируемаяПродукцияПоНоменклатуре(ТекстЗапроса, ИмяТаблицыНоменклатура, ИмяПоляНоменклатура) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ПриЗаполненииТекстаЗапросаПризнакаМаркируемаяПродукцияПоНоменклатуре(ТекстЗапроса, ИмяТаблицыНоменклатура, ИмяПоляНоменклатура) 
```
</details>

## ПриЗаполнениУпаковокНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет список упаковок с коэффициентом упаковки в выходящем параметре ТаблицаУпаковокНоменклатуры
// с признаками ЯвляетсяПотребительской, ЯвляетсяУпаковкойЧастичногоВыбытия
//
// Параметры:
//  Номерклатура - Массив из ОпределяемыйТип.Номенклатура
//  ТаблицаУпаковокНоменклатуры - см. ИнтеграцияИС.НоваяТаблицаУпаковокНоменклатуры
Процедура ПриЗаполнениУпаковокНоменклатуры(Номерклатура, ТаблицаУпаковокНоменклатуры) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ПриЗаполнениУпаковокНоменклатуры(Номерклатура, ТаблицаУпаковокНоменклатуры) 
```
</details>

## КоэффициентУпаковки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Коэффициент упаковки.
//
// Параметры:
// Коэффициент - Число - Выходное значение коэффициента упаковки.
//  Упаковка - ОпределяемыйТип.Упаковка - Упаковка
//  Номенклатура - Неопределено, ОпределяемыйТип.Номенклатура - Номенклатура
// КэшированныеЗначения - Произвольный - Кэшированные значениия
Процедура КоэффициентУпаковки(Коэффициент, Знач Упаковка, Знач Номенклатура, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.КоэффициентУпаковки(Коэффициент, Упаковка, Номенклатура, КэшированныеЗначения) 
```
</details>

## ЕдиницаИзмеренияКилограмм
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре требуется определить единицу измерения веса с кодом по ОКЕИ 166.
// Используется для пересчета упаковок в килограммы.
//
// Параметры:
//  ЕдиницаИзмеренияКилограмм - ОпределяемыйТип.Упаковка - Единица измерения веса (килограмм).
Процедура ЕдиницаИзмеренияКилограмм(ЕдиницаИзмеренияКилограмм) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЕдиницаИзмеренияКилограмм(ЕдиницаИзмеренияКилограмм) 
```
</details>

## ЕдиницаИзмеренияЛитр
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре требуется определить единицу измерения объема с кодом по ОКЕИ 112.
// Используется для пересчета упаковок в литры.
//
// Параметры:
//  ЕдиницаИзмеренияЛитр - ОпределяемыйТип.Упаковка - Единица измерения объема (литр).
Процедура ЕдиницаИзмеренияЛитр(ЕдиницаИзмеренияЛитр) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЕдиницаИзмеренияЛитр(ЕдиницаИзмеренияЛитр) 
```
</details>

## КоэффициентВесОбъемУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для получения значения коэффициента, веса, объема упаковки и типа измеряемой величины.
//
// Параметры:
//  ДанныеУпаковок - ТаблицаЗначений - Таблица с колонками:
//   * Номенклатура - ОпределяемыйТип.Номенклатура - Ссылка на номенклатуру - обязательно для указания.
//   * Упаковка     - ОпределяемыйТип.Упаковка - упаковка, данные которой нужно получить - если не указана,
//                                               тогда получаются данные базовой единицы измерения номенклатуры.
//   * Вес          - Число - Вес упаковки.
//   * Объем        - Число - Объем упаковки.
//   * Коэффициент  - Число - Коэффициент упаковки.
//   * ТипИзмеряемойВеличиныВес   - Булево - Устанавливается в значение Истина, если единица измерения номенклатуры
//                                           или упаковка, является единицой измерения веса.
//   * ТипИзмеряемойВеличиныОбъем - Булево - Устанавливается в значение Истина, если единица измерения номенклатуры
//                                           или упаковка, является единицой измерения объема.
//  ВесОбъемУпаковкиВЕдиницеКонстантИС - Булево - Если ЛОЖЬ, то вес и объем возвращаются в единицах измерения веса и объема,
//                                                иначе - в единицах измерения, указанных в константах:
//                                                ЕдиницаИзмеренияКилограммИС, ЕдиницаИзмеренияЛитрИС.
//
Процедура КоэффициентВесОбъемУпаковок(ДанныеУпаковок, ВесОбъемУпаковкиВЕдиницеКонстантИС = Истина) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.КоэффициентВесОбъемУпаковок(ДанныеУпаковок, ВесОбъемУпаковкиВЕдиницеКонстантИС);
```
</details>

## ПриОпределенииТекстаЗапросаСопоставлениеКодовТНВЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В данной процедуре требуется переопределить текст запроса, определяющий сопоставление классификатора ТН ВЭД и данных регистра сведений КодыТНВЭДИСМП.
//   Требования к тексту запроса:
//     Если классификатора ТН ВЭД не используется, переопределение также не заполнять.
//     Результат запроса обязательно должен содержать следующие поля:
//   Колонки временной таблицы "ДанныеШтрихкодовУпаковок":
//     КодТНВЭД           - Строка - код.
//     ВидПродукции       - ПеречислениеСсылка.ВидыПродукцииИС - вид продукции.
//     НаименованиеПолное - Строка - наименование.
//     КодТНВЭДСсылка     - Произвольный - ссылка на сопоставленный элемент классификатора.
//     Сопоставлено       - Число - 0, если в базе не найден соотвествующий элемент классификатора, 1 - если найден.
// Параметры:
//  ТекстЗапроса - Строка - Переопределяемый текст запроса.
Процедура ПриОпределенииТекстаЗапросаСопоставлениеКодовТНВЭД(ТекстЗапроса) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ПриОпределенииТекстаЗапросаСопоставлениеКодовТНВЭД(ТекстЗапроса) 
```
</details>

## ИспользуетсяПоддержкаПлатежейВСоответствииС275ФЗ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет признак использования гос.контрактов по 275ФЗ.
//
// Параметры:
//  Используется - Булево - Признак использования гос.контрактов по 275ФЗ. Значение по умолчанию Ложь.
Процедура ИспользуетсяПоддержкаПлатежейВСоответствииС275ФЗ(Используется) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ИспользуетсяПоддержкаПлатежейВСоответствииС275ФЗ(Используется) 
```
</details>

## ЗаполнитьСведенияОбОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре нужно реализовать заполнение структуры данными из информационной базы.
//
// Параметры:
//  Организация - ОпределяемыйТип.ОрганизацияКонтрагентГосИС - ссылка на собственную организацию или контрагента,
//  Сведения - Структура - структура с реквизитами организации, которые требуется заполнить,
//  ДатаСведений - Дата - дата, на которую требуется получить информацию.
//
Процедура ЗаполнитьСведенияОбОрганизации(Организация, Сведения, ДатаСведений = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЗаполнитьСведенияОбОрганизации(Организация, Сведения, ДатаСведений);
```
</details>

## ПриОпределенииИНННалоговыхНомеровКонтрагентов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре нужно реализовать заполнение соответствия ИНН (или налогового номера в стране регистрации) и контрагентов
// для переданного массива контрагентов.
//
// Параметры:
//  СоответствиеИННКонтрагентам - Соответствие из Строка- соответствие для заполнения:
//   * Ключ - ОпределяемыйТип.КонтрагентГосИС - ссылка на контрагента.
//   * Значение - Строка - ИНН (или его аналог).
//  Контрагенты - Массив из ОпределяемыйТип.КонтрагентГосИС - массив контрагентов.
Процедура ПриОпределенииИНННалоговыхНомеровКонтрагентов(СоответствиеИННКонтрагентам, Контрагенты) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ПриОпределенииИНННалоговыхНомеровКонтрагентов(СоответствиеИННКонтрагентам, Контрагенты) 
```
</details>

## ПриОпределенииИННКППGLNОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре нужно реализовать заполнение структуры данными ИНН/КПП/GLN из информационной базы.
//
// Параметры:
//  Сведения      - Структура - структура с реквизитами организации, которые требуется заполнить,
//  Организация   - ОпределяемыйТип.Организация - ссылка на собственную организацию,
//  Подразделение - ОпределяемыйТип.Подразделение - Подразделение организации.
Процедура ПриОпределенииИННКППGLNОрганизации(Сведения, Организация, Подразделение) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ПриОпределенииИННКППGLNОрганизации(Сведения, Организация, Подразделение) 
```
</details>

## КодОКОПФОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Получение кода ОКОПФ по организации.
//
//Параметры:
//  КодОКОПФ    - Строка - Код ОКОПФ организации.
//  Организация - ОпределяемыйТип.Организация - Организация, для которой необходимо получить код ОКОПФ.
//
Процедура КодОКОПФОрганизации(КодОКОПФ, Организация) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.КодОКОПФОрганизации(КодОКОПФ, Организация) 
```
</details>

## ОпределитьДанныеРуководителяОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет представление руководителя организации.
//
// Параметры:
//  ПредставлениеРуководителя - (см. ИнтеграцияИС.ДанныеРуководителяОрганизации)
//  Организация - ОпределяемыйТип.ОрганизацияКонтрагентГосИС - ссылка на собственную организацию или контрагента,
//  ДатаСведений - Дата - дата, на которую требуется получить информацию.
Процедура ОпределитьДанныеРуководителяОрганизации(ПредставлениеРуководителя, Организация, ДатаСведений) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ОпределитьДанныеРуководителяОрганизации(ПредставлениеРуководителя, Организация, ДатаСведений) 
```
</details>

## ЗаполнитьКонтрагентаПоИННКПП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре нужно реализовать поиск контрагента по ИНН и/или КПП.
//
// Параметры:
//  Контрагент - ОпределяемыйТип.ОрганизацияКонтрагентГосИС, ОпределяемыйТип.КонтрагентГосИС - найденный контрагент (исходящий),
//             - Неопределено - контрагент не найден (исходящий),
//  ИНН - Строка - ИНН искомого контрагента,
//  КПП - Строка - КПП искомого контрагента.
//
Процедура ЗаполнитьКонтрагентаПоИННКПП(Контрагент, ИНН, КПП) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЗаполнитьКонтрагентаПоИННКПП(Контрагент, ИНН, КПП) 
```
</details>

## ЗаполнитьСоответствиеИННКонтрагентам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре необходимо сформировать соответствие по коллекции ИНН.
//
// Параметры:
//  КоллекцияИНН - Массив Из Строка - Список ИНН.
//  Соответствие - Соответствие Из ОпределяемыйТип.КонтрагентГосИС - Соответсвие вида:
//   * Ключ - Строка - ИНН
//   * Значение - ОпределяемыйТип.КонтрагентГосИС - Контрагент
Процедура ЗаполнитьСоответствиеИННКонтрагентам(КоллекцияИНН, Соответствие) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЗаполнитьСоответствиеИННКонтрагентам(КоллекцияИНН, Соответствие) 
```
</details>

## ПриОпределенииСоответствияНалоговыхНомеровКонтрагентам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре необходимо сформировать соответствие по коллекции налоговых номеров. Ключ - налоговый номер, значение - Контрагент.
//
// Параметры:
//  КоллекцияНалоговыхНомеров - Массив Из Строка - Список налоговых номеров юр.лиц за пределами РФ.
//  Соответствие - Соответствие Из ОпределяемыйТип.КонтрагентГосИС - Соответсвие вида:
//    * Ключ - Строка - Налоговый номер
//    * Значение - ОпределяемыйТип.КонтрагентГосИС - Контрагент
Процедура ПриОпределенииСоответствияНалоговыхНомеровКонтрагентам(КоллекцияНалоговыхНомеров, Соответствие) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ПриОпределенииСоответствияНалоговыхНомеровКонтрагентам(КоллекцияНалоговыхНомеров, Соответствие) 
```
</details>

## ЗаполнитьСоответствиеИННОрганизациям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре необходимо заполнить соответствие по коллекции ИНН.
//
// Параметры:
//  КоллекцияИНН - Массив Из Строка - Список ИНН.
//  Соответствие - Соответствие Из ОпределяемыйТип.Организация - Соответсвие вида:
//   * Ключ - Строка - ИНН организации
//   * Значение - ОпределяемыйТип.Организация - Организация
Процедура ЗаполнитьСоответствиеИННОрганизациям(КоллекцияИНН, Соответствие) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЗаполнитьСоответствиеИННОрганизациям(КоллекцияИНН, Соответствие) 
```
</details>

## ПриОпределенииОрганизацииИзПрикладногоОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре нужно реализовать поиск организации в прикладном объекте.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - найденная организация
//  Объект      - Произвольный                - объект в котором производится поиск
//
Процедура ПриОпределенииОрганизацииИзПрикладногоОбъекта(Организация, Объект) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ПриОпределенииОрганизацииИзПрикладногоОбъекта(Организация, Объект) 
```
</details>

## ПриОпределенииОрганизацийИнтеркампани
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре необходимо реализовать заполнение таблицы данными организаций, доступных для интеркампани.
//
// Параметры:
//  ОрганизацииИнтеркампани - ТаблицаЗначений - Организации интеркампани:
// * Организация - ОпределяемыйТип.Организация - Ссылка на организацию.
// * Подразделение  - ОпределяемыйТип.Подразделение - Ссылка на подрезделение.
// * Представление - Строка - Представление организации.
// * ИНН - Строка - ИНН организации.
// * КПП - Строка - КПП организации.
Процедура ПриОпределенииОрганизацийИнтеркампани(ОрганизацииИнтеркампани) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ПриОпределенииОрганизацийИнтеркампани(ОрганизацииИнтеркампани) 
```
</details>

## НастроитьПодключаемоеОборудование
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Настраивает подключаемое оборудование в форме,
// устанавливает флаг ИспользоватьПодключаемоеОборудование в форме.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма, в которой необходимо настроить подключаемое оборудование,
//  ПрефиксыЭлементовФормы - Строка - строка имен табличных частей, разделенных запятыми, в которых нужно настроить видимость команд.
Процедура НастроитьПодключаемоеОборудование(Форма, ПрефиксыЭлементовФормы = "Товары") Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.НастроитьПодключаемоеОборудование(Форма, ПрефиксыЭлементовФормы);
```
</details>

## НастроитьДлительнуюОперацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Особенности работы с длительными операциями в конкретном окружении
//
//Параметры:
//   Параметры - Структура - параметры фонового задания.
//   ПараметрыВыполнения - см. ДлительныеОперации.ПараметрыВыполненияВФоне.
Процедура НастроитьДлительнуюОперацию(Параметры, ПараметрыВыполнения) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.НастроитьДлительнуюОперацию(Параметры, ПараметрыВыполнения) 
```
</details>

## ЗаполнитьПараметрыОтправки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет структуру параметров возможных получателей печатных форм при отправке по электронной почте.
//
// Параметры:
//  ПараметрыОтправки - Структура - содержит параметры отправки сформированных печатных форм
//  ДанныеОбъектовПечати - Массив,Соответствие - данные о печатаемых объектах
//  КоллекцияПечатныхФорм - ТаблицаЗначений - содержит информацию о формируемых печатных формах.
Процедура ЗаполнитьПараметрыОтправки(ПараметрыОтправки, ДанныеОбъектовПечати, КоллекцияПечатныхФорм) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЗаполнитьПараметрыОтправки(ПараметрыОтправки, ДанныеОбъектовПечати, КоллекцияПечатныхФорм)  
```
</details>

## ПроверитьВозможностьВводаНаОсновании
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// (См ОбщегоНазначенияУТ.ПроверитьВозможностьВводаНаОсновании)
Процедура ПроверитьВозможностьВводаНаОсновании(Документ, Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ПроверитьВозможностьВводаНаОсновании(Документ, );
```
</details>

## УстановитьПредставлениеОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление объекта.
//
// Параметры:
//  Представление - Строка - Исходящий параметр со значением представления.
//  ПараметрОбъект - Строка, ОбъектМетаданных - Наименование типа объекта либо сам объект.
Процедура УстановитьПредставлениеОбъекта(Представление, ПараметрОбъект) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.УстановитьПредставлениеОбъекта(Представление, ПараметрОбъект) 
```
</details>

## ПриОпределенииКомандПодключенныхКОбъекту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// (См. ОбщийМодуль.ПодключаемыеКомандыПереопределяемый.ПриОпределенииКомандПодключенныхКОбъекту)
//
Процедура ПриОпределенииКомандПодключенныхКОбъекту(НастройкиФормы, Источники, ПодключенныеОтчетыИОбработки, Команды) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ПриОпределенииКомандПодключенныхКОбъекту(НастройкиФормы, Источники, ПодключенныеОтчетыИОбработки, Команды) 
```
</details>

## ДобавитьКомандуСтруктураПодчиненности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду отчета в список команд.
//
// Параметры:
//   КомандыОтчетов - см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
Процедура ДобавитьКомандуСтруктураПодчиненности(КомандыОтчетов) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ДобавитьКомандуСтруктураПодчиненности(КомандыОтчетов) 
```
</details>

## ДобавитьКомандуДвиженияДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду отчета в список команд.
//
// Параметры:
//   КомандыОтчетов - см. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
Процедура ДобавитьКомандуДвиженияДокумента(КомандыОтчетов) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ДобавитьКомандуДвиженияДокумента(КомандыОтчетов) 
```
</details>

## ЗаполнитьИменаРеквизитовДляЗаполненияПараметровУказанияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет имена реквизитов, от значений которых зависят параметры указания серий.
//
// Параметры:
//  ИменаРеквизитов - Строка           - Результат заполнения.
//  ТипОбъекта      - ОбъектМетаданных - Тип объекта коллекции объектов метаданных.
Процедура ЗаполнитьИменаРеквизитовДляЗаполненияПараметровУказанияСерий(ИменаРеквизитов, ТипОбъекта) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЗаполнитьИменаРеквизитовДляЗаполненияПараметровУказанияСерий(ИменаРеквизитов, ТипОбъекта) 
```
</details>

## ЗаполнитьПараметрыУказанияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет параметры указания серий для товаров, указанных в объекте.
//
// Параметры:
//  Параметры  - Произвольный     - выходной, параметры указания серий, состав полей определен в прикладной конфигурации.
//  ТипОбъекта - ОбъектМетаданных - Тип объекта коллекции объектов метаданных.
//  Объект     - Структура        - Значения реквизитов объекта, необходимых для заполнения параметров указания серий.
Процедура ЗаполнитьПараметрыУказанияСерий(Параметры, ТипОбъекта, Объект) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЗаполнитьПараметрыУказанияСерий(Параметры, ТипОбъекта, Объект) 
```
</details>

## ЗаполнитьПараметрыУказанияСерийФормыОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры указания серий для товаров, указанных в объекте.
//
// Параметры:
//  Параметры - Структура - выходной, параметры указания серий, состав полей определен в прикладной конфигурации.
//  Объект    - ДокументОбъект, ДанныеФормыСтруктура - Объект, для формы которого нужно сформировать параметры
//                                             указания серий.
//  МенеджерОбъекта - ДокументМенеджер - Менеджер объекта, для формы которого нужно сформировать параметры указания серий.
Процедура ЗаполнитьПараметрыУказанияСерийФормыОбъекта(Параметры, Объект, МенеджерОбъекта) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЗаполнитьПараметрыУказанияСерийФормыОбъекта(Параметры, Объект, МенеджерОбъекта) 
```
</details>

## ОбработатьУказаниеСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Извлекает из временного хранилища серии, указанные в форме редактирования серий, помещает эти строки в ТЧ "Серии" объекта,
//   перерасчитывает статусы указания серий строках товарной табличной части.
//
// Параметры:
//  Форма                       - ФормаКлиентскогоПриложения    - Источник вызова.
//  ПараметрыФормыУказанияСерий - Структура           - Состав полей определен в функции НоменклатураСервер.ПараметрыФормыУказанияСерий.
//  КэшированныеЗначения        - Структура           - Сохраненные значения параметров, используемых при обработке строки таблицы.
Процедура ОбработатьУказаниеСерий(Форма, ПараметрыФормыУказанияСерий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ОбработатьУказаниеСерий(Форма, ПараметрыФормыУказанияСерий, КэшированныеЗначения) 
```
</details>

## ЗаполнитьСтатусыУказанияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет статусы указания серий в строках товарной табличной части.
//
// Параметры:
//  Объект - ДанныеФормыСтруктура, ФормаКлиентскогоПриложения - Общая форма или основной реквизит формы объекта.
//  ПараметрыУказанияСерий - Произвольный - Параметры указания серий номенклатуры.
//
Процедура ЗаполнитьСтатусыУказанияСерий(Объект, ПараметрыУказанияСерий) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЗаполнитьСтатусыУказанияСерий(Объект, ПараметрыУказанияСерий) 
```
</details>

## ЗаполнитьСтатусыУказанияСерийФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСтатусыУказанияСерийФормы(Форма, ИмяРеквизитаОбъект = "Объект", ИмяРеквизитаПараметрыУказанияСерий = "ПараметрыУказанияСерий") Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЗаполнитьСтатусыУказанияСерийФормы(Форма, ИмяРеквизитаОбъект, ИмяРеквизитаПараметрыУказанияСерий);
```
</details>

## ЗаполнитьПараметрыУказанияСерийФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьПараметрыУказанияСерийФормы(Менеджер, Форма, ИмяРеквизитаОбъект = "Объект", ИмяРеквизитаПараметрыУказанияСерий = "ПараметрыУказанияСерий") Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЗаполнитьПараметрыУказанияСерийФормы(Менеджер, Форма, ИмяРеквизитаОбъект, ИмяРеквизитаПараметрыУказанияСерий);
```
</details>

## ЗаполнитьСтатусыУказанияСерийПриОкончанииРедактированияСтрокиТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура пересчитывает статусы указания серий в строках товаров, если это необходимо, переподчиняет строки серий
// другим строкам таблицы.
//
// Параметры:
//  Форма                      - ФормаКлиентскогоПриложения    - Источник вызова.
//  ПараметрыУказанияСерий     - Произвольный - См. ИнтеграцияИС.ПараметрыУказанияСерий.
//  ТекущаяСтрокаИдентификатор - Число               - Идентификатор текущей строки товаров в форме объекта.
//  КэшированныеЗначения       - Структура           - Сохраненные значения параметров, используемых при обработке строки таблицы.
Процедура ЗаполнитьСтатусыУказанияСерийПриОкончанииРедактированияСтрокиТЧ( Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЗаполнитьСтатусыУказанияСерийПриОкончанииРедактированияСтрокиТЧ();
```
</details>

## ЗаполнитьТекстЗапросаЗаполненияСтатусовУказанияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет текст запроса заполнения статусов указания серий для товаров, указанных в документе.
//
// Параметры:
//  ТекстЗапроса           - Строка           - Текст запроса заполнения статусов указания серий.
//  ТипОбъекта             - ОбъектМетаданных - Тип документа коллекции объектов метаданных.
//  ПараметрыУказанияСерий - Произвольный     - См. ИнтеграцияИС.ПараметрыУказанияСерий.
Процедура ЗаполнитьТекстЗапросаЗаполненияСтатусовУказанияСерий(ТекстЗапроса, ТипОбъекта, ПараметрыУказанияСерий) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЗаполнитьТекстЗапросаЗаполненияСтатусовУказанияСерий(ТекстЗапроса, ТипОбъекта, ПараметрыУказанияСерий) 
```
</details>

## ЗаполнитьТекстЗапросаПроверкиЗаполненияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет текст запроса проверки заполнения серий в документе.
//
// Параметры:
//  ТекстЗапроса           - Строка           - Текст запроса проверки заполнения серий.
//  ТипОбъекта             - ОбъектМетаданных - Тип документа коллекции объектов метаданных.
//  ПараметрыУказанияСерий - Произвольный     - См. ИнтеграцияИС.ПараметрыУказанияСерий.
Процедура ЗаполнитьТекстЗапросаПроверкиЗаполненияСерий(ТекстЗапроса, ТипОбъекта, ПараметрыУказанияСерий) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ЗаполнитьТекстЗапросаПроверкиЗаполненияСерий(ТекстЗапроса, ТипОбъекта, ПараметрыУказанияСерий) 
```
</details>

## ОтразитьДвиженияСерийТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарело. Процедура формирования движений по регистру "Движения серий товаров".
//
// Параметры:
//  ДополнительныеСвойства - Структура - дополнительные свойства для записи движений
//  Движения - КоллекцияДвижений - движения по которым двигается документ
//  Отказ - Булево - признак отказа от проведения документа
Процедура ОтразитьДвиженияСерийТоваров(ДополнительныеСвойства, Движения, Отказ) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ОтразитьДвиженияСерийТоваров(ДополнительныеСвойства, Движения, Отказ) 
```
</details>

## ПриГенерацииСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет, при необходимости создает серии в документе ГосИС или его выделенных строках
//
// Параметры:
//  Объект - ДанныеФормыСтруктура - объект для заполнения
//  Товары - ДанныеФормыКоллекция, ТаблицаЗначений - табличная часть документа
//  ВыделенныеСтроки - Массив Из ДанныеФормыЭлементКоллекции - выделенные строки документа
//  ПараметрыУказанияСерий - см. ИнтеграцияИС.ПараметрыУказанияСерий
//  РезультатЗаполненияСерий - см. ИнтеграцияИС.РезультатГенерацииИЗаполненияСерий.
Процедура ПриГенерацииСерий(Объект, Товары, ВыделенныеСтроки, ПараметрыУказанияСерий, РезультатЗаполненияСерий) Экспорт
```

Пример вызова
```bsl
ИнтеграцияИСПереопределяемый.ПриГенерацииСерий(Объект, Товары, ВыделенныеСтроки, ПараметрыУказанияСерий, РезультатЗаполненияСерий) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
