---
title: Интеграция САТУРН
slug: erp-uh/интеграция-сатурн
---


## ПолучитьКлючСессии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текущий ключ сессии для обмена с ФГИС "Сатурн".
// При отсутствии действующего ключа, получает новый.
//
// Параметры:
// 	Пользователь - ОпределяемыйТип.ПользователиИС, Неопределено - Пользователь, для которого необходимо получить ключ сессии.
// 		Если пользователь не указан, то ключ будет получен для текущего пользователя системы или без учета пользователя.
//  БезУчетаПользователя - Булево - Устанавливается в Истина, если требуется получить ключ сессии
//  	без учета пользователя. Например, для выполнения регламентного задания.
//  	Если Истина, тогда значение параметра Пользователь игнорируется.
//  ПовторноеПолучение - Булево - Служебный параметр. Предназначен для защиты от зацикливания.
//  	Например, если из сервиса будет получен уже просроченый токен или наша система использует некорректное время.
// Возвращаемое значение:
//  Структура:
//   * ТокенАвторизации - Строка, Неопределено - Действующий ключ сессии для пользователя.
//   * ТекстОшибки - Строка, Неопределено - Описание ошибки.
//   * РезультатыЗапросов - Массив из Структура - результаты запросов.
Функция ПолучитьКлючСессии(Пользователь = Неопределено, БезУчетаПользователя = Ложь, ПовторноеПолучение = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСАТУРН.ПолучитьКлючСессии(Пользователь, БезУчетаПользователя, ПовторноеПолучение);
```
</details>

## УстановитьПараметрыСеанса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет установку параметров сеанса. Вызывается из модуля сеанса.
//
// Параметры:
//  ИмяПараметра			 - Строка           - имя параметра сеанса.
//  УстановленныеПараметры	 - Массив из Строка - все установленные параметры сеанса.
//
Процедура УстановитьПараметрыСеанса(ИмяПараметра, УстановленныеПараметры) Экспорт
```

Пример вызова
```bsl
ИнтеграцияСАТУРН.УстановитьПараметрыСеанса(ИмяПараметра, УстановленныеПараметры) 
```
</details>

## ПриОпределенииСправочниковХраненияФайлов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить справочники хранения файлов по типам владельцев.
//
// Параметры:
//  ТипВладелецФайла  - Тип - тип ссылки объекта, к которому добавляется файл.
//  ИменаСправочников - Соответствие - содержит в ключах имена справочников.
//                      При вызове содержит стандартное имя одного справочника,
//                      помеченного, как основной (если существует).
//                      Основной справочник используется для интерактивного
//                      взаимодействия с пользователем. Чтобы указать основной
//                      справочник, нужно установить Истина в значение соответствия.
//                      Если установить Истина более одного раза, тогда будет ошибка.
Процедура ПриОпределенииСправочниковХраненияФайлов(ТипВладелецФайла, ИменаСправочников) Экспорт
```

Пример вызова
```bsl
ИнтеграцияСАТУРН.ПриОпределенииСправочниковХраненияФайлов(ТипВладелецФайла, ИменаСправочников) 
```
</details>

## ПриОпределенииНастроекРаботыСФайлами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// см. РаботаСФайламиПереопределяемый.ПриОпределенииНастроек
Процедура ПриОпределенииНастроекРаботыСФайлами(Настройки) Экспорт
```

Пример вызова
```bsl
ИнтеграцияСАТУРН.ПриОпределенииНастроекРаботыСФайлами(Настройки) 
```
</details>

## ШаблонПредставленияДокументаДляПоляИнтеграции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ШаблонПредставленияДокументаДляПоляИнтеграции(МетаданныеДокумента, ДокументОснование) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСАТУРН.ШаблонПредставленияДокументаДляПоляИнтеграции(МетаданныеДокумента, ДокументОснование) 
```
</details>

## ИспользоватьАвтоматическийОбменДанными
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИспользоватьАвтоматическийОбменДанными(ОрганизацияСАТУРН) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСАТУРН.ИспользоватьАвтоматическийОбменДанными(ОрганизацияСАТУРН) 
```
</details>

## УстановитьВидимостьКомандыВыполнитьОбмен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает видимость команды "Выполнить обмен" в формах документов, протокола и панели обмена с САТУРН.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - Форма с кнопкой "Выполнить обмен с ФГИС САТУРН"
//  ИмяЭлемента - Строка - Имя кнопки формы
Процедура УстановитьВидимостьКомандыВыполнитьОбмен(Форма, ИмяЭлемента) Экспорт
```

Пример вызова
```bsl
ИнтеграцияСАТУРН.УстановитьВидимостьКомандыВыполнитьОбмен(Форма, ИмяЭлемента) 
```
</details>

## УстановитьПометкуУдаленияПрисоединенныхФайловДокументовСАТУРН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьПометкуУдаленияПрисоединенныхФайловДокументовСАТУРН(Источник, Отказ, РежимЗаписи, РежимПроведения) Экспорт
```

Пример вызова
```bsl
ИнтеграцияСАТУРН.УстановитьПометкуУдаленияПрисоединенныхФайловДокументовСАТУРН(Источник, Отказ, РежимЗаписи, РежимПроведения) 
```
</details>

## ДокументыОснованияДляДокументаСАТУРН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает допустимые типы документа-основания для указанного документа САТУРН.
//
// Параметры:
//	МетаданныеДокументаСАТУРН - ОбъектМетаданных - метаданные документа из ОпределяемыйТип.ДокументыСАТУРНПоддерживающиеСтатусыОформления
//
// Возвращаемое значение:
//	ОписаниеТипов - ОпределяемыйТип.Основание<МетаданныеДокументаСАТУРН.Имя>.Тип
//		тип реквизита ДокументОснование указанного документа САТУРН
//
Функция ДокументыОснованияДляДокументаСАТУРН(МетаданныеДокументаСАТУРН) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСАТУРН.ДокументыОснованияДляДокументаСАТУРН(МетаданныеДокументаСАТУРН) 
```
</details>

## ПриСозданииНаСервереФормыСпискаДокументовСАТУРН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриСозданииНаСервереФормыСпискаДокументовСАТУРН(Форма, ИменаСписков, ИменаСписковКОформлению) Экспорт
```

Пример вызова
```bsl
ИнтеграцияСАТУРН.ПриСозданииНаСервереФормыСпискаДокументовСАТУРН(Форма, ИменаСписков, ИменаСписковКОформлению) 
```
</details>

## ИспользуетсяИнтеграцияВФормеДокументаОснования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИспользуетсяИнтеграцияВФормеДокументаОснования(Форма, Объект) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСАТУРН.ИспользуетсяИнтеграцияВФормеДокументаОснования(Форма, Объект) 
```
</details>

## ОписаниеОформленныхДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОписаниеОформленныхДокументов(МетаданныеДокументаСАТУРН, ДокументОснование, ДокументыПоОснованию, СтатусыОформления) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСАТУРН.ОписаниеОформленныхДокументов(МетаданныеДокументаСАТУРН, ДокументОснование, ДокументыПоОснованию, СтатусыОформления) 
```
</details>

## ШаблонПредставленияДокументаСАТУРНДляПоляИнтеграции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ШаблонПредставленияДокументаСАТУРНДляПоляИнтеграции(МетаданныеДокументаСАТУРН, ДокументОснование) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСАТУРН.ШаблонПредставленияДокументаСАТУРНДляПоляИнтеграции(МетаданныеДокументаСАТУРН, ДокументОснование) 
```
</details>

## ЗагрузитьМестоХранения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загрузить место хранения
//
// Параметры:
//  ДанныеМестаХранения - Структура - (см. ИнтерфейсСАТУРН.ДанныеМестаХранения).
//  СправочникОбъект - СправочникОбъект.МестаХраненияСАТУРН, Неопределено - объект в который производится загрузка.
//  ПараметрыОбмена - Структура, Неопределено - см. ПараметрыОбмена().
//  ТребуетсяПоиск  - Булево - если не передан объект, искать элемент перед заполнением по идентификатору (по умолчанию Истина)
//
// Возвращаемое значение:
//  СправочникСсылка.МестаХраненияСАТУРН - ссылка на записанный/обновленный элемент справочника
//
Функция ЗагрузитьМестоХранения(ДанныеМестаХранения, СправочникОбъект = Неопределено, ПараметрыОбмена = Неопределено, ТребуетсяПоиск = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСАТУРН.ЗагрузитьМестоХранения(ДанныеМестаХранения, СправочникОбъект, ПараметрыОбмена, ТребуетсяПоиск);
```
</details>

## ЗагрузитьМестоПрименения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загрузить место применения
//
// Параметры:
//  ДанныеМестаХранения - Структура - (см. Справочник.МестаПримененияСАТУРН.ДанныеОбъекта).
//  СправочникОбъект - СправочникОбъект.МестаПримененияСАТУРН, Неопределено - объект в который производится загрузка.
//  ПараметрыОбмена - Структура, Неопределено - см. ПараметрыОбмена.
//  ТребуетсяПоиск  - Булево - если не передан объект, искать элемент перед заполнением по идентификатору (по умолчанию Истина)
//
// Возвращаемое значение:
//  СправочникСсылка.МестаПримененияСАТУРН - ссылка на записанный/обновленный элемент справочника
//
Функция ЗагрузитьМестоПрименения(ДанныеМестаПрименения, СправочникОбъект = Неопределено, ПараметрыОбмена = Неопределено, ТребуетсяПоиск = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСАТУРН.ЗагрузитьМестоПрименения(ДанныеМестаПрименения, СправочникОбъект, ПараметрыОбмена, ТребуетсяПоиск);
```
</details>

## ЗагрузитьОрганизацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загрузить организацию
//
// Параметры:
//  ДанныеОрганизации - Структура - (см. ИнтерфейсСАТУРН.ДанныеОрганизации).
//  СправочникОбъект - СправочникОбъект.КлассификаторОрганизацийСАТУРН, Неопределено - объект в который производится загрузка.
//  ПараметрыОбмена - Структура, Неопределено - см. ПараметрыОбмена.
//  ТребуетсяПоиск  - Булево - если не передан объект, искать элемент перед заполнением по идентификатору (по умолчанию Истина)
//
// Возвращаемое значение:
//  СправочникСсылка.КлассификаторОрганизацийСАТУРН - ссылка на записанный/обновленный элемент справочника
//
Функция ЗагрузитьОрганизацию(ДанныеОрганизации, СправочникОбъект = Неопределено, ПараметрыОбмена = Неопределено, ТребуетсяПоиск = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСАТУРН.ЗагрузитьОрганизацию(ДанныеОрганизации, СправочникОбъект, ПараметрыОбмена, ТребуетсяПоиск);
```
</details>

## ЗагрузитьПАТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загрузить ПАТ
//
// Параметры:
//  ДанныеПАТ - Структура - (см. ИнтерфейсСАТУРН.ДанныеПАТ).
//  СправочникОбъект - СправочникОбъект.КлассификаторПАТСАТУРН, Неопределено - объект в который производится загрузка.
//  ПараметрыОбмена - Структура, Неопределено - см. ПараметрыОбмена.
//  ТребуетсяПоиск  - Булево - если не передан объект, искать элемент перед заполнением по идентификатору (по умолчанию Истина)
//
// Возвращаемое значение:
//  СправочникСсылка.КлассификаторПАТСАТУРН - ссылка на записанный/обновленный элемент справочника
//
Функция ЗагрузитьПАТ(ДанныеПАТ, СправочникОбъект = Неопределено, ПараметрыОбмена = Неопределено, ТребуетсяПоиск = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСАТУРН.ЗагрузитьПАТ(ДанныеПАТ, СправочникОбъект, ПараметрыОбмена, ТребуетсяПоиск);
```
</details>

## ЗагрузитьПартию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загрузить партию
//
// Параметры:
//  ДанныеПартии - Структура - (см. ИнтерфейсСАТУРН.ДанныеПартии).
//  СправочникОбъект - СправочникОбъект.Партия, Неопределено - объект в который производится загрузка.
//  ПараметрыОбмена - Структура, Неопределено - см. ПараметрыОбмена.
//  ТребуетсяПоиск  - Булево - если не передан объект, искать элемент перед заполнением по идентификатору (по умолчанию Истина)
//
// Возвращаемое значение:
//  СправочникСсылка.Партия - ссылка на записанный/обновленный элемент справочника
//
Функция ЗагрузитьПартию(ДанныеПартии, СправочникОбъект = Неопределено, ПараметрыОбмена = Неопределено, ТребуетсяПоиск = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСАТУРН.ЗагрузитьПартию(ДанныеПартии, СправочникОбъект, ПараметрыОбмена, ТребуетсяПоиск);
```
</details>

## ЗагрузитьИмпортируемуюПартию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загрузить импортируемую партию
//
// Параметры:
//  ДанныеИмпортируемойПартии - Структура - (см. ИнтерфейсСАТУРН.ДанныеИмпортируемойПартии).
//  СправочникОбъект - СправочникОбъект.ИмпортируемаяПартияСАТУРН, Неопределено - объект в который производится загрузка.
//  ПараметрыОбмена - Структура, Неопределено - см. ПараметрыОбмена.
//  ТребуетсяПоиск  - Булево - если не передан объект, искать элемент перед заполнением по идентификатору (по умолчанию Истина)
//
// Возвращаемое значение:
//  СправочникСсылка.ИмпортируемаяПартияСАТУРН - ссылка на записанный/обновленный элемент справочника
//
Функция ЗагрузитьИмпортируемуюПартию(ДанныеИмпортируемойПартии, СправочникОбъект = Неопределено, ПараметрыОбмена = Неопределено, ТребуетсяПоиск = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСАТУРН.ЗагрузитьИмпортируемуюПартию(ДанныеИмпортируемойПартии, СправочникОбъект, ПараметрыОбмена, ТребуетсяПоиск);
```
</details>

## УказываетсяТранспортноеСредство
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция определяет признак использования справочника транспортных средств.
//
// Возвращаемое значение:
//	Булево - Признак использования справочника транспортных средств.
//
Функция УказываетсяТранспортноеСредство() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСАТУРН.УказываетсяТранспортноеСредство() 
```
</details>

## ЗаписатьСоответствиеНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сопоставляет продукцию САТУРН с номенклатурой.
//
// Параметры:
//  Объект - ДокументОбъект - Объект в котором сопоставляется номенклатура.
//  ОписаниеТабличнойЧасти - Строка, ТаблицаЗначений - имя табличной части или таблица значений для сопоставления.
//  ИмяКолонкиВыделеннаяПартия - Неопределено, Строка - имя колонки выделенная партия
Процедура ЗаписатьСоответствиеНоменклатуры(Объект, ОписаниеТабличнойЧасти = "Товары", ИмяКолонкиВыделеннаяПартия = Неопределено) Экспорт
```

Пример вызова
```bsl
ИнтеграцияСАТУРН.ЗаписатьСоответствиеНоменклатуры(Объект, ОписаниеТабличнойЧасти, ИмяКолонкиВыделеннаяПартия);
```
</details>

## ЗаполнитьСопоставленнуюПродукциюВДокументе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСопоставленнуюПродукциюВДокументе(ВходящиеДанные, ЗаполнятьПАТ) Экспорт
```

Пример вызова
```bsl
ИнтеграцияСАТУРН.ЗаполнитьСопоставленнуюПродукциюВДокументе(ВходящиеДанные, ЗаполнятьПАТ) 
```
</details>

## ЗаполнитьСопоставленныеТовары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСопоставленныеТовары(ТабличнаяЧасть, НоменклатураДляВыбора, ЗаполнятьНоменклатуру) Экспорт
```

Пример вызова
```bsl
ИнтеграцияСАТУРН.ЗаполнитьСопоставленныеТовары(ТабличнаяЧасть, НоменклатураДляВыбора, ЗаполнятьНоменклатуру) 
```
</details>

## ЗаполнитьТипИзмеряемойВеличиныИКоличествоВУпаковке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьТипИзмеряемойВеличиныИКоличествоВУпаковке(ТабличнаяЧасть) Экспорт
```

Пример вызова
```bsl
ИнтеграцияСАТУРН.ЗаполнитьТипИзмеряемойВеличиныИКоличествоВУпаковке(ТабличнаяЧасть) 
```
</details>

## УстановитьУсловноеОформлениеПоляПАТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьУсловноеОформлениеПоляПАТ(Форма, ИмяЭлемента = "ТоварыПАТ", ИмяТЧ = "Товары") Экспорт
```

Пример вызова
```bsl
ИнтеграцияСАТУРН.УстановитьУсловноеОформлениеПоляПАТ(Форма, ИмяЭлемента, ИмяТЧ);
```
</details>

## СверткаРегистраСоответствиеНоменклатурыСАТУРН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сворачивает остатки по партиям регистра соответствие номенклатуры САТУРН
//
Процедура СверткаРегистраСоответствиеНоменклатурыСАТУРН() Экспорт
```

Пример вызова
```bsl
ИнтеграцияСАТУРН.СверткаРегистраСоответствиеНоменклатурыСАТУРН() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
