---
title: Интеграция с маркетплейсом ozon вызов сервера
slug: erp-uh/интеграция-с-маркетплейсом-ozon-вызов-сервера
---


## НастройкиУчетнойЗаписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру с настройками учетной записи.
//
// Параметры:
//   УчетнаяЗаписьМаркетплейса - СправочникСсылка.УчетныеЗаписиМаркетплейсов - учетная запись подключения к сервису.
//
// Возвращаемое значение:
//   Структура - настройки учетной записи:
//     * ВидМаркетплейса                           - ПеречислениеСсылка.ВидыМаркетплейсов - вид маркетплейса;
//     * Организация                               - СправочникСсылка.Организации - организация;
//     * ИдентификаторКлиента                      - Строка - идентификатор клиента;
//     * ИсточникКатегории                         - ПеречислениеСсылка.ИсточникиКатегорийДляМаркетплейса - источник категории;
//     * ВалютаУчета                               - СправочникСсылка.Валюты - валюта учета;
//     * ВидыЦен                                   - Структура - используемые виды цен, где ключ - имя настройки, значение - вид цены;
//     * СхемаРаботы                               - ПеречислениеСсылка.СхемыРаботыТорговыхПлощадок - схема работы;
//     * Партнер                                   - СправочникСсылка.Партнеры - партнер;
//     * Контрагент                                - СправочникСсылка.Контрагенты - контрагент;
//     * Соглашение                                - СправочникСсылка.СоглашенияСКлиентами - соглашение;
//     * ДоговорПродажиЧерезСкладыТорговойПлощадки - СправочникСсылка.ДоговорыКонтрагентов - договор продажи через склады торговой площадки;
//     * ДоговорПродажиЧерезСкладыСобственные      - СправочникСсылка.ДоговорыКонтрагентов - договор продажи через склады собственные;
//     * ПродажиРазделяютсяПоДоговорам             - Булево - признак разделения продаж со складов торговой площадки и собственных складов;
//     * ДополнительныеНастройки                   - Соответствие Из КлючИЗначение - дополнительные настройки.
//
Функция НастройкиУчетнойЗаписи(УчетнаяЗаписьМаркетплейса) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСМаркетплейсомOzonВызовСервера.НастройкиУчетнойЗаписи(УчетнаяЗаписьМаркетплейса) 
```
</details>

## СписокНастроекПодключенияКСервису
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список действующих учетных записей маркетплейсов.
//
// Возвращаемое значение:
//   СписокЗначений Из СправочникСсылка.УчетныеЗаписиМаркетплейсов - не помеченные на удаление учетные записи Ozon.
//
Функция СписокНастроекПодключенияКСервису() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСМаркетплейсомOzonВызовСервера.СписокНастроекПодключенияКСервису() 
```
</details>

## ИзменитьКонтрольОбновленияДанныхТорговойПлощадки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменяет признак контроля обновления данных торговой площадки.
//
// Параметры:
//   УчетнаяЗаписьМаркетплейса         - СправочникСсылка.УчетныеЗаписиМаркетплейсов - учетная запись подключения к сервису.
//	 НеОбновлятьДанныеТорговойПлощадки - Булево - Истина, если необходимо запретить обновление данных торговой площадки.
//
// Возвращаемое значение:
//   Булево - результат выполнения действия.
//
Функция ИзменитьКонтрольОбновленияДанныхТорговойПлощадки(УчетнаяЗаписьМаркетплейса, НеОбновлятьДанныеТорговойПлощадки) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСМаркетплейсомOzonВызовСервера.ИзменитьКонтрольОбновленияДанныхТорговойПлощадки(УчетнаяЗаписьМаркетплейса, НеОбновлятьДанныеТорговойПлощадки) 
```
</details>

## ОбновленияДанныхТорговойПлощадкиРазрешено
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет признак контроля обновления данных торговой площадки.
//
// Параметры:
//   УчетнаяЗаписьМаркетплейса - СправочникСсылка.УчетныеЗаписиМаркетплейсов - учетная запись подключения к сервису.
//
// Возвращаемое значение:
//   Булево - Истина, если обновление данных торговой площадки разрешено;
//            Ложь - обновление данных запрещено.
//
Функция ОбновленияДанныхТорговойПлощадкиРазрешено(УчетнаяЗаписьМаркетплейса) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСМаркетплейсомOzonВызовСервера.ОбновленияДанныхТорговойПлощадкиРазрешено(УчетнаяЗаписьМаркетплейса) 
```
</details>

## ОпределитьТекущуюСопоставленнуюКатегориюМаркетплейсаПоНоменклатуре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет текущую сопоставленную категорию для указанной номенклатуры.
//
// Параметры:
//   УчетнаяЗаписьМаркетплейса - СправочникСсылка.УчетныеЗаписиМаркетплейсов - учетная запись подключения к сервису.
//   Номенклатура              - СправочникСсылка.Номенклатура - номенклатура, для которой требуется найти категорию.
//   ИдентификаторКатегории    - Строка - искомый идентификатор категории маркетплейса;
//   ИсточникКатегории         - ПеречислениеСсылка.ИсточникиКатегорийДляМаркетплейса - источник категории из настроек сопоставления.
//
// Возвращаемое значение:
//   Структура - результат поиска категории:
//     * ИсточникКатегории      - СправочникСсылка.ВидыНоменклатуры, СправочникСсылка.Номенклатура, СправочникСсылка.ТоварныеКатегории -
//                                  источник категории 1С;
//                              - Неопределено - источник категории не найден;
//     * Категория              - СправочникСсылка.ВидыНоменклатуры, СправочникСсылка.Номенклатура, СправочникСсылка.ТоварныеКатегории -
//                                  подобранная категория 1С;
//                              - Неопределено - категория не найдена;
//     * ИдентификаторКатегории - Строка - идентификатор сопоставленной категории маркетплейса;
//     * НаименованиеКатегории  - Строка - наименование сопоставленной категории маркетплейса.
//
Функция ОпределитьТекущуюСопоставленнуюКатегориюМаркетплейсаПоНоменклатуре(УчетнаяЗаписьМаркетплейса, Номенклатура, ИдентификаторКатегории, ИсточникКатегории) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСМаркетплейсомOzonВызовСервера.ОпределитьТекущуюСопоставленнуюКатегориюМаркетплейсаПоНоменклатуре(УчетнаяЗаписьМаркетплейса, Номенклатура, ИдентификаторКатегории, ИсточникКатегории) 
```
</details>

## ОпределитьТекущуюСопоставленнуюКатегориюМаркетплейсаПоИдентификатору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет текущую сопоставленную категорию для указанного идентификатора категории маркетплейса.
//
// Параметры:
//   УчетнаяЗаписьМаркетплейса - СправочникСсылка.УчетныеЗаписиМаркетплейсов - учетная запись подключения к сервису.
//   ИсточникКатегории         - СправочникСсылка.ВидыНоменклатуры, СправочникСсылка.Номенклатура, СправочникСсылка.ТоварныеКатегории -
//                                  искомый источник категории 1С.
//   ИдентификаторКатегории    - Строка - идентификатор категория маркетплейса, для которого требуется найти сопоставление.
//
// Возвращаемое значение:
//   - Неопределено             - сопоставление категорий не найдено.
//   - Структура                - результат поиска категории:
//       * Категория              - Неопределено
//                                - СправочникСсылка.ВидыНоменклатуры
//                                - СправочникСсылка.Номенклатура
//                                - СправочникСсылка.ТоварныеКатегории - подобранная категория 1С;
//       * ИдентификаторКатегории - Строка - идентификатор сопоставленной категории маркетплейса;
//       * НаименованиеКатегории  - Строка - наименование сопоставленной категории маркетплейса.
//
Функция ОпределитьТекущуюСопоставленнуюКатегориюМаркетплейсаПоИдентификатору(УчетнаяЗаписьМаркетплейса, ИсточникКатегории, ИдентификаторКатегории) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСМаркетплейсомOzonВызовСервера.ОпределитьТекущуюСопоставленнуюКатегориюМаркетплейсаПоИдентификатору(УчетнаяЗаписьМаркетплейса, ИсточникКатегории, ИдентификаторКатегории) 
```
</details>

## ПолучитьТекущийИсточникКатегорииМаркетплейса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет категорию-источник, для которой выполнены настройки сопоставления.
//
// Параметры:
//   УчетнаяЗаписьМаркетплейса - СправочникСсылка.УчетныеЗаписиМаркетплейсов - учетная запись подключения к сервису.
//   Категория1С               - СправочникСсылка.ВидыНоменклатуры
//                             - СправочникСсылка.Номенклатура
//                             - СправочникСсылка.ТоварныеКатегории - категория, для которой нужно получить категорию-источник.
//   БлижайшийРодитель         - Булево - признак определения только по ближайшему родителю (Истина) или с учетом
//                                 текущей категории (Ложь).
//
// Возвращаемое значение:
//   Структура - данные об источнике категории:
//     * ИсточникКатегорииМаркетплейса               - СправочникСсылка.ВидыНоменклатуры
//                                                   - СправочникСсылка.Номенклатура
//                                                   - СправочникСсылка.ТоварныеКатегории - источник категории;
//                                                   - Неопределено - источник категории не найден;
//     * ИдентификаторИсточникаКатегорииМаркетплейса - Строка - идентификатор источника категории;
//     * НаименованиеИсточникаКатегорииМаркетплейса  - Строка - наименование источника категории.
//
Функция ПолучитьТекущийИсточникКатегорииМаркетплейса(УчетнаяЗаписьМаркетплейса, Категория1С, БлижайшийРодитель = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСМаркетплейсомOzonВызовСервера.ПолучитьТекущийИсточникКатегорииМаркетплейса(УчетнаяЗаписьМаркетплейса, Категория1С, БлижайшийРодитель);
```
</details>

## ПолучитьРезультатВыполненияФоновогоЗадания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет результат выполнения фонового задания.
// Если результат является структурой, дополнительно добавляет свойство КодОшибки (если оно отсутствует).
//
// Параметры:
//   АдресРезультата - Строка - адрес временного хранилища, в которое помещен результат работы фоновой процедуры.
//
// Возвращаемое значение:
//   Произвольный - результат выполнения фонового задания.
//
Функция ПолучитьРезультатВыполненияФоновогоЗадания(АдресРезультата) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСМаркетплейсомOzonВызовСервера.ПолучитьРезультатВыполненияФоновогоЗадания(АдресРезультата) 
```
</details>

## ИспользуемыеХозяйственныеОперации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные о доступных хозяйственных операциях.
//
// Параметры:
//   ПостфиксЗаголовкаФормы - Строка - значение, однозначно идентифицирующее владельца формы использующей данные о
//                              доступных хозяйственных операциях.
//
// Возвращаемое значение:
//   Структура - используемые хозяйственные операции:
//     * Поставки - Соответствие Из КлючИЗначение - описание хозяйственных операций раздела "Поставки":
//       ** Ключ  - ПеречислениеСсылка.ХозяйственныеОперации - используемая хозяйственная операция;
//       ** Значение - Соответствие Из КлючИЗначение - описание документов:
//          *** Ключ     - Строка - полное имя документа, для которого используется текущая хозяйственная операция;
//          *** Значение - Строка - заголовок формы при выборе текущей хозяйственной операции и вида документа.
//     * Продажи  - Соответствие Из КлючИЗначение - описание хозяйственных операций раздела "Продажи":
//       ** Ключ  - ПеречислениеСсылка.ХозяйственныеОперации - используемая хозяйственная операция;
//       ** Значение - Соответствие Из КлючИЗначение - описание документов:
//          *** Ключ     - Строка - полное имя документа, для которого используется текущая хозяйственная операция;
//          *** Значение - Строка - заголовок формы при выборе текущей хозяйственной операции и вида документа.
//
Функция ИспользуемыеХозяйственныеОперации(ПостфиксЗаголовкаФормы = "все") Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСМаркетплейсомOzonВызовСервера.ИспользуемыеХозяйственныеОперации(ПостфиксЗаголовкаФормы);
```
</details>

## ПутьКРеквизитам1СПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие атрибутов реквизитам 1С, заданным по умолчанию.
//
// Возвращаемое значение:
//   См. ИнтеграцияСМаркетплейсомOzonСервер.ПутьКРеквизитам1СПоУмолчанию.
//
Функция ПутьКРеквизитам1СПоУмолчанию() Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСМаркетплейсомOzonВызовСервера.ПутьКРеквизитам1СПоУмолчанию() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
