---
title: Интеграция с яндекс маркет вызов сервера
slug: erp-uh/интеграция-с-яндекс-маркет-вызов-сервера
---


## ДанныеУчетнойЗаписиЯндексМаркет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет настройки учетной записи торговой площадки Яндекс Маркет.
//
// Параметры:
//   УчетнаяЗапись      - СправочникСсылка.УчетныеЗаписиМаркетплейсов - учетная запись подключения к сервису;
//   СлужебныеПараметры - Булево - признак необходимости возврата в результате дополнительных параметров.
//
// Возвращаемое значение:
//   Структура - настройки учетной записи:
//     * УчетнаяЗапись                     - СправочникСсылка.УчетныеЗаписиМаркетплейсов - учетная запись подключения к сервису.
//     * Наименование                      - Строка - наименование учетной записи (магазина);
//     * ПометкаУдаления                   - Булево - признак недействующего магазина;
//     * Организация                       - СправочникСсылка.Организации - организация, связанная с магазином;
//     * ИсточникКатегории                 - ПеречислениеСсылка.ИсточникиКатегорийДляМаркетплейса - источник категории;
//     * ЦенаПродажи                       - СправочникСсылка.ВидыЦен - вид цены продажи;
//     * СхемаРаботы                       - ПеречислениеСсылка.СхемыРаботыТорговыхПлощадок - схема работы магазина;
//     * ИдентификаторАккаунта             - Строка - идентификатор аккаунта;
//     * ИдентификаторКабинета             - Строка - идентификатор кабинета;
//     * ИдентификаторМагазина             - Строка - идентификатор кампании;
//     * ИдентификаторКлиента              - Строка - номер магазина;
//     * НеОбновлятьДанныеТорговойПлощадки - Булево - признак запрещенного обмена данными с торговой площадкой;
//     * ОбязательныеРеквизитыЗаполнены    - Булево - признак заполненности обязательных реквизитов учетной записи;
//     * ОбязательныеЗаданияВключены       - Булево - признак включенных обязательных регламентных заданий.
//
Функция ДанныеУчетнойЗаписиЯндексМаркет(УчетнаяЗапись, СлужебныеПараметры = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСЯндексМаркетВызовСервера.ДанныеУчетнойЗаписиЯндексМаркет(УчетнаяЗапись, СлужебныеПараметры);
```
</details>

## ПолучитьРезультатВыполненияФоновогоЗадания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет результат выполнения фонового задания.
// Если результат является структурой, дополнительно добавляет свойство КодОшибки (если оно отсутствует).
//
// Параметры:
//   АдресРезультата - Строка - адрес временного хранилища, в которое помещен результат работы фоновой процедуры.
//
// Возвращаемое значение:
//   Произвольный - результат выполнения фонового задания.
//
Функция ПолучитьРезультатВыполненияФоновогоЗадания(АдресРезультата) Экспорт
```

Пример вызова
```bsl
Результат = ИнтеграцияСЯндексМаркетВызовСервера.ПолучитьРезультатВыполненияФоновогоЗадания(АдресРезультата) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
