---
title: Интерфейс ИСМП общего назначения
slug: erp-uh/интерфейс-исмп-общего-назначения
---


## СокращеннаяИнформацияПоКМПриРозничнойПродаже
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить сокращенную информацию по КМ с крипточастью.
//
// Параметры:
//  ДанныеПроверкиКМ - Массив Из СтрокаТабличнойЧасти: см. ШтрихкодированиеИС.ИнициализацияТаблицыДанныхКодовМаркировки - Коллекция строк таблицы
//  Организация - СправочникСсылка.Организации - Организация
//  ИдентификаторФискальногоНакопителя - Строка - идентификатор фискального накопителя
//  ТаймаутНаПродажу - Булево - использовать таймаут на розничную продажу. Если за таймаут не был получен ответ,
//   продажа разрешена
//  ЭтоОперацияПробития - Булево - флаг устанавливается, если процедура вызывается длительной операцией при пробитии
//
// Возвращаемое значение:
//  Структура - Получить информацию по КМ от ККТ:
//  * АварийныйРежим - Булево - Истина, если действует аварийный режим или в ходе проверки он был объявлен
//  * ТребуетсяОбновлениеКлючаСессии - Булево - признак необходимости обновления ключа сессии
//  * ТребуетсяОбновлениеCDNПлощадок - Булево - признак необходимости обновления списка CDN-площадок
//  * ОтсутствуютCDNПлощадки - Булево - возвращает признак отсутствия CDN площадок, запросы не были отправлены
//  * РезультатыОтправкиЗапросов - Массив из см. ИнтерфейсМОТПСлужебный.ОбработатьРезультатОтправкиHTTPЗапросаКакJSON
//  * СтатусыКодовМаркировкиГИСМТ - Соответствие Из КлючИЗначение - Статусы кодов маркировки:
//		** Ключ - СтрокаТабличнойЧасти: см. ШтрихкодированиеИС.ИнициализацияТаблицыДанныхКодовМаркировки - Код маркировки.
//		** Значение - см. ПараметрыКодаМаркировкиМОТП
//  * КодыМаркировкиБезДанныхГИСМТ - Соответствие Из КлючИЗначение - Статусы кодов маркировки:
//		** Ключ - СтрокаТабличнойЧасти: см. ШтрихкодированиеИС.ИнициализацияТаблицыДанныхКодовМаркировки - Код маркировки.
//		** Значение - Булево - Истина, если можно продавать товар в отсутствие ответа ГИС МТ - например, истек таймер на ожидание ответа,
//			или получены ошибки 500 по молочной продукции из Беларуси
//			Если от ГИС МТ был получен ответ - он пишется в СтатусыКодовМаркировкиГИСМТ, и опираться следует на полученные от него данные
//  * ТекстОшибки - Строка - текст ошибки, полученной от ГИС МТ
// 		Общий текст ошибки, ошибки запросов по всем кодам
Функция СокращеннаяИнформацияПоКМПриРозничнойПродаже(ДанныеПроверкиКМ, Организация, ИдентификаторФискальногоНакопителя, ТаймаутНаПродажу = Истина, ЭтоОперацияПробития = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсИСМПОбщегоНазначения.СокращеннаяИнформацияПоКМПриРозничнойПродаже(ДанныеПроверкиКМ, Организация, ИдентификаторФискальногоНакопителя, ТаймаутНаПродажу, ЭтоОперацияПробития);
```
</details>

## АктуализацияСпискаCDNПлощадок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Актуализация списка CDN-площадок для обращения в ГИС МТ методом розничной продажи.
//  При своевременной актуализации списка гарантируется максимально быстрое получение идентификаторов
//  разрешительного режима для ускорения розничной продажи.
//
// Параметры:
//  Организация - СправочникСсылка.Организации - Организация
//
// Возвращаемое значение:
//  Структура - результат обновления площадок:
// * ТребуетсяОбновлениеКлючаСессииРозница - Булево - признак необходимости обновления ключа сессии
// * РезультатОтправкиЗапроса - (См. ОбщегоНазначенияИСМП.ОбработатьРезультатОтправкиHTTPЗапросаКакJSON).
// * СписокПлощадок - Соответствие Из КлючИЗначение - полученные CDN-площадки:
//		** Ключ - Строка - Адрес площадки.
//		** Значение - (см. ЗамерыСкоростиCDNПлощадок)
// * ТекстОшибки - Строка - текст ошибки, полученной от ГИС МТ
Функция АктуализацияСпискаCDNПлощадок(Организация) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсИСМПОбщегоНазначения.АктуализацияСпискаCDNПлощадок(Организация) 
```
</details>

## ДанныеПродукцииПоШтрихкодуEAN
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить данные продукции по штрихкоду EAN.
//
// Параметры:
// 	Значение - Массив Из Строка, Строка - GTIN для которых необходимо получить представление и прочие данные.
// 	ВидПродукции  - ПеречислениеСсылка.ВидыПродукцииИС, Неопределено - Вид продукции.
// 	Организация   - ОпределяемыйТип.Организация - Организация.
// Возвращаемое значение:
// 	Структура - Описание:
// 	* ТребуетсяОбновлениеКлючаСессии - Булево - Признак необходимости обновления ключа сессии.
// 	* РезультатОтправкиЗапроса - см. ОбщегоНазначенияИСМП.ОбработатьРезультатОтправкиHTTPЗапросаКакJSON - Результат
//	отправки запроса.
// 	* ДанныеПродукцииПоШтрихкодуEAN - Неопределено - Если при получении данных возникла ошибка.
// 	                                - Соответствие Из КлючИЗначение - Соответствие штрихкода EAN и данных продукции из сервиса ИС МОТП:
// 	 ** Ключ     - Строка - Штрихкод EAN.
// 	 ** Значение - см. ИнициализироватьДанныеПродукции - Реквизиты продукции:
// 	* ТекстОшибки - Строка - Текст ошибки.
Функция ДанныеПродукцииПоШтрихкодуEAN(Значение, ВидПродукции = Неопределено, Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсИСМПОбщегоНазначения.ДанныеПродукцииПоШтрихкодуEAN(Значение, ВидПродукции, Организация);
```
</details>

## МестаОсуществленияДеятельности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить места осуществления деятельности.
//
// Параметры:
// 	Организация   - ОпределяемыйТип.Организация - Организация.
// 	ВидПродукции  - ПеречислениеСсылка.ВидыПродукцииИС - Вид продукции.
// Возвращаемое значение:
// 	Структура - Описание:
// 	* ТребуетсяОбновлениеКлючаСессии - Булево - Признак необходимости обновления ключа сессии.
// 	* РезультатОтправкиЗапроса - см. ОбщегоНазначенияИСМП.ОбработатьРезультатОтправкиHTTPЗапросаКакJSON - Результат
//	отправки запроса.
// 	* МестаОсуществленияДеятельности - Неопределено - Если при получении данных возникла ошибка.
// 	                                - Соответствие Из КлючИЗначение -
// 	 ** Ключ     - Строка - КодФИАС
// 	 ** Значение - Строка - Код ФИАС
// 	* ТекстОшибки - Строка - Текст ошибки.
Функция МестаОсуществленияДеятельности(Организация, ВидПродукции) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсИСМПОбщегоНазначения.МестаОсуществленияДеятельности(Организация, ВидПродукции) 
```
</details>

## СписокМестОсуществленияДеятельности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод возвращает список МОД, которые соответствуют товарной группе «Пиво, напитки,
// изготавливаемые на основе пива, слабоалкогольные напитки» и принадлежат участнику оборота
// товаров, выполняющему запрос.
//
// Параметры:
// 	Организация   - ОпределяемыйТип.Организация - Организация.
// Возвращаемое значение:
// 	Структура:
// 	* ТребуетсяОбновлениеКлючаСессии - Булево - Признак необходимости обновления ключа сессии.
// 	* РезультатОтправкиЗапроса - Неопределено,
// 	                             См. ОбщегоНазначенияИСМП.ОбработатьРезультатОтправкиHTTPЗапросаКакJSON() - результат.
// 	* МестаОсуществленияДеятельности - Неопределено - Если при получении данных возникла ошибка.
// 	                                 - Массив Из Структура:
// 	 ** КодФИАС     - Строка - КодФИАС.
// 	* ТекстОшибки - Строка - Текст ошибки.
Функция СписокМестОсуществленияДеятельности(Организация) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсИСМПОбщегоНазначения.СписокМестОсуществленияДеятельности(Организация) 
```
</details>

## ПараметрыКодаМаркировкиМОТП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру данных кода маркировки.
// Параметры:
// 	ЭлементДанных - Соответствие из КлючИЗначение, Структура, Неопределено - Данные ГИС МТ
// 	ВидПродукции - ПеречислениеСсылка.ВидыПродукцииИС, Неопределено - Вид продукции.
// 	ДополнительныеПараметры - Структура:
// 		* НастройкиРазбора - см. РазборКодаМаркировкиИССлужебный.НастройкиРазбораКодаМаркировки.
// 		* Организация - ОпределяемыйТип.Организация
// 		* КешОрганизаций - Соответствие из КлючИЗначение - кеш для получения ИНН организаций-владельцев кода:
// 			** Ключ - ОпределяемыйТип.Организация - организация
// 			** Значение - Строка - ИНН организации
//
// Возвращаемое значение:
//  см. ИнициализироватьПараметрыКодаМаркировкиМОТП
Функция ПараметрыКодаМаркировкиМОТП(ЭлементДанных = Неопределено, ВидПродукции = Неопределено, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсИСМПОбщегоНазначения.ПараметрыКодаМаркировкиМОТП(ЭлементДанных, ВидПродукции, ДополнительныеПараметры);
```
</details>

## ИнициализироватьПараметрыКодаМаркировкиМОТП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИнициализироватьПараметрыКодаМаркировкиМОТП() Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсИСМПОбщегоНазначения.ИнициализироватьПараметрыКодаМаркировкиМОТП() 
```
</details>

## ТоварнаяГруппа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразовывает текстовое представление товарной группы в значение перечисления и наоборот.
//
// Параметры:
//  ЗначениеПоиска - ПеречислениеСсылка.ВидыПродукцииИС, Строка - значение для перекодировки
//  ВидПродукции - ПеречислениеСсылка.ВидыПродукцииИС - Вид продукции для уточнения неоднозначности
//
// Возвращаемое значение:
//  ПеречислениеСсылка.ВидыПродукцииИС, Строка - Товарная группа.
Функция ТоварнаяГруппа(Знач ЗначениеПоиска, ВидПродукции = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсИСМПОбщегоНазначения.ТоварнаяГруппа(ЗначениеПоиска, ВидПродукции);
```
</details>

## ТоварнаяГруппаЧислом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразовывает текстовое представление товарной группы в значение перечисления и наоборот.
//
// Параметры:
//  ЗначениеПоиска - ПеречислениеСсылка.ВидыПродукцииИС, Строка - значение для перекодировки
//  ВидПродукции - ПеречислениеСсылка.ВидыПродукцииИС, Неопределено - Вид продукции
//
// Возвращаемое значение:
//  ПеречислениеСсылка.ВидыПродукцииИС, Строка - Товарная группа.
Функция ТоварнаяГруппаЧислом(Знач ЗначениеПоиска, ВидПродукции = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсИСМПОбщегоНазначения.ТоварнаяГруппаЧислом(ЗначениеПоиска, ВидПродукции);
```
</details>

## СтатусКодаМаркировкиИСМП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразовывает текстовое представление статуса кода маркировки ИСМП в значение перечисления и наоборот.
//
// Параметры:
//  ЗначениеПоиска - ПеречислениеСсылка.СтатусыКодовМаркировкиИСМП, Строка - значение для перекодировки
//
// Возвращаемое значение:
//  ПеречислениеСсылка.СтатусыКодовМаркировкиИСМП, Строка - статус кода маркировки.
Функция СтатусКодаМаркировкиИСМП(Знач ЗначениеПоиска) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсИСМПОбщегоНазначения.СтатусКодаМаркировкиИСМП(ЗначениеПоиска) 
```
</details>

## ВидУпаковки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразовывает текстовое представление вида упаковки в значение перечисления.
//
// Параметры:
//  ЗначениеПоиска - Строка - значение для перекодировки
//  ВидПродукции   - ПеречислениеСсылка.ВидыПродукцииИС  - Вид продукции.
//  ЗначениеПоискаДополнительное - Строка
//
// Возвращаемое значение:
//  ПеречислениеСсылка.ВидыУпаковокИС - вид упаковки.
//
Функция ВидУпаковки(Знач ЗначениеПоиска, ВидПродукции, ЗначениеПоискаДополнительное = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсИСМПОбщегоНазначения.ВидУпаковки(ЗначениеПоиска, ВидПродукции, ЗначениеПоискаДополнительное);
```
</details>

## СтатусКодаМаркировкиМОТП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразовывает текстовое представление статуса кода маркировки МОТП в значение перечисления.
//
// Параметры:
//  ЗначениеПоиска - Строка - значение для перекодировки
//
// Возвращаемое значение:
//  ПеречислениеСсылка.СтатусыКодовМаркировкиМОТП - статус кода маркировки.
//
Функция СтатусКодаМаркировкиМОТП(Знач ЗначениеПоиска) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсИСМПОбщегоНазначения.СтатусКодаМаркировкиМОТП(ЗначениеПоиска) 
```
</details>

## СтатусКодаМаркировкиПоДаннымГИСМТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Статус кода маркировки по структуре данных ГИС МТ - признаков продажи, нанесения, возможности реализации
//
// Параметры:
//  СтруктураКода - Структура - Структура признаков:
//  	* Продано - Булево
//  	* ВозможностьРеализации - Булево
//  	* Нанесен - Булево
//  ЭтоПродукцияМОТП - Булево - признак, что продукция является МОТП
//
// Возвращаемое значение:
//  ПеречислениеСсылка.СтатусыКодовМаркировкиИСМП - Статус кода маркировки по данным ГИС МТ
Функция СтатусКодаМаркировкиПоДаннымГИСМТ(Знач СтруктураКода, ЭтоПродукцияМОТП = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсИСМПОбщегоНазначения.СтатусКодаМаркировкиПоДаннымГИСМТ(СтруктураКода, ЭтоПродукцияМОТП);
```
</details>

## ИнициализироватьДанныеПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализировать структуру данных продукции.
//
// Возвращаемое значение:
//  Структура - Реквизиты продукции:
//   * Идентификатор             - Строка - Идентификатор продукции.
//   * Наименование              - Строка - Наименование продукции.
//   * НаименованиеПолное        - Строка - Наименование продукции.
//   * GTIN                      - Строка - GTIN.
//   * ТорговаяМарка             - Строка - Торговая марка.
//   * ТипУпаковки               - Строка - Тип упаковки.
//   * КоличествоПотребительскихУпаковок - Строка - Количество вложенных единиц.
//   * Модель                    - Строка - Модель производителя.
//   * ДатаПубликации            - Дата   - Дата публикации.
//   * ИННПроизводителя          - Строка - ИНН производителя (импортера).
//   * СтранаПроизводства        - Строка - Страна производства.
//   * ТипПродукции              - Строка - Вид обуви (код).
//   * ТипПродукцииНаименование  - Строка - Вид обуви (наименование).
//   * Цвет              - Строка - Цвет.
//   * Размер            - Строка - Размер.
//   * МатериалВерха     - Строка - Материал верха.
//   * МатериалНиза      - Строка - Материал низа.
//   * МатериалПодкладки - Строка - Материал подкладки.
Функция ИнициализироватьДанныеПродукции(ДанныеОбработки = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсИСМПОбщегоНазначения.ИнициализироватьДанныеПродукции(ДанныеОбработки);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
