---
title: Интерфейс МОТП
slug: erp-uh/интерфейс-мотп
---


## ДеревоУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Построить дерево упаковок на основании данных о кодах маркировки.
//
// Параметры:
// 	Значение - Массив, Строка - Коды маркировки для которых необходимо построить дерево упаковок
// 	Детализация - ПеречислениеСсылка.ДетализацияСтруктурыХраненияИС, Неопределено - Детализация хранения табачной продукции
// 	ПараметрыСканирования - См. ШтрихкодированиеОбщегоНазначенияИС.ПараметрыСканирования
// Возвращаемое значение:
// 	Структура - Описание:
//	 * ТребуетсяОбновлениеКлючаСессии - Булево - Признак необходимости обновления ключа сессии.
//	 * ТекстОшибки                    - Строка - Текст ошибки.
//	 * ДеревоУпаковок                 - ДеревоЗначений, Неопределено - Дерево упаковок, построенное по переданным кодам маркировки.
//	 * GTIN - ТаблицаЗначений - Список GTIN в разрезе МРЦ:
//	  ** GTIN - Строка - GTIN.
//	  ** МРЦ - Число - МРЦ.
//
Функция ДеревоУпаковок(Значение, Детализация = Неопределено, ПараметрыСканирования = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсМОТП.ДеревоУпаковок(Значение, Детализация, ПараметрыСканирования);
```
</details>

## ЗапроситьСтатусыКодовМаркировки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запрос статусов кодов маркировки (включая владельца).
// В результате успешного выполнения запроса в ответе вернется список кодов маркировки,
// их статус и владелец на момент запроса. Статусы могут принимать следующие значение:
// 	EMITTED - Эмитирован,
// 	APPLIED - Нанесён,
// 	INTRODUCED - Введён в оборот,
// 	WRITTEN_OFF - Выведен из оборота, списан,
// 	WITHDRAWN - Выведен из оборота, продан,
// 	UNDEFINED - Неопределен.
//
// Параметры:
// 	ДанныеДляЗапроса          - Массив из Структура,СтрокаТаблицыЗначений,СтрокаДереваЗначений
// 	                            Структура,СтрокаТаблицыЗначений           - Данные для запроса статусов.
// 	СтатусыКодовМаркировкиКеш - Соответствие, Неопределено                - Кеш статусов кодов маркировки.
// 	Организация               - ОпределяемыйТип.Организация               - Организация.
// 	ЗапрашиватьСтатусыКодовЕАЭС - Булево                                  - флаг использования запроса для проверки в сервисе.
// Возвращаемое значение:
//	Структура - Описание:
//	* ТребуетсяОбновлениеКлючаСессии - Булево - Признак необходимости обновления ключа сессии.
//	* РезультатОтправкиЗапроса - (См. ОбщегоНазначенияИСМП.ОбработатьРезультатОтправкиHTTPЗапросаКакJSON).
//	* СтатусыКодовМаркировки - Соответствие - кодов маркировки и структур:
//		* Статус       - ПеречислениеСсылка.СтатусыКодовМаркировкиМОТП - Статус кода маркировки.
//		* ИННВладельца - Строка                                        - ИНН владельца кода маркировки.
// * ТекстОшибки - Строка - Текст сообщения об ошибке.
Функция ЗапроситьСтатусыКодовМаркировки(ДанныеДляЗапроса, Организация = Неопределено, ЗапрашиватьСтатусыКодовЕАЭС = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсМОТП.ЗапроситьСтатусыКодовМаркировки(ДанныеДляЗапроса, Организация, ЗапрашиватьСтатусыКодовЕАЭС);
```
</details>

## ЗапроситьСтатусыКодовМаркировкиПакетно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполнить запрос статусов для списка кодов маркировки.
// В результате успешного выполнения запроса в ответе вернется список кодов маркировки,
// их статус и владелец на момент запроса. Статусы могут принимать следующие значение:
// 	EMITTED - Эмитирован,
// 	APPLIED - Нанесён,
// 	INTRODUCED - Введён в оборот,
// 	WRITTEN_OFF - Выведен из оборота, списан,
// 	WITHDRAWN - Выведен из оборота, продан,
// 	UNDEFINED - Неопределен.
//
// Параметры:
// 	МассивИсходныхСтрок       - Массив из Структура,СтрокаТаблицыЗначений - Массив кодов маркировки.
//
// Возвращаемое значение:
//	Структура - Описание:
//	* ТребуетсяОбновлениеКлючаСессии - Булево - Признак необходимости обновления ключа сессии.
//	* РезультатОтправкиЗапроса - (См. ОбщегоНазначенияИСМП.ОбработатьРезультатОтправкиHTTPЗапросаКакJSON).
//	* СтатусыКодовМаркировки - Соответствие - кодов маркировки и структур:
//		* Статус       - ПеречислениеСсылка.СтатусыКодовМаркировкиМОТП - Статус кода маркировки.
//		* ИННВладельца - Строка                                        - ИНН владельца кода маркировки.
// * ТекстОшибки - Строка - Текст сообщения об ошибке.
Функция ЗапроситьСтатусыКодовМаркировкиПакетно(МассивИсходныхСтрок, ПараметрыЗапросаСтатусов) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсМОТП.ЗапроситьСтатусыКодовМаркировкиПакетно(МассивИсходныхСтрок, ПараметрыЗапросаСтатусов) 
```
</details>

## ЗапроситьСтатусыКодовМаркировкиЕАЭС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполнить запрос статусов для кодов маркировки из ЕАЭС.
// В результате успешного выполнения запроса в ответе вернется список кодов маркировки,
// их статус и владелец на момент запроса. Статусы могут принимать следующие значение:
// 	cisStatusId:
// 	"00" - не определён;
// 	"1" - в обороте на территории государства-члена ЕАЭС;
// 	"2" - не в обороте на территории государства-члена ЕАЭС
//
// Параметры:
// 	МассивИсходныхСтрок       - Массив из Структура,СтрокаТаблицыЗначений - Массив кодов маркировки.
// 	СтатусыКодовМаркировкиКеш - Соответствие, Неопределено                - Кеш статусов кодов маркировки.
// 	Организация               - ОпределяемыйТип.Организация               - Организация.
// 	ПолеИсточник              - Строка - Поле источник данных.
// 	НастройкиРазбора - (см. РазборКодаМаркировкиИССлужебный.НастройкиРазбораКодаМаркировки).
// Возвращаемое значение:
//	Структура - Описание:
//	* ТребуетсяОбновлениеКлючаСессии - Булево - Признак необходимости обновления ключа сессии.
//	* РезультатОтправкиЗапроса - (См. ОбщегоНазначенияИСМП.ОбработатьРезультатОтправкиHTTPЗапросаКакJSON).
//	* СтатусыКодовМаркировки - Соответствие - кодов маркировки и структур.
// * ТекстОшибки - Строка - Текст сообщения об ошибке.
Функция ЗапроситьСтатусыКодовМаркировкиЕАЭС(СоответствиеИсходныхСтрок, СтатусыКодовМаркировкиКеш = Неопределено, Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсМОТП.ЗапроситьСтатусыКодовМаркировкиЕАЭС(СоответствиеИсходныхСтрок, СтатусыКодовМаркировкиКеш, Организация);
```
</details>

## ПроверитьСеруюЗонуКодовМаркировки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет коды пачек, блоков и логистических упаковок на принадлежность к серой зоне.
//
// Параметры:
// 	МассивИсходныхСтрок       - Массив из Структура, СтрокаТаблицыЗначений - Массив кодов маркировки.
// 	СтатусыКодовМаркировкиКеш - Соответствие, Неопределено                - Кеш статусов кодов маркировки.
// 	Организация               - ОпределяемыйТип.Организация               - Организация.
// Возвращаемое значение:
//	Структура - Описание:
//	* ТребуетсяОбновлениеКлючаСессии - Булево - Признак необходимости обновления ключа сессии.
//	* РезультатОтправкиЗапроса - (См. ОбщегоНазначенияИСМП.ОбработатьРезультатОтправкиHTTPЗапросаКакJSON).
//	* СостояниеСеройЗоны - Соответствие Из КлючИЗначение:
//		* Ключ - Структура - Исходная строка
//		* Значение - Структура - Состояние серой зоны.
// * ТекстОшибки - Строка - Текст сообщения об ошибке.
Функция ПроверитьСеруюЗонуКодовМаркировки(ДанныеДляЗапроса, Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсМОТП.ПроверитьСеруюЗонуКодовМаркировки(ДанныеДляЗапроса, Организация);
```
</details>

## ПроверитьСеруюЗонуКодовМаркировкиПакетно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет коды пачек, блоков и логистических упаковок на принадлежность к серой зоне.
//
// Параметры:
// 	МассивИсходныхСтрок       - Массив из Структура, СтрокаТаблицыЗначений - Массив кодов маркировки.
// 	СтатусыКодовМаркировкиКеш - Соответствие, Неопределено                - Кеш статусов кодов маркировки.
// 	Организация               - ОпределяемыйТип.Организация               - Организация.
// Возвращаемое значение:
//	Структура - Описание:
//	* ТребуетсяОбновлениеКлючаСессии - Булево - Признак необходимости обновления ключа сессии.
//	* РезультатОтправкиЗапроса - (См. ОбщегоНазначенияИСМП.ОбработатьРезультатОтправкиHTTPЗапросаКакJSON).
//	* СостояниеСеройЗоны - Соответствие Из КлючИЗначение:
//		* Ключ - Структура - Исходная строка
//		* Значение - Структура - Состояние серой зоны.
// * ТекстОшибки - Строка - Текст сообщения об ошибке.
Функция ПроверитьСеруюЗонуКодовМаркировкиПакетно(МассивИсходныхСтрок, СостояниеСеройЗоныКеш = Неопределено, Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсМОТП.ПроверитьСеруюЗонуКодовМаркировкиПакетно(МассивИсходныхСтрок, СостояниеСеройЗоныКеш, Организация);
```
</details>

## ЗапроситьДанныеОбАгрегацииКодовМаркировки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполнить запрос данных об агрегации кодов маркировки в ИС МОТП.
// В результате успешного выполнения запроса в ответе вернется информация о составе кода агрегата.
// В запросе следует указывать только один код маркировки.
//
// Параметры:
// 	СтрокаКодаМаркировки - Структура, СтрокаТаблицыЗначений - Строка кода маркировки.
// Возвращаемое значение:
//	 Структура - Вложенные коды упаковок:
//		* ТребуетсяОбновлениеКлючаСессии - Булево - Признак необходимости обновления ключа сессии.
//		* РезультатОтправкиЗапроса - (См. ОбщегоНазначенияИСМП.ОбработатьРезультатОтправкиHTTPЗапросаКакJSON).
//		* ТекстОшибки - Строка - Текст ошибки
//		* ДанныеОбАгрегации - Массив из Структура:
//			* КодМаркировки - Строка                                        - Код маркировки.
//			* Статус        - ПеречислениеСсылка.СтатусыКодовМаркировкиМОТП - Статус кода маркировки.
//			* ИНН           - Строка                                        - ИНН владельца кода маркировки.
Функция ЗапроситьДанныеОбАгрегацииКодовМаркировки(СтрокаКодаМаркировки, Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсМОТП.ЗапроситьДанныеОбАгрегацииКодовМаркировки(СтрокаКодаМаркировки, Организация);
```
</details>

## ЗапроситьДанныеОбАгрегацииКодовМаркировкиПакетно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполнить запрос данных об агрегации кодов маркировки в ИС МОТП.
// В результате успешного выполнения запроса в ответе вернется информация о составе кода агрегата.
// В запросе следует указывать только один код маркировки.
//
// Параметры:
// 	СтрокаКодаМаркировки - Структура - Строка кода маркировки.
// Возвращаемое значение:
//	 Структура - Вложенные коды упаковок:
//		* ТребуетсяОбновлениеКлючаСессии - Булево - Признак необходимости обновления ключа сессии.
//		* РезультатОтправкиЗапроса - (См. ОбщегоНазначенияИСМП.ОбработатьРезультатОтправкиHTTPЗапросаКакJSON).
//		* ТекстОшибки - Строка - Текст ошибки
//		* ДанныеОбАгрегации - Массив из Структура:
//			* КодМаркировки - Строка                                        - Код маркировки.
//			* Статус        - ПеречислениеСсылка.СтатусыКодовМаркировкиМОТП - Статус кода маркировки.
//			* ИНН           - Строка                                        - ИНН владельца кода маркировки.
Функция ЗапроситьДанныеОбАгрегацииКодовМаркировкиПакетно(ПакетКодовМаркировки, Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсМОТП.ЗапроситьДанныеОбАгрегацииКодовМаркировкиПакетно(ПакетКодовМаркировки, Организация);
```
</details>

## ЗапроситьМРЦДляКодаМаркировки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В результате успешного выполнения запроса в ответе вернется информация о максимальной
// розничной цене табачной продукции, если она установлена.
//
// Параметры:
// 	ДанныеДляЗапроса - Массив из Структура,СтрокаТаблицыЗначений,СтрокаДереваЗначений,
// 	Структура,СтрокаТаблицыЗначений,СтрокаДереваЗначений - Коллекция или элемент коллекции.
// Возвращаемое значение:
//	Структура - Описание:
//	* ТребуетсяОбновлениеКлючаСессии - Булево - Признак необходимости обновления ключа сессии.
//	* РезультатОтправкиЗапроса - (См. ОбщегоНазначенияИСМП.ОбработатьРезультатОтправкиHTTPЗапросаКакJSON).
//	* ДанныеПродукции - Соответствие - где:
//   * Ключ - Структура,СтрокаТаблицыЗначений,СтрокаДереваЗначений - Переданное значение в параметре ДанныеДляЗапроса,
//   * Значение - Структура - данные о статусе и МРЦ:
//		** Статус - ПеречислениеСсылка.СтатусыКодовМаркировкиМОТП - Статус кода.
//		** МРЦ  - Число  - МРЦ для кода маркировки. Если указано -1, то МРЦ не ограничено.
//		** Наименование - Строка - Наименование продукции.
// * ТекстОшибки - Строка - Текст сообщения об ошибке.
Функция ЗапроситьМРЦДляКодаМаркировки(ДанныеДляЗапроса) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсМОТП.ЗапроситьМРЦДляКодаМаркировки(ДанныеДляЗапроса) 
```
</details>

## ЗапроситьСписокПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполнить запрос списка продукции.
// В результате успешного выполнения запроса в ответе вернется список продукции,
// содержащие id - идентификатор продукта, gtin - международный товарный идентификатор и producerINN - ИНН производителя.
//
// Возвращаемое значение:
//	Структура - Структура со свойствами:
//	* ТребуетсяОбновлениеКлючаСессии - Булево          - Необходимость обновления ключа сессии.
//	* РезультатОтправкиЗапроса       - (См. ОбщегоНазначенияИСМП.ОбработатьРезультатОтправкиHTTPЗапросаКакJSON).
//	* ПродукцияОрганизации           - ТаблицаЗначений - Список продукции организации:
//		** GTIN                - Строка - GTIN товара.
//		** ИННПроизводителя    - Строка - ИНН производителя.
//		** ТипУпаковки         - Строка - Тип упаковки товара.
//		** КоличествоВложенных - Число  - Количество вложенных единиц.
//  * ТекстОшибки                    - Строка          - Текст сообщения об ошибке.
Функция ЗапроситьСписокПродукции(НомерСтраницы = 0) Экспорт
```

Пример вызова
```bsl
Результат = ИнтерфейсМОТП.ЗапроситьСписокПродукции(НомерСтраницы);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
