---
title: Источники данных повт исп
slug: erp-uh/источники-данных-повт-исп
---


## СхемаКомпоновкиДанныхПравила
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ссылку на схему по типу, разделу и указанному источнику данных
// Предназначен для обезличенного, не зависящего от ссылки кэшированного получения схем из справочников-правил получения
// данных Если схема модифицируется в последствии в коде, то именно она будет возвращаться из кэша.
//
// Параметры:
//  ИмяСправочникаИсточника - Строка - например, "ПравилаПолученияФактаПоПоказателямБюджетов"
//  РазделИсточникаДанных - ПеречислениеСсылка.РазделыИсточниковДанныхБюджетирования - оперативный, международный или
//                                                                                     регламентированный учет.
//  ИсточникДанных - СправочникСсылка.НастройкиХозяйственныхОпераций, ПланВидовХарактеристикСсылка.СтатьиАктивовПассивов - объект,
//    содержащий имя макета СКД в правиле.
//
// Возвращаемое значение:
// 	 СхемаКомпоновкиДанных - СхемаКомпоновкиДанных - схема получения фактических данных, соответствующая источнику.
//						   - Неопределено - если макет не найден.
//
Функция СхемаКомпоновкиДанныхПравила(ИмяСправочникаИсточника, РазделИсточникаДанных, ИсточникДанных) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.СхемаКомпоновкиДанныхПравила(ИмяСправочникаИсточника, РазделИсточникаДанных, ИсточникДанных) 
```
</details>

## ПроизвольнаяСхемаКомпоновкиДанныхПравила
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ссылку на схему по типу, разделу и указанному хешу компоновки данных
// Предназначен для обезличенного, не зависящего от ссылки кэшированного получения схем из справочников-правил получения
// данных Если схема модифицируется в последствии в коде, то именно она будет возвращаться из кэша.
//
// Параметры:
//  ИмяСправочникаИсточника - Строка - например, "ПравилаПолученияФактаПоПоказателямБюджетов"
//  РазделИсточникаДанных - ПеречислениеСсылка.РазделыИсточниковДанныхБюджетирования - произвольные данные
//  ХешСхемыКомпоновкиДанных - Строка - хеш сумма произвольной схемы компоновки данных.
//
// Возвращаемое значение:
// 	 СхемаКомпоновкиДанных - СхемаКомпоновкиДанных - схема получения фактических данных, соответствующая источнику.
//						   - Неопределено - если макет не найден.
//
Функция ПроизвольнаяСхемаКомпоновкиДанныхПравила(ИмяСправочникаИсточника, РазделИсточникаДанных, ХешСхемыКомпоновкиДанных) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ПроизвольнаяСхемаКомпоновкиДанныхПравила(ИмяСправочникаИсточника, РазделИсточникаДанных, ХешСхемыКомпоновкиДанных) 
```
</details>

## ПоддерживаемыеСправочникиИсточникиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие поддерживаемых типов и их имен
//
// Возвращаемое значение:
// 	 Соответствие из КлючИЗначение:
//		*Ключ - Тип- тип поддерживаемого объекта метаданных
//		*Значение - Строка - имя справочника, как оно задано в конфигураторе.
//
Функция ПоддерживаемыеСправочникиИсточникиДанных() Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ПоддерживаемыеСправочникиИсточникиДанных() 
```
</details>

## ИменаСхемУмолчанийДляИсточниковДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя схемы-умолчания на случай, когда иные схемы не найдены
//
// Возвращаемое значение:
// 	 Соответствие из КлючИЗначение:
//		*Ключ - Строка - имя справочника, как оно задано в конфигураторе
//		*Значение - Строка - имя макета схемы компоновки данных.
//
Функция ИменаСхемУмолчанийДляИсточниковДанных() Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ИменаСхемУмолчанийДляИсточниковДанных() 
```
</details>

## ПолучитьМакетСправочника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает макет из указанного справочника
//
// Параметры:
//  ИмяСправочникаИсточника - Строка - например, "ПравилаПолученияФактаПоПоказателямБюджетов"
//  ИмяМакета               - Строка - например, "ВыданныеАвансы".
//
// Возвращаемое значение:
//  ТабличныйДокумент, ТекстовыйДокумент - объект, который может быть макетом.
//
Функция ПолучитьМакетСправочника(ИмяСправочникаИсточника, Знач ИмяМакета = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ПолучитьМакетСправочника(ИмяСправочникаИсточника, ИмяМакета);
```
</details>

## ПоддерживаемыеТипыИсточниковИмениМакета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив поддерживаемых типов источников имени макета
//
// Возвращаемое значение:
// 	 Массив из Тип - тип поддерживаемого объекта метаданных.
//
Функция ПоддерживаемыеТипыИсточниковИмениМакета() Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ПоддерживаемыеТипыИсточниковИмениМакета() 
```
</details>

## ПолучитьХранимыеНастройкиСправочника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает хранимые настройки из указанного справочника
//
// Параметры:
//  ИмяСправочникаИсточника  - Строка - например, "ПравилаПолученияФактаПоПоказателямБюджетов"
//  ХешНастроек - Строка - хеш-сумма настроенных отборов компоновки данных.
//
// Возвращаемое значение:
//  КомпоновщикНастроекКомпоновкиДанных
//
Функция ПолучитьХранимыеНастройкиСправочника(ИмяСправочникаИсточника, ХешНастроек) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ПолучитьХранимыеНастройкиСправочника(ИмяСправочникаИсточника, ХешНастроек) 
```
</details>

## ПолучитьХранимыйМакетСправочника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает хранимый макет из указанного справочника
//
// Параметры:
//  ИмяСправочникаИсточника  - Строка - например, "ПравилаПолученияФактаПоПоказателямБюджетов"
//  ХешСхемыКомпоновкиДанных - Строка - хеш-сумма произвольной схемы компоновки данных.
//
// Возвращаемое значение:
//  ТабличныйДокумент, ТекстовыйДокумент - объект, который может быть макетом.
//
Функция ПолучитьХранимыйМакетСправочника(ИмяСправочникаИсточника, ХешСхемыКомпоновкиДанных) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ПолучитьХранимыйМакетСправочника(ИмяСправочникаИсточника, ХешСхемыКомпоновкиДанных) 
```
</details>

## ОписаниеТипаПравил
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание типов правил получения фактических данных
//
// Возвращаемое значение:
//  ОписаниеТипов
//
Функция ОписаниеТипаПравил() Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ОписаниеТипаПравил() 
```
</details>

## ОписаниеТипаПолученияДанныхБюджетирования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание типов типа правила получения фактических данных
//
// Возвращаемое значение:
//  ОписаниеТипов
//
Функция ОписаниеТипаПолученияДанныхБюджетирования() Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ОписаниеТипаПолученияДанныхБюджетирования() 
```
</details>

## ВыражениеПоказателяСуммы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает выражение суммового показателя для правила получения фактических данных.
//
// Параметры:
//	ИмяСправочникаИсточника      - Строка - например, "ПравилаПолученияФактаПоПоказателямБюджетов". См. ИсточникиДанныхПовтИсп.ПоддерживаемыеСправочникиИсточникиДанных
//	ИдентификаторИсточникаДанных - Строка - имя поставляемого макета или хеш-сумма произвольной схемы компоновки данных. В СКД должен быть набор данных - ОбъединенныйФакт
//	ИсточникВалюты               - Строка - может принимать значения "Валюта", "ВалютаУпр", "ВалютаРегл", "ВалютаМеждународ", "КорВалюта"
//	РазделИсточникаДанных        - ПеречислениеСсылка.РазделыИсточниковДанныхБюджетирования - оперативный, международный, регламентированный учет или произвольные данные
//	ТипИтога                     - ПеречислениеСсылка.ТипыИтогов - тип итоговых данных по счету, если он источник данных
//	ИсточникСуммыОперации        - ПеречислениеСсылка.ПоказателиАналитическихРегистров, Неопределено - источник получения суммы из аналитического регистра
//  ИсточникВалютный             - Булево - признак того, что суммы могут хранятся в разных валютах.
//
// Возвращаемое значение:
//	Строка - имя поля в схеме-источнике данных.
//
Функция ВыражениеПоказателяСуммы(ИмяСправочникаИсточника, ИдентификаторИсточникаДанных, ИсточникВалюты, РазделИсточникаДанных, ТипИтога, ИсточникСуммыОперации = Неопределено, ИсточникВалютный = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ВыражениеПоказателяСуммы(ИмяСправочникаИсточника, ИдентификаторИсточникаДанных, ИсточникВалюты, РазделИсточникаДанных, ТипИтога, ИсточникСуммыОперации, ИсточникВалютный);
```
</details>

## ВыраженияПоказателейСуммы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает все возможные выражения суммового показателя для правила получения фактических данных.
//
// Параметры:
//  ИмяСправочникаИсточника      - Строка - например, "ПравилаПолученияФактаПоПоказателямБюджетов". См. ИсточникиДанныхПовтИсп.ПоддерживаемыеСправочникиИсточникиДанных
//  ИдентификаторИсточникаДанных - Строка - имя поставляемого макета или хеш-сумма произвольной схемы компоновки данных.
//                                          В СКД должен быть набор данных - ОбъединенныйФакт.
//  РазделИсточникаДанных        - ПеречислениеСсылка.РазделыИсточниковДанныхБюджетирования - оперативный,
//      международный, регламентированный учет или произвольные данные.
//  ТипИтога                     - ПеречислениеСсылка.ТипыИтогов, Неопределено - тип итоговых данных по счету, если он
//                                                                               источник данных.
//  ИсточникСуммыОперации        - ПеречислениеСсылка.ПоказателиАналитическихРегистров, Неопределено - источник
//      получения суммы из аналитического регистра.
//  ИсточникВалютный             - Булево - признак того, что суммы могут хранятся в разных валютах.
//
// Возвращаемое значение:
//	Структура - сопоставленные показатели факта и поля источника данных:
//		*Ключ     - Строка - имя показателя фактических данных
//		*Значение - Строка - имя поля в схеме-источнике данных.
//
Функция ВыраженияПоказателейСуммы(ИмяСправочникаИсточника, ИдентификаторИсточникаДанных, РазделИсточникаДанных, ТипИтога = Неопределено, ИсточникСуммыОперации = Неопределено, ИсточникВалютный = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ВыраженияПоказателейСуммы(ИмяСправочникаИсточника, ИдентификаторИсточникаДанных, РазделИсточникаДанных, ТипИтога, ИсточникСуммыОперации, ИсточникВалютный);
```
</details>

## ВыражениеПоказателяКоличества
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает выражение количественного показателя для правила получения фактических данных.
//
// Параметры:
//  ИмяСправочникаИсточника      - Строка - например, "ПравилаПолученияФактаПоПоказателямБюджетов". См. ИсточникиДанныхПовтИсп.ПоддерживаемыеСправочникиИсточникиДанных
//  ИдентификаторИсточникаДанных - Строка - имя поставляемого макета или хеш-сумма произвольной схемы компоновки данных
//  РазделИсточникаДанных        - ПеречислениеСсылка.РазделыИсточниковДанныхБюджетирования - оперативный,
//      международный, регламентированный учет или произвольные данные.
//  ТипИтога                     - ПеречислениеСсылка.ТипыИтогов - тип итоговых данных по счету, если он источник данных.
//
// Возвращаемое значение:
//	Структура - сопоставленные показатели факта и поля источника данных:
//		*Ключ     - Строка - имя показателя фактических данных
//		*Значение - Строка - имя поля в схеме-источнике данных.
//
Функция ВыражениеПоказателяКоличества(ИмяСправочникаИсточника, ИдентификаторИсточникаДанных, РазделИсточникаДанных, ТипИтога) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ВыражениеПоказателяКоличества(ИмяСправочникаИсточника, ИдентификаторИсточникаДанных, РазделИсточникаДанных, ТипИтога) 
```
</details>

## СлужебныеПоляМакетовРасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает служебные поля-измерения, недоступные для выбора пользователем
//
// Возвращаемое значение:
//	Массив из Строка - массив служебных полей-измерений.
//
Функция СлужебныеПоляМакетовРасчета() Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.СлужебныеПоляМакетовРасчета() 
```
</details>

## ПоказателиСуммыПоИсточникуДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие суммовых показателей для хозяйственной операции в зависимости от типов данных учета приход и расход
//
// Параметры:
//  ИсточникДанных - СправочникСсылка.НастройкиХозяйственныхОпераций
//
// Возвращаемое значение:
//	Соответствие из КлючИЗначение:
//	* Ключ - ПеречислениеСсылка.ПоказателиАналитическихРегистров
//	* Значение - Строка - имя поля, связанное с показателем.
//
Функция ПоказателиСуммыПоИсточникуДанных(ИсточникДанных) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ПоказателиСуммыПоИсточникуДанных(ИсточникДанных) 
```
</details>

## ПоказателиСуммыПоУмолчаниюПоИсточникуДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает суммовые показатели по умолчанию для хозяйственной операции в зависимости от типов данных учета приход и расход (для служебного регистра корреспонденций)
//
// Параметры:
//  ИсточникДанных - СправочникСсылка.НастройкиХозяйственныхОпераций
//
// Возвращаемое значение:
//	Массив из ПеречислениеСсылка.ПоказателиАналитическихРегистров
//
Функция ПоказателиСуммыПоУмолчаниюПоИсточникуДанных(ИсточникДанных) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ПоказателиСуммыПоУмолчаниюПоИсточникуДанных(ИсточникДанных) 
```
</details>

## ПоказателиКоличестваПоИсточникуДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие количественных показателей для хозяйственной операции в зависимости от типов данных учета приход и расход
//
// Параметры:
//  ИсточникДанных - СправочникСсылка.НастройкиХозяйственныхОпераций
//
// Возвращаемое значение:
//	Соответствие из КлючИЗначение:
//	* Ключ - ПеречислениеСсылка.ПоказателиАналитическихРегистров
//	* Значение - Строка - имя поля, связанное с показателем.
//
Функция ПоказателиКоличестваПоИсточникуДанных(ИсточникДанных) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ПоказателиКоличестваПоИсточникуДанных(ИсточникДанных) 
```
</details>

## ПоказателиДвиженияДенежныхСредствКВыплате
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив суммовых показателей, относящихся к контролю лимита расхода денежных средств.
//
// Возвращаемое значение:
//  Массив из ПеречислениеСсылка.ПоказателиАналитическихРегистров
//
Функция ПоказателиДвиженияДенежныхСредствКВыплате() Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ПоказателиДвиженияДенежныхСредствКВыплате() 
```
</details>

## СтруктураАналитикиПоТипуДанныхУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру аналитики по указанному типу данных учета
//
// Параметры:
//	ТипДанныхУчета - ПеречислениеСсылка.ТипыДанныхУчета - тип данных учета
//
// Возвращаемое значение:
//	Структура:
//	* Подразделение - Структура - параметры поля аналитики:
//	  ** ПутьКДанным - Строка - путь к полю аналитики.
//	  ** Тип - ОписаниеТипов - тип значения аналитики.
//	  ** Заголовок - Строка - представление поля аналитики.
//	  ** ИмяКор - Строка - имя поля в качестве кор. аналитики
//	  ** ЗаголовокКор - Строка - представление поля кор. аналитики
//
Функция СтруктураАналитикиПоТипуДанныхУчета(ТипДанныхУчета) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.СтруктураАналитикиПоТипуДанныхУчета(ТипДанныхУчета) 
```
</details>

## ИмяПоляПоТипуДанныхУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя поля аналитики статьи бюджета в зависимости от типа данных учета.
//
// Параметры:
//  ИмяПоля - Строка - исходное имя поля аналитики
//  ЗаголовокПоля - Строка - представление заголовка поля аналитики
//  ТипДанныхУчета - ПеречислениеСсылка.ТипыДанныхУчета - тип данных учета, для которого определяется имя поля аналитики.
//
// Возвращаемое значение:
//  Строка - видоизмененное поле аналитики в зависимости от типа данных учета.
//
Функция ИмяПоляПоТипуДанныхУчета(ИмяПоля, ЗаголовокПоля, ТипДанныхУчета) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ИмяПоляПоТипуДанныхУчета(ИмяПоля, ЗаголовокПоля, ТипДанныхУчета) 
```
</details>

## ПараметрыРесурсовСуммыИКоличества
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры суммовых и количественных ресурсов балансовых регистров.
//
// Возвращаемое значение:
//  Структура:
//  * ДлинаСуммы - Число
//  * ТочностьСуммы - Число
//  * ДлинаКоличества - Число
//  * ТочностьКоличества - Число
//
Функция ПараметрыРесурсовСуммыИКоличества() Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ПараметрыРесурсовСуммыИКоличества() 
```
</details>

## ПоказателиПоКорреспондирующимРегистрам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив показателей, относящихся одновременно к обоим балансовым регистрам и использующихся только в паре.
//
// Возвращаемое значение:
//  Массив из ПеречислениеСсылка.ПоказателиАналитическихРегистров
//
Функция ПоказателиПоКорреспондирующимРегистрам() Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ПоказателиПоКорреспондирующимРегистрам() 
```
</details>

## ИменаСуммовыхПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие показателей и их имен для добавления колонок в таблицу корреспонденций балансовых регистров
//
// Возвращаемое значение:
//  Соответствие из КлючИЗначение:
//  * Ключ - ПеречислениеСсылка.ПоказателиАналитическихРегистров - показатеь
//  * Значение - Структура:
//   ** Ключ - Строка - тип показателя (упр, регл, вал)
//   ** Значение - Строка - имя показателя
//
Функция ИменаСуммовыхПоказателей() Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ИменаСуммовыхПоказателей() 
```
</details>

## ИменаВидовДокументовПоТипуДанныхУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив имен документов по указанному типу данных учета хозяйственной операции
//
// Параметры:
//  ТипДанныхУчета - ПеречислениеСсылка.ТипыДанныхУчета - тип данных учета
// Возвращаемое значение:
//  Массив из Строка - массив балансовых регистров
//
Функция ИменаВидовДокументовПоТипуДанныхУчета(ТипДанныхУчета) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ИменаВидовДокументовПоТипуДанныхУчета(ТипДанныхУчета) 
```
</details>

## ИменаВидовДокументовДляКонтроляЛимитов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив имен видов документов, по которым осуществляется контроль лимита расхода денежных средств.
//
// Параметры:
//  ТипДанныхУчета - ПеречислениеСсылка.ТипыДанныхУчета
//
// Возвращаемое значение:
//  Массив из Строка - массив имен видов документов
//
Функция ИменаВидовДокументовДляКонтроляЛимитов(ТипДанныхУчета) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ИменаВидовДокументовДляКонтроляЛимитов(ТипДанныхУчета) 
```
</details>

## СхемаПолученияДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Для хозяйственной операции возвращает схему компоновки данных
// с помощью которой можно получить движения по текущей хозяйственной операции.
//
// Параметры:
//  ХозяйственнаяОперация - СправочникСсылка.НастройкиХозяйственныхОпераций - хозяйственная операция
//                        для которой требуется получить схему получения данных.
//
// Возвращаемое значение:
//   СхемаКомпоновкиДанных - схема получения данных по текущей хозяйственной операции.
//
Функция СхемаПолученияДанных(ХозяйственнаяОперация) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.СхемаПолученияДанных(ХозяйственнаяОперация) 
```
</details>

## ХозяйственныеОперацииАналитическихРегистров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет список хозяйственных операций отражаемых в текущем регистре накопления.
//
// Параметры:
//  ИмяРегистра - Строка - имя регистра накопления.
//
// Возвращаемое значение:
//    СправочникСсылка.НастройкиХозяйственныхОпераций - массив хозяйственных операций отражаемых в переданном регистре накопления.
//
Функция ХозяйственныеОперацииАналитическихРегистров(ИмяРегистра) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ХозяйственныеОперацииАналитическихРегистров(ИмяРегистра) 
```
</details>

## ДоступныеИсточникиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список всех регистров накопления используемых для хранения аналитической информации.
//
// Возвращаемое значение:
//    СписокЗначений - список регистров накопления.
//
Функция ДоступныеИсточникиДанных() Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхПовтИсп.ДоступныеИсточникиДанных() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
