---
title: Источники данных сервер
slug: erp-uh/источники-данных-сервер
---


## ИсточникиСуммыПравила
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имена показателей и соответствующих полей из схемы-источника
//
// Параметры:
//	СхемаКомпоновкиДанных - СхемаКомпоновкиДанных - схема источник данных, которая содержит набор данных типа "Объединение" с именем "ОбъединенныйФакт"
//	Правило - СправочникСсылка.ПравилаПолученияФактаПоПоказателямБюджетов, СправочникСсылка.ПравилаПолученияФактаПоСтатьямБюджетов - правило получения фактических данных.
//
// Возвращаемое значение:
//	Структура - сопоставленные показатели факта и поля источника данных:
//		* Ключ     - Строка - имя показателя фактических данных
//		* Значение - Строка - имя поля в схеме-источнике данных.
//
Функция ИсточникиСуммыПравила(СхемаКомпоновкиДанных, Правило) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхСервер.ИсточникиСуммыПравила(СхемаКомпоновкиДанных, Правило) 
```
</details>

## СвернутьПоКолонкамИдентификаторам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Делает свертку однотипно названных колонок таблицы значений в одну колонку с переносом данных.
// Например, позволяет несколько колонок Аналитика1..6 свернуть в одну колонку Аналитика.
// Имена сворачиваемых колонок должны состоять из двух (трех) частей - ИмяКолонкиИзмерения+(ПрефиксИдентификатора)+Идентификатор.
//
// Параметры:
//	ТаблицаДанных         - ТаблицаЗначений - таблица, колонки которой будут свернуты
//		После свертки таблица будет содержать следующие колонки:
//			Колонки, не указанные в КолонкиИзмерения
//			Колонки, указанные в КолонкиИзмерения, но свернутые из нескольких в одну
//			Колонки, указанные в КолонкиАгрегаты с просуммированными данными.
//	КолонкиИзмерения      - Строка, Массив - имена колонок через запятую, по уникальным  значениям которых будет сворачиваться таблица.
//		После свертки колонки будут удалены.
//	Идентификаторы        - Массив - строковые идентификаторы, по которым будут сворачиваться колонки и которые содержаться в именах колонок.
//		Например, уникальный идентификатор или порядковый номер колонки.
//	ПрефиксИдентификатора - Строка - префикс, который будет использоваться как составная часть идентификатора
//	КолонкиАгрегаты       - Строка, Массив - мена колонок через запятую, значения которых будут суммироваться при свертке.
//	НечеткоеСоответствиеИдентификаторов - Булево - Признак нечеткого соответствия идентификаторов
//
Процедура СвернутьПоКолонкамИдентификаторам(ТаблицаДанных, КолонкиИзмерения, Идентификаторы, ПрефиксИдентификатора = "", КолонкиАгрегаты = Неопределено, НечеткоеСоответствиеИдентификаторов = Ложь) Экспорт
```

Пример вызова
```bsl
ИсточникиДанныхСервер.СвернутьПоКолонкамИдентификаторам(ТаблицаДанных, КолонкиИзмерения, Идентификаторы, ПрефиксИдентификатора, КолонкиАгрегаты, НечеткоеСоответствиеИдентификаторов);
```
</details>

## СхемаКомпоновкиДанныхПравила
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает схему для правила получения фактических данных
//
// Параметры:
//	ОписаниеПравила - СправочникСсылка.ПравилаПолученияФактаПоПоказателямБюджетов,
//	                - СправочникСсылка.ПравилаПолученияФактаПоСтатьямБюджетов,
//	                - ВыборкаИзРезультатаЗапроса, СтрокаТаблицыЗначений, Структура - Правило получения факта по показателям бюджетов.
//	ОчищаемыеКоллекцииНастроек - Соответствие - имена коллекций, которые требуется гарантированно очистить. Если значение заполнено, будет получена копия СКД.
//	                           - Неопределено - Значение по умолчанию. Настройки не очищаются.
//	РежимПолученияДанных - ПеречислениеСсылка.РежимПолученияДанныхБюджетирования -
//	                                  Все         - в этом случае в запросах схемы компоновки данных удаляется слово РАЗРЕШЕННЫЕ. Возвращена будет копия СКД.
//	                                  Разрешенные - в этом случае схема исполняется как есть.
//	                       Если значение заполнено, будет получена копия СКД.
//	                     - Неопределено - Значение по умолчанию. Текст запроса не меняется.
//	ПолучатьКопиюДляИзменения  - Булево - По умолчанию Ложь. Если Истина, то возвращена будет копия СКД.
//	ТаблицаКорреспонденций - ТаблицаЗначений - таблица фактических данных на основе корреспонденции балансовых регистров.
//
// Возвращаемое значение:
//	СхемаКомпоновкиДанных - СхемаКомпоновкиДанных - схема получения фактических данных, соответствующая источнику.
//
Функция СхемаКомпоновкиДанныхПравила(ОписаниеПравила, ОчищаемыеКоллекцииНастроек = Неопределено, РежимПолученияДанных = Неопределено, ПолучатьКопиюДляИзменения = Ложь, ТаблицаКорреспонденций = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхСервер.СхемаКомпоновкиДанныхПравила(ОписаниеПравила, ОчищаемыеКоллекцииНастроек, РежимПолученияДанных, ПолучатьКопиюДляИзменения, ТаблицаКорреспонденций);
```
</details>

## ШаблонПараметровПолученияФакта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры получения факта по умолчанию
//
// Параметры:
//   ЗначенияПоУмолчанию             - Структура, Неопределено - переопределенные начальные значения параметров.
//   ПараметрыИдентификацииВыражений - Структура, Неопределено - состав используемых выражений.
//
// Возвращаемое значение:
//  Структура - Параметры получения факта по статьям и показателя бюджетов:
//    * ВалютаМеждународ                 - СправочникСсылка.Валюты - Закешированное значение функциональной валюты международного учета (см. МеждународныйУчетОбщегоНазначения.УчетныеВалюты)
//    * ВалютаОтчета                     - СправочникСсылка.Валюты - Валюта данных
//    * ВалютаРегл                       - СправочникСсылка.Валюты - Закешированное значение валюты регл. учета.
//    * ВалютаУпр                        - СправочникСсылка.Валюты - Закешированное значение валюты упр. учета.
//    * ВидыАналитик                     - Массив из ПланВидовХарактеристикСсылка.АналитикиСтатейБюджетов - содержит значения
//    аналитик, в разрезе которой необходимо получить факт. **  - значения массива.
//    * ПоПравиламПолученияДанных        - Булево - добавлять в таблицу данных колонку с примененным правилом
//    * ВозвращатьСтатьюПоказательБюджета- Булево - добавлять в таблицу данных колонку со статьей/показателем (источник данных)
//    * ВозвращатьУпрИРеглСуммы          - Булево - Вернуть суммы из регистров упр. и регл.
//    * ДополнительныеДанные             - Структура - дополнительные данные, которые будут присоединяться к фактическим
//      данным:
//      ** Вид                   - ПеречислениеСсылка.ВидДополнительныхДанныхИсточниковДанных - описывает способ
//          дополнения фактических данных
//      ** ТаблицаДанных         - ТаблицаЗначений - таблица дополнительных данных, содержащая колонку с именем поля-идентификатора
//    * ДополнительныйОтбор              - НастройкиКомпоновкиДанных - дополнительный глобальный отбор, который
//                                                                     накладывается на данные источника.
//    * ДополнительныеФильтрыПоАналитикам- Структура - поля глобального отбора на аналитики 1..6, на основании которого
//    формируются настройки:
//      ** Ключ     - Строка - имя поля, по которому требуется применить доп. отбор
//      ** Значение - Произвольный - значение доп. отбора
//    * ДополнительныеФильтрыПоИзмерениям- Структура - поля глобального отбора на измерения, на основании которого
//    формируются настройки:
//      ** Ключ     - Строка - имя поля, по которому требуется применить доп. отбор
//      ** Значение - Произвольный - значение доп. отбора
//    * ИндексыТаблиц                    - Соответствие - имена таблиц значений параметров получения факта и массивы
//      включенных в них индексах:
//      ** Ключ - Строка - имя таблицы в параметрах получения факта
//      ** Значение - Массив - массив строк, описывающих примененные индексы
//    * ИсходныеВыраженияЗаполненияАналитик - Соответствие - исходные выражения заполнения аналитик на языке формул:
//      **Ключ - Строка - Исходное выражение заполнения аналитики.
//      **Значение - СправочникСсылка.СтатьиБюджетов, СправочникСсылка.ПоказателиБюджетов - Статья или показатель бюджета
//      		(для указания на конкретный объект в случае ошибки).
//    * ИспользуемыеНумерованныеАналитики- Структура - задействованные нумерованные аналитики. Принимает значения от
//    "Аналитика1" до "Аналитика6"
//    * МаксимальныйНомерАналитики       - Число - число задействованных аналитик. Принимает значения от 1 до 6
//    * ОстаткиТолькоНаНачалоПериода     - Булево - Получать факт только на начало периода (для остатков), в противном
//                                                  случае данные получаются на конец каждого из подпериодов.
//    * Период                           - СтандартныйПериод - Период выборки
//    * Периодичность                    - ПеречислениеСсылка.Периодичность, Неопределено - Периодичность детализации
//        данных за период. Неопределено - без детализации.
//    * Показатели                       - Структура - показатели, которые автоматически подбираются в выборку с учетом
//      настроек набора данных источника:
//      ** Количество - Булево, Неопределено - присутствие свойства в структуре означает, что в выборку следует добавить
//                                             получение количества
//      ** Сумма      - Булево, Неопределено - присутствие свойства в структуре означает, что в выборку следует добавить
//                                             получение суммы
//    * ФактПоСтатьямВлияющимНаПоказателиБюджетовДополнятьХранимымФактом - Булево - Дополнять факт по статьям, влияющим на показатели хранимым фактом.
//                                                                                - По умолчанию Ложь. Ложь - если весь хранимый факт получается отдельно (с помощью кэшируемых скд).
//                                                                                - В бюджетных отчетах (и экземплярах бюджетов) хранимый факт получается отдельно (с помощью кэшируемых скд),
//                                                                                  в лимитах хранимый факт не используется (т.к. правила с типом исполнение бюджета не поддерживают хранимый факт).
//    * ПоВалютам                        - Булево - Развернуть по валютам (суммовые показатели).
//    * ПоЕдиницамИзмерения              - Булево - Развернуть по единицам измерения (количественные показатели).
//    * ПоОрганизациям                   - Булево - Развернуть по организациям.
//    * ПоПодразделениям                 - Булево - Развернуть по подразделениям.
//    * ПоРегистратору                   - Булево - Развернуть факт по регистратору (для оборотов).
//    * РежимПолученияДанных             - ПеречислениеСсылка.РежимПолученияДанныхБюджетирования - определяет режим
//        использования RLS при получении данных
//    * ТаблицаАналитик                  - ТаблицаЗначений - правила, используемые измерения, аналитики и мэппинг
//      аналитик (вид и выражение для получения). По умолчанию пустая таблица:
//      ** Правило                          - СправочникСсылка.ПравилаПолученияФактаПоСтатьямБюджетов - ссылка на правило
//      ** ПоОрганизациям                   - Булево - получать данные по соответствующему измерению
//      ** ПоПодразделениям                 - Булево - получать данные по соответствующему измерению
//      ** ВидАналитики                     - ПланВидовХарактеристикСсылка.АналитикиСтатейБюджетов - вид аналитики
//      ** ВыражениеЗаполненияАналитики     - Строка - выражение для получения данные из полей схемы-источника
//    * ТаблицаПериодов                  - ТаблицаЗначений - непрерывные периоды, за которые требуется получить данные.
//      По умолчанию пустая таблица:
//      ** ПравилоФакта  - СправочникСсылка.ПравилаПолученияФактаПоСтатьямБюджетов - ссылка на правило
//      ** НачалоПериода - Дата - дата начала периода
//      ** КонецПериода  - Дата - дата окончания периода
//    * ТаблицаПравилСтатей              - ТаблицаЗначений - правила получения факта и колонки с реквизитами. По
//        умолчанию пустая таблица. См. в Справочники.ПравилаПолученияФактаПоСтатьямБюджетов.Макеты.ПравилаПолученияФакта
//
Функция ШаблонПараметровПолученияФакта(ЗначенияПоУмолчанию = Неопределено, ПараметрыИдентификацииВыражений = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхСервер.ШаблонПараметровПолученияФакта(ЗначенияПоУмолчанию, ПараметрыИдентификацииВыражений);
```
</details>

## ПолучитьХранимыеНастройкиСправочника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает хранимые настройки из указанного справочника
//
// Параметры:
//  ИмяСправочникаИсточника  - Строка - например, "ПравилаПолученияФактаПоПоказателямБюджетов"
//  ХешНастроек - Строка - хеш-сумма настроенных отборов компоновки данных
//  ПроверкаУникальности - Булево - указывает на необходимость добавления в дополнительные свойства Ссылки.
//
// Возвращаемое значение:
//  КомпоновщикНастроекКомпоновкиДанных
//
Функция ПолучитьХранимыеНастройкиСправочника(ИмяСправочникаИсточника, ХешНастроек, ПроверкаУникальности = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхСервер.ПолучитьХранимыеНастройкиСправочника(ИмяСправочникаИсточника, ХешНастроек, ПроверкаУникальности);
```
</details>

## ПолучитьХранимыйМакетСправочника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает хранимый макет из указанного справочника
//
// Параметры:
//  ИмяСправочникаИсточника  - Строка - например, "ПравилаПолученияФактаПоПоказателямБюджетов"
//  ХешСхемыКомпоновкиДанных - Строка - хеш-сумма произвольной схемы компоновки данных
//  ПроверкаУникальности - Булево - указывает на необходимость добавления в дополнительные свойства Ссылки.
//
// Возвращаемое значение:
//  ТабличныйДокумент, ТекстовыйДокумент - объект, который может быть макетом.
//
Функция ПолучитьХранимыйМакетСправочника(ИмяСправочникаИсточника, ХешСхемыКомпоновкиДанных, ПроверкаУникальности = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхСервер.ПолучитьХранимыйМакетСправочника(ИмяСправочникаИсточника, ХешСхемыКомпоновкиДанных, ПроверкаУникальности);
```
</details>

## ИменаВидовДокументовПоИсточникуДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив имен видов документов по источнику данных
//
// Параметры:
//  ИсточникДанных - СправочникСсылка.НастройкиХозяйственныхОпераций
//
// Возвращаемое значение:
//  Массив из Строка
Функция ИменаВидовДокументовПоИсточникуДанных(ИсточникДанных) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхСервер.ИменаВидовДокументовПоИсточникуДанных(ИсточникДанных) 
```
</details>

## ТипыДанныхУчетаЗаявки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает типы данных учета Приход и Расход по хозяйственной операции
//
// Параметры:
//  ДокументЗаявки - ДокументСсылка.ЗаявкаНаРасходованиеДенежныхСредств,
//					 ДокументСсылка.ЗаявкаНаКомандировку
//
// Возвращаемое значение:
//  Массив из Структура:
//   Ключ - Строка (Приход и Расход)
//   Значение - ПеречислениеСсылка.ТипыДанныхУчета
//
Функция ТипыДанныхУчетаЗаявки(ДокументЗаявки) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхСервер.ТипыДанныхУчетаЗаявки(ДокументЗаявки) 
```
</details>

## ИндексыТаблицыВМассив
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строковые представления индексов
//
// Параметры:
//	ТаблицаЗначений - ТаблицаЗначений - таблица, индексы которой требуется получить.
//
// Возвращаемое значение:
//	Массив - строковые представления индексов таблицы.
//
Функция ИндексыТаблицыВМассив(ТаблицаЗначений) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхСервер.ИндексыТаблицыВМассив(ТаблицаЗначений) 
```
</details>

## ИменаТаблицИИндексы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строковые представления индексов для нескольких таблиц
//
// Параметры:
//	ТаблицыЗначений - Соответствие, Структура - таблицы, индексы которой требуется получить:
//		* Ключ     - Строка - имя таблицы
//		* Значение - ТаблицаЗначений - таблица, индексы которой требуется получить.
//
// Возвращаемое значение:
//	Соответствие - индексы таблиц:
//		* Ключ     - Строка - имя таблицы
//		* Значение - Массив - строковые представления индексов таблицы.
//
Функция ИменаТаблицИИндексы(ТаблицыЗначений) Экспорт
```

Пример вызова
```bsl
Результат = ИсточникиДанныхСервер.ИменаТаблицИИндексы(ТаблицыЗначений) 
```
</details>

## УстановитьИндексыИзМассива
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает или очищает индексы таблицы значений
//
// Параметры:
//	ТаблицаЗначений - ТаблицаЗначений - таблица, индексы которой требуется установить
//	ИндексыТаблицы - Массив, Неопределено - строковые представления индексов таблицы.
//		Если передано Неопределено, то индексы таблицы будут очищены.
//
Процедура УстановитьИндексыИзМассива(ТаблицаЗначений, ИндексыТаблицы = Неопределено) Экспорт
```

Пример вызова
```bsl
ИсточникиДанныхСервер.УстановитьИндексыИзМассива(ТаблицаЗначений, ИндексыТаблицы);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
