---
title: Кассовые смены
slug: erp-uh/кассовые-смены
---


## СменаАктивна
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет активна ли кассовая смена. Под активностью понимается соблюдение следующих условий:
// кассовая смена не закрыта с момента открытия кассовой смены прошло не более 24 часов.
//
// Параметры:
//  КассоваяСмена - ДокументСсылка.КассоваяСмена - Кассовая смена, активность которой необходимо проверить
//
// Возвращаемое значение:
//  Булево - активность смены.
Функция СменаАктивна(КассоваяСмена) Экспорт
```

Пример вызова
```bsl
Результат = КассовыеСмены.СменаАктивна(КассоваяСмена) 
```
</details>

## СменаЗакрыта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет закрыта ли кассовая смена.
//
// Параметры:
//  КассоваяСмена - ДокументСсылка.КассоваяСмена - Кассовая смена, активность которой необходимо проверить
//
// Возвращаемое значение:
//  Булево - Истина - смена закрыта, Ложь - смена не закрыта
Функция СменаЗакрыта(КассоваяСмена) Экспорт
```

Пример вызова
```bsl
Результат = КассовыеСмены.СменаЗакрыта(КассоваяСмена) 
```
</details>

## ОписаниеКассовойСмены
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает реквизиты кассовой смены
//
// Параметры:
//  КассоваяСмена - ДокументСсылка.КассоваяСмена - Кассовая смена, активность которой необходимо проверить
//
// Возвращаемое значение:
//  Структура - реквизиты кассовой смены. Содержит следующие реквизиты:
//    *КассоваяСмена - ДокументСсылка.КассоваяСмена - ссылка на кассовую смену
//    *ФискальноеУстройство - СправочникСсылка.ПодключаемоеОборудование - ссылка на устройство, на котором открыта смена
//    *НачалоКассовойСмены - Дата - дата открытия смены
//    *ОкончаниеКассовойСмены - Дата - дата закрытия смены (если смена закрывалась)
//    *ДатаИстеченияСрокаДействия - Дата - в которую закончиться срок действия смены (дата открытия + 24 часа)
//    *Организация - ОпределяемыйТип.ОрганизацияБПО - организация, указанная в документе КассоваяСмена
//    *Статус - ПеречислениеСсылка.СтатусыКассовойСмены - статус кассовой смены.
Функция ОписаниеКассовойСмены(КассоваяСмена) Экспорт
```

Пример вызова
```bsl
Результат = КассовыеСмены.ОписаниеКассовойСмены(КассоваяСмена) 
```
</details>

## СтатусПоследнейСмены
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// По фискальному устройству определяет статус смены и проверяет ее активность. Под активностью понимается соблюдение следующих условий:
// - кассовая смена не закрыта с момента открытия кассовой смены прошло не более 24 часов.
//
// Параметры:
//  ФискальноеУстройство - СправочникСсылка.ПодключаемоеОборудование - фискальное устройство, для которого требуется определить активность смены
//
// Возвращаемое значение:
//  Структура:
//    *Открыта - Булево - Истина - смена открыта, Ложь - смена закрыта.
//    *Активна - Булево - Истина - смена открыта, Ложь - смена закрыта, прошло более 24 часов с момента открытия или никогда не была открыта.
//    *ТекущийНомерЧека - Число - текущий номер чека ККТ.
//
Функция СтатусПоследнейСмены(ФискальноеУстройство) Экспорт
```

Пример вызова
```bsl
Результат = КассовыеСмены.СтатусПоследнейСмены(ФискальноеУстройство) 
```
</details>

## ПоследняяСменаЗакрыта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// По фискальному устройству определяет последнюю смену и проверяет закрыта ли она.
//
// Параметры:
//  ФискальноеУстройство - СправочникСсылка.ПодключаемоеОборудование - фискальное устройство, для которого требуется определить закрыта ли смена
//
// Возвращаемое значение:
//  Булево - Истина - смена закрыта или никогда не была открыта, Ложь - смена не закрыта
Функция ПоследняяСменаЗакрыта(ФискальноеУстройство) Экспорт
```

Пример вызова
```bsl
Результат = КассовыеСмены.ПоследняяСменаЗакрыта(ФискальноеУстройство) 
```
</details>

## ОписаниеПоследнейКассовойСмены
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// По фискальному устройству определяет последнюю смену и получает ее реквизиты.
//
// Параметры:
//  ФискальноеУстройство - СправочникСсылка.ПодключаемоеОборудование - фискальное устройство, для которого требуется определить активность смены.
//
// Возвращаемое значение:
//  Структура - реквизиты кассовой смены, Неопределено - если ни одной смены не было открыто. Содержит следующие реквизиты:
//    *КассоваяСмена - ДокументСсылка.КассоваяСмена - ссылка на кассовую смену
//    *ФискальноеУстройство - СправочникСсылка.ПодключаемоеОборудование - ссылка на устройство, на котором открыта смена
//    *НачалоКассовойСмены - Дата - дата открытия смены
//    *ОкончаниеКассовойСмены - Дата - дата закрытия смены (если смена закрывалась)
//    *ДатаИстеченияСрокаДействия - Дата - в которую закончиться срок действия смены (дата открытия + 24 часа)
//    *Организация - ОпределяемыйТип.ОрганизацияБПО - организация, указанная в документе КассоваяСмена.
//    *Статус - ПеречислениеСсылка.СтатусыКассовойСмены - статус кассовой смены.
Функция ОписаниеПоследнейКассовойСмены(ФискальноеУстройство) Экспорт
```

Пример вызова
```bsl
Результат = КассовыеСмены.ОписаниеПоследнейКассовойСмены(ФискальноеУстройство) 
```
</details>

## НоваяКассоваяСмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создать новую кассовую смену.
//
// Параметры:
//  ФискальноеУстройство - СправочникСсылка.ПодключаемоеОборудование
//  ПараметрыКоманды - Структура
//
// Возвращаемое значение:
//  ДокументСсылка.КассоваяСмена.
//
Функция НоваяКассоваяСмена(ФискальноеУстройство, ПараметрыКоманды) Экспорт
```

Пример вызова
```bsl
Результат = КассовыеСмены.НоваяКассоваяСмена(ФискальноеУстройство, ПараметрыКоманды) 
```
</details>

## ЗакрытьКассовуюСмену
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Закрыть открытую ранее кассовую смену.
//
// Параметры:
//  ПараметрыКоманды - Структура
//   * КассоваяСмена - ДокументСсылка.КассоваяСмена
//
Процедура ЗакрытьКассовуюСмену(ПараметрыКоманды) Экспорт
```

Пример вызова
```bsl
КассовыеСмены.ЗакрытьКассовуюСмену(ПараметрыКоманды) 
```
</details>

## ПолучитьТекущийНомерЧекаККТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить текущий номер чека ККТ
//
// Параметры:
//  ФискальноеУстройство - СправочникСсылка.ПодключаемоеОборудование - фискальное устройство, для которого требуется определить номер чека.
//  КассоваяСмена - ДокументСсылка.КассоваяСмена - Кассовая смена в рамках которой необходимо получить текущий номер чека ККТ.
//
// Возвращаемое значение:
//  Число - Текущий номер чека ККТ.
//
Функция ПолучитьТекущийНомерЧекаККТ(ФискальноеУстройство, КассоваяСмена) Экспорт
```

Пример вызова
```bsl
Результат = КассовыеСмены.ПолучитьТекущийНомерЧекаККТ(ФискальноеУстройство, КассоваяСмена) 
```
</details>

## ИнкрементироватьТекущийНомерЧекаККТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инкрементировать текущий номер чека ККТ
//
// Параметры:
//  ФискальноеУстройство - СправочникСсылка.ПодключаемоеОборудование - фискальное устройство,  для которого требуется инкрементировать номер чека.
//  КассоваяСмена - ДокументСсылка.КассоваяСмена - Кассовая смена в рамках которой необходимо получить текущий номер чека ККТ.
//
Процедура ИнкрементироватьТекущийНомерЧекаККТ(ФискальноеУстройство, КассоваяСмена) Экспорт
```

Пример вызова
```bsl
КассовыеСмены.ИнкрементироватьТекущийНомерЧекаККТ(ФискальноеУстройство, КассоваяСмена) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
