---
title: Компоновка данных клиент сервер
slug: erp-uh/компоновка-данных-клиент-сервер
---


## СкопироватьЭлементы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Копирует элементы из одной коллекции в другую
//
// Параметры:
//	ПриемникЗначения	- коллекция элементов КД, куда копируются параметры
//	ИсточникЗначения	- коллекция элементов КД, откуда копируются параметры
//	ОчищатьПриемник		- признак необходимости очистки приемника (Булево, по умолчанию: истина)
//
Процедура СкопироватьЭлементы(ПриемникЗначения, ИсточникЗначения, ОчищатьПриемник = Истина) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхКлиентСервер.СкопироватьЭлементы(ПриемникЗначения, ИсточникЗначения, ОчищатьПриемник);
```
</details>

## ЗаполнитьЭлементы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет одну коллекцию элементов на основании другой
//
// Параметры:
//	ПриемникЗначения	- коллекция элементов КД, куда копируются параметры
//	ИсточникЗначения	- коллекция элементов КД, откуда копируются параметры
//	ПервыйУровень		- уровень структуры коллекции элементов КД для копирования параметров
//
Процедура ЗаполнитьЭлементы(ПриемникЗначения, ИсточникЗначения, ПервыйУровень = Неопределено) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхКлиентСервер.ЗаполнитьЭлементы(ПриемникЗначения, ИсточникЗначения, ПервыйУровень);
```
</details>

## ДобавитьОформляемоеПоле
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в коллекцию оформляемых полей компоновки данных новое поле
//
// Параметры:
//	КоллекцияОформляемыхПолей 	- ОформляемыеПоляКомпоновкиДанных - коллекция оформляемых полей КД
//	ИмяПоля						- Строка - имя поля
//
// Возвращаемое значение:
//	ОформляемоеПолеКомпоновкиДанных - созданное поле
//
// Пример:
// 	Форма.УсловноеОформление.Элементы[0].Поля
//
Функция ДобавитьОформляемоеПоле(КоллекцияОформляемыхПолей, ИмяПоля) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхКлиентСервер.ДобавитьОформляемоеПоле(КоллекцияОформляемыхПолей, ИмяПоля) 
```
</details>

## ДобавитьГруппуОтбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в коллекцию отбора новую группу указанного типа.
//
// Параметры:
//	КоллекцияЭлементовОтбора - КоллекцияЭлементовОтбораКомпоновкиДанных
//	ТипГруппы - ТипГруппыЭлементовОтбораКомпоновкиДанных - ГруппаИ или ГруппаИли
//
// Возвращаемое значение:
//	ГруппаЭлементовОтбораКомпоновкиДанных - добавленная группа
//
Функция ДобавитьГруппуОтбора(КоллекцияЭлементовОтбора, ТипГруппы) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхКлиентСервер.ДобавитьГруппуОтбора(КоллекцияЭлементовОтбора, ТипГруппы) 
```
</details>

## ДобавитьВыбранноеПоле
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет выбранное поле компоновки данных
//
// Параметры:
//	Куда - КомпоновщикНастроекКомпоновкиДанных, НастройкиКомпоновкиДанных, ВыбранныеПоляКомпоновкиДанных - назначение, куда нужно добавить поле
//	ИмяИлиПолеКД - Строка, ПолеКомпоновкиДанных - имя добавляемого поля
//	Заголовок - Строка - заголовок поля в результате компоновки.
//
// Возвращаемое значение:
//	ВыбранноеПолеКомпоновкиДанных - выбранное поле.
//
Функция ДобавитьВыбранноеПоле(Куда, ИмяИлиПолеКД, Заголовок = "") Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхКлиентСервер.ДобавитьВыбранноеПоле(Куда, ИмяИлиПолеКД, Заголовок);
```
</details>

## ДобавитьГруппировку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет группировку в компоновщик настроек в самый нижний уровень структуры, если поле не указано - детальные поля.
//
// Параметры:
//	КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных, НастройкиКомпоновкиДанных - элемент структуры КД.
//	Поле - Строка, ПолеКомпоновкиДанных - имя или поле КД
//	Строки - Булево - признак для получения последний группировки строк (Серий) или колонок (точек)
//	ПараметрыГруппировки - Структура - Структура со свойствами:
//		*НачалоПериода - Дата - начало периода группировки по полю периода.
//		*КонецПериода - Дата - конец периода группировки по полю периода.
//		*ТипГруппировки - ТипГруппировкиКомпоновкиДанных - тип группировки.
//		*ТипДополнения - ТипДополненияПериодаКомпоновкиДанных - тип дополнения.
//
// Возвращаемое значение:
//	ГруппировкаТаблицыКомпоновкиДанных, ГруппировкаДиаграммыКомпоновкиДанных, ГруппировкаКомпоновкиДанных - новая группировка.
//
Функция ДобавитьГруппировку(КомпоновщикНастроек, Знач Поле = Неопределено, Строки = Истина, ПараметрыГруппировки = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхКлиентСервер.ДобавитьГруппировку(КомпоновщикНастроек, Поле, Строки, ПараметрыГруппировки);
```
</details>

## ДобавитьГруппировкуВКореньСтруктуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет группировку в компоновщик настроек в корневой уровень структуры настроек, если поле не указано - детальные поля.
//
// Параметры:
//	КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных, НастройкиКомпоновкиДанных - элемент структуры КД
//	Поле - Строка, ПолеКомпоновкиДанных - имя или поле компоновки данных.
//	ПараметрыГруппировки - Структура - Структура со свойствами:
//		*НачалоПериода - Дата - начало периода группировки по полю периода.
//		*КонецПериода - Дата - конец периода группировки по полю периода.
//		*ТипГруппировки - ТипГруппировкиКомпоновкиДанных - тип группировки.
//		*ТипДополнения - ТипДополненияПериодаКомпоновкиДанных - тип дополнения.
//
// Возвращаемое значение:
//	ГруппировкаТаблицыКомпоновкиДанных, ГруппировкаДиаграммыКомпоновкиДанных, ГруппировкаКомпоновкиДанных - новая группировка в корне структуры.
//
Функция ДобавитьГруппировкуВКореньСтруктуры(КомпоновщикНастроек, Знач Поле = Неопределено, ПараметрыГруппировки = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхКлиентСервер.ДобавитьГруппировкуВКореньСтруктуры(КомпоновщикНастроек, Поле, ПараметрыГруппировки);
```
</details>

## ДобавитьОтбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет отбор в коллекцию отборов компоновщика или группы отборов
//
// Параметры:
//	ЭлементСтруктуры - КомпоновщикНастроекКомпоновкиДанных, НастройкиКомпоновкиДанных - элемент структуры компоновки данных.
//	Поле - Строка - имя поля, по которому добавляется отбор.
//	Значение - Произвольный - значение отбора компоновки данных.
//	ВидСравнения - ВидСравненияКомпоновкиДанных - вид сравнений КД (по умолчанию: Неопределено).
//	Использование - Булево - признак использования отбора (по умолчанию: Истина).
//	ДополнительныеПараметры - Структура - Структура со свойствами:
//		*ВПользовательскиеНастройки - Булево - признак добавления в пользовательские настройки компоновки данных (по умолчанию: ложь).
//		*ЗаменятьСуществующий - Булево - признак полной замены существующего отбора по полю (по умолчанию: истина).
//
// Возвращаемое значение:
//	ЭлементОтбораКомпоновкиДанных - добавленный отбор.
//
Функция ДобавитьОтбор(ЭлементСтруктуры, Знач Поле, Значение = Неопределено, ВидСравнения = Неопределено, Использование = Истина, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхКлиентСервер.ДобавитьОтбор(ЭлементСтруктуры, Поле, Значение, ВидСравнения, Использование, ДополнительныеПараметры);
```
</details>

## ОчиститьНастройкиКомпоновкиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Очищает все элементы настройки компоновки данных из объекта
// Параметры:
//  Настройки - НастройкиКомпоновкиДанных - очищаемые настройки.
//
Процедура ОчиститьНастройкиКомпоновкиДанных(Настройки) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхКлиентСервер.ОчиститьНастройкиКомпоновкиДанных(Настройки) 
```
</details>

## ОтключитьВыводОбщихИтогов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отключает в корневом элементе вывод общих итогов по вертикали и горизонтали
// Параметры:
//  Настройки - НастройкиКомпоновкиДанных - изменяемые настройки.
//
Процедура ОтключитьВыводОбщихИтогов(Настройки) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхКлиентСервер.ОтключитьВыводОбщихИтогов(Настройки) 
```
</details>

## ПолеИспользуется
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак используется ли поле в настройке СКД
//
// Параметры:
//	ЭлементСтруктуры - КомпоновщикНастроекКомпоновкиДанных, НастройкиКомпоновкиДанных - элемент структуры КД
//	Поле - Строка, ПолеКомпоновкиДанных - имя или поле компоновки данных.
//	ВключаяВложенныеПоля - Булево - Если Истина, то будут проверятся вложенные поля. Например, "Регистратор.Дата".
//					По умолчанию Ложь.
//
// Возвращаемое значение:
//	Булево - Истина, если поле найдено в какой-либо из настроек.
//
Функция ПолеИспользуется(ЭлементСтруктуры, Поле, ВключаяВложенныеПоля = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхКлиентСервер.ПолеИспользуется(ЭлементСтруктуры, Поле, ВключаяВложенныеПоля);
```
</details>

## ПолучитьГруппировки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список всех группировок компоновщика настроек
//
// Параметры:
//	ЭлементСтруктуры - КомпоновщикНастроекКомпоновкиДанных, НастройкиКомпоновкиДанных - элемент структуры КД
//	ПоказыватьГруппировкиТаблиц - Булево - признак добавления в список группировки колонок (по умолчанию Истина).
//
// Возвращаемое значение:
// 	СписокЗначений - Список группировок:
// 	 *Значение - ГруппировкаТаблицыКомпоновкиДанных -
// 	 *Значение - ГруппировкаДиаграммыКомпоновкиДанных -
// 	 *Значение- ГруппировкаКомпоновкиДанных - найденная группировка.
//
Функция ПолучитьГруппировки(ЭлементСтруктуры, ПоказыватьГруппировкиТаблиц = Истина) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхКлиентСервер.ПолучитьГруппировки(ЭлементСтруктуры, ПоказыватьГруппировкиТаблиц);
```
</details>

## ПолучитьПараметр
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение параметра компоновки данных
//
// Параметры:
//	ОбъектНастройки - НастройкиКомпоновкиДанных - объект настройки.
//					- ПользовательскиеНастройкиКомпоновкиДанных -
//					- КомпоновщикНастроекКомпоновкиДанных -
//					- НастройкиВложенногоОбъектаКомпоновкиДанных -
//					- ДанныеРасшифровкиКомпоновкиДанных -
//					- КоллекцияЗначенийПараметровКомпоновкиДанных -
//					- ОформлениеКомпоновкиДанных -
//	Параметр		- Строка, ПараметрКомпоновкиДанных - поле или имя поля, для которого нужно вернуть параметр.
//
// Возвращаемое значение:
//	ЗначениеПараметраНастроекКомпоновкиДанных - Неопределено, если параметр не найден.
//
Функция ПолучитьПараметр(ОбъектНастройки, Параметр) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхКлиентСервер.ПолучитьПараметр(ОбъектНастройки, Параметр) 
```
</details>

## ПолучитьПоследнийЭлементСтруктуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает последний элемент структуры - группировку
//
// Параметры:
//	ЭлементСтруктурыНастроек - КомпоновщикНастроекКомпоновкиДанных, НастройкиКомпоновкиДанных - элемент структуры КД
//	Строки - Булево - признак для получения последний группировки строк (серий) или колонок (точек).
//
// Возвращаемое значение:
//	КоллекцияЭлементовСтруктурыДиаграммыКомпоновкиДанных, КоллекцияЭлементовСтруктурыТаблицыКомпоновкиДанных, КоллекцияЭлементовСтруктурыНастроекКомпоновкиДанных - Неопределено, если ничего не найдено.
//
Функция ПолучитьПоследнийЭлементСтруктуры(ЭлементСтруктурыНастроек, Строки = Истина) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхКлиентСервер.ПолучитьПоследнийЭлементСтруктуры(ЭлементСтруктурыНастроек, Строки);
```
</details>

## ПолучитьЭлементСтруктурыДетальныеЗаписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает группировку - детальные записи компоновщика настроек
//
// Параметры:
//	КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных, НастройкиКомпоновкиДанных - элемент структуры КД.
//
// Возвращаемое значение:
//	См. КомпоновкаДанныхКлиентСервер.ПолучитьПоследнийЭлементСтруктуры
//
Функция ПолучитьЭлементСтруктурыДетальныеЗаписи(КомпоновщикНастроек) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхКлиентСервер.ПолучитьЭлементСтруктурыДетальныеЗаписи(КомпоновщикНастроек) 
```
</details>

## СкопироватьНастройкиКомпоновкиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Копирует настройки компоновки данных
//
// Параметры:
//	НастройкиПриемник	- НастройкиКомпоновкиДанных -
//						- НастройкиВложенногоОбъектаКомпоновкиДанных -
//						- ГруппировкаКомпоновкиДанных -
//						- ГруппировкаТаблицыКомпоновкиДанных -
//						- ГруппировкаДиаграммыКомпоновкиДанных -
//						- ТаблицаКомпоновкиДанных -
//						- ДиаграммаКомпоновкиДанных - коллекция настроек КД, куда копируются настройки.
//	НастройкиИсточник	- НастройкиКомпоновкиДанных -
//						- НастройкиВложенногоОбъектаКомпоновкиДанных -
//						- ГруппировкаКомпоновкиДанных -
//						- ГруппировкаТаблицыКомпоновкиДанных -
//						- ГруппировкаДиаграммыКомпоновкиДанных -
//						- ТаблицаКомпоновкиДанных -
//						- ДиаграммаКомпоновкиДанных - коллекция настроек КД, откуда копируются настройки.
//
Процедура СкопироватьНастройкиКомпоновкиДанных(НастройкиПриемник, НастройкиИсточник) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхКлиентСервер.СкопироватьНастройкиКомпоновкиДанных(НастройкиПриемник, НастройкиИсточник) 
```
</details>

## СкопироватьОтборКомпоновкиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Копирует отбор из одних настроек компоновки данных в другие настройки
//
// Параметры:
//	СхемаПриемник		- СхемаКомпоновкиДанных - схема КД, в чьи настройки копируется отбор
//	НастройкиПриемник	- НастройкиКомпоновкиДанных - настройки КД, в которое копируется отбор
//	НастройкиИсточник	- НастройкиКомпоновкиДанных - настройки КД, из которых копируется отбор
//	ПоляИсключения		- Строка, Массив, Неопределено - имена полей, которые следует пропустить при копировании.
//
Процедура СкопироватьОтборКомпоновкиДанных(СхемаПриемник, НастройкиПриемник, НастройкиИсточник, Знач ПоляИсключения = Неопределено) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхКлиентСервер.СкопироватьОтборКомпоновкиДанных(СхемаПриемник, НастройкиПриемник, НастройкиИсточник, ПоляИсключения);
```
</details>

## ДобавитьВОтборЭлементОтбораСПроверкой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьВОтборЭлементОтбораСПроверкой(ОтборПриемник, ЭлементОтбора, ПоляИсключения) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхКлиентСервер.ДобавитьВОтборЭлементОтбораСПроверкой(ОтборПриемник, ЭлементОтбора, ПоляИсключения));
```
</details>

## УдалитьОтбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет отбор из компоновщика настроек, если поле не указано, очищает отбор
//
// Параметры:
//	ЭлементСтруктуры - КомпоновщикНастроекКомпоновкиДанных, ОтборКомпоновкиДанных - элемент структуры компоновки
//	Поле - Строка, ПолеКомпоновкиДанных - имя или поле компоновки.
//
// Возвращаемое значение:
//	Булево - признак успешного удаления/очистки.
//
Функция УдалитьОтбор(ЭлементСтруктуры, Знач Поле = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхКлиентСервер.УдалитьОтбор(ЭлементСтруктуры, Поле);
```
</details>

## УстановитьПараметр
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает параметр настроек компоновки данных
//
// Параметры:
//	Настройки - НастройкиКомпоновкиДанных -
//				- ПользовательскиеНастройкиКомпоновкиДанных -
//				- КомпоновщикНастроекКомпоновкиДанных - настройки КД, для которых требуется установить параметры.
//	Параметр - Строка, ПараметрКомпоновкиДанных - параметр, который требуется установить
//	Значение - Произвольный - значение, которое требуется установить.
//	Использование - Булево - признак использования параметра КД.
//	Недоступный - Булево - Истина, если элемент настройки не предназначен для изменения в составе пользовательской настройки.
//
// Возвращаемое значение:
//	ЗначениеПараметраНастроекКомпоновкиДанных - установленный параметр настроек КД. Неопределено, если параметр на найден.
//
Функция УстановитьПараметр(Настройки, Параметр, Значение, Использование = Истина, Недоступный = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхКлиентСервер.УстановитьПараметр(Настройки, Параметр, Значение, Использование, Недоступный);
```
</details>

## УстановитьКоллекциюПараметров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает параметры настроек компоновки данных
//
// Параметры:
//	Настройки - НастройкиКомпоновкиДанных, ПользовательскиеНастройкиКомпоновкиДанных, КомпоновщикНастроекКомпоновкиДанных - настройки СКД, для которых требуется установить параметры
//	УстанавливаемыеПараметры - Соответствие - в котором:
//		*Ключ - Строка - имя параметра компоновки данных, как оно задано в схеме
//		*Значение - Произвольный - устанавливаемое значение.
//
Процедура УстановитьКоллекциюПараметров(Настройки, УстанавливаемыеПараметры) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхКлиентСервер.УстановитьКоллекциюПараметров(Настройки, УстанавливаемыеПараметры) 
```
</details>

## УстановитьПараметрВывода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает параметр вывода компоновщика настроек или настройки КД
//
// Параметры:
//	КомпоновщикНастроекГруппировка - ГруппировкаКомпоновкиДанных -
//									- ГруппировкаТаблицыКомпоновкиДанных -
//									- ГруппировкаДиаграммыКомпоновкиДанных - компоновщик настроек или настройка/группировка КД.
//	ИмяПараметра - Строка - имя параметра КД.
//	Значение - Произвольный - значение параметра вывода КД.
//
// Возвращаемое значение:
//	ЗначениеПараметраКомпоновкиДанных - установленный параметр настроек КД. Неопределено, если параметр на найден.
//
Функция УстановитьПараметрВывода(КомпоновщикНастроекГруппировка, ИмяПараметра, Значение) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхКлиентСервер.УстановитьПараметрВывода(КомпоновщикНастроекГруппировка, ИмяПараметра, Значение) 
```
</details>

## ДобавитьПараметрыВПользовательскиеНастройки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает параметры настройки компоновки данных. При этом, если параметр включен в пользовательские настройки,
// то редактируется пользовательская настройка с соответствующим идентификатором. Применяется в случаях, когда
// когда требуется программно установить пользовательские параметры.
//
// Параметры:
//	КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных - элемент структуры КД
//	МассивПараметров - Массив - Массив параметров.
//
Процедура ДобавитьПараметрыВПользовательскиеНастройки(КомпоновщикНастроек, МассивПараметров) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхКлиентСервер.ДобавитьПараметрыВПользовательскиеНастройки(КомпоновщикНастроек, МассивПараметров) 
```
</details>

## РазделитьИмяПоляИРеквизита
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя поля и его дочерних реквизитов, указанных через точку
//
// Параметры:
//	ИмяПоля - Строка - имя поля в формате "ИмяПоля" или "ИмяПоля.Реквизит.Реквизит..."
//
// Возвращаемое значение:
//	Структура - имя и реквизит в строковом виде:
//		*Имя - Строка - Имя поля
//		*Реквизит - Строка - Имя реквизита в формате "Реквизит.Реквизит..."
//
Функция РазделитьИмяПоляИРеквизита(ИмяПоля) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхКлиентСервер.РазделитьИмяПоляИРеквизита(ИмяПоля) 
```
</details>

## ИспользуемыеОтборыРавны
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет на равенство два переданных отбора схемы компоновки данных
//
// Параметры:
//  ИсточникОтбор - НастройкиКомпоновкиДанных - первый элемент сравнения
//  ЭлементСравненияОтбор - НастройкиКомпоновкиДанных - второй элемент сравнения.
//
// Возвращаемое значение:
//   Булево - Истина, если переданные отборы равны, в противном случае ложь.
//
Функция ИспользуемыеОтборыРавны(ИсточникОтбор, ЭлементСравненияОтбор) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхКлиентСервер.ИспользуемыеОтборыРавны(ИсточникОтбор, ЭлементСравненияОтбор) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
