---
title: Компоновка данных сервер
slug: erp-uh/компоновка-данных-сервер
---


## ОбработатьРасшифровку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура формирует отчет-расшифровку, по описанию, подготовленному соответствующей функцией клиентского модуля.
//
// Параметры:
//		Форма - Форма - форма, в которой расположен отчет
//		ИмяРеквизитаФормы - Строка - имя реквизита формы типа ОтчетОбъект
//		ОписаниеОбработкиРасшифровки - ОписаниеОбработкиРасшифровкиКомпоновкиДанных - значение, сформированное соответствующей клиентской функцией.
//
Процедура ОбработатьРасшифровку(Форма, ИмяРеквизитаФормы, ОписаниеОбработкиРасшифровки) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.ОбработатьРасшифровку(Форма, ИмяРеквизитаФормы, ОписаниеОбработкиРасшифровки) 
```
</details>

## СформироватьОтчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура формирует отчет, расположенный в форме настройками, которые сделал пользователь.
//
// Параметры:
//		Форма - Форма - форма, в которой расположен отчет
//		ИмяРеквизитаФормы - Строка - имя реквизита формы типа ОтчетОбъект
//		ИмяОтчета - Строка - имя формируемого отчета в метаданных
//		ИмяВариантаНастроек - Строка - имя варианта отчета в настройках отчета.
//
Процедура СформироватьОтчет(Форма, ИмяРеквизитаФормы, ИмяОтчета, ИмяВариантаНастроек) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.СформироватьОтчет(Форма, ИмяРеквизитаФормы, ИмяОтчета, ИмяВариантаНастроек) 
```
</details>

## УстановитьСтандартныеНастройки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура инициализирует отчет, расположенный в форме настройками по умолчанию и устанавливает контекстные отборы.
//
// Параметры:
//		Форма - Форма - форма, в которой расположен отчет
//		ИмяРеквизитаФормы - Строка - имя реквизита формы типа ОтчетОбъект
//		ИмяОтчета - Строка - имя формируемого отчета в метаданных
//		ИмяВариантаНастроек - Строка - имя варианта отчета в настройках отчета
//		Отбор - Структура - ключ - имя отбора, значение - значение отбора
//		Параметры - Структура - ключ - имя параметра, значение - значение параметра.
//
Процедура УстановитьСтандартныеНастройки(Форма, ИмяРеквизитаФормы, ИмяОтчета, ИмяВариантаНастроек, Отбор, Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.УстановитьСтандартныеНастройки(Форма, ИмяРеквизитаФормы, ИмяОтчета, ИмяВариантаНастроек, Отбор, Параметры);
```
</details>

## СтрУникальныйИдентификатор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строковое представление уникального идентификатора
// Символы "-" заменяются на "_"
// Предназначена для использования в выражениях СКД.
//
// Параметры:
//	ИсточникИдентификатора - ЛюбаяСсылка, Строка, УникальныйИдентификатор - любая ссылка, строка, число.
//
// Возвращаемое значение:
//	Строка - строковое представление уникального идентификатора.
//
Функция СтрУникальныйИдентификатор(ИсточникИдентификатора) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.СтрУникальныйИдентификатор(ИсточникИдентификатора) 
```
</details>

## ОформитьДиаграммыОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура изменяет настройки диаграмм и их элементов в части оформления
// Параметры оформления (поддерживаемые) могут использовать независимо.
//
// Параметры:
//		КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных - настройки отчета
//		ТабличныйДокумент - ТабличныйДокумент - результат вывода отчета
//		ПараметрыДиаграмм - Структура - Структура изменяемых параметров диаграмм
//			Поддерживаемые параметры:
//				МаксимумСерийКоличество - Число - больше 0, определяет количество выводимых серий диаграммы, "лишние" серии объединяются в сводную серию.
//					Значение 999 используется для снятия ограничения и вывода всех серий.
//				МаксимумСерийПроцент - Число - 0 - 100%, , определяет количество выводимых серий диаграммы, "лишние" серии объединяются в сводную серию.
//					Значение 999 используется для снятия ограничения и вывода всех серий.
//				ТипДиаграммы - Строка - название типа диаграммы, как оно задано в конфигураторе
//				ВыделениеСерийДиаграмм - Число - "0" - не выделять, "1" - выделять первую серию, "2" - Выделять отслеживаемые аналитики
//				ГрадиентСерийДиаграмм - Булево - включает/отключает режима градиента цветом серий данных.
//
Процедура ОформитьДиаграммыОтчета(КомпоновщикНастроек, ТабличныйДокумент, ПараметрыДиаграмм = Неопределено) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.ОформитьДиаграммыОтчета(КомпоновщикНастроек, ТабличныйДокумент, ПараметрыДиаграмм);
```
</details>

## ПараметрыДиаграмм
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров диаграмм для переопределения
//
// Параметры:
//		КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных - настройки отчета
// Возвращаемое значение:
//		Структура - в ключе задается имя параметра, в значении - значение параметры.
Функция ПараметрыДиаграмм(КомпоновщикНастроек) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.ПараметрыДиаграмм(КомпоновщикНастроек) 
```
</details>

## СкрытьВспомогательныеПараметрыОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура удаляет строки с вспомогательными параметрами из секции параметров отчета.
//
// Параметры:
//		СхемаКомпоновкиДанных - СхемаКомпоновкиДанных - Схема компоновки.
//		КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных - Компоновщик настроек.
//		ТабличныйДокумент - ТабличныйДокумент - результат вывода отчета.
//		ПараметрыОтчета - Массив из Строка - имена параметров отчета.
//
Процедура СкрытьВспомогательныеПараметрыОтчета(СхемаКомпоновкиДанных, КомпоновщикНастроек, ТабличныйДокумент, ПараметрыОтчета) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.СкрытьВспомогательныеПараметрыОтчета(СхемаКомпоновкиДанных, КомпоновщикНастроек, ТабличныйДокумент, ПараметрыОтчета) 
```
</details>

## ДобавитьВспомогательныеПараметрыОтчетаПоФункциональнымОпциям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура добавляет в массив вспомогательные параметры отчета,
// которые не отключаются автоматически по значениям функциональных опций
// Следует использовать совместно с методом ОтчетыУТПереопределяемый.НастроитьПараметрыОтборыПоФункциональнымОпциям.
//
// Параметры:
//		ПараметрыОтчета - Массив из Строка - имена параметров отчета.
//
Процедура ДобавитьВспомогательныеПараметрыОтчетаПоФункциональнымОпциям(ПараметрыОтчета) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.ДобавитьВспомогательныеПараметрыОтчетаПоФункциональнымОпциям(ПараметрыОтчета) 
```
</details>

## УстановитьЗаголовкиМакетаКомпоновки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Перебирает ячейки макета компоновки и подменяет их текст.
//
// Параметры:
//		ПараметрыЗамены - Структура, Соответствие - Ключ определяет текст, заданный в схеме компоновки
//													(обрамленный знаками "%"), значение - текст замены.
//		МакетКомпоновки - МакетКомпоновкиДанных - Макет компоновки, заголовки которого будут подменены.
//
Процедура УстановитьЗаголовкиМакетаКомпоновки(ПараметрыЗамены, МакетКомпоновки) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.УстановитьЗаголовкиМакетаКомпоновки(ПараметрыЗамены, МакетКомпоновки) 
```
</details>

## ДобавитьПредставленияПараметраВМассив
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура осуществляет поиск представлений параметров по их имени
// и помещает найденные представления в переданный массив.
//
// Параметры:
//		СхемаКомпоновкиДанных - СхемаКомпоновкиДанных - схема отчета
//		КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных - настройки отчета
//		Параметры - Массив - скрываемые из табличного документа отчета параметры
//		ИмяПараметра - Строка - имя скрываемого параметра отчета.
//
Процедура ДобавитьПредставленияПараметраВМассив(СхемаКомпоновкиДанных, КомпоновщикНастроек, Параметры, ИмяПараметра) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.ДобавитьПредставленияПараметраВМассив(СхемаКомпоновкиДанных, КомпоновщикНастроек, Параметры, ИмяПараметра) 
```
</details>

## ЗаголовкиПолейЕдиницИзмерений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру для подмены заголовков полей веса, объема и таблицы группировки количества по единицам измерения.
//
// Параметры:
//	КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных - настройки отчета.
//	ПереопределениеЗаголовков - Структура - позволяет переопределить заголовки, может содержать свойства:
//		* ИтогоВЕдиницахХранения - Строка -
//		* ИтогоВЕдиницахДляОтчетов - Строка -
//
// Возвращаемое значение:
//	Структура - в ключе задается шаблон замены заголовка, а в значении - значение замены.
//
Функция ЗаголовкиПолейЕдиницИзмерений(КомпоновщикНастроек, ПереопределениеЗаголовков = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.ЗаголовкиПолейЕдиницИзмерений(КомпоновщикНастроек, ПереопределениеЗаголовков);
```
</details>

## СоответствиеЗаголовковПолейЕдиницИзмерений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие для подмены заголовков полей веса, объема и таблицы группировки количества по единицам измерения.
//
// Параметры:
//	КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных - настройки отчета.
//
// Возвращаемое значение:
//	Соответствие - в ключе задается шаблон замены заголовка, а в значении - значение замены.
//
Функция СоответствиеЗаголовковПолейЕдиницИзмерений(КомпоновщикНастроек) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.СоответствиеЗаголовковПолейЕдиницИзмерений(КомпоновщикНастроек) 
```
</details>

## НастроитьДинамическийПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает формулу расчета и формат динамического периода
//
// Параметры:
//		СхемаКомпоновкиДанных - СхемаКомпоновкиДанных - СКД отчета
//		КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных - настройки отчета
//		ДополнятьПериод - Булево - признак использования дополнения периода.
//		ДополнениеПути - Строка - Префикс к полю динамического периода, например, "Периоды."
//
Процедура НастроитьДинамическийПериод(СхемаКомпоновкиДанных, КомпоновщикНастроек, ДополнятьПериод = Ложь, ДополнениеПути = "") Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.НастроитьДинамическийПериод(СхемаКомпоновкиДанных, КомпоновщикНастроек, ДополнятьПериод, ДополнениеПути);
```
</details>

## ПолучитьПараметрСКД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение параметра схемы компоновки данных
//
// Параметры:
//	СхемаКомпоновкиДанных - СхемаКомпоновкиДанных - Схема.
//	Параметр - Строка, ПараметрКомпоновкиДанных - имя параметра КД для которого нужно вернуть значение параметра.
//
// Возвращаемое значение:
//	ПараметрСхемыКомпоновкиДанных, Неопределено - Значение параметра, если параметр не найден.
//
Функция ПолучитьПараметрСКД(СхемаКомпоновкиДанных, Параметр) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.ПолучитьПараметрСКД(СхемаКомпоновкиДанных, Параметр) 
```
</details>

## УстановитьПараметрСКД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает параметр схемы компоновки данных
//
// Параметры:
//	СхемаКомпоновкиДанных - СхемаКомпоновкиДанных - Схема компоновки.
//	Параметр - Строка, ПараметрКомпоновкиДанных - параметр, который требуется установить.
//	Значение - Произвольный - значение, которое требуется установить.
//	Использование - Булево - признак использования параметра КД.
//
// Возвращаемое значение:
//	ПараметрСхемыКомпоновкиДанных - установленный параметр настроек КД. Неопределено, если параметр не найден.
//
Функция УстановитьПараметрСКД(СхемаКомпоновкиДанных, Параметр, Значение, Использование = Истина) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.УстановитьПараметрСКД(СхемаКомпоновкиДанных, Параметр, Значение, Использование);
```
</details>

## НайтиПолеСКДПоПолномуИмени
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Находит среди элементов полей СКД поле по полному имени.
//
// Параметры:
//	Элементы - КоллекцияДоступныхПолейКомпоновкиДанных - поля СКД.
//	ПолноеИмя - Строка - полное имя поля СКД.
//
// Возвращаемое значение:
//	ПолеКомпоновкиДанных - поле СКД.
//
Функция НайтиПолеСКДПоПолномуИмени(Элементы, ПолноеИмя) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.НайтиПолеСКДПоПолномуИмени(Элементы, ПолноеИмя) 
```
</details>

## ПолучитьЗапросИзМакетаКомпоновки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает и возвращает запрос из переданного макета компоновки данных
//
// Параметры:
//  Макет - МакетКомпоновкиДанных - макет, из которого требуется получить запрос.
//  ИмяНабораДанных - Строка - имя набора данных из макета, для которого получается запрос.
//
// Возвращаемое значение:
//	Строка - запрос, сформированный на основании макета компоновки.
//
Функция ПолучитьЗапросИзМакетаКомпоновки(Макет, ИмяНабораДанных) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.ПолучитьЗапросИзМакетаКомпоновки(Макет, ИмяНабораДанных) 
```
</details>

## ПолучитьМакетКомпоновки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает и возвращает макет компоновки данных для схемы компоновки
//
// Параметры:
//  СхемаКомпоновки - СхемаКомпоновкиДанных - для которой получается макет компоновки
//  Настройки - НастройкиКомпоновкиДанных - применяются к схеме.
//
// Возвращаемое значение:
//	МакетКомпоновкиДанных - макет, скомпилированный из схемы и настроек.
//
Функция ПолучитьМакетКомпоновки(СхемаКомпоновки, Настройки) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.ПолучитьМакетКомпоновки(СхемаКомпоновки, Настройки) 
```
</details>

## УдалитьЭлементОтбораИзВсехНастроекОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет отбор из настроек и пользовательских настроек отчета
// Если переданы настройки компоновки данных, то только из них.
//
// Параметры:
//  НастройкиКомпоновкиДанных - КомпоновщикНастроек, НастройкиКомпоновкиДанных, ГруппировкаКомпоновкиДанных, ГруппировкаТаблицыКомпоновкиДанных - Настройки.
//  ИмяЭлемента  - Строка - имя элемента, который будет удален.
//
Процедура УдалитьЭлементОтбораИзВсехНастроекОтчета(НастройкиКомпоновкиДанных, ИмяЭлемента) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.УдалитьЭлементОтбораИзВсехНастроекОтчета(НастройкиКомпоновкиДанных, ИмяЭлемента) 
```
</details>

## УдалитьПараметрИзПользовательскихНастроекОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет параметр из пользовательских настроек отчета
//
// Параметры:
//  НастройкиКомпоновкиДанных - КомпоновщикНастроекКомпоновкиДанных, НастройкиКомпоновкиДанных - Настройки
//  ИмяПараметра  - Строка - имя параметра, который будет удален.
//
Процедура УдалитьПараметрИзПользовательскихНастроекОтчета(НастройкиКомпоновкиДанных, ИмяПараметра) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.УдалитьПараметрИзПользовательскихНастроекОтчета(НастройкиКомпоновкиДанных, ИмяПараметра) 
```
</details>

## УдалитьВыбранноеПолеИзВсехНастроекОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет выбранное поле из настроек и пользовательских настроек отчета
//
// Параметры:
//  НастройкиКомпоновкиДанных - КомпоновщикНастроек, НастройкиКомпоновкиДанных, ГруппировкаКомпоновкиДанных, ГруппировкаТаблицыКомпоновкиДанных -
//  ИменаЭлементов - Строка, Массив - имя элемента, который будет удален.
//  ИскатьВГруппировках - Булево - Искать поле в выбранных полях группировок отчета первого уровня.
//
Процедура УдалитьВыбранноеПолеИзВсехНастроекОтчета(НастройкиКомпоновкиДанных, ИменаЭлементов, ИскатьВГруппировках = Ложь) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.УдалитьВыбранноеПолеИзВсехНастроекОтчета(НастройкиКомпоновкиДанных, ИменаЭлементов, ИскатьВГруппировках);
```
</details>

## УдалитьГруппуВыбранногоПоляИзВсехНастроекОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Удаляет выбранное поле из настроек и пользовательских настроек отчета
//
// Параметры:
//  НастройкиКомпоновкиДанных - КомпоновщикНастроекКомпоновкиДанных, НастройкиКомпоновкиДанных, ГруппировкаКомпоновкиДанных, ГруппировкаТаблицыКомпоновкиДанных -
//  ИмяЭлемента - Строка - имя элемента, родитель которого будет удален.
//
Процедура УдалитьГруппуВыбранногоПоляИзВсехНастроекОтчета(НастройкиКомпоновкиДанных, ИмяЭлемента) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.УдалитьГруппуВыбранногоПоляИзВсехНастроекОтчета(НастройкиКомпоновкиДанных, ИмяЭлемента) 
```
</details>

## УдалитьГруппировкуИзВсехНастроекОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет группировку из настроек и пользовательских настроек отчета
//
// Параметры:
//  НастройкиКомпоновкиДанных - КомпоновщикНастроекКомпоновкиДанных, НастройкиКомпоновкиДанных - Настройки.
//  ИмяЭлемента - Строка - имя элемента, который будет удален.
//
Процедура УдалитьГруппировкуИзВсехНастроекОтчета(НастройкиКомпоновкиДанных, ИмяЭлемента) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.УдалитьГруппировкуИзВсехНастроекОтчета(НастройкиКомпоновкиДанных, ИмяЭлемента) 
```
</details>

## ОтключитьВыбранноеПолеВПользовательскихНастройках
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отключает использование выбранного поле в пользовательских настройках отчета
//
// Параметры:
//  НастройкиКомпоновкиДанных - КомпоновщикНастроекКомпоновкиДанных, НастройкиКомпоновкиДанных - Настройки
//  ИмяЭлемента - Строка - имя элемента, который будет отключен.
//
Процедура ОтключитьВыбранноеПолеВПользовательскихНастройках(НастройкиКомпоновкиДанных, ИмяЭлемента) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.ОтключитьВыбранноеПолеВПользовательскихНастройках(НастройкиКомпоновкиДанных, ИмяЭлемента) 
```
</details>

## ВключитьВыбранноеПолеВПользовательскихНастройках
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Включает использование выбранного поле в пользовательских настройках отчета
//
// Параметры:
//  НастройкиКомпоновкиДанных - КомпоновщикНастроекКомпоновкиДанных, НастройкиКомпоновкиДанных - Настройки
//  ИмяЭлемента - Строка - имя элемента, который будет отключен.
//
Процедура ВключитьВыбранноеПолеВПользовательскихНастройках(НастройкиКомпоновкиДанных, ИмяЭлемента) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.ВключитьВыбранноеПолеВПользовательскихНастройках(НастройкиКомпоновкиДанных, ИмяЭлемента) 
```
</details>

## ОчиститьСтруктуруПоФункциональнымОпциям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Очищает структуру отчета от удаляемых полей.
//
// Параметры:
//  СтруктураОтчета - КоллекцияЭлементовСтруктурыНастроекКомпоновкиДанных
//  УдаляемыеПоля  - Массив - содержит поля компоновки, которые необходимо удалить из структуры отчета.
//
Процедура ОчиститьСтруктуруПоФункциональнымОпциям(СтруктураОтчета, УдаляемыеПоля) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.ОчиститьСтруктуруПоФункциональнымОпциям(СтруктураОтчета, УдаляемыеПоля) 
```
</details>

## УстановитьЗаголовкиВыбранныхПолей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает параметризуемые заголовки выбранных полей компоновки данных.
//
// Параметры:
//	Поля - ВыбранныеПоляКомпоновкиДанных - поля компоновки данных, у которых требуется установить заголовки.
//	Параметры - Структура, Соответствие - параметры замены текста заголовка поля компоновки данных.
//											Ключ определяет текст, заданный в схеме компоновки (обрамленный знаками "%").
//											Значение - текст замены.
//
Процедура УстановитьЗаголовкиВыбранныхПолей(Поля, Параметры) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.УстановитьЗаголовкиВыбранныхПолей(Поля, Параметры) 
```
</details>

## УстановитьЗаголовкиПолейГруппировки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает параметризуемые заголовки полей группировки компоновки данных.
//
// Параметры:
//	Поля - КоллекцияЭлементовСтруктурыНастроекКомпоновкиДанных, КоллекцияЭлементовПользовательскихНастроекКомпоновкиДанных - поля компоновки данных, у которых требуется установить заголовки.
//	Параметры - Структура, Соответствие - параметры замены текста заголовка поля компоновки данных.
//											Ключ определяет текст, заданный в схеме компоновки (обрамленный знаками "%").
//											Значение - текст замены.
//
Процедура УстановитьЗаголовкиПолейГруппировки(Поля, Параметры) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.УстановитьЗаголовкиПолейГруппировки(Поля, Параметры) 
```
</details>

## ЗначениеСимвола
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает непечатный символ по имени
//
// Параметры:
//	ИмяСимвола - Строка - имя непечатного символа как оно задано в системном перечислении Символы.
//
// Возвращаемое значение:
//	Строка - значение символа
//
Функция ЗначениеСимвола(ИмяСимвола) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.ЗначениеСимвола(ИмяСимвола) 
```
</details>

## СтрЗаменитьКомпоновка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Полный аналог СтрЗаменить для использования в выражениях СКД
//
// Параметры:
//  Строка - Строка - Исходная строка.
//  ПодстрокаПоиска - Строка - Искомая подстрока.
//  ПодстрокаЗамены - Строка - Подстрока, на которую будет заменена подстрока поиска.
//
// Возвращаемое значение:
//  Строка - полученная в результате замены.
//
Функция СтрЗаменитьКомпоновка(Строка, ПодстрокаПоиска, ПодстрокаЗамены) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.СтрЗаменитьКомпоновка(Строка, ПодстрокаПоиска, ПодстрокаЗамены) 
```
</details>

## ОптимизацияИспользованияОборотнойАналитики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует новый макет компоновки после замены параметров в выражениях итоговых полей
// Вызывается из отчета СебестоимостьТоваров.
//
// Параметры:
//  МакетКомпоновкиДанных - МакетКомпоновкиДанных - исходный макет, сформированный в отчете
//  СхемаКомпоновкиДанных - СхемаКомпоновкиДанных - схема компоновки отчета, в которой есть параметр ИспользуютсяОборотныеАналитики
//							и этот параметр указан в выражениях итоговых полей
//	НастройкиОтчета - НастройкиКомпоновкиДанных - настройки, на основании которых будет формировать новый макет компоновки
//	ДанныеРасшифровки - ДанныеРасшифровкиКомпоновкиДанных - данные расшифровки отчета.
//
Процедура ОптимизацияИспользованияОборотнойАналитики(МакетКомпоновкиДанных, СхемаКомпоновкиДанных, НастройкиОтчета, Знач ДанныеРасшифровки) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.ОптимизацияИспользованияОборотнойАналитики(МакетКомпоновкиДанных, СхемаКомпоновкиДанных, НастройкиОтчета, ДанныеРасшифровки) 
```
</details>

## МестоВПорядке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вычисляет порядковое место числа относительно других чисел массива после его сортировки.
//
// Параметры:
//	ДанныеГрупповойОбработкиКомпоновкиДанных - Структура - Структура со свойствами:
//	 *Данные - ТаблицаЗначений - обрабатываемая таблица СКД, место определяется для значений первой колонки
//	 *ТекущийЭлемент - СтрокаТаблицыЗначений - текущая строка таблицы значений.
//	ПорядокСортировки - НаправлениеСортировкиКомпоновкиДанных - определяет, сверху или снизу массива будет вычисляться порядковое место.
//
// Возвращаемое значение:
//	Число - поле СКД
//
Функция МестоВПорядке(ДанныеГрупповойОбработкиКомпоновкиДанных, ПорядокСортировки) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.МестоВПорядке(ДанныеГрупповойОбработкиКомпоновкиДанных, ПорядокСортировки) 
```
</details>

## КлассификацияОборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вычисляет сумму неклассифицированного оборота для отчетов, использующих оборотные аналитики
// Вызывается при расчете сумм ресурсов.
//
// Параметры:
//	ДанныеГрупповойОбработкиКомпоновкиДанных - Структура - Структура со свойствами:
//	 *Данные - ТаблицаЗначений - таблица данных.
//			Состав колонок обрабатываемых данных:
//				"ИмяОборотнойАналитики" - колонка со значениями оборотной аналитики.
//				"ИмяРесурса" - колонка ресурсы основного набора данных.
//				"Об_ИмяРесурса" - колонка ресурса набора данных по документам. Имя образуется путем добавления
//						префикса "Об_" к имени колонки ИмяРесурса.
//				"Док_ИмяРесурса" - колонка ресурса набора данных по оборотным аналитикам. Имя образуется путем
//						добавления префикса "Об_" к имени колонки ИмяРесурса.
//	 *ТекущийЭлемент - СтрокаТаблицыЗначений - Текущая строка таблицы данных.
//	 *ВременныеДанныеОбработки - Структура - Структура со свойствами (не обязательны):
//	   **ОборотНакопительный - Число - Оборот накопительный.
//	   **НеклассифицированныйОборот - Число - Неклассифицированный оборот.
//	   **ОбработанноеЗначениеАналитики - Произвольный - Обработанное значение аналитики.
//	ИмяРесурса - Строка - имя обрабатываемого ресурса.
//	ИтогРесурса - Число, Null - Расчитанный итог.
//	ИмяОборотнойАналитики - Строка - имя обрабатываемой аналитики.
//	ЗначениеАналитики - Произвольный - Значение аналитики.
//
// Возвращаемое значение:
//	Число - итог по полю.
//
Функция КлассификацияОборота(ДанныеГрупповойОбработкиКомпоновкиДанных, ИмяРесурса, ИтогРесурса, ИмяОборотнойАналитики, ЗначениеАналитики) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.КлассификацияОборота(ДанныеГрупповойОбработкиКомпоновкиДанных, ИмяРесурса, ИтогРесурса, ИмяОборотнойАналитики, ЗначениеАналитики) 
```
</details>

## ГраницаПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ГраницаПериода(Дата, ВидГраницыИмяЗначения) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.ГраницаПериода(Дата, ВидГраницыИмяЗначения) 
```
</details>

## МодульЧисла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вычисляет модуль
//
// Параметры:
// 	Число - Число
//
// Возвращаемое значение:
// Число - Модуль числа
//
Функция МодульЧисла(Число) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.МодульЧисла(Число) 
```
</details>

## ПустаяСхема
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает пустую схему СКД
//
// Параметры:
//  ИмяИсточника - Строка - имя источника данных новой схемы компоновки (необязательное по умолчанию "ИсточникДанных1")
//  ТипИсточника - Строка - тип источника данных новой схему компоновки данных (необязательное по умолчанию "Local").
//
// Возвращаемое значение:
//  СхемаКомпоновкиДанных - пустая схема компоновки данных.
//
Функция ПустаяСхема(ИмяИсточника = "ИсточникДанных1", ТипИсточника = "Local") Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.ПустаяСхема(ИмяИсточника, ТипИсточника);
```
</details>

## СкопироватьСхемуКомпоновкиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращается независимую копию исходной схемы компоновки данных
//
// Параметры:
//  ИсходнаяСхема - СхемаКомпоновкиДанных - схема, которую требуется скопировать.
//
// Возвращаемое значение:
//  СхемаКомпоновкиДанных - новая схема компоновки данных с настройками, идентичными исходной схеме.
//
Функция СкопироватьСхемуКомпоновкиДанных(ИсходнаяСхема) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.СкопироватьСхемуКомпоновкиДанных(ИсходнаяСхема) 
```
</details>

## ДобавитьПустойНаборДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет новый набор данных заданного типа и возвращает ссылку на него
//
// Параметры:
//  СхемаНабор - СхемаКомпоновкиДанных -
//  			- НаборыДанныхСхемыКомпоновкиДанных -
//  			- НаборДанныхОбъединениеСхемыКомпоновкиДанных - схема или набор компоновки данных, в которой необходимо создать новый набор.
//  ТипНабора - Тип - Тип нового набора (необязательное по умолчанию "НаборДанныхЗапросСхемыКомпоновкиДанных")
//  					Тип("НаборДанныхЗапросСхемыКомпоновкиДанных")
//  					Тип("НаборДанныхОбъектСхемыКомпоновкиДанных").
//  ИмяНабора - Строка - имя нового набора (необязательное по умолчанию "НаборДанных1")
//  ИмяИсточника - Строка - имя источника данных новой схемы компоновки (необязательное по умолчанию "ИсточникДанных1")
//  ИмяОбъекта - Строка - имя внешнего источника данных (необязательное по умолчанию равно имени набора данных).
//
// Возвращаемое значение:
//  НаборДанныхЗапросСхемыКомпоновкиДанных, НаборДанныхОбъединениеСхемыКомпоновкиДанных, НаборДанныхОбъектСхемыКомпоновкиДанных - новый набор данных заданного типа.
//
Функция ДобавитьПустойНаборДанных(СхемаНабор, ТипНабора = Неопределено, ИмяНабора = "НаборДанных1", ИмяИсточника = "ИсточникДанных1", ИмяОбъекта = "") Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.ДобавитьПустойНаборДанных(СхемаНабор, ТипНабора, ИмяНабора, ИмяИсточника, ИмяОбъекта);
```
</details>

## СкопироватьНаборыДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет копировать наборы данных из одной схемы в другую или внутри схемы.
// Возвращает массив ссылок на скопированные наборы в приемнике.
//
// Параметры:
// 	ПриемникНаборовДанных - СхемаКомпоновкиДанных -
//							- НаборыДанныхСхемыКомпоновкиДанных -
//							- НаборДанныхОбъединениеСхемыКомпоновкиДанных - Набор приемник.
// 	ИсточникНаборовДанных - СхемаКомпоновкиДанных -
//							НаборыДанныхСхемыКомпоновкиДанных -
//							НаборДанныхОбъединениеСхемыКомпоновкиДанных -
//							НаборДанныхЗапросСхемыКомпоновкиДанных -
//							НаборДанныхОбъектСхемыКомпоновкиДанных - Набор источник.
// 	ОсновноеИмяНабораДанных - Строка - имя набора данных в приемнике.
//									Если в приемнике уже есть набор данных с таким именем, то к имени будет добавлен очередной порядковый номер.
//									Если источник содержит несколько наборов данных, то основное имя применятся не будет.
//									Если источник содержит одно объединение, то основное имя будет применено только к нему.
//									Если имя не задано, то по возможности будут сохранятся исходные имена наборов данных.
//
// Возвращаемое значение:
// 	Массив из НаборыДанныхСхемыКомпоновкиДанных, НаборДанныхОбъединениеСхемыКомпоновкиДанных, НаборДанныхЗапросСхемыКомпоновкиДанных, НаборДанныхОбъектСхемыКомпоновкиДанных - ссылки
// 				на скопированные наборы в приемнике.
//
Функция СкопироватьНаборыДанных(ПриемникНаборовДанных, ИсточникНаборовДанных, ОсновноеИмяНабораДанных = "") Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.СкопироватьНаборыДанных(ПриемникНаборовДанных, ИсточникНаборовДанных, ОсновноеИмяНабораДанных);
```
</details>

## СкопироватьПоляНабораДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет копировать поля из одного набора данных в другой.
// Если поле уже есть в приемнике, то оно пропускается.
// Возвращает массив ссылок на скопированные поля набора данных в приемнике.
//
// Параметры:
// 	ПриемникПолейНабораДанных - НаборДанныхОбъединениеСхемыКомпоновкиДанных -
//								- НаборДанныхЗапросСхемыКомпоновкиДанных -
//								- НаборДанныхОбъектСхемыКомпоновкиДанных - набор приемник.
// 	ИсточникПолейНабораДанных - НаборДанныхОбъединениеСхемыКомпоновкиДанных -
//								- НаборДанныхЗапросСхемыКомпоновкиДанных -
//								- НаборДанныхОбъектСхемыКомпоновкиДанных - набор источник.
// 	ДублироватьИмяВПутиПоля - Булево - признак необходимости приравнять путь к данным и выражение поля (по умолчанию Ложь).
//
// Возвращаемое значение:
// 	Массив из ПолеНабораДанныхСхемыКомпоновкиДанных, ПапкаПолейНабораДанныхСхемыКомпоновкиДанных - ссылки на скопированные поля набораданных в приемнике.
//
Функция СкопироватьПоляНабораДанных(ПриемникПолейНабораДанных, ИсточникПолейНабораДанных, ДублироватьИмяВПутиПоля = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.СкопироватьПоляНабораДанных(ПриемникПолейНабораДанных, ИсточникПолейНабораДанных, ДублироватьИмяВПутиПоля);
```
</details>

## ДобавитьСвязьНаборовДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новую связь наборов данных в переданной схеме.
// Возвращает объект созданной связи.
//
// Параметры:
// 	СхемаКомпоновкиДанных - СхемаКомпоновкиДанных - схема, в которую нужно добавить связь.
// 	НаборДанныхИсточник - Строка -
//							- НаборДанныхОбъединениеСхемыКомпоновкиДанных -
//							- НаборДанныхЗапросСхемыКомпоновкиДанных -
//							- НаборДанныхОбъектСхемыКомпоновкиДанных - имя набора данных, от которого будет осуществляться связь.
// 	НаборДанныхПриемник - Строка -
//							- НаборДанныхОбъединениеСхемыКомпоновкиДанных -
//							- НаборДанныхЗапросСхемыКомпоновкиДанных -
//							- НаборДанныхОбъектСхемыКомпоновкиДанных - имя набора данных, к которому будет осуществляться связь.
// 	ВыражениеИсточник - Строка - выражение, по которому будет определяться значение связи источника.
// 	ВыражениеПриемник - Строка - выражение, по которому будет определяться значение связи приемника.
// 	Параметр - Строка - имя параметра, в который будет помещено значение связи источника.
// 	РазрешенСписокПараметров - Булево - возможность использования в качестве значения параметра список значений.
//
// Возвращаемое значение:
// 	СвязьНаборовДанныхСхемыКомпоновкиДанных - добавленная связь.
//
Функция ДобавитьСвязьНаборовДанных(СхемаКомпоновкиДанных, НаборДанныхИсточник, НаборДанныхПриемник, ВыражениеИсточник, ВыражениеПриемник, Параметр = Неопределено, РазрешенСписокПараметров = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.ДобавитьСвязьНаборовДанных(СхемаКомпоновкиДанных, НаборДанныхИсточник, НаборДанныхПриемник, ВыражениеИсточник, ВыражениеПриемник, Параметр, РазрешенСписокПараметров);
```
</details>

## ДобавитьПараметр
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет или перезаполняет свойства параметра в схеме компоновки данных
//
// Параметры:
//	СхемаКомпоновкиДанных - СхемаКомпоновкиДанных - схема, в которую нужно добавить параметры или найти и перезаполнить свойства.
//	ИмяПараметра - Строка - имя параметра.
//	ТипЗначения - Тип, Неопределено - тип значений параметра.
//	Значение - Произвольный, Неопределено - значение по умолчанию.
//	ИспользованиеВсегда - Булево - Истина, тогда параметры будет использоваться всегда. Ложь - автоматическое управление платформой.
//	ПерезаполнитьСуществующий - Булево - Истина, перед добавлением будет осуществляться поиск параметра с заданным именем.
//		Внимание, операция ресурсоемкая и следует включать только если нельзя проверить уникальность параметров иначе.
//
// Возвращаемое значение:
//	ПараметрКомпоновкиДанных - созданный или перезаполненный параметр.
//
Функция ДобавитьПараметр(СхемаКомпоновкиДанных, ИмяПараметра, ТипЗначения = Неопределено, Значение = Неопределено, ИспользованиеВсегда = Истина, ПерезаполнитьСуществующий = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.ДобавитьПараметр(СхемаКомпоновкиДанных, ИмяПараметра, ТипЗначения, Значение, ИспользованиеВсегда, ПерезаполнитьСуществующий);
```
</details>

## ДобавитьОтборПоКолонкеТаблицыЗначений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет отбор для сравнения со списком значений, выгруженных из указанной колонки таблицы.
//
// Параметры:
//	ЭлементНастроекКомпоновки - КомпоновщикНастроекКомпоновкиДанных, НастройкиКомпоновкиДанных - элемент структуры компоновки данных
//	ТаблицаДанных - ТаблицаЗначений - таблица с данными
//	ИмяКолонки - Строка - имя колонки, со значениями которой будут сравнение в отборе.
//
Процедура ДобавитьОтборПоКолонкеТаблицыЗначений(ЭлементНастроекКомпоновки, ТаблицаДанных, ИмяКолонки) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.ДобавитьОтборПоКолонкеТаблицыЗначений(ЭлементНастроекКомпоновки, ТаблицаДанных, ИмяКолонки) 
```
</details>

## НаборыДанныхСсылаютсяВЗапросахНаТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак того, что хотя бы одно из переданных имен таблиц встречается в хотя бы одном тексте запроса одного
// из наборов данных.
//
// Параметры:
//	НаборыДанных - НаборыДанныхСхемыКомпоновкиДанных - коллекция наборов данных
//	ИменаТаблиц - Массив - имена искомых таблиц.
//
// Возвращаемое значение:
//	Булево - Истина, имена таблиц встречаются в запросах наборов данных.
//
Функция НаборыДанныхСсылаютсяВЗапросахНаТаблицы(НаборыДанных, ИменаТаблиц) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.НаборыДанныхСсылаютсяВЗапросахНаТаблицы(НаборыДанных, ИменаТаблиц) 
```
</details>

## СкопироватьПараметры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет копировать параметры из одной схемы в другую или внутри схемы.
// Возвращает массив ссылок на скопированные параметры в приемнике.
// ВНИМАНИЕ. Параметры редактирования не переносятся.
//
// Параметры:
// 	ПриемникПараметров - СхемаКомпоновкиДанных - схема-приемник
//						- ПараметрыСхемыКомпоновкиДанных - коллекция-приемник параметров
// 	ИсточникПараметров - СхемаКомпоновкиДанных - схема-источник
//						- ПараметрыСхемыКомпоновкиДанных - коллекция-источник параметров
//	ПерезаполнитьСуществующий - Булево - Истина, перед добавлением будет осуществляться поиск параметра с заданным именем.
//		Внимание, операция ресурсоемкая и следует включать только если нельзя проверить уникальность параметров иначе.
//
//
// Возвращаемое значение:
// 	Массив - ссылки на скопированные параметры в приемнике:
// 		* Элементы - ПараметрКомпоновкиДанных - отдельный параметр.
//
Функция СкопироватьПараметры(ПриемникПараметров, ИсточникПараметров, ПерезаполнитьСуществующий = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.СкопироватьПараметры(ПриемникПараметров, ИсточникПараметров, ПерезаполнитьСуществующий);
```
</details>

## ПараметрыВыгрузитьРезультатСКД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры функции КомпоновкаДанныхСервер.ВыгрузитьРезультатСКД
//
// Возвращаемое значение:
//  Структура:
//  * СхемаКомпоновки - Строка - адрес во временном хранилище
//								или полное имя макета, например, Документ.РеализацияТоваровУслуг.ДанныеШаблонаСообщений.
//						- СхемаКомпоновкиДанных - собственно схема компоновки данных.
//  * НастройкиКомпоновки - Строка - адрес во временном хранилище настроек компоновки или имя варианта настроек компоновки.
//						- НастройкиКомпоновкиДанных - собственно настройки компоновки.
//						- Неопределено - будут применены настройки по умолчанию.
//  * ОжидаемыеКолонки - ТаблицаЗначений - если колонки, описанные в макете, отключаются по ФО, то
//					в полученной после использования компоновки таблице(дереве) значений они будут отсутствовать,
//					если этот параметр передан, то функция дополнит полученную таблицу(дерево) значений недостающими
//					колонками.
//  * ВыполнятьВПривилегированномРежиме - Булево - значение по умолчанию Ложь.
//  * ТипРезультата - Строка - возможные значения: ""ТаблицаЗначений"", "ДеревоЗначений"", значение по умолчанию ""ТаблицаЗначений"".
//  * ВнешниеНаборыДанных - Структура, Неопределено - внешние наборы компоновки данных,
//									если передана структура, то ключ - наименование внешнего набора,
//									значение - таблица значений внешнего набора.
//  * ВозможностьИспользованияВнешнихФункций - Булево - Указывает возможность использования функции
//														общих модулей конфигурации в выражениях компоновки данных, значение
//														по умолчанию - Истина.
//
Функция ПараметрыВыгрузитьРезультатСКД() Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.ПараметрыВыгрузитьРезультатСКД() 
```
</details>

## ВыгрузитьРезультатСКД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Исполняет макет компоновки, применяя настройки, и возвращает таблицу значений или дерево значений
//
// Параметры:
//  Параметры - см. КомпоновкаДанныхСервер.ПараметрыВыгрузитьРезультатСКД
//  АдресВременногоХранилища - Строка - если в этом параметре передается адрес временного хранилища,
//  				то результатирующая таблица помещается по этому адресу.
//
// Возвращаемое значение:
//  ТаблицаЗначений, Строка - результирующая таблица значений или ее адрес во временном хранилище
//
Функция ВыгрузитьРезультатСКД(Параметры, АдресВременногоХранилища = "") Экспорт
```

Пример вызова
```bsl
Результат = КомпоновкаДанныхСервер.ВыгрузитьРезультатСКД(Параметры, АдресВременногоХранилища);
```
</details>

## ИнициализироватьКомпоновщикНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализировать компоновщик настроек компоновки данных.
// Схему компоновки данных можно передать непосредственно в параметре, или задать имя (адрес) макета
//
// Параметры:
//  КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных
//  СхемаКомпоновкиДанных - Строка, СхемаКомпоновкиДанных - адрес схемы компоновки временном хранилище
//											или полное имя макета, например, Документ.РеализацияТоваровУслуг.ДанныеШаблонаСообщений
//											или собственно схема компоновки.
//  НастройкиКомпоновки - Строка - адрес во временном хранилище настроек компоновки или имя варианта настроек компоновки.
//						- НастройкиКомпоновкиДанных - собственно настройки компоновки.
//						- Неопределено - будут применены настройки по умолчанию.
//
Процедура ИнициализироватьКомпоновщикНастроек(КомпоновщикНастроек, Знач СхемаКомпоновкиДанных, Знач НастройкиКомпоновки = Неопределено) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.ИнициализироватьКомпоновщикНастроек(КомпоновщикНастроек, СхемаКомпоновкиДанных, НастройкиКомпоновки);
```
</details>

## НайтиВыбранноеПолеРекурсивно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет массив элементов компоновки.
//
// Параметры:
// 	КоллекцияЭлементов - КоллекцияЭлементовУсловногоОформленияКомпоновкиДанных, КоллекцияВыбранныхПолейКомпоновкиДанных, КоллекцияЭлементовОтбораКомпоновкиДанных, КоллекцияЭлементовПорядкаКомпоновкиДанных - Описание
// 	МассивЭлементов - Массив из ВыбранноеПолеКомпоновкиДанных - массив элементов.
// 	ЗначенияПоиска - ПолеКомпоновкиДанных или Массив из ПолеКомпоновкиДанных - Значение поиска.
Процедура НайтиВыбранноеПолеРекурсивно(КоллекцияЭлементов, МассивЭлементов, ЗначенияПоиска) Экспорт
```

Пример вызова
```bsl
КомпоновкаДанныхСервер.НайтиВыбранноеПолеРекурсивно(КоллекцияЭлементов, МассивЭлементов, ЗначенияПоиска) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
