---
title: Контролируемые сделки
slug: erp-uh/контролируемые-сделки
---


## ОпределитьСвойстваОбъектовДляОтображенииВФормеОтчетность
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура переопределяет свойства объекта, с которыми он будет отображен в форме Отчетность
// Параметры:
//  СвойстваОбъектов  - ТаблицаЗначений - Таблица, содержащая в себе описания ссылок, переданных в закладке Ссылка таблицы
//		Каждая колонка таблицы соответствует свойству объекта.
//		Таблица содержит следующие колонки:
//			- ДатаСоздания - Дата - Дата создания объекта
//			- Наименование - Строка - Наименование объекта, с которым он будет отображаться в форме Отчетность
//			- КодКонтролирующегоОргана - Строка - Код контролирующего органа, в который отправляется отчетности по ТКС
//			- ДатаНачала - Дата - Дата начала периода. Пустая, если дата начала периода отсутствует
//			- ДатаОкончания - Дата - Дата окончания периода. Пустая, если дата окончания периода отсутствует
//			- ВариантОтчета - Строка(3) - Корректировочный номер (0 - Первичный)
//			- ПометкаУдаления - Булево - Истина, если объект помечен на удаление
//			- Организация - СправочникСсылка.Организации - Организация, которой принадлежит объект
//			- Комментарий - Строка - Комментарий из объекта.
Процедура ОпределитьСвойстваОбъектовДляОтображенииВФормеОтчетность(СвойстваОбъектов) Экспорт
```

Пример вызова
```bsl
КонтролируемыеСделки.ОпределитьСвойстваОбъектовДляОтображенииВФормеОтчетность(СвойстваОбъектов) 
```
</details>

## НайтиУведомлениеОрганизацииВОтчетномГоду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Найти уведомление организации в отчетном году.
//
// Параметры:
//  Организация - СправочникСсылка.Организации.
//  ОтчетныйГод -Число.
//  ТипУведомления - Число -  0 - Уведомление, 1 - Корректировка.
//  НомерКорректировки - Число.
//  ТипПоиска - Строка.
//
// Возвращаемое значение:
//  Неопределено - если уведомление не найдено.
Функция НайтиУведомлениеОрганизацииВОтчетномГоду(Организация, ОтчетныйГод, ТипУведомления = Неопределено, НомерКорректировки = Неопределено, ТипПоиска = "Последний") Экспорт
```

Пример вызова
```bsl
Результат = КонтролируемыеСделки.НайтиУведомлениеОрганизацииВОтчетномГоду(Организация, ОтчетныйГод, ТипУведомления, НомерКорректировки, ТипПоиска);
```
</details>

## ИнициализироватьДопСведенияДоговоровУчастниковКонтролируемыхСделок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура, вызываемая из одноименного обработчика события формы.
//
// Параметры:
//  Форма					- УправляемаяФорма - форма, из обработчика события которой происходит вызов процедуры;
//  Отказ					- Булево - признак отказа от создания формы;
//  СтандартнаяОбработка	- Булево - признак выполнения стандартной (системной) обработки события;
//  ДополнительныеПараметры	- Структура - дополнительные параметры.
//
Процедура ИнициализироватьДопСведенияДоговоровУчастниковКонтролируемыхСделок(Форма, Отказ, СтандартнаяОбработка, ДополнительныеПараметры) Экспорт
```

Пример вызова
```bsl
КонтролируемыеСделки.ИнициализироватьДопСведенияДоговоровУчастниковКонтролируемыхСделок(Форма, Отказ, СтандартнаяОбработка, ДополнительныеПараметры) 
```
</details>

## СохранитьДопСведенияДоговоровУчастниковКонтролируемыхСделок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СохранитьДопСведенияДоговоровУчастниковКонтролируемыхСделок(Форма, ТекущийОбъект, ДополнительныеПараметры) Экспорт
```

Пример вызова
```bsl
КонтролируемыеСделки.СохранитьДопСведенияДоговоровУчастниковКонтролируемыхСделок(Форма, ТекущийОбъект, ДополнительныеПараметры) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
