---
title: Льготы по имущественным налогам клиент сервер
slug: erp-uh/льготы-по-имущественным-налогам-клиент-сервер
---


## НаименованиеМестнойЛьготы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует наименование для местной (региональной) льготы.
//
// Параметры:
//  Объект - СправочникОбъект.ОснованияЛьготПоИмущественнымНалогам, ДанныеФормыСтруктура - объект справочника льгот,
//		для которого нужно сформировать наименование.
//  СведенияОПунктеРегЗакона - Структура - описание конкретного пункта местного (регионального) закона, по которому
//  	предоставлена льгота. См. НовыйСведенияОПунктеМестногоЗакона()
//  НаименованиеРегиона - Строка - наименование субъекта РФ из адресного классификатора
//
// Возвращаемое значение:
//  Строка - наименование льготы
//
Функция НаименованиеМестнойЛьготы(Объект, НаименованиеРегиона = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЛьготыПоИмущественнымНалогамКлиентСервер.НаименованиеМестнойЛьготы(Объект, НаименованиеРегиона);
```
</details>

## ПолныйКодОснованияЛьготы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строковый код основания применения льготной налоговой ставки в формате декларации
// на основании номеров статьи, части, пункта, подпункта, абзаца (или иной единицы деления текста) нормативного акта.
//
// Параметры:
//  Статья    - Строка - номер статьи нормативного акта.
//  Часть     - Строка - номер части статьи нормативного акта.
//  Пункт     - Строка - номер пункта статьи или части статьи нормативного акта.
//  Подпункт  - Строка - номер подпункта статьи нормативного акта.
//  Абзац     - Строка - номер абзаца пункта или подпункта статьи нормативного акта.
//  Иное      - Строка - номер прочей единицы деления текста нормативного акта.
//
// Возвращаемое значение:
//  Строка - код основания применения льготной ставки налога (длина - 24).
//
Функция ПолныйКодОснованияЛьготы(Знач Статья, Знач Часть, Знач Пункт, Знач Подпункт, Знач Абзац, Знач Иное) Экспорт
```

Пример вызова
```bsl
Результат = ЛьготыПоИмущественнымНалогамКлиентСервер.ПолныйКодОснованияЛьготы(Статья, Часть, Пункт, Подпункт, Абзац, Иное) 
```
</details>

## НормативныеДанныеОснованияЛьготы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует по переданному коду основания льготы развернутые сведения о местном (региональном) нормативном акте -
// номере статьи, части, пункте, подпункте, абзаце (или иное), на основании которых применяется льготная ставка налога.
//
// Параметры:
//  КодОснованияЛьготы - Строка	- код основания применения льготной ставки налога в формате заявления о льготе (длина - 24).
//                                См. также ПолныйКодОснованияЛьготы().
//  БезЛидирующихНолей - Булево - если Истина, то значения структурных единиц закона возвращаются без лидирующих нолей.			 -
//
// Возвращаемое значение:
//  Структура - разобранный код основания льготы:
//  * Статья      - Строка
//  * Часть       - Строка
//  * Пункт       - Строка
//  * Подпункт    - Строка
//  * Абзац       - Строка
//  * Иное        - Строка
//
Функция НормативныеДанныеОснованияЛьготы(Знач КодОснованияЛьготы, БезЛидирующихНолей = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ЛьготыПоИмущественнымНалогамКлиентСервер.НормативныеДанныеОснованияЛьготы(КодОснованияЛьготы, БезЛидирующихНолей);
```
</details>

## СокращенныйКодОснованияЛьготы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует по переданному полному коду основания льготы (24 символа) сокращенный код (12 символом) - оставляет только
// номер статьи, пункта и подпункта. Часть, абзац и иное игнорируются.
// Данный формат используется в декларации по налогу на имущество.
//
// Параметры:
//  КодОснованияЛьготы  - Строка - код основания применения льготной ставки налога в формате заявления о льготе (длина - 24).
//                                 См. также ПолныйКодОснованияЛьготы().
//
// Возвращаемое значение:
//  Строка - сокращенный код основания применения льготной ставки налога (длина - 12).
//
Функция СокращенныйКодОснованияЛьготы(Знач КодОснованияЛьготы) Экспорт
```

Пример вызова
```bsl
Результат = ЛьготыПоИмущественнымНалогамКлиентСервер.СокращенныйКодОснованияЛьготы(КодОснованияЛьготы) 
```
</details>

## КодРегиональнойЛьготыПоНалогуНаИмуществоСнижениеНалоговойСтавки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КодРегиональнойЛьготыПоНалогуНаИмуществоСнижениеНалоговойСтавки() Экспорт
```

Пример вызова
```bsl
Результат = ЛьготыПоИмущественнымНалогамКлиентСервер.КодРегиональнойЛьготыПоНалогуНаИмуществоСнижениеНалоговойСтавки() 
```
</details>

## КодРегиональнойЛьготыПоНалогуНаИмуществоСнижениеСуммыНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КодРегиональнойЛьготыПоНалогуНаИмуществоСнижениеСуммыНалога() Экспорт
```

Пример вызова
```bsl
Результат = ЛьготыПоИмущественнымНалогамКлиентСервер.КодРегиональнойЛьготыПоНалогуНаИмуществоСнижениеСуммыНалога() 
```
</details>

## ПредставлениеНалоговойЛьготыПоЗемельномуНалогу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Готовит текстовое описание всех применяемых льгот по земельному участку
//
// Параметры:
//  ПараметрыЛьготы - Структура - см. НовыеПараметрыОписанияЛьготыПоЗемельномуНалогу()
//
// Возвращаемое значение:
//  Строка -  Описание применяемых льгот
Функция ПредставлениеНалоговойЛьготыПоЗемельномуНалогу(ПараметрыЛьготы) Экспорт
```

Пример вызова
```bsl
Результат = ЛьготыПоИмущественнымНалогамКлиентСервер.ПредставлениеНалоговойЛьготыПоЗемельномуНалогу(ПараметрыЛьготы) 
```
</details>

## НовыеПараметрыОписанияЛьготыПоЗемельномуНалогу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует структуру с набором свойств, необходимых для описания льгот по земельному участку
//
// Возвращаемое значение:
//  Структура -  Новые параметры описания льготы по земельному налогу:
// * ОснованиеЛьготыПоНалоговойБазе
// * НачалоДействияЛьготыПоНалоговойБазе
// * ОкончаниеДействияЛьготыПоНалоговойБазе
// * ДоляНеОблагаемойНалогомПлощадиЗнаменатель
// * ДоляНеОблагаемойНалогомПлощадиЧислитель
// * НеОблагаемаяНалогомСумма
// * ОснованиеЛьготыСнижениеСуммыНалога
// * НачалоДействияЛьготыСнижениеСуммыНалога
// * ОкончаниеДействияЛьготыСнижениеСуммыНалога
// * СуммаУменьшенияСуммыНалога
// * ПроцентУменьшенияСуммыНалога
// * ОснованиеЛьготыСнижениеСтавки
// * НачалоДействияЛьготыСнижениеСтавки
// * ОкончаниеДействияЛьготыСнижениеСтавки
// * СниженнаяНалоговаяСтавка
// * ВидЛьготыПоНалоговойБазе
// * ВидЛьготыСнижениеСуммыНалога
// * ВидЛьготыСнижениеСтавки
Функция НовыеПараметрыОписанияЛьготыПоЗемельномуНалогу() Экспорт
```

Пример вызова
```bsl
Результат = ЛьготыПоИмущественнымНалогамКлиентСервер.НовыеПараметрыОписанияЛьготыПоЗемельномуНалогу() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
