---
title: Международная отчетность вызов сервера
slug: erp-uh/международная-отчетность-вызов-сервера
---


## ДобавитьСохраненныйОперанд
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция добавляет сохраненные операнды в таблицу операндов
//
// Параметры:
//  Операнд - см. МеждународнаяОтчетностьКлиентСервер.НовыеДанныеОперанда
//  ИдентификаторГлавногоХранилища - УникальныйИдентификатор - идентификатор формы отчета.
//
// Возвращаемое значение:
//   Структура - массив добавленных строк таблицы операндов:
//   *Формула - Строка
//   *НовыеОперанды - см. МеждународнаяОтчетностьКлиентСервер.НовыеДанныеОперанда
//
Функция ДобавитьСохраненныйОперанд(Операнд, ИдентификаторГлавногоХранилища) Экспорт
```

Пример вызова
```bsl
Результат = МеждународнаяОтчетностьВызовСервера.ДобавитьСохраненныйОперанд(Операнд, ИдентификаторГлавногоХранилища) 
```
</details>

## ПроверитьФормулу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет на исполнимость формулу производного показателя генератора финансовой отчетности.
//
// Параметры:
//  Формула - Строка - текст формулы расчета производного показателя.
//  Операнды - см. МеждународнаяОтчетностьКлиент.ДобавитьОперандыФормулы.ТаблицаОперандов
//  Отказ - Булево - Истина, если не удалось выполнить расчет по формуле.
//  Поле - Строка - Имя реквизита формы содержащего формулу.
//  ПутьКДанным - Строка - путь к реквизиту формы содержащего формулу.
//
Процедура ПроверитьФормулу(Формула, Операнды, Отказ, Поле = "", ПутьКДанным = "") Экспорт
```

Пример вызова
```bsl
МеждународнаяОтчетностьВызовСервера.ПроверитьФормулу(Формула, Операнды, Отказ, Поле, ПутьКДанным);
```
</details>

## ВычислитьСуммуВыделенныхЯчеекТабличногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сумму выделенных ячеек табличного документа.
//
// Параметры:
//	Результат - ТабличныйДокумент - Табличный документ, содержащий ячейки для суммирования.
//	КэшВыделеннойОбласти - Структура - Содержит ячейки выделенной области.
//
// Возвращаемое значение:
//	Число - Сумма значений ячеек.
//
Функция ВычислитьСуммуВыделенныхЯчеекТабличногоДокумента(Знач Результат, КэшВыделеннойОбласти) Экспорт
```

Пример вызова
```bsl
Результат = МеждународнаяОтчетностьВызовСервера.ВычислитьСуммуВыделенныхЯчеекТабличногоДокумента(Результат, КэшВыделеннойОбласти) 
```
</details>

## ЕстьСсылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Ищет ссылки в других отчетах на переданный элемент финансового отчета
//
//Параметры:
//  ЭлементОтчета - СправочникСсылка.ЭлементыФинансовыхОтчетов
//  КоличествоСсылок - Число - будет помещено найденное количество ссылок.
//
// Возвращаемое значение:
//  Булево - Истина, если на текущий элемент отчета есть ссылки в других отчетах.
//
Функция ЕстьСсылки(ЭлементОтчета, КоличествоСсылок = 0) Экспорт
```

Пример вызова
```bsl
Результат = МеждународнаяОтчетностьВызовСервера.ЕстьСсылки(ЭлементОтчета, КоличествоСсылок);
```
</details>

## ПараметрыРасшифровкиОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает параметры для расшифровочного отчета по данным стандартной расшифровки СКД и параметров вызывающего отчета.
//
// Параметры:
//  Расшифровка - Структура из КлючИЗначение - содержит значение полей текущей группировки дополненная:
//   *ДатаНачала - Дата -
//   *ДатаОкончания - Дата -
//   *Точность - Число -
//  ПараметрыОтчета - Структура из КлючИЗначение - Параметры вызывающего отчета.
//
// Возвращаемое значение:
//  Структура из КлючИЗначение - см. НовыеПараметрыРасшифровкиОтчета - Содержащая параметры для расшифровочного отчета.
//
Функция ПараметрыРасшифровкиОтчета(Расшифровка, ПараметрыОтчета) Экспорт
```

Пример вызова
```bsl
Результат = МеждународнаяОтчетностьВызовСервера.ПараметрыРасшифровкиОтчета(Расшифровка, ПараметрыОтчета) 
```
</details>

## НастроитьАнализСчетаХозрасчетный
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает параметры для расшифровочного отчета АнализСчетаХозрасчетный
//
// Параметры:
//  Адрес - Строка - адрес во временном хранилище данных расшифровки вызывающего отчета
//  Параметры - Структура из КлючИЗначение- параметры вызывающего отчета:
//   *Показатель - Структура из КлючИЗНачение - см. Реквизиты
//
// Возвращаемое значение:
//  Структура - КлючИЗначение - содержащая параметры настройки отчета АнализСчетаХозрасчетный:
//   *АдресНастроек - Строка - адрес во временном хранилище данных расшифровки вызывающего отчета.
//
Функция НастроитьАнализСчетаХозрасчетный(Адрес, Параметры) Экспорт
```

Пример вызова
```bsl
Результат = МеждународнаяОтчетностьВызовСервера.НастроитьАнализСчетаХозрасчетный(Адрес, Параметры) 
```
</details>

## ПараметрыОткрытияБухгалтерскогоОтчетаМеждународногоДляРасшифровки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает параметры для расшифровочного отчета по счету международного учета
//
// Параметры:
//  СчетУчета - ПланСчетовСсылка.Международный - Счет учета
//  Параметры - Структура - параметры вызывающего отчета.
//
// Возвращаемое значение:
//  Структура - содержит:
//  	* ИмяОтчета - Строка - Имя отчета расшифровки
//  	* ИмяВариантаОтчета - Строка - Имя варианта расшифровки
//  	* КомпоновщикНастроек - КомпоновщикНастроекКомпоновкиДанных - Компоновщик настроек отчета
//
Функция ПараметрыОткрытияБухгалтерскогоОтчетаМеждународногоДляРасшифровки(Знач СчетУчета, Знач Параметры) Экспорт
```

Пример вызова
```bsl
Результат = МеждународнаяОтчетностьВызовСервера.ПараметрыОткрытияБухгалтерскогоОтчетаМеждународногоДляРасшифровки(СчетУчета, Параметры) 
```
</details>

## ЭтоГруппаШаблонов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция получает реквизит "ЭтоГруппаШаблонов" для переданного шаблона проводки
//
// Параметры:
//	ШаблонПроводки - СправочникСсылка.ШаблоныПроводокДляМеждународногоУчета - шаблон проводки.
//
// Возвращаемое значение:
//	Булево - Истина если шаблон проводки является группой шаблонов.
//
Функция ЭтоГруппаШаблонов(Знач ШаблонПроводки) Экспорт
```

Пример вызова
```bsl
Результат = МеждународнаяОтчетностьВызовСервера.ЭтоГруппаШаблонов(ШаблонПроводки) 
```
</details>

## ПредставлениеЗакрытияДоходовРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует текстовое представление документа РегламентнаяОперацияМеждународныйУчет
// с хоз. операцией ЗакрытиеСчетовДоходовРасходов.
//
// Параметры:
//  ПредставлениеСсылки - Булево - Истина, возвращается шаблон представления для последующего заполнения
//                                 в обработчике ОбработкаПолученияПредставления.
//
// Возвращаемое значение:
//  Строка - Строка представления документа.
//
Функция ПредставлениеЗакрытияДоходовРасходов(ПредставлениеСсылки = Истина) Экспорт
```

Пример вызова
```bsl
Результат = МеждународнаяОтчетностьВызовСервера.ПредставлениеЗакрытияДоходовРасходов(ПредставлениеСсылки);
```
</details>

## ПредставлениеРасчетКурсовыхРазницФункциональнойВалюте
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует текстовое представление документа РегламентнаяОперацияМеждународныйУчет
// с хоз. операцией РасчетКурсовыхРазницФункциональнаяВалюта.
//
// Параметры:
//  ПредставлениеСсылки - Булево - Истина, возвращается шаблон представления для последующего заполнения
//                                 в обработчике ОбработкаПолученияПредставления.
//
// Возвращаемое значение:
//  Строка - Строка представления документа.
//
Функция ПредставлениеРасчетКурсовыхРазницФункциональнойВалюте(ПредставлениеСсылки = Истина) Экспорт
```

Пример вызова
```bsl
Результат = МеждународнаяОтчетностьВызовСервера.ПредставлениеРасчетКурсовыхРазницФункциональнойВалюте(ПредставлениеСсылки);
```
</details>

## ПредставлениеРасчетКурсовыхРазницВалютеПредставления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует текстовое представление документа РегламентнаяОперацияМеждународныйУчет
// с хоз. операцией РасчетКурсовыхРазницВалютаПредставления.
//
// Параметры:
//  ПредставлениеСсылки - Булево - Истина, возвращается шаблон представления для последующего заполнения
//                                 в обработчике ОбработкаПолученияПредставления.
//
// Возвращаемое значение:
//  Строка - Строка представления документа.
//
Функция ПредставлениеРасчетКурсовыхРазницВалютеПредставления(ПредставлениеСсылки = Истина) Экспорт
```

Пример вызова
```bsl
Результат = МеждународнаяОтчетностьВызовСервера.ПредставлениеРасчетКурсовыхРазницВалютеПредставления(ПредставлениеСсылки);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
