---
title: Международная отчетность клиент сервер
slug: erp-uh/международная-отчетность-клиент-сервер
---


## СкрыватьНастройкиПриФормированииОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Скрывает видимость элементов формы, связанных с настройками отчета.
//
// Параметры:
//	Форма - ФормаКлиентскогоПриложения -
//	ДополнительныеПараметры - Структура, Неопределено - Структура, содержащая ключи:
//		* СкрыватьНастройкиПриФормированииОтчета - Булево - Признак необходимости скрытия настроек.
//		* ИмяГруппаПанельНастроек - Строка - Имя панели с настройками на форме.
//		* ИмяКнопкаПанельНастроек - Строка - Имя кнопки вызова панели настроек (опционально).
//
Процедура СкрыватьНастройкиПриФормированииОтчета(Форма, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
МеждународнаяОтчетностьКлиентСервер.СкрыватьНастройкиПриФормированииОтчета(Форма, ДополнительныеПараметры);
```
</details>

## ПоместитьЭлементВХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает данные переданного элемента вида отчета во временное хранилище формы.
//
// Параметры:
//  Элемент - см. ФинансоваяОтчетностьКлиентСервер.СтруктураЭлементаОтчета
//  АдресХранилища - УникальныйИдентификатор - УИД формы вида отчета
//  ОчиститьСсылки - Булево - Если истина тогда ссылка элемента справочника и ссылка владельца отчета будут очищены.
//                            При записи такого элемента отчета будет сформирована новая ссылка т.о. помещаемый элемент
//                            будет скопирован.
//
// Возвращаемое значение:
//   Строка - Адрес в хранилище
//
Функция ПоместитьЭлементВХранилище(Элемент, АдресХранилища = Неопределено, ОчиститьСсылки = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = МеждународнаяОтчетностьКлиентСервер.ПоместитьЭлементВХранилище(Элемент, АдресХранилища, ОчиститьСсылки);
```
</details>

## ПоместитьКопиюЭлементаВХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает данные переданного элемента вида отчета во временное хранилище формы без ссылки элемента справочника.
// При записи такого элемента отчета будет сформирована новая ссылка т.о. помещаемый элемент будет скопирован.
//
// Параметры:
//  Элемент - см. ФинансоваяОтчетностьКлиентСервер.СтруктураЭлементаОтчета
//  АдресХранилища - УникальныйИдентификатор - УИД формы вида отчета.
//
// Возвращаемое значение:
//   Строка - Адрес в хранилище
//
Функция ПоместитьКопиюЭлементаВХранилище(Элемент, АдресХранилища = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = МеждународнаяОтчетностьКлиентСервер.ПоместитьКопиюЭлементаВХранилище(Элемент, АдресХранилища);
```
</details>

## НовыеДанныеЗаполненияСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает структуру параметров для процедуры ЗаполнитьСтрокуДерева
//
// Параметры:
//  ДополнительныеРеквизитыСтроки - Строка - могут быть переданы дополнительные реквизиты строки дерева.
//
// Возвращаемое значение:
//  Структура - параметры для заполнения новой строки дерева значений элементов отчета:
//   *Источник - Структура -
//   *СтрокаПриемник - ДанныеФормыЭлементДерева, ДанныеФормыЭлементКоллекции -
//   *АдресЭлементаВХранилище - Строка -
//   *Поле - ДанныеФормыКоллекция -
//
Функция НовыеДанныеЗаполненияСтроки(ДополнительныеРеквизитыСтроки = "") Экспорт
```

Пример вызова
```bsl
Результат = МеждународнаяОтчетностьКлиентСервер.НовыеДанныеЗаполненияСтроки(ДополнительныеРеквизитыСтроки);
```
</details>

## НовыеПараметрыДереваЭлементов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует стандартную структуру параметров для получения дерева элементов отчета
//
// Возвращаемое значение:
//  Структура - Параметры:
//  	* ИмяЭлементаДерева - Строка - Имя элемента дерева элементов
//  	* РежимРаботы - ПеречислениеСсылка.РежимыОтображенияДереваНовыхЭлементов -
//  	* БыстрыйПоиск - Строка -
//  	* ФильтрПоВидуОтчета - СправочникСсылка.ВидыФинансовыхОтчетов -
//  	* ТекущийВидОтчета - СправочникСсылка.ВидыФинансовыхОтчетов -
//  	* ПланыСчетов - Массив Из СправочникСсылка.ПланыСчетовМеждународногоУчета -
//  	              - Массив Из СправочникСсылка.ИдентификаторыОбъектовМетаданных -
//
Функция НовыеПараметрыДереваЭлементов() Экспорт
```

Пример вызова
```bsl
Результат = МеждународнаяОтчетностьКлиентСервер.НовыеПараметрыДереваЭлементов() 
```
</details>

## НовыеПараметрыФормированияОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует стандартную структуру параметров формирования финансовой отчетности
//
// Возвращаемое значение:
//  Структура - поля параметров для формирования финансовой отчетности.
//
Функция НовыеПараметрыФормированияОтчета() Экспорт
```

Пример вызова
```bsl
Результат = МеждународнаяОтчетностьКлиентСервер.НовыеПараметрыФормированияОтчета() 
```
</details>

## НовыеДанныеОперанда
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует стандартную структуру одиночного элемента финансового отчета
//
// Возвращаемое значение:
//  Структура - поля одиночного элемента финансового отчета.
//
Функция НовыеДанныеОперанда() Экспорт
```

Пример вызова
```bsl
Результат = МеждународнаяОтчетностьКлиентСервер.НовыеДанныеОперанда() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
