---
title: Международный учет внеоборотные активы
slug: erp-uh/международный-учет-внеоборотные-активы
---


## ПроверитьВозможностьСменыСостоянияНМА
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку возможности смены статуса для переданных в качестве параметра активов.
//
// Параметры:
// 		ОбъектДокумента - ДокументСсылка.ПринятиеКУчетуНМАМеждународныйУчет, ДокументСсылка.СписаниеНМАМеждународныйУчет - Объект документа, который меняет состояние актива
// 		ВнеоборотныеАктивы - Массив, СправочникСсылка.НематериальныеАктивы - Внеоборотные активы для проверки
// 		НовоеСостояние - Перечисление.СостоянияНМА - Значение нового состояния актива
// 		Отказ - Булево - возвращаемый параметр.
//
Процедура ПроверитьВозможностьСменыСостоянияНМА(ОбъектДокумента, ВнеоборотныеАктивы, НовоеСостояние, Отказ=Ложь) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетВнеоборотныеАктивы.ПроверитьВозможностьСменыСостоянияНМА(ОбъектДокумента, ВнеоборотныеАктивы, НовоеСостояние, Отказ);
```
</details>

## ПроверитьВозможностьСменыСостоянияОС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку возможности смены статуса для переданных в качестве параметра активов.
//
// Параметры:
// 		ОбъектДокумента - ДокументСсылка.ПринятиеКУчетуОСМеждународныйУчет, ДокументСсылка.СписаниеОСМеждународныйУчет - Объект документа, который меняет состояние актива
// 		ВнеоборотныеАктивы - Массив, СправочникСсылка.ОбъектыЭксплуатации - Внеоборотные активы для проверки
// 		НовоеСостояние - Перечисление.СостоянияОС - Значение нового состояния актива
// 		Отказ - Булево - возвращаемый параметр.
//
Процедура ПроверитьВозможностьСменыСостоянияОС(ОбъектДокумента, ВнеоборотныеАктивы, НовоеСостояние, Отказ=Ложь) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетВнеоборотныеАктивы.ПроверитьВозможностьСменыСостоянияОС(ОбъектДокумента, ВнеоборотныеАктивы, НовоеСостояние, Отказ);
```
</details>

## ПроверитьСостояниеВнеоборотныхАктивов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку принадлежности объекта внеоборотного актива условиям требуемого состояния.
//
// Параметры:
// 		ВнеоборотныеАктивы - Массив из СправочникСсылка.НематериальныеАктивы, СправочникСсылка.ОбъектыЭксплуатации, СправочникСсылка.НематериальныеАктивы, СправочникСсылка.ОбъектыЭксплуатации - Внеоборотные активы для проверки
// 		ТребуемоеСостояние - Структура - Структура описания требуемого состояния:
// 			*Организация - Массив из СправочникСсылка.Организации, СправочникСсылка.Организации - (необязательно) Список организаций, которым может принадлежать актив
// 			*Подразделение - Массив из СправочникСсылка.СтруктураПредприятия, СправочникСсылка.СтруктураПредприятия - (необязательно) Список подразделений, которым может принадлежать актив
// 			*Состояние - Массив из ПеречислениеСсылка.СостоянияНМА, ПеречислениеСсылка.СостоянияОС - (необязательно) Список состояний, которым может принадлежать актив
// 			*ВидАктива - Массив из ПеречислениеСсылка.ВидыВнеоборотныхАктивов - (необязательно) Список видов актива, которым может принадлежать актив
// 		ПараметрыПроверки - Неопределено, Структура - Структура параметров проверки:
// 			*ДатаСведений - Дата - (необязательно) Дата получения сведений об активе
// 			*ИсключаемыйРегистратор - ДокументСсылка - (необязательно) Ссылка на документ, исключаемый из выборки при получении состояния активов.
//
// Возвращаемое значение:
// 		Соответствие Из КлючИЗначение - Соответствие объектов учета, не удовлетворяющих условиям заданного требуемого состояния:
// 			*Ключ - СправочникСсылка.НематериальныеАктивы, СправочникСсылка.ОбъектыЭксплуатации - объект проверки
// 			*Значение - Структура - Структура с полями описания текущего состояния объекта:
// 				** Организация - СправочникСсылка.Организации
// 				** Подразделение - СправочникСсылка.СтруктураПредприятия
//
Функция ПроверитьСостояниеВнеоборотныхАктивов(ВнеоборотныеАктивы, ТребуемоеСостояние, ПараметрыПроверки=Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = МеждународныйУчетВнеоборотныеАктивы.ПроверитьСостояниеВнеоборотныхАктивов(ВнеоборотныеАктивы, ТребуемоеСостояние, ПараметрыПроверки);
```
</details>

## ОрганизацияВКоторойОСПринятоКУчету
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет в какой организации ОС принято к учету.
//
// Параметры:
//  ОсновноеСредство - СправочникСсылка.ОбъектыЭксплуатации - ОС, для которого нужно проверить принятие к учету.
//
// Возвращаемое значение:
//  СправочникСсылка.Организации - организация, в которой данное ОС принято к учету.
//
Функция ОрганизацияВКоторойОСПринятоКУчету(ОсновноеСредство) Экспорт
```

Пример вызова
```bsl
Результат = МеждународныйУчетВнеоборотныеАктивы.ОрганизацияВКоторойОСПринятоКУчету(ОсновноеСредство) 
```
</details>

## ОрганизацияВКоторойНМАПринятКУчету
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет в какой организации НМА принят к учету.
//
// Параметры:
//  НематериальныйАктив - СправочникСсылка.НематериальныеАктивы - НМА, для которого нужно проверить принятие к учету.
//
// Возвращаемое значение:
//  СправочникСсылка.Организации - организация, в которой НМА принят к учету.
//
Функция ОрганизацияВКоторойНМАПринятКУчету(НематериальныйАктив) Экспорт
```

Пример вызова
```bsl
Результат = МеждународныйУчетВнеоборотныеАктивы.ОрганизацияВКоторойНМАПринятКУчету(НематериальныйАктив) 
```
</details>

## АмортизационныеРасходыПоНМА
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу с данными об амортизации к начислению и настройках отражения в заданном периоде.
//
// Параметры:
// 		Дата - Дата - Дата периода начисления амортизации
// 		Организация - СправочникСсылк.Организации - Организация, в которой приняты к учету объекты внеоборотных активов
// 		Объекты - Массив, СправочникСсылка.НематериальныеАктивы - Массив ссылок на объект или ссылка на объект для начисления амортизации.
//
// Возвращаемое значение:
// 		ТаблицаЗначений - Таблица в формате, который описан в процедуре МеждународныйУчетВнеоборотныеАктивы.ТаблицаАмортизационныхРасходов.
//
Функция АмортизационныеРасходыПоНМА(Знач Дата, Знач Организация, Знач Объекты=Неопределено, ТаблицаПараметровРасчетаАмортизации = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = МеждународныйУчетВнеоборотныеАктивы.АмортизационныеРасходыПоНМА(Дата, Организация, Объекты, ТаблицаПараметровРасчетаАмортизации);
```
</details>

## АмортизационныеРасходыПоОС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу с данными об амортизации к начислению и настройках отражения в заданном периоде.
//
// Параметры:
// 		Дата - Дата - Дата периода начисления амортизации
// 		Организация - СправочникСсылк.Организации - Организация, в которой приняты к учету объекты внеоборотных активов
// 		Объекты - Массив, СправочникСсылка.ОбъектыЭксплуатации - Массив ссылок на объект или ссылка на объект для начисления амортизации.
//
// Возвращаемое значение:
// 		ТаблицаЗначений - Таблица в формате, который описан в процедуре МеждународныйУчетВнеоборотныеАктивы.ТаблицаАмортизационныхРасходов.
//
Функция АмортизационныеРасходыПоОС(Знач Дата, Знач Организация, Знач Объекты=Неопределено, ТаблицаПараметровРасчетаАмортизации = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = МеждународныйУчетВнеоборотныеАктивы.АмортизационныеРасходыПоОС(Дата, Организация, Объекты, ТаблицаПараметровРасчетаАмортизации);
```
</details>

## ТаблицаАмортизационныхРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает пустую таблицу для данных о начисленной амортизации
//
// Возвращаемое значение:
// 		ТаблицаЗначений - Таблица для данных о начисленной амортизации.
//
Функция ТаблицаАмортизационныхРасходов() Экспорт
```

Пример вызова
```bsl
Результат = МеждународныйУчетВнеоборотныеАктивы.ТаблицаАмортизационныхРасходов() 
```
</details>

## ПустаяТаблицаПараметровРасчетаАмортизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПустаяТаблицаПараметровРасчетаАмортизации() Экспорт
```

Пример вызова
```bsl
Результат = МеждународныйУчетВнеоборотныеАктивы.ПустаяТаблицаПараметровРасчетаАмортизации() 
```
</details>

## ОшибкиЗаполненияШаблоновПроводокАмортизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку и возвращает массив ошибок заполнения шаблонов проводок по амортизации внеоборотных активов.
//
// Параметры:
// 		Дата - Дата - Дата документа, с которой сравнивается период действия настройки
// 		Организация - СправочникСсылка.Организации - Организация
// 		СтатьиРасходов - Массив - Массив элементов типа <ПланВидовХарактеристикСсылка.СтатьиРасходов>.
//
// Возвращаемое значение:
// 		Структура - Структура списка ошибок создаваемая при первом вызове ОбщегоНазначенияКлиентСервер.ДобавитьОшибкуПользователю.
//
Функция ОшибкиЗаполненияШаблоновПроводокАмортизации(Дата, Организация, СтатьиРасходов) Экспорт
```

Пример вызова
```bsl
Результат = МеждународныйУчетВнеоборотныеАктивы.ОшибкиЗаполненияШаблоновПроводокАмортизации(Дата, Организация, СтатьиРасходов) 
```
</details>

## ИнициализироватьПараметрыЗапросаПриОтраженииАмортизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует параметры запроса данных проведения при отражении начисленной амортизации.
//
// Параметры:
// 		Запрос - Запрос - Объект запроса к данным.
//
Процедура ИнициализироватьПараметрыЗапросаПриОтраженииАмортизации(Запрос) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетВнеоборотныеАктивы.ИнициализироватьПараметрыЗапросаПриОтраженииАмортизации(Запрос) 
```
</details>

## ОтражениеДокументовВМеждународномУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет текст запроса движений по регистру отражения документов в международном учете.
//
// Параметры:
// 		ТекстыЗапроса - СписокЗначений - Список текстов запроса
// 		Регистры - Строка, Структура, Неопределено - список регистров, разделенных запятой, или структура, в ключах которой - имена регистров требующихся к заполнению.
//
Процедура ОтражениеДокументовВМеждународномУчете(ТекстыЗапроса, Регистры) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетВнеоборотныеАктивы.ОтражениеДокументовВМеждународномУчете(ТекстыЗапроса, Регистры) 
```
</details>

## ПрочиеРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет текст запроса движений по прочим расходам
//
// Параметры:
// 		ТекстыЗапроса - СписокЗначений - Список текстов запроса
// 		Регистры - Строка, Структура, Неопределено - список регистров, разделенных запятой, или структура, в ключах которой - имена регистров требующихся к заполнению
// 		ДополнительныйТекстЗапроса - Строка - Текст запроса для включение в объединение с основным.
//
Процедура ПрочиеРасходы(ТекстыЗапроса, Регистры, ДополнительныйТекстЗапроса=Неопределено) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетВнеоборотныеАктивы.ПрочиеРасходы(ТекстыЗапроса, Регистры, ДополнительныйТекстЗапроса);
```
</details>

## ПартииПрочихРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет текст запроса движений по партиям прочих расходов
//
// Параметры:
// 		ТекстыЗапроса - СписокЗначений - Список текстов запроса
// 		Регистры - Строка, Структура, Неопределено - список регистров, разделенных запятой, или структура, в ключах которой - имена регистров требующихся к заполнению
// 		ДополнительныйТекстЗапроса - Строка - Текст запроса для включение в объединение с основным.
//
Процедура ПартииПрочихРасходов(ТекстыЗапроса, Регистры, ДополнительныйТекстЗапроса=Неопределено) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетВнеоборотныеАктивы.ПартииПрочихРасходов(ТекстыЗапроса, Регистры, ДополнительныйТекстЗапроса);
```
</details>

## ПрочиеАктивыПассивы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Текст запроса таблицы движений прочих активов/пассивов при проведении документа начисления амортизации.
//
// Параметры:
// 		ТекстыЗапроса - СписокЗначений - Список текстов запроса
// 		Регистры - Строка, Структура, Неопределено - список регистров, разделенных запятой, или структура, в ключах которой - имена регистров требующихся к заполнению
// 		ДополнительныйТекстЗапроса - Строка - Текст запроса для включение в объединение с основным.
//
Процедура ПрочиеАктивыПассивы(ТекстыЗапроса, Регистры, ДополнительныйТекстЗапроса=Неопределено) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетВнеоборотныеАктивы.ПрочиеАктивыПассивы(ТекстыЗапроса, Регистры, ДополнительныйТекстЗапроса);
```
</details>

## Международный
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет текст запроса проводок амортизации в регистре международного учета
//
// Параметры:
// 		ТекстыЗапроса - СписокЗначений - Список текстов запроса
// 		Регистры - Строка, Структура, Неопределено - список регистров, разделенных запятой, или структура, в ключах которой - имена регистров требующихся к заполнению
// 		ДополнительныйТекстЗапроса - Строка - Текст запроса для включение в объединение с основным.
//
Процедура Международный(ТекстыЗапроса, Регистры, ДополнительныйТекстЗапроса=Неопределено) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетВнеоборотныеАктивы.Международный(ТекстыЗапроса, Регистры, ДополнительныйТекстЗапроса);
```
</details>

## ТекстЗапросаТаблицаВтИсходныеПрочиеРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ТекстЗапросаТаблицаВтИсходныеПрочиеРасходы(ТекстыЗапроса, ДополнительныйТекстЗапроса) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетВнеоборотныеАктивы.ТекстЗапросаТаблицаВтИсходныеПрочиеРасходы(ТекстыЗапроса, ДополнительныйТекстЗапроса));
```
</details>

## ТекстЗапросаТаблицаВтПрочиеРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекстЗапросаТаблицаВтПрочиеРасходы(ТекстыЗапроса, ДополнительныйТекстЗапроса) Экспорт
```

Пример вызова
```bsl
Результат = МеждународныйУчетВнеоборотныеАктивы.ТекстЗапросаТаблицаВтПрочиеРасходы(ТекстыЗапроса, ДополнительныйТекстЗапроса));
```
</details>

## ТекстЗапросаТаблицаВтИсходныеПартииПрочихРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ТекстЗапросаТаблицаВтИсходныеПартииПрочихРасходов(ТекстыЗапроса, ДополнительныйТекстЗапроса) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетВнеоборотныеАктивы.ТекстЗапросаТаблицаВтИсходныеПартииПрочихРасходов(ТекстыЗапроса, ДополнительныйТекстЗапроса));
```
</details>

## ТекстЗапросаТаблицаВтПартииПрочихРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекстЗапросаТаблицаВтПартииПрочихРасходов(ТекстыЗапроса, ДополнительныйТекстЗапроса) Экспорт
```

Пример вызова
```bsl
Результат = МеждународныйУчетВнеоборотныеАктивы.ТекстЗапросаТаблицаВтПартииПрочихРасходов(ТекстыЗапроса, ДополнительныйТекстЗапроса));
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
