---
title: Международный учет проведение сервер
slug: erp-uh/международный-учет-проведение-сервер
---


## ВернутьДокументыКОтражению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает документы к отражению в международном учете для заданных периодов отражения
//
// Параметры:
// 	ДокументыКОтражению -   ТаблицаЗначений,
// 							МенеджерВременныхТаблиц - Таблица документов, которые надо вернуть к отражению,
// 													  или менеджер временных таблиц имеющий таблицу ДокументыКОтражению
// 													  Таблица должна иметь колонки Документ, Организация, ДатаОтражения.
//
Процедура ВернутьДокументыКОтражению(ДокументыКОтражению) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетПроведениеСервер.ВернутьДокументыКОтражению(ДокументыКОтражению) 
```
</details>

## ЗарегистрироватьКОтражению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует движения по регистру ОтражениеДокументовВМеждународномУчете, выполняет очистку неактуальных записей в Международный.
// Для документов отражаемых в международном учете по данным оборотных регистров и регл. учета.
//
// Параметры:
//  Объект - ДокументОбъект, Структура - документ регистрируемый к отражению.
//  ДополнительныеСвойства - Структура - дополнительные свойства документа инициализированные при проведении документа.
//  Движения - КоллекцияДвижений - наборы записей регистров записываемые документом.
//                                 На момент вызова метода все наборы должны быть записаны.
//  Отказ - Булево - признак отказа в проведении.
//
Процедура ЗарегистрироватьКОтражению(Объект, ДополнительныеСвойства, Движения, Отказ = Ложь) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетПроведениеСервер.ЗарегистрироватьКОтражению(Объект, ДополнительныеСвойства, Движения, Отказ);
```
</details>

## ЗарегистрироватьДокументыРасчетовСПартнерамиКОтражениюВМеждународномУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует документы расчетов с партнерами к отражению в международном учете.
//
// Параметры:
//	ТаблицаРасчетов - ТаблицаЗначений - Таблица изменений по расчетам с партнерами:
//	                      * Регистратор - ДокументСсылка - Документ-регистратор движений
//	                      * Период - Дата - Период движений
//	                      * АналитикаУчетаПоПартнерам - СправочникСсылка.КлючиАналитикиУчетаПоПартнерам - Аналитика учета.
//
Процедура ЗарегистрироватьДокументыРасчетовСПартнерамиКОтражениюВМеждународномУчете(ТаблицаРасчетов) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетПроведениеСервер.ЗарегистрироватьДокументыРасчетовСПартнерамиКОтражениюВМеждународномУчете(ТаблицаРасчетов) 
```
</details>

## ВернутьДокументыКОтражениюВыборочноПакетно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает движения по регистру ОтражениеДокументаВМеждународномУчете, выполняет очистку неактуальных записей в Международный.
// Вызывается из оффлайновых общих модулей НДС.
//
// Параметры:
// 	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - менеджер временных таблиц, имеющий таблицы
// 		ТаблицаТекущейРегистрации и ТаблицаВыборочнойРегистрации.
// 		Таблицы должны иметь колонки Документ, Организация, ДатаОтражения.
// 	КоличествоОбработанных - Число - Параметр, в котором необходимо вернуть количество возвращенных к отражению документов.
//
Процедура ВернутьДокументыКОтражениюВыборочноПакетно(МенеджерВременныхТаблиц, КоличествоОбработанных = Неопределено) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетПроведениеСервер.ВернутьДокументыКОтражениюВыборочноПакетно(МенеджерВременныхТаблиц, КоличествоОбработанных);
```
</details>

## ПараметрыОтраженияВМеждународномУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры отражения в международном учете
//
// Возвращаемое значение:
// 	Структура - Параметры отражения:
// 		* Документы - ДокументСсылка, Массив Из ДокументСсылка - Отбор по конкретным документам, Если Неопределено, то все.
// 		* Организации - СправочникСсылка.Организации, Массив Из СправочникСсылка.Организации - Отбор по организациям. Если Неопределено, то все.
// 		* ДатаОкончания - Дата - Отбор документов к отражению по дате. По умолчанию все документы.
// 		* ЗаписыватьПроводки - Булево - Записывать проводки, получившиеся в результате отражения.
// 		* ВыполнитьПересчеты - Булево - Выполнять офлайновые операции перед формированием проводок.
// 		* ПроверятьСтатусОтражения - Булево - Выполнять отражение для документов с определенными значениями статуса в регистре ОтражениеДокументовВМеждународномУчете.
// 		* ПланыСчетовСКорреспонденцией - Массив из СправочникСсылка.ПланыСчетовМеждународногоУчета - Планы счетов с поддержкой корреспонденции
// 		* ПланыСчетовБезКорреспонденции - Массив из СправочникСсылка.ПланыСчетовМеждународногоУчета - Планы счетов без поддержки корреспонденции
// 		* ПрогнозныеПараметры - см. ПрогнозныеПараметрыОтраженияВМеждународномУчете.
// 		* ПроводокДляПереходаВФон - Число - Количество формируемых проводок, начиная с которого отражение выполняется в фоновом задании при интерактивном запуске.
// 		* МинимальныйРазмерПорции - Число - Количество формируемых проводок, начиная с которого отражение выполняется в несколько потоков, если возможно.
// 		* КоличествоПотоков - Число - Количество сеансов отражения документов, выполняющихся одновременно.
// 		* КоличествоПопыток - Число - Количество попыток обработки одной порции документов.
// 		* ИспользованиеТекущихИтогов - Булево - Сохраняет состояние использования текущих итогов в регистрах бухгалтерии перед отражением в многопоточном режиме.
// 		* МаксимальныйПериодИтогов - Дата - Сохраняет максимальный хранимый период итогов в регистрах бухгалтерии перед отражением в многопоточном режиме.
// 		* МинимальныйПериодИтогов - Дата - Сохраняет минимальный хранимый период итогов в регистрах бухгалтерии перед отражением в многопоточном режиме.
// 		* ВосстановитьСостояниеИтогов - Булево - Сохраняет необходимость восстановления состояния итогов регистров бухгалтерии после отражения в многопоточном режиме.
//
Функция ПараметрыОтраженияВМеждународномУчете() Экспорт
```

Пример вызова
```bsl
Результат = МеждународныйУчетПроведениеСервер.ПараметрыОтраженияВМеждународномУчете() 
```
</details>

## ОтразитьВМеждународномУчетеРегламентнымЗаданием
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик вызываемый регламентным заданием ОтражениеДокументовВМеждународномУчете.
//
Процедура ОтразитьВМеждународномУчетеРегламентнымЗаданием() Экспорт
```

Пример вызова
```bsl
МеждународныйУчетПроведениеСервер.ОтразитьВМеждународномУчетеРегламентнымЗаданием() 
```
</details>

## НачатьОтражениеВМеждународномУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Начинает отражение документов в международном учете в длительной операции.
//
// Параметры:
//	ПараметрыОтраженияВМеждународномУчете - См. ПараметрыОтраженияВМеждународномУчете
//	ИдентификаторФормы - УникальныйИдентификатор - Идентификатор формы, из которой запущено отражение документов в учете
//
// Возвращаемое значение:
//	См. ДлительныеОперации.ВыполнитьФункцию
//
Функция НачатьОтражениеВМеждународномУчете(ПараметрыОтраженияВМеждународномУчете, ИдентификаторФормы) Экспорт
```

Пример вызова
```bsl
Результат = МеждународныйУчетПроведениеСервер.НачатьОтражениеВМеждународномУчете(ПараметрыОтраженияВМеждународномУчете, ИдентификаторФормы) 
```
</details>

## ОтразитьВМеждународномУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет отражение документов в международном учете.
//
// Параметры:
//	ПараметрыОтраженияВМеждународномУчете - см. ПараметрыОтраженияВМеждународномУчете
//	НомерИтерации - Число - Текущий номер повтора выполнения
//
// Возвращаемое значение:
//	см. ТаблицаПроводок
//
Функция ОтразитьВМеждународномУчете(ПараметрыОтраженияВМеждународномУчете, Знач НомерИтерации = 0) Экспорт
```

Пример вызова
```bsl
Результат = МеждународныйУчетПроведениеСервер.ОтразитьВМеждународномУчете(ПараметрыОтраженияВМеждународномУчете, НомерИтерации);
```
</details>

## ЗаписываемыеПроводки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// По передаваемой в качестве параметра таблице проводок, возвращает таблицу проводок, удовлетворяющих условиям записи.
//
// Параметры:
//	ПроводкиДокумента - см. ТаблицаПроводок
//	ПланСчетов - СправочникСсылка.ПланыСчетовМеждународногоУчета, Массив из СправочникСсылка.ПланыСчетовМеждународногоУчета - отбор по плану счетов
//	ОтбиратьПоПлануСчетов - Булево - необходимость выполнения отбора по плану счетов
//
// Возвращаемое значение:
//	 см. ТаблицаПроводок
//
Функция ЗаписываемыеПроводки(ПроводкиДокумента, ПланСчетов, Знач ОтбиратьПоПлануСчетов = Истина) Экспорт
```

Пример вызова
```bsl
Результат = МеждународныйУчетПроведениеСервер.ЗаписываемыеПроводки(ПроводкиДокумента, ПланСчетов, ОтбиратьПоПлануСчетов);
```
</details>

## ОбновитьСтатусОтраженияДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет равенство идентификаторов статусов отражения, считанных в момент начала формирования проводок
// и перед записью сформированных проводок. При совпадении идентификаторов обновляет статус отражения
// документа в международном учете и комментарий на основе статусов сформированных проводок.
//
// Параметры:
//	Документ - ДокументСсылка - ссылка на документ.
//	Измерения - ТаблицаЗначений - Таблица измерений, по которым нужно обновить статус отражения. Колонки таблицы:
//			* ПланСчетов - СправочникСсылка.ПланыСчетовМеждународногоУчета - План счетов для обновления статуса
//			* Организация - СправочникСсылка.Организации - Организация для обновления статуса
//			* ДатаОтражения - Дата - Дата отражения, накоторую нужно обновить статус
//			* ИдентификаторСтатуса - УникальныйИдентификатор - Значение идентификатора, считанное в момент начала формирования проводок
//	ПроводкиДокумента - ТаблицаЗначений - Таблица проводок документа, на основании которой обновляется статус. Колонки таблицы:
//			* Период - Дата - Период проводки
//			* ПланСчетов - СправочникСсылка.ПланыСчетовМеждународногоУчета - План счетов для отметки статуса
//			* Организация - СправочникСсылка.Организации - Организация для отметки статуса
//			* Статус - ПеречислениеСсылка.СтатусыОтраженияВМеждународномУчете - Статус отражения
//			* Комментарий - Строка - Комментарий к статусу отражения
//	ВозвращатьКОтражениюДокументСторно - Булево - Возвращать к отражению сторнирующий документ.
//
// Возвращаемое значение:
//	Булево - Истина если идентификаторы статусов отражения не изменились с момента начала формирования проводок
//		и новые значения статусов записаны в регистр сведений ОтражениеДокументовВМеждународномУчете
//
Функция ОбновитьСтатусОтраженияДокумента(Документ, Измерения, ПроводкиДокумента) Экспорт
```

Пример вызова
```bsl
Результат = МеждународныйУчетПроведениеСервер.ОбновитьСтатусОтраженияДокумента(Документ, Измерения, ПроводкиДокумента) 
```
</details>

## ЗаписатьНовыйСтатусОтражения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает новый статус отражения в учете.
//
// Параметры:
//  МассивДокументов - Массив из ДокументСсылка - Массив документов.
//  НовыйСтатусОтражения - ПеречислениеСсылка.СтатусыОтраженияВМеждународномУчете - Новый статус отражения.
//  СтарыеСтатусыОтражения - Массив из ПеречислениеСсылка.СтатусыОтраженияВМеждународномУчете - Старые статусы отражения.
Процедура ЗаписатьНовыйСтатусОтражения(МассивДокументов, НовыйСтатусОтражения, СтарыеСтатусыОтражения) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетПроведениеСервер.ЗаписатьНовыйСтатусОтражения(МассивДокументов, НовыйСтатусОтражения, СтарыеСтатусыОтражения) 
```
</details>

## ОтменитьОтражениеДокументовВУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отменяет отражение документов в учете.
//
// Параметры:
//  МассивДокументов - Массив из ДокументСсылка - Массив документов.
Процедура ОтменитьОтражениеДокументовВУчете(МассивДокументов) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетПроведениеСервер.ОтменитьОтражениеДокументовВУчете(МассивДокументов) 
```
</details>

## ВернутьКОтражениюДокументыСторно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает к отражению сторнирующие документы при изменении проводок сторнируемых документов.
//
// Параметры:
//  ПараметрыФормированияПроводок - см. ПараметрыФормированияПроводок
//  Документы - ДокументСсылка, Массив из ДокументСсылка - сторнируемые документы, у которых изменились проводки.
Процедура ВернутьКОтражениюДокументыСторно(ПараметрыФормированияПроводок = Неопределено, Документы = Неопределено) Экспорт
```

Пример вызова
```bsl
МеждународныйУчетПроведениеСервер.ВернутьКОтражениюДокументыСторно(ПараметрыФормированияПроводок, Документы);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
