---
title: Многооборотная тара сервер
slug: erp-uh/многооборотная-тара-сервер
---


## ЗаполнитьМногооборотнуюТаруИзХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет в документе подобранную обработкой многооборотную тару
//
// Параметры:
// Объект - ДокументОбъект            - Документ, в котором необходимо заполнить многооборотную тару.
// АдресТарыВХранилище                - Строка - Адрес таблицы многооборотной тары во временном хранилище.
// ИмяТаблицы                         - Строка - Имя таблицы документа, в которой необходимо заполнить многооборотную тару.
// ИменаКолонок                       - Строка - Имена колонок таблицы, по которым необходимо осуществлять поиск строк.
//                                              "Номенклатура, Характеристика, Склад, Дата" (Имена могут меняться в
//                                              зависимости от документа).
// СтруктураДействийИзмененныеСтроки  - Структура - Действия с измененными строками.
// СтруктураДействийДобавленныеСтроки - Структура - Действия с добавленными строками.
// КэшированныеЗначения               - см. ОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ЗаполнитьМногооборотнуюТаруИзХранилища(Объект, Экспорт
```

Пример вызова
```bsl
МногооборотнаяТараСервер.ЗаполнитьМногооборотнуюТаруИзХранилища(Объект, );
```
</details>

## РассчитатьДатуВозвратаМногооборотнойТары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает дату возврата многооборотной тары по условиям соглашения
//
// Параметры:
//  Объект                                   - ДокументОбъект - Документ, для которого считается срок возврата тары
//  СрокВозвратаМногооборотнойТары           - Число - Срок возврата многооборотной тары в днях
//  РассчитыватьДатуВозвратаТарыПоКалендарю  - Булево - Определяет вариант расчета даты: по всем дня или по основному
//                                                      календарю предприятия.
//  Календарь                                - СправочникСсылка.ПроизводственныеКалендари - Определяет календарь
//                                                                                          возврата тары.
//
// Возвращаемое значение:
//  Дата - рассчитанная дата возврата.
//
Функция РассчитатьДатуВозвратаМногооборотнойТары(Знач Объект, Экспорт
```

Пример вызова
```bsl
Результат = МногооборотнаяТараСервер.РассчитатьДатуВозвратаМногооборотнойТары(Объект, );
```
</details>

## ОбновитьСостояниеЗаполненияМногооборотнойТары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сбрасывает состояние заполнения многооборотной тары в документе после изменения табличной части.
//
// Параметры:
// 	СостояниеЗаполненияМногооборотнойТары - ПеречислениеСсылка.СостоянияЗаполненияМногооборотнойТары -
//
Процедура ОбновитьСостояниеЗаполненияМногооборотнойТары(СостояниеЗаполненияМногооборотнойТары) Экспорт
```

Пример вызова
```bsl
МногооборотнаяТараСервер.ОбновитьСостояниеЗаполненияМногооборотнойТары(СостояниеЗаполненияМногооборотнойТары) 
```
</details>

## ОбновитьПризнакБезВозвратнойТары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет связанные с возвратной тарой колонки таблицы
//
// Параметры:
// Товары - ДанныеФормыКоллекция - Таблица документа, в которой необходимо обновить колонки
// ВернутьМногооборотнуюТару - Булево - если Истина, то тара возвратная
// СтруктураДополнительныхДействий - Структура - Дополнительные действия, которые необходимо выполнить.
//
Процедура ОбновитьПризнакБезВозвратнойТары(Товары, ВернутьМногооборотнуюТару, СтруктураДополнительныхДействий = Неопределено) Экспорт
```

Пример вызова
```bsl
МногооборотнаяТараСервер.ОбновитьПризнакБезВозвратнойТары(Товары, ВернутьМногооборотнуюТару, СтруктураДополнительныхДействий);
```
</details>

## ПараметрыПроверкиУказанияМногооборотнойТары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров проверки указания многооборотной тары в документе
//
// Возвращаемое значение:
//  Структура - структура с полями:
//   * ИмяТЧ      - Строка - имя табличной части документа, которую нужно проверить
//   * ЕстьЯчейки - Булево - признак, что в ТЧ есть ячейки.
//
Функция ПараметрыПроверкиУказанияМногооборотнойТары() Экспорт
```

Пример вызова
```bsl
Результат = МногооборотнаяТараСервер.ПараметрыПроверкиУказанияМногооборотнойТары() 
```
</details>

## ПроверитьУказаниеМногооборотнойТары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура проверят, что в табличной части тары указано не меньше, чем упаковок, которые ее требуют.
//
// Параметры:
//		Объект - ДокументОбъект - проверяемый документ
//		ПараметрыПроверкиУказанияМногооборотнойТары - Структура - возвращается функцией ПараметрыПроверкиУказанияМногооборотнойТары
//		Отказ - Булево - результат проверки.
//
Процедура ПроверитьУказаниеМногооборотнойТары(Объект, ПараметрыПроверкиУказанияМногооборотнойТары, Отказ) Экспорт
```

Пример вызова
```bsl
МногооборотнаяТараСервер.ПроверитьУказаниеМногооборотнойТары(Объект, ПараметрыПроверкиУказанияМногооборотнойТары, Отказ) 
```
</details>

## МногооборотнаяТараНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает таблицу многооборотной тары по номенклатуре и упаковке (с учетом иерархии упаковок).
//
// Параметры:
//  Номенклатура - СправочникСсылка.Номенклатура - номенклатура для отбора.
//  Упаковка - СправочникСсылка.УпаковкиЕдиницыИзмерения - упаковка для отбора.
//
//  Возвращаемое значение:
//   ТаблицаЗначений - таблица значений с колонками:
//    * Номенклатура               - СправочникСсылка.Номенклатура - номенклатура тары для переданного товара.
//    * Характеристика             - СправочникСсылка.ХарактеристикиНоменклатуры - характеристика тары для переданного товара.
//    * ХарактеристикиИспользуются - Булево - признак использования характеристик для номенклатура тары.
//    * Количество                 - Число - количество номенклатуры.
//
Функция МногооборотнаяТараНоменклатуры(Номенклатура, Упаковка) Экспорт
```

Пример вызова
```bsl
Результат = МногооборотнаяТараСервер.МногооборотнаяТараНоменклатуры(Номенклатура, Упаковка) 
```
</details>

## ПараметрыУстановкиУсловногоОформленияДляСтрокСМногооборотнойТарой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция-конструктор параметров установки условного оформления строк с многооборотной тарой.
//
// Возвращаемое значение:
// 	Структура - Структура параметров:
//      * Форма - ФормаКлиентскогоПриложения - Содержит данную форму
//      * ЭтоПоступление - Булево - Истина, если это документ поступления
//      * ИмяПоляВводаСтавкиНДС - Строка - Наименование элемента формы, содержащего ставку НДС, если оно отличается от "ТоварыСтавкаНДС"
//      * ИмяПоляВводаЦены - Строка - Наименование элемента формы, содержащего цену, если оно отличается от "ТоварыЦена"
//      * ИмяПоляВводаСуммы - Строка - Наименование элемента формы, содержащего сумму, если оно отличается от "ТоварыСумма"
//      * ПутьКТЧОтбора - Строка - Полный путь к ТЧ, содержащей указанные выше поля, если он отличается от "Объект.Товары.
//
Функция ПараметрыУстановкиУсловногоОформленияДляСтрокСМногооборотнойТарой() Экспорт
```

Пример вызова
```bsl
Результат = МногооборотнаяТараСервер.ПараметрыУстановкиУсловногоОформленияДляСтрокСМногооборотнойТарой() 
```
</details>

## УстановитьУсловноеОформлениеДляСтрокСМногооборотнойТарой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление цены, суммы, ставки НДС строк с многооборотной тарой.
//
// Параметры:
// 	ПараметрыУстановки - см. МногооборотнаяТараСервер.ПараметрыУстановкиУсловногоОформленияДляСтрокСМногооборотнойТарой
//
Процедура УстановитьУсловноеОформлениеДляСтрокСМногооборотнойТарой(ПараметрыУстановки) Экспорт
```

Пример вызова
```bsl
МногооборотнаяТараСервер.УстановитьУсловноеОформлениеДляСтрокСМногооборотнойТарой(ПараметрыУстановки) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
