---
title: Мобильные приложения вызов сервера
slug: erp-uh/мобильные-приложения-вызов-сервера
---


## ПолучитьПриложение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает мобильное приложение, хранимое в ИБ.
//
// Параметры:
//  ИмяПользователя - Строка - имя пользователя, для которого требуется получить приложение.
//  КодМобильногоКомпьютера - Строка - код компьютера, для которого требуется получить приложение.
//  ПараметрыОбменаДанными - Строка - xml-строка, содержащая параметры обмена данными.
//
// Возвращаемое значение:
//  Строка - мобильное приложение в виде кодированной строки.
//
Функция ПолучитьПриложение(ИмяПользователя, КодМобильногоКомпьютера, ПараметрыОбменаДанными = "") Экспорт
```

Пример вызова
```bsl
Результат = МобильныеПриложенияВызовСервера.ПолучитьПриложение(ИмяПользователя, КодМобильногоКомпьютера, ПараметрыОбменаДанными);
```
</details>

## ПолучитьДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные, выбранные из ИБ в соответствии с заданной для пользователя схемой обмена.
//
// Параметры:
//  ИмяПользователя - Строка - имя пользователя мобильного приложения, для которого требуется получить данные ИБ.
//  КодМобильногоКомпьютера - Строка - код мобильного компьютера, для которого запрашиваются данные.
//  НачальнаяИнициализацияИБ - Булево - признак, указывающий на то, что производится начальная инициализация мобильной ИБ.
//  ПараметрыОбменаДанными - Строка - XMl-строка параметров, определенных в мобильном приложении.
//
// Возвращаемое значение:
//  Строка - данные ИБ в виде строки.
//
Функция ПолучитьДанные(ИмяПользователя, КодМобильногоКомпьютера, Знач НачальнаяИнициализацияИБ = Ложь, ПараметрыОбменаДанными = "") Экспорт
```

Пример вызова
```bsl
Результат = МобильныеПриложенияВызовСервера.ПолучитьДанные(ИмяПользователя, КодМобильногоКомпьютера, НачальнаяИнициализацияИБ, ПараметрыОбменаДанными);
```
</details>

## ЗаписатьДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет запись данных, полученных от мобильного приложения, в текущую ИБ.
//
// Параметры:
//  ИмяПользователя - Строка - имя пользователя мобильного приложения, чьи данные необходимо записать.
//  КодМобильногоКомпьютера - Строка - код мобильного компьютера, от которого получены данные.
//  ДанныеМобильногоПриложения - Строка - строка, содержащая сериализованные в XML данные, полученные от мобильного приложения.
//  ПараметрыОбменаДанными - Строка - XMl-строка параметров, определенных в мобильном приложении.
//
Процедура ЗаписатьДанные(ИмяПользователя, КодМобильногоКомпьютера, ДанныеМобильногоПриложения, ПараметрыОбменаДанными = "") Экспорт
```

Пример вызова
```bsl
МобильныеПриложенияВызовСервера.ЗаписатьДанные(ИмяПользователя, КодМобильногоКомпьютера, ДанныеМобильногоПриложения, ПараметрыОбменаДанными);
```
</details>

## ЗарегистрироватьПолучениеДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет отражение в ИБ факта получения данных мобильным клиентом.
//
// Параметры:
//  ИмяПользователя - Строка - имя пользователя мобильного приложения, получение данных которого нужно зарегистрировать.
//  КодМобильногоКомпьютера - Строка - код мобильного компьютера, получение данных от которого нужно зарегистрировать.
//  ПараметрыОбменаДанными - Строка - XMl-строка параметров, определенных в мобильном приложении.
//
Процедура ЗарегистрироватьПолучениеДанных(ИмяПользователя, КодМобильногоКомпьютера, ПараметрыОбменаДанными = "") Экспорт
```

Пример вызова
```bsl
МобильныеПриложенияВызовСервера.ЗарегистрироватьПолучениеДанных(ИмяПользователя, КодМобильногоКомпьютера, ПараметрыОбменаДанными);
```
</details>

## АутентификацияВыполнена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет аутентификацию мобильного пользователя.
//
// Параметры:
//  ИмяПользователя - Строка - имя пользователя мобильного приложения, получение данных которого нужно зарегистрировать.
//  КодМобильногоКомпьютера - Строка - код мобильного компьютера, аутентификация которого выполняется.
//  ПарольПользователя - Строка - пароль мобильного пользователя.
//
// Возвращаемое значение:
//  Булево - результат аутентификации: Истина - аутентификация выполнена, Ложь - аутентификация не выполнена.
//
Функция АутентификацияВыполнена(ИмяПользователя, КодМобильногоКомпьютера, ПарольПользователя) Экспорт
```

Пример вызова
```bsl
Результат = МобильныеПриложенияВызовСервера.АутентификацияВыполнена(ИмяПользователя, КодМобильногоКомпьютера, ПарольПользователя) 
```
</details>

## ПолучитьНастройкиРаботыПользователяСКомпонентойОбменаДанными
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает настройки пользователя.
//
// Возвращаемое значение:
//  Произвольный - настройки пользователя.
//
Функция ПолучитьНастройкиРаботыПользователяСКомпонентойОбменаДанными() Экспорт
```

Пример вызова
```bsl
Результат = МобильныеПриложенияВызовСервера.ПолучитьНастройкиРаботыПользователяСКомпонентойОбменаДанными() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
