---
title: Мониторинг целевых показателей клиент сервер
slug: erp-uh/мониторинг-целевых-показателей-клиент-сервер
---


## СтандартныеНастройки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает стандартные настройки формирования монитора целевых показателей
//
// Возвращаемое значение:
//	Структура - стандартные настройки:
//		* ВариантГруппировкиПоказателей - Строка - "ПоКатегориямЦелей", группировка показателей по категориям целей
//		* КоличествоКолонокМонитораПоказателей - Число - 3 колонки, количество колонок
//		* РазмерДиаграмм - Число - крупный (2), высота примерно равна ширине
//		* ПроизвольныйМасштаб - Число - 100 %, стандартное значение масштабирования
//		* ВариантОтображенияДеталей - Строка - "ПоказыватьТолькоТекущееЗначение" - только текущее значение
//		* ПериодАвтообновления - Число - 15 мин. Число минут, через которые следует автоматически обновлять данные на форме.
//
Функция СтандартныеНастройки() Экспорт
```

Пример вызова
```bsl
Результат = МониторингЦелевыхПоказателейКлиентСервер.СтандартныеНастройки() 
```
</details>

## ПериодПрописью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает названия перечисления Периодичность в разных склонениях
//
// Параметры:
//	ЧислоПериодов - Число - количество периодов, определяет склонение
//	Периодичность - ссылка на значение перечисления "Периодичность".
//
// Возвращаемое значение:
//  Строка - название периода в правильном склонении.
//
Функция ПериодПрописью(ЧислоПериодов, Периодичность) Экспорт
```

Пример вызова
```bsl
Результат = МониторингЦелевыхПоказателейКлиентСервер.ПериодПрописью(ЧислоПериодов, Периодичность) 
```
</details>

## ИнициализацияПараметровСоставаМонитора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру настроек для формирования состава монитора
//
// Возвращаемое значение:
//	Структура - незаполненная структура с требуемыми свойствами:
//		* АдресаДинамическихПараметров - Строка - содержит указание на временные настройки вывода вариантов анализа в монитор целевых показателей.
//		* ВидПоиска - ПеречислениеСсылка.ВидыПоискаСвязанныхПоказателей, Строка - значения зависимые, влияющие, взаимосвязанные, все.
//		* ДемонстрационныйРежим - Булево - указание на необходимость отображения демонстрационных данных вариантов анализа.
//		* ОтборВариантовАнализа - СправочникСсылка.ВариантыАнализаЦелевыхПоказателей, Массив - отбор данных на основании ссылки на вариант анализа.
//		* ОтборЗонаВнимания - Число - параметр устарел, оставлен для совместимости.
//		* ОтборСтатус - Строка - отбор вариантов анализа по их статусу.
//			Принимает значения: "" (без учета состояния), "ЦельДостигнута", "ПриемлемоеСостояние", "НеприемлемоеСостояние", "СостояниеНеОпределено", "РассчитаноСОшибками".
//		* ПериодичностьКонтроля - ПеречислениеСсылка.Периодичность - отбор вариантов анализа по соответствующему реквизиту
//		* ПринудительноОбновитьДанные - Булево - указание на обновление кэша ранее запланированного времени
//		* РежимАнализаВзаимосвязанных - Булево - признак, что производится анализ связанных показателей
//		* СвойстваВариантаАнализа - Структура - свойства:
//			** Ссылка - СправочникСсылка.ВариантыАнализаЦелевыхПоказателей - вариант анализа, для которого будут получаться данные
//			** ПериодАнализа - ХранилищеЗначения - содержит упакованный СтандартныйПериод, описывающий период выборки данных
//		* СтруктураНастроек - см. МониторингЦелевыхПоказателей.ПолучитьНастройкиМонитораЦелевыхПоказателей
//		* УчитыватьВариантыОтображения - Булево - Истина, подготовка данных с учетом отображения в виде таблицы, диаграммы или текста.
//
Функция ИнициализацияПараметровСоставаМонитора() Экспорт
```

Пример вызова
```bsl
Результат = МониторингЦелевыхПоказателейКлиентСервер.ИнициализацияПараметровСоставаМонитора() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
