---
title: Назначения сервер
slug: erp-uh/назначения-сервер
---


## ЗаполнитьТипНазначенияВТаблице
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет поле ТипНазначения в строках таблицы
//
// Параметры:
//  Таблица             - ДанныеФормыКоллекция - обрабатываемая таблица
//  Строки              - Массив из ДанныеФормыЭлементКоллекции - массив обрабатываемых строк
//                      - Неопределено
//  ПараметрыЗаполнения - см. НазначенияКлиентСервер.ПараметрыЗаполнения
//
Процедура ЗаполнитьТипНазначенияВТаблице(Таблица, Строки = Неопределено, ПараметрыЗаполнения = Неопределено) Экспорт
```

Пример вызова
```bsl
НазначенияСервер.ЗаполнитьТипНазначенияВТаблице(Таблица, Строки, ПараметрыЗаполнения);
```
</details>

## ЗаполнитьТипНазначения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет служебный реквизит "ТипНазначения" в строке по данным указанного назначения
//
// Параметры:
//  ТекущаяСтрока        - Структура            - данные обрабатываемой строки.
//  КэшированныеЗначения - Структура            - сохраненные значения параметров, используемых при обработке.
//  ПараметрыЗаполнения  - см. НазначенияКлиентСервер.ПараметрыЗаполнения
//
Процедура ЗаполнитьТипНазначения(ТекущаяСтрока, КэшированныеЗначения, ПараметрыЗаполнения = Неопределено) Экспорт
```

Пример вызова
```bsl
НазначенияСервер.ЗаполнитьТипНазначения(ТекущаяСтрока, КэшированныеЗначения, ПараметрыЗаполнения);
```
</details>

## ПорядокЗаполненияНазначенийВДокументе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор структуры парамтеров встраивания направлений деятельности в документ.
//  Возвращаемое значение:
//   Структура - структура полей:
//    * ИменаТабличныхЧастейДляЗаполненияНазначения - Строка, Неопределено -
//    * ИменаТабличныхЧастейДляОчисткиНекорректныхНазначений - Строка, Неопределено -
//    * УсловияОбработкиСтрок - Соответствие Из Строка -
//    * ЗаполнятьНазначениеВШапке - Булево
//    * ИмяЭлементаФормыОбособленно - Строка, Неопределено -
//    * ИмяГруппыЭлементовКомандыОбособленно - Строка, Неопределено -
//    * ИмяРеквизитаПоЗаказу - Строка, Неопределено -
//    * ВДокументеОпределенаФункцияШаблонНазначения - Булево -
//    * ИменаТаблицЗначенийДляОчисткиНекорректныхНазначений - Строка, Неопределено -
Функция ПорядокЗаполненияНазначенийВДокументе() Экспорт
```

Пример вызова
```bsl
Результат = НазначенияСервер.ПорядокЗаполненияНазначенийВДокументе() 
```
</details>

## УсловияОбработкиНазначенийВСтроках
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция УсловияОбработкиНазначенийВСтроках(ШаблоныУсловий) Экспорт
```

Пример вызова
```bsl
Результат = НазначенияСервер.УсловияОбработкиНазначенийВСтроках(ШаблоныУсловий) 
```
</details>

## СтруктураОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор структуры по умолчанию для использования в функциях ОписаниеФормыДокументаДляЗаполненияРеквизитовСвязанныхСНаправлениемДеятельности
// модулей менеджеров документов.
//
// Возвращаемое значение:
//  Структура - структура с полями:
//   *ОформляетсяПоЗаказу - Булево - признак, что строки табличных частей могут быть оформлены по заказу.
//   *ЭтоИсточникПотребности - Булево - признак, что документ является документом фиксации обособленной потребности (заказом).
//   *ЕстьНазначениеВТЧ - Булево - признак, что в строках табличных частей есть реквизит назначение.
//   *ВТЧНазначениеОтгрузки - Булево - признак, что в строках табличных частей реквизит назначение используется для указания
//                            назначения отгружаемых товаров и работ, а не принимаемых).
//   *ТабЧасти - Структура - описание табличной части документа, используется для переопределения общих параметров, заданных для
//                           всех табличных частей.
//
Функция СтруктураОбъекта() Экспорт
```

Пример вызова
```bsl
Результат = НазначенияСервер.СтруктураОбъекта() 
```
</details>

## ПерезаполнитьСлужебныеРеквизитыТабличнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//  Используется в формах документов. Заполняет реквизит формы "Отгружать обособленно" табличной части исходя из заполненности назначения.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма в которой необходимо инициализировать реквизиты связанные с использованием
//                             направлений деятельности.
//
Процедура ПерезаполнитьСлужебныеРеквизитыТабличнойЧасти(Форма, Устарело = Ложь) Экспорт
```

Пример вызова
```bsl
НазначенияСервер.ПерезаполнитьСлужебныеРеквизитыТабличнойЧасти(Форма, Устарело);
```
</details>

## ТолкающееНазначение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает назначение по направлению деятельности.
//
// Параметры:
//  НаправлениеДеятельности - СправочникСсылка.НаправленияДеятельности - направление деятельности.
//
// Возвращаемое значение:
//  СправочникСсылка.Назначения - назначение, связанное с направлением деятельности.
//
Функция ТолкающееНазначение(НаправлениеДеятельности) Экспорт
```

Пример вызова
```bsl
Результат = НазначенияСервер.ТолкающееНазначение(НаправлениеДеятельности) 
```
</details>

## ПриЧтенииСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Используется в формах документов, в одноименных процедурах "ПриЧтенииСозданииНаСервере".
// Инициализирует реквизиты формы, используемые при интерактивной работе пользователя. Заполняет назначение, исходя из
// направления деятельности.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма в которой необходимо инициализировать реквизиты связанные с использованием
//   направлений деятельности.
//  Устарело - Булево - для совместимости с НаправленияДеятельностиСервер.ПриЧтенииСозданииНаСервере
//
Процедура ПриЧтенииСозданииНаСервере(Форма, Устарело = Ложь) Экспорт
```

Пример вызова
```bsl
НазначенияСервер.ПриЧтенииСозданииНаСервере(Форма, Устарело);
```
</details>

## ПослеЗаписиНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Используется в формах документов, в одноименных процедурах "ПослеЗаписиНаСервере".
// Заполняет реквизит формы "Отгружать обособленно" табличной части исходя из заполненности назначения.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма в которой необходимо инициализировать реквизиты связанные с использованием
//            направлений деятельности.
//  Устарело - Булево - для совместимости с НаправленияДеятельностиСервер.ПриИзмененииНаправленияДеятельности
//
Процедура ПослеЗаписиНаСервере(Форма, Устарело) Экспорт
```

Пример вызова
```bsl
НазначенияСервер.ПослеЗаписиНаСервере(Форма, Устарело) 
```
</details>

## ПриИзмененииШаблонаНазначенияВДокументе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет назначение по умолчанию в документе, в соответствии с изенениями шаблона,
// произошедшего в результате редактирования реквизитов документа.
// Проверяет назначения в табличной части и заполняет их в соотвествии с изменившимся шаблоном.
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа
//  Устарело - Булево - для совместимости с НаправленияДеятельностиСервер.ПриИзмененииНаправленияДеятельности
// Возвращаемое значение:
//  Массив Из ДанныеФормыЭлементКоллекции - массив измененных строк табличной части документа.
//
Функция ПриИзмененииШаблонаНазначенияВДокументе(Форма, Устарело = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = НазначенияСервер.ПриИзмененииШаблонаНазначенияВДокументе(Форма, Устарело);
```
</details>

## ПриЗаполненииПоСпецификацииСервер
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Используется в форме документа заказ переработчику при заполнении документа по спецификации.
// Инициализирует реквизиты формы, используемые при интерактивной работе пользователя. Заполняет назначение, исходя из
// направления деятельности.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма в которой необходимо инициализировать реквизиты связанные с использованием
//   направлений деятельности.
//  Устарело - Булево - для совместимости с НаправленияДеятельностиСервер.ПриЗаполненииПоСпецификацииСервер
//
Процедура ПриЗаполненииПоСпецификацииСервер(Форма, Устарело = Ложь) Экспорт
```

Пример вызова
```bsl
НазначенияСервер.ПриЗаполненииПоСпецификацииСервер(Форма, Устарело);
```
</details>

## УстановитьУсловноеОформлениеФлагаОбособленно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Используется в формах документов. Устанавливает условное оформление флага Обособленно.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма в которой необходимо установить условное оформление.
//  Устарело - Булево - для совместимости с НаправленияДеятельностиСервер.УстановитьУсловноеОформлениеФлагаОбособленно
Процедура УстановитьУсловноеОформлениеФлагаОбособленно(Форма, Устарело = Ложь) Экспорт
```

Пример вызова
```bsl
НазначенияСервер.УстановитьУсловноеОформлениеФлагаОбособленно(Форма, Устарело);
```
</details>

## УстановитьВидимостьЭлементовОбособленно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Используется в формах документов, в процедурах, приводящих к изменению флага по заказам.
// Управляет видимостью элементов.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма в которой необходимо отреагировать на изменение флага по заказам.
//  Устарело - Булево - для совместимости с НаправленияДеятельностиСервер.УстановитьВидимостьЭлементовОбособленно
//
Процедура УстановитьВидимостьЭлементовОбособленно(Форма, Устарело = Ложь) Экспорт
```

Пример вызова
```bsl
НазначенияСервер.УстановитьВидимостьЭлементовОбособленно(Форма, Устарело);
```
</details>

## УстановитьСнятьОтметкуОбособленно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В табличной части формы документа устанавливает флаг "Обособленно" для выделенных строк.
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - Форма.
//  Установить - Булево - Истина если нужно установить флаг, Ложь - если нужно сбросить флаг.
//  Устарело - Булево - Для совместимости с НаправленияДеятельностиСервер.УстановитьСнятьОтметкуОбособленно
Процедура УстановитьСнятьОтметкуОбособленно(Форма, Установить, Устарело = Ложь) Экспорт
```

Пример вызова
```bsl
НазначенияСервер.УстановитьСнятьОтметкуОбособленно(Форма, Установить, Устарело);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
