---
title: Накладные клиент
slug: erp-uh/накладные-клиент
---


## СсылкиВыделенныхСтрокСпискаПоВидам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует массив ссылок по выделенным строкам списка, исключая группировки,
// предупреждает пользователя об отсутствии выделенных строк.
//
// Параметры:
//  Список 			- ДинамическийСписок - список, выделенные строки которого содержат ссылки для дальнейшей обработки.
//  ТипНакладная	- ОписаниеТипов - описание типов, содержащее типы накладных, присутствующих в списке.
//  СвойстваЗаказов	- Строка - перечень свойств, которые нужно получить из списка.
//
// Возвращаемое значение:
//  Структура - содержит два массива "Заказы" и "Накладные", содержащие ссылки на выделенные строки списка.
//
Функция СсылкиВыделенныхСтрокСпискаПоВидам(Список, ТипНакладная, СвойстваЗаказов = "") Экспорт
```

Пример вызова
```bsl
Результат = НакладныеКлиент.СсылкиВыделенныхСтрокСпискаПоВидам(Список, ТипНакладная, СвойстваЗаказов);
```
</details>

## СообщитьОбОшибкахЗаполненияВнутреннейНакладной
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сообщает об ошибках создания накладной на основании заказов, если у заказов не совпадают реквизиты шапки.
// Параметры:
//  ТекстыОшибок - Массив, Строка - Массив текстов ошибок или текст одной ошибки.
//
Процедура СообщитьОбОшибкахЗаполненияВнутреннейНакладной(ТекстыОшибок) Экспорт
```

Пример вызова
```bsl
НакладныеКлиент.СообщитьОбОшибкахЗаполненияВнутреннейНакладной(ТекстыОшибок) 
```
</details>

## ДанныеДляОформленияПоЗаказам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует список группировок по выделенным строкам списка распоряжений, исключая некорректные состояния,
// в которых содержится необходимая информация для оформления накладной по заказу.
//
// Параметры:
//  ДанныеРаспоряжений	 - ДанныеФормыКоллекция - реквизит на форме, содержащий данные списка распоряжений.
//  ИдентификаторыСтрок	 - Массив - идентификаторы строк в коллекции, которые нужно обработать.
//  ПоляГруппировки		 - Строка - имена полей в данных распоряжений по которым их необходимо сгруппировать.
//  СписокОшибок		 - Структура - список ошибок.
//  ПолеОшибки			 - Строка - значение, которое задается в свойстве Поле объекта СообщениеПользователю.
//  МетаданныеНакладных	 - ДанныеФормыКоллекция - таблица с полями:
//  												ХозяйственнаяОперация        - оформляемая хоз. операция
//  												КлючевыеПоляШапки            - ключевые реквизиты распоряжений по которым их можно группировать
//  												ПолноеИмяДокумента           - имя документа в метаданных
//  												ЗаголовокФормыПереоформления - заголовок для ОбщаяФорма.ПереоформлениеНакладныхПоРаспоряжениям.
//	ПоНоменклатуре 		 - Булево - признак режима формирования по номенклатуре (характеристике)
//
// Возвращаемое значение:
//  Массив из Структура:
//  * МассивЗаказов - Массив
//  * ПоляЗаполнения - Структура
//  * КлючевыеПоляШапки - Строка
//  * ИмяОформляемогоДокумента - Строка
//  * Обработчик - Строка
//  * ЕстьНакладные - Булево
//  * ЭтоНакладная - Булево
//  * ЗаголовокФормыПереоформления - Строка
//  * Склад - СправочникСсылка.Склады
//  * НакладнаяНаОтгрузку - ДокументСсылка
//  * НакладнаяНаПриемку - ДокументСсылка
//
Функция ДанныеДляОформленияПоЗаказам( Экспорт
```

Пример вызова
```bsl
Результат = НакладныеКлиент.ДанныеДляОформленияПоЗаказам();
```
</details>

## ДанныеДляОформленияПоОрдерам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует список группировок по выделенным строкам списка распоряжений, исключая некорректные состояния,
// в которых содержится необходимая информация для оформления накладной по ордерам.
//
// Параметры:
//  ДанныеРаспоряжений	 - ДанныеФормыКоллекция - реквизит на форме, содержащий данные списка распоряжений.
//  ИдентификаторыСтрок	 - Массив - идентификаторы строк в коллекции, которые нужно обработать.
//  ПоляГруппировки		 - Строка - имена полей в данных распоряжений по которым их необходимо сгруппировать.
//  СписокОшибок		 - Структура - список ошибок.
//  ПолеОшибки			 - Строка - значение, которое задается в свойстве Поле объекта СообщениеПользователю.
//  МетаданныеНакладных	 - ДанныеФормыКоллекция - таблица с полями:
//  												ХозяйственнаяОперация        - оформляемая хоз. операция
//  												КлючевыеПоляШапки            - ключевые реквизиты распоряжений по которым их можно группировать
//  												ПолноеИмяДокумента           - имя документа в метаданных
//  												ЗаголовокФормыПереоформления - заголовок для ОбщаяФорма.ПереоформлениеНакладныхПоРаспоряжениям.
//	ПоНоменклатуре 		 - Булево - признак режима формирования по номенклатуре (характеристике)
//
// Возвращаемое значение:
//  Массив из Структура:
//  * МассивЗаказов - Массив
//  * ПоляЗаполнения - Структура
//  * КлючевыеПоляШапки - Строка
//  * ИмяОформляемогоДокумента - Строка
//  * Обработчик - Строка
//  * ЕстьНакладные - Булево
//  * ЭтоНакладная - Булево
//  * ЗаголовокФормыПереоформления - Строка
//  * Склад - СправочникСсылка.Склады
//  * НакладнаяНаОтгрузку - ДокументСсылка
//  * НакладнаяНаПриемку - ДокументСсылка
//
Функция ДанныеДляОформленияПоОрдерам( Экспорт
```

Пример вызова
```bsl
Результат = НакладныеКлиент.ДанныеДляОформленияПоОрдерам();
```
</details>

## ОткрытьФормуСозданныхДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму оформления либо список уже оформленных документов.
//
// Параметры:
//  ПараметрыСозданныхДокументов - Структура - содержащая поля "ИмяФормы" и "Параметры".
//  Владелец					 - Форма - элемент формы - владелец открываемой формы.
//
Процедура ОткрытьФормуСозданныхДокументов(ПараметрыСозданныхДокументов, Владелец) Экспорт
```

Пример вызова
```bsl
НакладныеКлиент.ОткрытьФормуСозданныхДокументов(ПараметрыСозданныхДокументов, Владелец) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
