---
title: Налог на прибыль бухгалтерский учет
slug: erp-uh/налог-на-прибыль-бухгалтерский-учет
---


## ОписаниеКоллекцииСумм
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция - Описание коллекции сумм
//
// Параметры:
//  ИспользуетсяНалоговыйУчет            - Булево -
//  ИспользуютсяРазницыПоНалогуНаПрибыль - Булево -
//  ИспользоватьУправленческийУчет       - Булево -
//
// Возвращаемое значение:
//  Структура - коллекция сумм
//
Функция ОписаниеКоллекцииСумм(ИспользуетсяНалоговыйУчет = Истина, ИспользуютсяРазницыПоНалогуНаПрибыль = Истина, ИспользоватьУправленческийУчет = Истина) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльБухгалтерскийУчет.ОписаниеКоллекцииСумм(ИспользуетсяНалоговыйУчет, ИспользуютсяРазницыПоНалогуНаПрибыль, ИспользоватьУправленческийУчет);
```
</details>

## ИмяНабораСуммРазницыПоНалогуНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИмяНабораСуммРазницыПоНалогуНаПрибыль() Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльБухгалтерскийУчет.ИмяНабораСуммРазницыПоНалогуНаПрибыль() 
```
</details>

## ЕстьРазницыПоНалогуНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЕстьРазницыПоНалогуНаПрибыль(ОписаниеСумм) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльБухгалтерскийУчет.ЕстьРазницыПоНалогуНаПрибыль(ОписаниеСумм) 
```
</details>

## РассчитатьРазницыПоНалогуНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает в коллекции Приемник разницы по налогу на прибыль, т.е. обеспечивает выполнение равенства БУ = НУ + ПР + ВР.
// При этом, если равенство не выполняется, то суммы ПР и ВР будут рассчитаны заново исходя из сумм БУ и НУ.
//
// Какие именно суммы в этом случае получатся (как разница между БУ и НУ распределится между ПР или ВР),
// зависит от данных Источника.
// Правила:
// 1. Разница в Приемнике, по возможности (по возможности, при соблюдении правила БУ = НУ + ПР + ВР в Источнике),
//    должна появиться там же, где была в Источнике.
//    Если в Источнике оба вида разниц не равны нулю и имеют одинаковый знак, то делим пропорционально.
// 2. Неосновную разницу ограничиваем с учетом знака: она может быть по модулю меньше, чем в Источнике, но не больше
//    (это может быть запрещено параметром функции)
// 3. В случае сомнений признаем разницу основного вида (по умолчанию - временную).
//
// Поскольку в соответствии с современной трактовкой ПБУ 18 основной вид разниц - временные,
// то использование постоянных разниц в качестве основного вида считаем оставленным для совместимости.
// Поэтому в таком режиме правила могут выполняться не в полном объеме, чтобы поведение соответствовало предыдущим версиям.
//
// Параметры:
//  Приемник     - Структура - см. КоллекцииСумм.НовыйКоллекцияСумм, модифицируемая коллекция сумм,
//                             должна содержать Сумма, СуммаНУ, СуммаПР, СуммаВР
//                             См. также ОписаниеКоллекцииСумм.
//  Источник     - Структура - см. КоллекцииСумм.НовыйКоллекцияСумм, коллекция, используемая как шаблон
//                             должна содержать Сумма, СуммаНУ, СуммаПР, СуммаВР
//                             См. также ОписаниеКоллекцииСумм.
//  ОписаниеСумм - Структура - см. КоллекцииСумм.НовыйОписаниеКоллекцииСумм. Описание коллекций Приемник и Источник
//  ОграничиватьСуммуРазницыНеосновногоВида - Булево - Ложь,
//                          если не требуется ограничивать сумму неосновной разницы с учетом знака
//                          (т.е. допускается относить, например, на постоянные разницы отрицательную сумму,
//                          при условии, если в Источнике постоянные разницы положительны).
//  ОсновнойВидРазниц - ПеречислениеСсылка.ВидыРазницПБУ18 - вид разниц,
//                           к которым разница между БУ и НУ относится по умолчанию
//                           (т.е. если это нельзя однозначно определить из Источника).
//                    - Неопределено - по умолчанию разницы относятся к временным
//
Процедура РассчитатьРазницыПоНалогуНаПрибыль(Приемник, Источник, ОписаниеСумм, ОграничиватьСуммуРазницыНеосновногоВида = Истина, ОсновнойВидРазниц = Неопределено) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльБухгалтерскийУчет.РассчитатьРазницыПоНалогуНаПрибыль(Приемник, Источник, ОписаниеСумм, ОграничиватьСуммуРазницыНеосновногоВида, ОсновнойВидРазниц);
```
</details>

## ИсправитьПогрешностиОкругления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ИсправитьПогрешностиОкругления(Доли, ИсходныеСуммы, ОписаниеСумм, Числитель, Знаменатель, ОсновнойВидРазниц = Неопределено) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльБухгалтерскийУчет.ИсправитьПогрешностиОкругления(Доли, ИсходныеСуммы, ОписаниеСумм, Числитель, Знаменатель, ОсновнойВидРазниц);
```
</details>

## ОсновнойВидРазниц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОсновнойВидРазниц(Период, Организация) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльБухгалтерскийУчет.ОсновнойВидРазниц(Период, Организация) 
```
</details>

## ИнициализироватьРасчетОтложенногоНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализируется расчет отложенного налога в переходном режиме
//
// Параметры:
//  Движения      - КоллекцияДвижений            - движения документа "РегламентнаяОперация"
//  ПериодРасчета - Дата                         - дата расчета отложенного налога
//  Организация   - СправочникСсылка.Организации - организация, по которой производится расчет
//
Процедура ИнициализироватьРасчетОтложенногоНалога(Движения, ПериодРасчета, Организация) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльБухгалтерскийУчет.ИнициализироватьРасчетОтложенногоНалога(Движения, ПериодРасчета, Организация) 
```
</details>

## ПолучитьСтатусПримененияМетодовУчетаОтложенногоНалогаПоВсемОрганизациям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает актуальный статус применения методов учета отложенного налога по всем организациям
// Если хотя бы в одной из организаций применяется один из методов,
// то свойству будет присвоено значение "Истина".
//
// Возвращаемое значение:
//  Структура -
//
Функция ПолучитьСтатусПримененияМетодовУчетаОтложенногоНалогаПоВсемОрганизациям() Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльБухгалтерскийУчет.ПолучитьСтатусПримененияМетодовУчетаОтложенногоНалогаПоВсемОрганизациям() 
```
</details>

## ОтразитьПоследствияНачисленияНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует регистры по начислению отложенного налога
//
// Параметры:
//  Движения     - КоллекцияДвижений - движения документа "РегламентнаяОперация"
//  Период       - Дата - дата документа регламентной операции
//  Организация  - СправочникСсылка.Организации - организация
//  Ссылка       - ДокументСсылка.РегламентнаяОперация - ссылка регл. операцию
//
Процедура ОтразитьПоследствияНачисленияНалога(Движения, Период, Организация, Ссылка, КоличествоОбрабатываемыхДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльБухгалтерскийУчет.ОтразитьПоследствияНачисленияНалога(Движения, Период, Организация, Ссылка, КоличествоОбрабатываемыхДанных) 
```
</details>

## ПараметрыЗаполненияПроводокОтложенногоНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция-конструктор параметров процедуры НалогНаПрибыльБухгалтерскийУчет.ДобавитьПроводкуОтложенныйНалог
//
// Возвращаемое значение:
//  Cтруктура:
//        * Проводки - ТаблицаЗначений -
//        * ВариантНалогообложенияПрибыли - СправочникСсылка.ВариантыНалогообложенияПрибыли -
//        * Сумма - Число -
//        * Содержание - Строка -
//        * ВидДвижения - ВидДвиженияБухгалтерии -
//        * Счет - ПланСчетовСсылка.Хозрасчетный -
//        * ВидАктивовИОбязательств - ПеречислениеСсылка.ВидыАктивовИОбязательств -
//        * КорСчет - ПланСчетовСсылка.Хозрасчетный -
//        * КонтекстРасчета - Структура -
//
Функция ПараметрыЗаполненияПроводокОтложенногоНалога() Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльБухгалтерскийУчет.ПараметрыЗаполненияПроводокОтложенногоНалога());
```
</details>

## НовыйПравилаГруппировкиАктивовОбязательств
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор правил группировки активов обязательств
//
// Возвращаемое значение:
//  ТаблицаЗначений - каркас таблицы правил группировки:
//   * ОсновнойСчет - ПланСчетовСсылка.Хозрасчетный -
//   * ВидАктивовОбязательств - ПеречислениеСсылка.ВидыАктивовИОбязательств -
//   * ДополнительныеСчета - Массив Из ПланСчетовСсылка.Хозрасчетный -
//   * ИсключенныеСубконто - Массив Из ПланВидовХарактеристикСсылка.ВидыСубконтоХозрасчетные -
//
Функция НовыйПравилаГруппировкиАктивовОбязательств() Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльБухгалтерскийУчет.НовыйПравилаГруппировкиАктивовОбязательств() 
```
</details>

## ЗаполнитьПравилаГруппировкиВидовАктивовИОбязательств
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет правила группировки видов активов и обязательств
//
// Параметры:
//  Правила - см. НовыйПравилаГруппировкиАктивовОбязательств
//
Процедура ЗаполнитьПравилаГруппировкиВидовАктивовИОбязательств(Правила) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльБухгалтерскийУчет.ЗаполнитьПравилаГруппировкиВидовАктивовИОбязательств(Правила) 
```
</details>

## ПолучитьПравилаГруппировкиВидовАктивовИОбязательств
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет правила группировки видов активов и обязательств по данным справочника
//
// Параметры:
//  Правила - см. НовыйПравилаГруппировкиАктивовОбязательств
//
Процедура ПолучитьПравилаГруппировкиВидовАктивовИОбязательств(Правила) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльБухгалтерскийУчет.ПолучитьПравилаГруппировкиВидовАктивовИОбязательств(Правила) 
```
</details>

## ПланГруппировкиАктивовОбязательств
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразовывает правила группировки в план запроса к регистру бухгалтерии
//
// Параметры:
//  ПравилаГруппировки - см. НовыйПравилаГруппировкиАктивовОбязательств
//
// Возвращаемое значение:
//  ТаблицаЗначений -  План группировки активов обязательств:
// * Счет - ПланСчетовСсылка.Хозрасчетный -
// * СчетГруппировки - ПланСчетовСсылка.Хозрасчетный -
// * ВидАктивовОбязательств - ПеречислениеСсылка.ВидыАктивовИОбязательств -
// * ПозицияСубконто1 - Число -
// * ПозицияСубконто2 - Число -
// * ПозицияСубконто3 - Число -
// * НомерВариантаИсключения - Число -
// * ВыбиратьТолькоРазницы - Булево -
// * ПозицияСубконтоВариантНалогообложения - Число -
//
Функция ПланГруппировкиАктивовОбязательств(ПравилаГруппировки) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльБухгалтерскийУчет.ПланГруппировкиАктивовОбязательств(ПравилаГруппировки) 
```
</details>

## ПользователюДоступныСуммыРазниц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет в целом для сеанса работы, может ли потребоваться рассчитывать,
// заполнять и отображать пользователю суммы разниц в проводках.
//
// Обращение к функции следует выполнять через кеш повтоно используемых значений.
// см. БухгалтерскийУчетВызовСервераПовтИсп.ПользователюДоступныСуммыПостоянныхВременныхРазниц
//
// Возвращаемое значение:
//  Булево - Истина, если может потребоваться использовать суммы разниц в проводках.
//
Функция ПользователюДоступныСуммыРазниц() Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльБухгалтерскийУчет.ПользователюДоступныСуммыРазниц() 
```
</details>

## ВариантУчетаОтложенногоНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает применяемый вариант учета отложенного налога по организации на дату
//
// Параметры:
//  Период		 - Дата - Дата, на которую требуется определение
//  Организация	 - СправочникСсылка.Организации - Организация, по которой требуется определение
//
// Возвращаемое значение:
//  ПеречислениеСсылка.ВариантыУчетаОтложенногоНалога -
//
Функция ВариантУчетаОтложенногоНалога(Период, Организация) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльБухгалтерскийУчет.ВариантУчетаОтложенногоНалога(Период, Организация) 
```
</details>

## СчетаТекущегоНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет перечень счетов, в корреспонденции с которыми отражается начисление налога на прибыль
// в вариантах, когда ПБУ 18 применяется.
//
// Возвращаемое значение:
//  Массив - содержит ПланСчетовСсылка.Хозрасчетный
//
Функция СчетаТекущегоНалога() Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльБухгалтерскийУчет.СчетаТекущегоНалога() 
```
</details>

## СчетТекущегоНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция - Счет текущего налога на прибыль
//
// Параметры:
//  ВариантУчета - ПеречислениеСсылка.ВариантыУчетаОтложенногоНалога - вариант учета отложенного налога
//
// Возвращаемое значение:
//  ПланСчетовСсылка.Хозрасчетный - счет учета текущего налога на прибыль
//
Функция СчетТекущегоНалогаНаПрибыль(ВариантУчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльБухгалтерскийУчет.СчетТекущегоНалогаНаПрибыль(ВариантУчета) 
```
</details>

## ИспользоватьСуммыРазниц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, нужно ли рассчитывать, заполнять и отображать пользователю суммы разниц в проводках.
//
// Параметры:
//  Организация - СправочникСсылка.Организации -
//  Период      - Дата -
//
// Возвращаемое значение:
//  Булево - Истина, если нужно использовать суммы разниц в проводках.
//
Функция ИспользоватьСуммыРазниц(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльБухгалтерскийУчет.ИспользоватьСуммыРазниц(Организация, Период) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
