---
title: Налог на прибыль декларация
slug: erp-uh/налог-на-прибыль-декларация
---


## НовыйКонтекстРасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описывает контекст, в котором выполняется расчет показателей декларации -
// организацию, период и т.п.
//
// Параметры:
//  Организация                      - СправочникСсылка.Организации - налогоплательщик
//  КонецПериода					 - Дата - характеризует отчетный период; дата из последнего месяца отчетного периода
//	ПоМесту							 - Строка - код места представления декларации
//  ДатаПодписи						 - Дата - дата подписи декларации
//  КППОбособленногоПодразделения	 - Строка -
// 		* пустая строка, если декларация представляется по месту нахождения организации
//		* КПП обособленного подразделения, если декларация представляется по месту нахождения обособленного подразделения
//	Периодичность					 - ПеречислениеСсылка.Периодичность - характеризует отчетный период.
//
// Возвращаемое значение:
//  Структура    - состав см. в теле функции
//  Неопределено - в указанном периоде организация не существовала.
//
Функция НовыйКонтекстРасчета(Организация, КонецПериода, ПоМесту, ДатаПодписи = '0001-01-01', КППОбособленногоПодразделения = "", Периодичность = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НовыйКонтекстРасчета(Организация, КонецПериода, ПоМесту, ДатаПодписи, КППОбособленногоПодразделения, Периодичность);
```
</details>

## ЗаполнитьРегламентированныйОтчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает данные декларации и помещает их в контейнер, поставляемый БРО
//
// Параметры:
//  Контейнер       - см. РегламентированнаяОтчетностьПереопределяемый.ЗаполнитьОтчет()
//  Расшифровка     - см. ОбщаяФорма.РасшифровкаПоказателейРегламентированныхОтчетов.ПриСозданииНаСервере()
//  ИмяРедакции     - Строка - Имя редакции отчета в терминах БРО
//  КонтекстРасчета - см. НовыйКонтекстРасчета() - содержит сведения о том, какая декларация заполняется: по какой
//                                                 организации, за какой период и т.п.
//
Процедура ЗаполнитьРегламентированныйОтчет(Контейнер, Расшифровка, ИмяРедакции, КонтекстРасчета) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ЗаполнитьРегламентированныйОтчет(Контейнер, Расшифровка, ИмяРедакции, КонтекстРасчета) 
```
</details>

## ЗаполняемыеЯчейкиРегламентированногоОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет перечень ячеек отчета (в терминах БРО), данные для заполнения которых предоставляются прикладным решением.
//
// Параметры:
//  ИмяРедакции - Строка - Имя редакции отчета в терминах БРО
//  Организация  - СправочникСсылка.Организации
//  КонецПериода - Дата - характеризует отчетный период. Отчетный период всегда начинается с начала года.
//
Функция ЗаполняемыеЯчейкиРегламентированногоОтчета(ИмяРедакции, Организация, КонецПериода) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ЗаполняемыеЯчейкиРегламентированногоОтчета(ИмяРедакции, Организация, КонецПериода) 
```
</details>

## ЗаполнятьДетальнуюИнформациюПоТорговомуСборуВДекларации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, нужно ли заполнять детальные строки торгового сбора в декларации по налогу на прибыль.
//
// Параметры:
//  КонецПериода - Дата - характеризует отчетный период, за который представляется декларация.
//
Функция ЗаполнятьДетальнуюИнформациюПоТорговомуСборуВДекларации(КонецПериода) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ЗаполнятьДетальнуюИнформациюПоТорговомуСборуВДекларации(КонецПериода) 
```
</details>

## СхемаРасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описывает в общем (прикладном) виде порядок расчета налога на прибыль.
// Порядок расчета включает в себя описание:
// - данных, которые нужно получить из информационной базы
// - арифметических действий, которые нужно с этими данными выполнить.
//
// Параметры:
//  КонтекстРасчета - см. НовыйКонтекстРасчета() - содержит сведения о том, какая декларация заполняется: по какой
//                                                 организации, за какой период и т.п.
//  ОписаниеСумм - см. КоллекцииСумм.НовыйОписаниеКоллекцииСумм() - набор сумм, которые нужно рассчитать в соответствии
//                                                                  со схемой.
//
// Возвращаемое значение:
//  см. НовыйСхемаРасчета
//
Функция СхемаРасчета(КонтекстРасчета, ОписаниеСумм) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.СхемаРасчета(КонтекстРасчета, ОписаниеСумм));
```
</details>

## СоставДекларации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описывает состав декларации: какие листы (приложения) включаются в текущем периоде,
// в т.ч. в зависимости от наличия в них данных
//
// Параметры:
//  КонтекстРасчета - см. НовыйКонтекстРасчета - контекст, в котором рассчитывается налог (организация, период и т.п.)
//
// Возвращаемое значение:
//  см. НовыйСоставДекларации
//
Функция СоставДекларации(КонтекстРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.СоставДекларации(КонтекстРасчета));
```
</details>

## ОписаниеФормыОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Составляет перечень показателей, размещенных в форме декларации,
// с указанием актуальных для редакции этой декларации номеров строк.
//
// Параметры:
//  ИмяРедакции  - Строка - Имя редакции отчета в терминах БРО
//  СхемаРасчета - см. СхемаРасчета() - схема, на основании которой составляется описание
// Возвращаемое значение:
//  см. НовыйОписаниеФормыОтчета().
//
Функция ОписаниеФормыОтчета(ИмяРедакции, СхемаРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ОписаниеФормыОтчета(ИмяРедакции, СхемаРасчета));
```
</details>

## РежимСовместимостиИзлишкиПриИнвентаризации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РежимСовместимостиИзлишкиПриИнвентаризации(Период) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.РежимСовместимостиИзлишкиПриИнвентаризации(Период));
```
</details>

## ЭтапыРасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтапыРасчета(ПрименяютсяСпециальныеРежимы) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ЭтапыРасчета(ПрименяютсяСпециальныеРежимы));
```
</details>

## ЭтапРасчетаСпециальныеРежимы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтапРасчетаСпециальныеРежимы(ЭтапРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ЭтапРасчетаСпециальныеРежимы(ЭтапРасчета));
```
</details>

## ОператорЭтапаРасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОператорЭтапаРасчета(ЭтапРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ОператорЭтапаРасчета(ЭтапРасчета));
```
</details>

## ПредставлениеЭтапаРасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПредставлениеЭтапаРасчета(ЭтапРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ПредставлениеЭтапаРасчета(ЭтапРасчета));
```
</details>

## ОтключитьОтображениеЭтапаРасчетаНеУчитываемые
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОтключитьОтображениеЭтапаРасчетаНеУчитываемые(ЗаписьПротокола, ЭтапРасчета, ОписаниеСумм) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ОтключитьОтображениеЭтапаРасчетаНеУчитываемые(ЗаписьПротокола, ЭтапРасчета, ОписаниеСумм));
```
</details>

## ДобавитьСлагаемоеПрямыеРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьСлагаемоеПрямыеРасходы(СхемаРасчета, КорСчет) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ДобавитьСлагаемоеПрямыеРасходы(СхемаРасчета, КорСчет));
```
</details>

## СчетаКосвенныхРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СчетаКосвенныхРасходов() Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.СчетаКосвенныхРасходов());
```
</details>

## ДобавитьСлагаемоеКосвенныеРасходыПоВидуРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьСлагаемоеКосвенныеРасходыПоВидуРасходов(СхемаРасчета, ВидСтатьиРасходов) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ДобавитьСлагаемоеКосвенныеРасходыПоВидуРасходов(СхемаРасчета, ВидСтатьиРасходов));
```
</details>

## ДобавитьСлагаемоеПрочиеРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьСлагаемоеПрочиеРасходы(СхемаРасчета, ВидСтатьиРасходов) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ДобавитьСлагаемоеПрочиеРасходы(СхемаРасчета, ВидСтатьиРасходов));
```
</details>

## ДобавитьРасчетПрочегоУбытка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьРасчетПрочегоУбытка(СхемаРасчета, Имя, ВидСтатьи, НомерСтрокиВыручки, ОписаниеВыручки, НомерСтрокиРасходов, ОписаниеРасходов, СпособПереносаУбытка = Неопределено) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ДобавитьРасчетПрочегоУбытка(СхемаРасчета, Имя, ВидСтатьи, НомерСтрокиВыручки, ОписаниеВыручки, НомерСтрокиРасходов, ОписаниеРасходов, СпособПереносаУбытка);
```
</details>

## ДобавитьИсточникДанныхРеализацияАмортизируемогоИмущества
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьИсточникДанныхРеализацияАмортизируемогоИмущества(СхемаРасчета, ИмяПоказателя) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ДобавитьИсточникДанныхРеализацияАмортизируемогоИмущества(СхемаРасчета, ИмяПоказателя));
```
</details>

## ПолучитьДанныеИнформационнойБазы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура-маршрутизатор: вызывает конкретные алгоритмы получения данных информационной базы.
// Сами алгоритмы размещены в областях внутри области ПолучениеДанных.
//
// Параметры:
//  ПроцессорПолученияДанных - см. НовыйПроцессорПолученияДанных() - структура, определяющая, что нужно сделать.
//                             Результат выполнения - полученные данные - записывается в список задач внутри процессора.
Процедура ПолучитьДанныеИнформационнойБазы(ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ПолучитьДанныеИнформационнойБазы(ПроцессорПолученияДанных));
```
</details>

## НовыйОтборДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор коллекции, содержащей отбор данных информационной базы, с помощью которого можно параметризовать алгоритм
// получения данных. То есть, отбор содержит те поля, с помощью которых можно управлять тем, какие именно данные будут получены.
// Конкретный набор полей и их семантика определяется алгоритмом.
//
// Параметры:
//  ИмяАлгоритма - Строка
// Возвращаемое значение:
//  Структура - Ключ - имя поля, по которому выполняется отбор, Значение - значение отбора.
Функция НовыйОтборДанных(ИмяАлгоритма) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НовыйОтборДанных(ИмяАлгоритма));
```
</details>

## НовыйУсловиеПолученияДанныхИнформационнойБазы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор коллекции, содержащей условия, в соответствии с которым были получены данные информационной базы.
// Включает в себя
// - (всегда) - отбор - см. НовыйОтборДанных()
// - (всегда) - счет, по которому получены данные, заданный алгоритмом "жестко"
// - (когда данные получаются из информационной базы с большей детализацией) - другие поля
// Конкретный набор полей и их семантика определяется алгоритмом.
//
// Параметры:
//  ИмяАлгоритма - Строка
//  СхемаРасчета - см. НовыйСхемаРасчета
// Возвращаемое значение:
//  Структура - Ключ - имя поля, по которому выполняется отбор, Значение - значение отбора.
Функция НовыйУсловиеПолученияДанныхИнформационнойБазы(ИмяАлгоритма) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НовыйУсловиеПолученияДанныхИнформационнойБазы(ИмяАлгоритма));
```
</details>

## НастройкиОтчетаРасшифровкаЗначения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура-маршрутизатор: вызывает конкретные алгоритмы подготовки настроек стандартного отчета,
// с помощью которого можно проиллюстрировать шаг расчета.
// Сами алгоритмы размещены в областях внутри области ПолучениеДанных.
//
// Параметры:
//  ЗаписьПротокола	 - см. НовыйПротоколРасчета() - иллюстрируемая запись протокола расчета
//  СхемаРасчета	 - см. НовыйСхемаРасчета()    - общая схема иллюстрируемого расчета
// Возвращаемое значение:
//  см. ЗаполнениеРасшифровкаРегламентированнойОтчетности.НовыйНастройкиОтчетаПоРегиструБухгалтерии -
//     настройки отчета в формате, понятном форме РасшифровкаПоказателейРегламентированныхОтчетов.
Функция НастройкиОтчетаРасшифровкаЗначения(ЗаписьПротокола, СхемаРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НастройкиОтчетаРасшифровкаЗначения(ЗаписьПротокола, СхемаРасчета));
```
</details>

## СоздатьВременнуюТаблицуСчетаУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьВременнуюТаблицуСчетаУчета(СчетаУчета, ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.СоздатьВременнуюТаблицуСчетаУчета(СчетаУчета, ПроцессорПолученияДанных));
```
</details>

## СоздатьВременнуюТаблицуДолиСпециальныеРежимы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьВременнуюТаблицуДолиСпециальныеРежимы(ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.СоздатьВременнуюТаблицуДолиСпециальныеРежимы(ПроцессорПолученияДанных));
```
</details>

## НовыйОтборПоЭтапуРасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НовыйОтборПоЭтапуРасчета(ЭтапРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НовыйОтборПоЭтапуРасчета(ЭтапРасчета));
```
</details>

## ПолучитьВыручкаОбычныеВидыДеятельности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьВыручкаОбычныеВидыДеятельности(ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ПолучитьВыручкаОбычныеВидыДеятельности(ПроцессорПолученияДанных));
```
</details>

## ДобавитьВТекстЗапросаТаблицуРегистраторовСебестоимости
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьВТекстЗапросаТаблицуРегистраторовСебестоимости(ШаблонТекстаЗапроса) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ДобавитьВТекстЗапросаТаблицуРегистраторовСебестоимости(ШаблонТекстаЗапроса));
```
</details>

## НастройкиОтчетаВыручкаОбычныеВидыДеятельности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НастройкиОтчетаВыручкаОбычныеВидыДеятельности(ЭтапРасчета, Счет, Раздел, НастройкаУчетаПроизводства, СхемаРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НастройкиОтчетаВыручкаОбычныеВидыДеятельности(ЭтапРасчета, Счет, Раздел, НастройкаУчетаПроизводства, СхемаРасчета));
```
</details>

## ДобавитьСлагаемоеПрочиеДоходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьСлагаемоеПрочиеДоходы(СхемаРасчета, ИмяПоказателя, НомерСтроки, Описание, СтатьиДоходов) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ДобавитьСлагаемоеПрочиеДоходы(СхемаРасчета, ИмяПоказателя, НомерСтроки, Описание, СтатьиДоходов));
```
</details>

## ПолучитьИзлишкиПриИнвентаризацииДляСовместимости
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьИзлишкиПриИнвентаризацииДляСовместимости(ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ПолучитьИзлишкиПриИнвентаризацииДляСовместимости(ПроцессорПолученияДанных));
```
</details>

## ПолучитьПрямыеРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьПрямыеРасходы(ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ПолучитьПрямыеРасходы(ПроцессорПолученияДанных));
```
</details>

## НастройкиОтчетаПрямыеРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НастройкиОтчетаПрямыеРасходы(ЭтапРасчета, Счет, КорСчет, СхемаРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НастройкиОтчетаПрямыеРасходы(ЭтапРасчета, Счет, КорСчет, СхемаРасчета));
```
</details>

## ПолучитьКосвенныеРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьКосвенныеРасходы(ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ПолучитьКосвенныеРасходы(ПроцессорПолученияДанных));
```
</details>

## НастройкиОтчетаКосвенныеРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НастройкиОтчетаКосвенныеРасходы(ЭтапРасчета, Счет, ВидРасходов, СхемаРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НастройкиОтчетаКосвенныеРасходы(ЭтапРасчета, Счет, ВидРасходов, СхемаРасчета));
```
</details>

## ДобавитьВНастройкиОтчетаОтборПоСвойствамКорСубконто
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьВНастройкиОтчетаОтборПоСвойствамКорСубконто(Настройки, ИмяСвойства, ЗначениеОтбора, ВидСравненияОтбора = Неопределено) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ДобавитьВНастройкиОтчетаОтборПоСвойствамКорСубконто(Настройки, ИмяСвойства, ЗначениеОтбора, ВидСравненияОтбора);
```
</details>

## ПолучитьПрочиеДоходыРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// ИмяПоказателя - Строка - "ПрочиеДоходы" или "ПрочиеРасходы"
Процедура ПолучитьПрочиеДоходыРасходы(ПроцессорПолученияДанных, ИмяПоказателя) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ПолучитьПрочиеДоходыРасходы(ПроцессорПолученияДанных, ИмяПоказателя));
```
</details>

## ХарактеристикиПрочиеДоходыРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ХарактеристикиПрочиеДоходыРасходы(ИмяПоказателя, ДетализироватьПоРеализованнымОбъектам) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ХарактеристикиПрочиеДоходыРасходы(ИмяПоказателя, ДетализироватьПоРеализованнымОбъектам));
```
</details>

## РезультатЗапросаПрочиеДоходыРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РезультатЗапросаПрочиеДоходыРасходы(ХарактеристикиДоходовРасходов, ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.РезультатЗапросаПрочиеДоходыРасходы(ХарактеристикиДоходовРасходов, ПроцессорПолученияДанных));
```
</details>

## НастройкиОтчетаПрочиеДоходыРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НастройкиОтчетаПрочиеДоходыРасходы(ЭтапРасчета, Счет, ВидСтатьи, СхемаРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НастройкиОтчетаПрочиеДоходыРасходы(ЭтапРасчета, Счет, ВидСтатьи, СхемаРасчета));
```
</details>

## ДанныеПоСчетуПрочиеРасходыМожноПолучитьОтчетомОборотыСчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДанныеПоСчетуПрочиеРасходыМожноПолучитьОтчетомОборотыСчета() Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ДанныеПоСчетуПрочиеРасходыМожноПолучитьОтчетомОборотыСчета());
```
</details>

## СоздатьВременнуюТаблицуСтатьиПрочихДоходовРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьВременнуюТаблицуСтатьиПрочихДоходовРасходов(ВидыДоходовРасходов, ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.СоздатьВременнуюТаблицуСтатьиПрочихДоходовРасходов(ВидыДоходовРасходов, ПроцессорПолученияДанных));
```
</details>

## НовыйОтборПрочихДоходовРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НовыйОтборПрочихДоходовРасходов(ЭтапРасчета, ВидСтатьи) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НовыйОтборПрочихДоходовРасходов(ЭтапРасчета, ВидСтатьи));
```
</details>

## ДобавитьОтборПрочихДоходовРасходовВНастройкиОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьОтборПрочихДоходовРасходовВНастройкиОтчета(Настройки, ИмяИлиОписаниеПоля, ЭтапРасчета, ВидСтатьи, Счет = Неопределено) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ДобавитьОтборПрочихДоходовРасходовВНастройкиОтчета(Настройки, ИмяИлиОписаниеПоля, ЭтапРасчета, ВидСтатьи, Счет);
```
</details>

## СтатьяПрочихДоходовРасходовПрименима
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СтатьяПрочихДоходовРасходовПрименима(ВидСтатьи, Показатель, ЭтапРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.СтатьяПрочихДоходовРасходовПрименима(ВидСтатьи, Показатель, ЭтапРасчета));
```
</details>

## ПолучитьПрочиеРасходыПризнанныеПослеПолученияУбытка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьПрочиеРасходыПризнанныеПослеПолученияУбытка(ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ПолучитьПрочиеРасходыПризнанныеПослеПолученияУбытка(ПроцессорПолученияДанных));
```
</details>

## ХарактеристикиРасходыПризнанныеПослеПолученияУбытка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ХарактеристикиРасходыПризнанныеПослеПолученияУбытка(ДетализироватьПоРеализованнымОбъектам) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ХарактеристикиРасходыПризнанныеПослеПолученияУбытка(ДетализироватьПоРеализованнымОбъектам));
```
</details>

## РезультатЗапросаРасходыПризнанныеПослеПолученияУбытка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РезультатЗапросаРасходыПризнанныеПослеПолученияУбытка(ХарактеристикиРасходов, ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.РезультатЗапросаРасходыПризнанныеПослеПолученияУбытка(ХарактеристикиРасходов, ПроцессорПолученияДанных));
```
</details>

## НастройкиОтчетаПрочиеРасходыПризнанныеПослеПолученияУбытка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НастройкиОтчетаПрочиеРасходыПризнанныеПослеПолученияУбытка(ЭтапРасчета, СчетРасходов, ВидСтатьиРасходов, СчетУбытков, ВидСтатьиУбытков, СхемаРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НастройкиОтчетаПрочиеРасходыПризнанныеПослеПолученияУбытка(ЭтапРасчета, СчетРасходов, ВидСтатьиРасходов, СчетУбытков, ВидСтатьиУбытков, СхемаРасчета));
```
</details>

## ПолучитьРеализацияАмортизируемогоИмущества
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьРеализацияАмортизируемогоИмущества(ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ПолучитьРеализацияАмортизируемогоИмущества(ПроцессорПолученияДанных));
```
</details>

## ОператорШагаРасчетаРеализацияАмортизируемогоИмущества
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОператорШагаРасчетаРеализацияАмортизируемогоИмущества(ИмяШага) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ОператорШагаРасчетаРеализацияАмортизируемогоИмущества(ИмяШага));
```
</details>

## ИнициализироватьПротоколРасчетаУбыткаРеализацияАмортизируемогоИмущества
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИнициализироватьПротоколРасчетаУбыткаРеализацияАмортизируемогоИмущества(Протокол) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ИнициализироватьПротоколРасчетаУбыткаРеализацияАмортизируемогоИмущества(Протокол));
```
</details>

## НастройкиОтчетаРеализацияАмортизируемогоИмущества
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НастройкиОтчетаРеализацияАмортизируемогоИмущества(ЭтапРасчета, ИмяПоказателя, ВсеРеализованныеОбъекты, РеализованныйОбъект, СчетДоходовРасходов, ВидСтатьиРасходов, СчетУбытков, ВидСтатьиУбытков, СхемаРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НастройкиОтчетаРеализацияАмортизируемогоИмущества(ЭтапРасчета, ИмяПоказателя, ВсеРеализованныеОбъекты, РеализованныйОбъект, СчетДоходовРасходов, ВидСтатьиРасходов, СчетУбытков, ВидСтатьиУбытков, СхемаРасчета));
```
</details>

## ПолучитьТорговыйСбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьТорговыйСбор(ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ПолучитьТорговыйСбор(ПроцессорПолученияДанных));
```
</details>

## НастройкиОтчетаПоСуммамНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НастройкиОтчетаПоСуммамНалога(СхемаРасчета, СчетНалога, Знач КонецПериода = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НастройкиОтчетаПоСуммамНалога(СхемаРасчета, СчетНалога, КонецПериода);
```
</details>

## НастройкиОтчетаУменьшениеНалогаНаТорговыйСбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НастройкиОтчетаУменьшениеНалогаНаТорговыйСбор(СхемаРасчета, Условие) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НастройкиОтчетаУменьшениеНалогаНаТорговыйСбор(СхемаРасчета, Условие));
```
</details>

## ПолучитьКапитальныеВложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьКапитальныеВложения(ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ПолучитьКапитальныеВложения(ПроцессорПолученияДанных));
```
</details>

## НастройкиОтчетаКапитальныеВложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НастройкиОтчетаКапитальныеВложения(СхемаРасчета, ОсновноеСредство) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НастройкиОтчетаКапитальныеВложения(СхемаРасчета, ОсновноеСредство));
```
</details>

## ПолучитьАмортизация
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьАмортизация(ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ПолучитьАмортизация(ПроцессорПолученияДанных));
```
</details>

## СчетаУчетаАмортизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СчетаУчетаАмортизации() Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.СчетаУчетаАмортизации());
```
</details>

## СуммыАмортизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СуммыАмортизации(ТекстЗапроса, СчетаУчета, ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.СуммыАмортизации(ТекстЗапроса, СчетаУчета, ПроцессорПолученияДанных));
```
</details>

## ИсключенияНелинейногоМетода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИсключенияНелинейногоМетода() Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ИсключенияНелинейногоМетода());
```
</details>

## СоздатьПеречниОбъектовИсключенияНелинейногоМетода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьПеречниОбъектовИсключенияНелинейногоМетода(МенеджерВременныхТаблиц) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.СоздатьПеречниОбъектовИсключенияНелинейногоМетода(МенеджерВременныхТаблиц));
```
</details>

## СуммыАмортизацииИсключенияНелинейногоМетода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СуммыАмортизацииИсключенияНелинейногоМетода(ШаблонЗапроса, СчетаУчета, ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.СуммыАмортизацииИсключенияНелинейногоМетода(ШаблонЗапроса, СчетаУчета, ПроцессорПолученияДанных));
```
</details>

## СуммыАмортизацииСпециальныеНалоговыеРежимы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СуммыАмортизацииСпециальныеНалоговыеРежимы(ШаблонЗапроса, ЕстьИсключенияНелинейногоМетода, СчетаУчета, ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.СуммыАмортизацииСпециальныеНалоговыеРежимы(ШаблонЗапроса, ЕстьИсключенияНелинейногоМетода, СчетаУчета, ПроцессорПолученияДанных));
```
</details>

## ДобавитьУсловиеВиртуальнойТаблицыОборотыДтКт
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьУсловиеВиртуальнойТаблицыОборотыДтКт(ПараметрыВиртуальнойТаблицы, ТекстУсловия) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ДобавитьУсловиеВиртуальнойТаблицыОборотыДтКт(ПараметрыВиртуальнойТаблицы, ТекстУсловия));
```
</details>

## ЕстьИсключенияНелинейногоМетода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЕстьИсключенияНелинейногоМетода(Задачи) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ЕстьИсключенияНелинейногоМетода(Задачи));
```
</details>

## НастройкиОтчетаАмортизация
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НастройкиОтчетаАмортизация(ВидАктива, ИсключенияНелинейногоМетода, ЭтапРасчета, СхемаРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НастройкиОтчетаАмортизация(ВидАктива, ИсключенияНелинейногоМетода, ЭтапРасчета, СхемаРасчета));
```
</details>

## НастройкиОтчетаАмортизацияНеУчитываемые
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НастройкиОтчетаАмортизацияНеУчитываемые(ВидАктива, ИсключенияНелинейногоМетода, СхемаРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НастройкиОтчетаАмортизацияНеУчитываемые(ВидАктива, ИсключенияНелинейногоМетода, СхемаРасчета));
```
</details>

## НастроитьОтчетИсключенияНелинейногоМетодаАмортизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура НастроитьОтчетИсключенияНелинейногоМетодаАмортизации(Настройки, ПолеВиртуальнойТаблицы, ВидАктива, СчетУчета) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.НастроитьОтчетИсключенияНелинейногоМетодаАмортизации(Настройки, ПолеВиртуальнойТаблицы, ВидАктива, СчетУчета));
```
</details>

## ДобавитьОтборИсключенияНелинейногоМетодаАмортизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьОтборИсключенияНелинейногоМетодаАмортизации(Настройки, ИмяПоля, ВидСубконто) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ДобавитьОтборИсключенияНелинейногоМетодаАмортизации(Настройки, ИмяПоля, ВидСубконто));
```
</details>

## ПолучитьМетодАмортизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьМетодАмортизации(ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ПолучитьМетодАмортизации(ПроцессорПолученияДанных));
```
</details>

## ПолучитьУбыткиПрошлыхЛет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Это алгоритм получения данных списка

Процедура ПолучитьУбыткиПрошлыхЛет(ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ПолучитьУбыткиПрошлыхЛет(ПроцессорПолученияДанных));
```
</details>

## НастройкиОтчетаУбыткиПрошлыхЛет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НастройкиОтчетаУбыткиПрошлыхЛет(ПериодВозникновенияУбытка, СхемаРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НастройкиОтчетаУбыткиПрошлыхЛет(ПериодВозникновенияУбытка, СхемаРасчета));
```
</details>

## ПолучитьПереносУбытковПрошлыхЛет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьПереносУбытковПрошлыхЛет(ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ПолучитьПереносУбытковПрошлыхЛет(ПроцессорПолученияДанных));
```
</details>

## НастройкиОтчетаПереносУбытковПрошлыхЛет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НастройкиОтчетаПереносУбытковПрошлыхЛет(СхемаРасчета) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НастройкиОтчетаПереносУбытковПрошлыхЛет(СхемаРасчета));
```
</details>

## ПорядокУчетаУбытковПрошлыхЛет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПорядокУчетаУбытковПрошлыхЛет(ОписаниеСумм) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ПорядокУчетаУбытковПрошлыхЛет(ОписаниеСумм));
```
</details>

## ПредставлениеНомераГода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПредставлениеНомераГода(Период) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ПредставлениеНомераГода(Период));
```
</details>

## ЗаписатьНомерГода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаписатьНомерГода(ХранилищеСумм, Период, ОписаниеСумм) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ЗаписатьНомерГода(ХранилищеСумм, Период, ОписаниеСумм));
```
</details>

## ПрочитатьНомерГода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПрочитатьНомерГода(ХранилищеСумм, ОписаниеСумм) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ПрочитатьНомерГода(ХранилищеСумм, ОписаниеСумм));
```
</details>

## ОписаниеФормыРасчетаРаспределенияНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// распределение налога между обособленными подразделениями

Функция ОписаниеФормыРасчетаРаспределенияНалога(КонтекстРасчета, ИмяРедакции) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ОписаниеФормыРасчетаРаспределенияНалога(КонтекстРасчета, ИмяРедакции));
```
</details>

## ПрефиксИмениРаспределениеНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПрефиксИмениРаспределениеНалога() Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ПрефиксИмениРаспределениеНалога());
```
</details>

## НовыйРасчетРаспределенияНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НовыйРасчетРаспределенияНалога() Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.НовыйРасчетРаспределенияНалога());
```
</details>

## ПередатьРасчетРаспределенияНалогаБРО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПередатьРасчетРаспределенияНалогаБРО(Контейнер, Расчет, ИмяРедакции, КонтекстРасчета, ИндексСтраницы, ПризнакНалогоплательщика) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.ПередатьРасчетРаспределенияНалогаБРО(Контейнер, Расчет, ИмяРедакции, КонтекстРасчета, ИндексСтраницы, ПризнакНалогоплательщика));
```
</details>

## СформироватьСтраницыБРО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СформироватьСтраницыБРО(РазделБРО, ОписаниеФормы, ИмяРедакции, КоличествоСтраницНужно) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.СформироватьСтраницыБРО(РазделБРО, ОписаниеФормы, ИмяРедакции, КоличествоСтраницНужно));
```
</details>

## ИмяПоказателяКолонкаСписка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИмяПоказателяКолонкаСписка(ИмяСписка, ИмяПоказателя) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ИмяПоказателяКолонкаСписка(ИмяСписка, ИмяПоказателя));
```
</details>

## ИмяЗаписиПротоколаСтрокаСписка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИмяЗаписиПротоколаСтрокаСписка(ИмяСписка, ИмяКолонки, СтрокаСписка) Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ИмяЗаписиПротоколаСтрокаСписка(ИмяСписка, ИмяКолонки, СтрокаСписка));
```
</details>

## ЭтапРасчетаПоказателейСписка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтапРасчетаПоказателейСписка() Экспорт
```

Пример вызова
```bsl
Результат = НалогНаПрибыльДекларация.ЭтапРасчетаПоказателейСписка());
```
</details>

## УстановитьРезультатРасчетаСписок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьРезультатРасчетаСписок(ПроцессорПолученияДанных) Экспорт
```

Пример вызова
```bsl
НалогНаПрибыльДекларация.УстановитьРезультатРасчетаСписок(ПроцессорПолученияДанных));
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
