---
title: Налоговый учет
slug: erp-uh/налоговый-учет
---


## ЗаполнитьНалоговыеСуммыПроводки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает в проводке суммы НУ,ПР,ВР в зависимости от признака ведения налогового учета на счете.
//
// Параметры:
//		СуммаНУДт - Число - Дебетовая сумма налогового учета
//		СуммаНУКт - Число - Кредитовая сумма налогового учета
//		СуммаПРДт - Число - Дебетовая сумма постоянной разницы
//		СуммаПРКт - Число - Кредитовая сумма постоянной разницы
//		СуммаВРДт - Число - Дебетовая сумма временной разницы
//		СуммаВРКт - Число - Кредитовая сумма временной разницы
//		Проводка - Запись регистра бухгалтерии
//		ЕстьРазницы - Булево
//
Процедура ЗаполнитьНалоговыеСуммыПроводки(СуммаНУДт = 0, СуммаНУКт = 0, Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.ЗаполнитьНалоговыеСуммыПроводки(СуммаНУДт, СуммаНУКт, );
```
</details>

## ПериодичностьОтчетногоПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет периодичность, с которой должна отчитываться организация в данном налоговом периоде.
//
// Параметры:
//  Период		- Дата - дата, характеризующая налоговый период
//  Организация	- СправочникСсылка.Организации - налогоплательщик.
//
// Возвращаемое значение:
//  ПеречислениеСсылка.Периодичность - периодичность (продолжительность первого отчетного периода).
//
Функция ПериодичностьОтчетногоПериода(Период, Организация) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПериодичностьОтчетногоПериода(Период, Организация) 
```
</details>

## ПоказательОпределенияДолиПрибыли
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает показатель определения доли прибыли по ст. 288 НК РФ: расходы на оплату труда или среднесписочноую численность.
//
// Параметры:
//  Период		- Дата - дата, характеризующая налоговый период
//  Организация	- СправочникСсылка.Организации - налогоплательщик.
//
// Возвращаемое значение:
//  ПеречислениеСсылка.ПоказателиДляОпределенияДолиПрибыли - показатель.
//
Функция ПоказательОпределенияДолиПрибыли(Период, Организация) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПоказательОпределенияДолиПрибыли(Период, Организация) 
```
</details>

## БлижайшийНалоговыйПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет границы налогового периода, к которому относится переданная дата.
//  Возвращает данные первого налогового периода организации, если переданная дата относится к периоду до ее создания.
//
// Параметры:
//  ПроверяемыйПериод	 - Дата - дата в периоде, границы которого определяются
//  Организация			 - СправочникСсылка.Организации - налогоплательщик.
//
// Возвращаемое значение:
//  Структура - границы периода
//    * Период - Дата - стандартное начало налогового периода (например, 01 июля для третьего квартала);
//    * Начало - Дата - фактическое начало налогового периода (может совпадать со стандартным началом или
//               датой регистрации организации;
//    * Конец  - Дата - дата с указанием времени.
//
Функция БлижайшийНалоговыйПериод(ПроверяемыйПериод, Организация) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.БлижайшийНалоговыйПериод(ПроверяемыйПериод, Организация) 
```
</details>

## ИнформацияНалоговыйПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Готовит тексты информации для пользователя об особенностях первого налогового периода по налогу на прибыль
// организации, зарегистрированной в декабре.
//
// Параметры:
//  Период		- Дата - конец отчетного периода, к которому относится информация
//  Организация	- СправочникСсылка.Организации - налогоплательщик
//  ОписаниеНалоговогоПериода
//              - Структура - результат функции ИнтерфейсыВзаимодействияБРО.БлижайшийНалоговыйПериод.
//                Может быть передан для оптимизации производительности, если уже рассчитан в вызывающем коде.
//
// Возвращаемое значение:
//  Структура - ИнформированиеНалоговыйПериодКлиентСервер.НовыйИнформация.
//
Функция ИнформацияНалоговыйПериод(Период, Организация, ОписаниеНалоговогоПериода = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ИнформацияНалоговыйПериод(Период, Организация, ОписаниеНалоговогоПериода);
```
</details>

## ТребуетсяНалоговыйУчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, требуется ли в информационной базе вести налоговый учет по налогу на прибыль организаций.
//
// Возвращаемое значение:
//  Булево
//
Функция ТребуетсяНалоговыйУчет() Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ТребуетсяНалоговыйУчет() 
```
</details>

## НачалоНалоговогоПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет дату начала налогового периода по налогу на прибыль.
//
// Параметры:
//  Период	    - Дата - дата, характеризующая налоговый период
//  Организация	- СправочникСсылка.Организации - организация, дату регистрации которой следует учесть при получении периода.
//
// Возвращаемое значение:
//  Дата         - дата начала налогового периода по налогу на прибыль
//  Неопределено - в запрошенный период организация не существовала.
//
Функция НачалоНалоговогоПериода(Период, Организация) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.НачалоНалоговогоПериода(Период, Организация) 
```
</details>

## КонецПредыдущегоОтчетногоПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет дату окончания предыдущего отчетного периода по налогу на прибыль в рамках налогового периода.
//
// Параметры:
//  Период	    - Дата - дата, характеризующая налоговый период
//  Организация	- СправочникСсылка.Организации - организация, сведения о которой следует учесть при получении периода
//  Кеш         - Соответствие - можно передать, если для одной и той же организации следует определить множество
//                отчетных периодов. Для вызовов с разными организациями следует передавать разный Кеш.
//
// Возвращаемое значение:
//  Дата         - дата окончания предыдущего отчетного периода по налогу на прибыль.
//  Неопределено - это первый отчетный период в течение налогового - предыдущего нет.
//
Функция КонецПредыдущегоОтчетногоПериода(Период, Организация, Кеш = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.КонецПредыдущегоОтчетногоПериода(Период, Организация, Кеш);
```
</details>

## ВыручкаОтРеализации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ВыручкаОтРеализации(Период, Организация) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ВыручкаОтРеализации(Период, Организация) 
```
</details>

## ПрименяютсяРазныеСтавкиНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак применения разных ставок по налогу на прибыль
//
// Возвращаемое значение:
// 	Булево -
Функция ПрименяютсяРазныеСтавкиНалогаНаПрибыль() Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПрименяютсяРазныеСтавкиНалогаНаПрибыль() 
```
</details>

## НалоговаяСтавкаФедеральныйБюджет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет ставку налога на прибыль, подлежащего уплате в федеральный бюджет
//
// Параметры:
//  Период	              - Дата - характеризует налоговый период
//  Организация	          - СправочникСсылка.Организации - налогоплательщик
//  ФормаПредставленияРезультата - Строка - форма, в которой функция вернет значение
//                          * "Доля"                              - как доля от налоговой базы (например, 0,2).
//                          * "Процент", "%" и любые другие слова - как процент, где база принята за 100% (например, 20%).
//  ВариантНалогообложенияПрибыли - Неопределено, СправочникСсылка.ВариантыНалогообложенияПрибыли -
//
// Возвращаемое значение:
//  Число - значение ставки налога (в долях от единицы или в процентах - см. ФормаПредставленияРезультата).
//
Функция НалоговаяСтавкаФедеральныйБюджет(Период, Организация, ФормаПредставленияРезультата = "Доля", Знач ВариантНалогообложенияПрибыли = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.НалоговаяСтавкаФедеральныйБюджет(Период, Организация, ФормаПредставленияРезультата, ВариантНалогообложенияПрибыли);
```
</details>

## НалоговаяСтавкаРегиональныйБюджет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет ставку налога на прибыль, подлежащего уплате в региональный бюджет (бюджет субъекта Российской Федерации).
//
// Параметры:
//  Период	              - Дата - характеризует налоговый период
//  Организация           - СправочникСсылка.Организации	- налогоплательщик
//  ФормаПредставленияРезультата - Строка - форма, в которой функция вернет значение
//                          * "Доля"                              - как доля от налоговой базы (например, 0,2).
//                          * "Процент", "%" и любые другие слова - как процент, где база принята за 100% (например, 20%).
//  ВариантНалогообложенияПрибыли - Неопределено, СправочникСсылка.ВариантыНалогообложенияПрибыли - Уточнение по варианту н/о
//  РегистрацияВНалоговомОргане   - Неопределено, СправочникСсылка.РегистрацииВНалоговомОргане - Уточнение по ФНС
//
// Возвращаемое значение:
//  Число - значение ставки налога (в долях от единицы или в процентах - см. ФормаПредставленияРезультата).
//
Функция НалоговаяСтавкаРегиональныйБюджет(Период, Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.НалоговаяСтавкаРегиональныйБюджет(Период, );
```
</details>

## ПолучитьСтавкуНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела.
// Следует использовать
// - НалоговаяСтавкаФедеральныйБюджет()
// - НалоговаяСтавкаРегиональныйБюджет()
// - НалоговыйУчетОбособленныхПодразделений.ЗаполнитьНалоговыеСтавкиРегиональныйБюджет().
Функция ПолучитьСтавкуНалогаНаПрибыль(СтруктураШапкиДокумента, ИФНС = Неопределено, СтавкаФБ = 0, СтавкаРФ = 0, СтавкаМестный = 0) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПолучитьСтавкуНалогаНаПрибыль(СтруктураШапкиДокумента, ИФНС, СтавкаФБ, СтавкаРФ, СтавкаМестный);
```
</details>

## ПолучитьТаблицуВидовАктивовИОбязательств
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Формируется таблица строк в которой задано соответствие видов активов
// (обязательства) и счетов налогового учета, на которых отражаются разницы
// по этим видам активов.
//
// Возвращаемое значение:
//   ТаблицаЗначений - таблица соответствия.
//
Функция ПолучитьТаблицуВидовАктивовИОбязательств() Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПолучитьТаблицуВидовАктивовИОбязательств() 
```
</details>

## ДобавитьТекстЗапросаСчетаЕНВД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция добавляет в текст запроса временную таблицу, содержащую счета ЕНВД.
//
//	Параметры:
//		Запрос - запрос, в который необходимо добавить временную таблицу со счетами.
//
//	Возвращаемое значение:
//		ТекстЗапроса - Строка неограниченной длины - первоначальный текст запроса, перед которым добавлено получение временной таблицы со счетами ЕНВД.
//
Функция ДобавитьТекстЗапросаСчетаЕНВД(Запрос) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ДобавитьТекстЗапросаСчетаЕНВД(Запрос) 
```
</details>

## ОстаткиВременныхРазницПоВидуАктивовОбязательств
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отложенные налоговые активы и отложенные налоговые обязательства.
// Определяются суммы временных разницы, которые отражены на плане счетов
// по конкретному виду ОНА (ОНО) и распределяются на вычитаемые и налогооблагаемые разницы,
// числящиеся на остатках текущего периода.
//
// Параметры:
//		СтрокаВидАктиваОбязательства - строка таблицы в которой задано соответствие
//			вида актива (обязательства) и счетов налогового учета, на которых
//			отражаются разницы по этому виду активов.
//
Функция ОстаткиВременныхРазницПоВидуАктивовОбязательств(СтрокаВидАктиваОбязательства, Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ОстаткиВременныхРазницПоВидуАктивовОбязательств(СтрокаВидАктиваОбязательства, );
```
</details>

## КоэффициентРаспределенияРасходовПоВидамДеятельности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет коэффициент распределения расходов по видам деятельности с разным порядком налогообложения.
//
// Параметры
//  Организации - СправочникСсылка.Организации или массив со значениями этого типа
//  НачалоПериода,
//  КонецПериода - Дата - характеризует период, за который рассчитывается коэффициент. Период всегда кратен месяцу.
//                        Предполагается, что период лежит в пределах налогового периода,
//                        параметры учетной политики в течение которого неизменны.
//
// Возвращаемое значение:
//   Число - коэффициент распределения расходов по видам деятельности.
//
Функция КоэффициентРаспределенияРасходовПоВидамДеятельности(Организации, Знач НачалоПериода, Знач КонецПериода = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.КоэффициентРаспределенияРасходовПоВидамДеятельности(Организации, НачалоПериода, КонецПериода);
```
</details>

## ДолиСписанияРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регламентная операция "Расчет долей".
// Определяет на основании базы данных доли списания расходов, см. процедуру Документы.РегламентнаяОперация.МодульОбъекта.РасчетДолейСписанияКосвенныхРасходов.
//
//	Параметры:
//		Период - Дата - на основании даты определяется анализируемый период (берется начало и конец месяца от даты)
//		Организация - СправочникСсылка.Организации
//		ПротоколНормируемыеРасходы - Таблица значений - пустая, содержит колонки регистра сведений "РасчетНормированияРасходов".
//		ТранспортныеРасходы - Булево - учитывать или нет транспортные расходы при определении долей.
//
//	Возвращаемое значение:
//		Структура - инициализируется в начале функции.
//
Функция ДолиСписанияРасходов(Период, Организация, ПротоколНормируемыеРасходы, ТранспортныеРасходы) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ДолиСписанияРасходов(Период, Организация, ПротоколНормируемыеРасходы, ТранспортныеРасходы) 
```
</details>

## ВсяОрганизация
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает перечень (массив) всех структурных частей переданной головной организации, имеющих отдельный баланс.
// В перечень входит головная организация и все ее обособленные подразделения на выделенном балансе.
// В перечень входят только те организации, данные по которым доступны текущему пользователю.
//
// Параметры:
//  Организация - организация, которая явялется головной для остальных.
//
// Возвращаемое значение:
//  Массив - организация, которая является головной для остальных
//           и все структурно подчиненные ей организации.
//
Функция ВсяОрганизация(Организация) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ВсяОрганизация(Организация) 
```
</details>

## ПрибылиИУбытки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция рассчитывает прибыли убытки по указанном виду доходов и расходов
//
// Параметры:
//   Счет учета доходов   91.01
//   Счет учета расхоов   91.02
//   Вид доходов и расходов из перечисления ВидыПрочихДоходовИРасходов
//   Флаг выдаваемого результата. "Убыток" - выдать сумму убытка, иначе - выдать сумму прибыли.
//
//
Функция ПрибылиИУбытки(Запрос, Счет911, Счет912, ВидДоходовРасходов, Флаг) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПрибылиИУбытки(Запрос, Счет911, Счет912, ВидДоходовРасходов, Флаг) 
```
</details>

## ТекстЗапросаСоздатьВременнуюТаблицуДолиСпециальныеРежимы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекстЗапросаСоздатьВременнуюТаблицуДолиСпециальныеРежимы() Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ТекстЗапросаСоздатьВременнуюТаблицуДолиСпециальныеРежимы() 
```
</details>

## УбытокОтРеализацииПраваТребованияВключаетсяЕдиновременно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция УбытокОтРеализацииПраваТребованияВключаетсяЕдиновременно(НалоговыйПериод) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.УбытокОтРеализацииПраваТребованияВключаетсяЕдиновременно(НалоговыйПериод) 
```
</details>

## НоваяТаблицаНачисленияНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НоваяТаблицаНачисленияНалога() Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.НоваяТаблицаНачисленияНалога() 
```
</details>

## УстановитьСубконтоСчетаПоНачислениюНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает значения субконто для проводки по начислению налога
//
// Параметры:
//   ТекущаяПроводка - Структура, СтрокаТаблицыЗначений - данные проводки по начислению налога
//   Счет            - ПланСчетовСсылка.Хозрасчетный - счет, для которого требуется установить субконто
//   СубконтоСчета   - РегистрБухгалтерииСубконто.Хозрасчетный - субконто, для которого требуется установить значения
//
Процедура УстановитьСубконтоСчетаПоНачислениюНалога(ТекущаяПроводка, Счет, СубконтоСчета) Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.УстановитьСубконтоСчетаПоНачислениюНалога(ТекущаяПроводка, Счет, СубконтоСчета) 
```
</details>

## ВыводитьУведомлениеОбИзмененииСтавкиНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает необходимость вывода уведомления об изменении ставки налога на прибыль.
//
// Параметры:
// 	Период - Дата - Дата проверки
//
// Возвращаемое значение:
//  Булево
Функция ВыводитьУведомлениеОбИзмененииСтавкиНалогаНаПрибыль(Знач Период) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ВыводитьУведомлениеОбИзмененииСтавкиНалогаНаПрибыль(Период) 
```
</details>

## ДатаНачалаДействия176ФЗ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дату начала действия редакции 1 ст. 284 НК РФ в ред. Федерального закона от 12.07.2024 N 176-ФЗ
//
// Возвращаемое значение:
// 	Булево - Дата начала действия редакции.
//
Функция ДатаНачалаДействия176ФЗ() Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ДатаНачалаДействия176ФЗ() 
```
</details>

## ВыполненРасчетНалогаПослеИзмененияСтавки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает наличие регламентных операций по расчету налога на прибыль после изменения ставки.
//
// Параметры:
// 	Период - Дата - Период изменения ставки
//
// Возвращаемое значение:
// 	Булево - Выполнен расчет налога после изменения ставки
//
Функция ВыполненРасчетНалогаПослеИзмененияСтавки(Знач Период, Знач Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ВыполненРасчетНалогаПослеИзмененияСтавки(Период, Организация);
```
</details>

## ДобавитьЭтап_ОсвобождениеОтУплатыНалоговВСвязиСКоронавирусом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет этап в таблицу этапов закрытия месяца.
// Элементы данной таблицы являются элементами второго уровня в дереве этапов в форме закрытия месяца.
//
// Параметры:
// 	ТаблицаЭтапов - ТаблицаЗначений - см. Обработка.ОперацииЗакрытияМесяца.ЗаполнитьОписаниеЭтаповЗакрытияМесяца
// 	ТекущийРодитель - Строка - идентификатор группы.
Процедура ДобавитьЭтап_ОсвобождениеОтУплатыНалоговВСвязиСКоронавирусом(ТаблицаЭтапов,ТекущийРодитель) Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.ДобавитьЭтап_ОсвобождениеОтУплатыНалоговВСвязиСКоронавирусом(ТаблицаЭтапов, ТекущийРодитель) 
```
</details>

## Использование_ОсвобождениеОтУплатыНалоговВСвязиСКоронавирусом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчики этапа.
Процедура Использование_ОсвобождениеОтУплатыНалоговВСвязиСКоронавирусом(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.Использование_ОсвобождениеОтУплатыНалоговВСвязиСКоронавирусом(ПараметрыОбработчика) 
```
</details>

## ДобавитьЭтап_ПереходНаУчетКурсовыхРазницНУПо67ФЗ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет этап в таблицу этапов закрытия месяца.
// Элементы данной таблицы являются элементами второго уровня в дереве этапов в форме закрытия месяца.
//
// Параметры:
// 	ТаблицаЭтапов - ТаблицаЗначений - см. Обработка.ОперацииЗакрытияМесяца.ЗаполнитьОписаниеЭтаповЗакрытияМесяца
// 	ТекущийРодитель - Строка - идентификатор группы.
Процедура ДобавитьЭтап_ПереходНаУчетКурсовыхРазницНУПо67ФЗ(ТаблицаЭтапов,ТекущийРодитель) Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.ДобавитьЭтап_ПереходНаУчетКурсовыхРазницНУПо67ФЗ(ТаблицаЭтапов, ТекущийРодитель) 
```
</details>

## Использование_ПереходНаУчетКурсовыхРазницНУПо67ФЗ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчики этапа.
Процедура Использование_ПереходНаУчетКурсовыхРазницНУПо67ФЗ(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.Использование_ПереходНаУчетКурсовыхРазницНУПо67ФЗ(ПараметрыОбработчика) 
```
</details>

## ЭтоНепринимаемаяСтатьяДоходовРасходовПоНУ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
// Определяет относится ли статья доходов/расходов к не облагаемой дейтельности по налоговому учету.
//
Функция ЭтоНепринимаемаяСтатьяДоходовРасходовПоНУ(СтатьяДоходовРасходов) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ЭтоНепринимаемаяСтатьяДоходовРасходовПоНУ(СтатьяДоходовРасходов) 
```
</details>

## ПолучитьДолюКосвенногоРасхода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет доли списания нормируемых расходов,
// транспортных расходов, расходов, распределяемых по видам деятельности.
Функция ПолучитьДолюКосвенногоРасхода(ТаблицаДолейКосвенныхРасходов, ВидРасхода) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПолучитьДолюКосвенногоРасхода(ТаблицаДолейКосвенныхРасходов, ВидРасхода) 
```
</details>

## ОборотыВременныхРазницПоВидуАктивовОбязательствРасчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОборотыВременныхРазницПоВидуАктивовОбязательствРасчет(Реквизиты, Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ОборотыВременныхРазницПоВидуАктивовОбязательствРасчет(Реквизиты, );
```
</details>

## ПолучитьМассивСчетовУчетаРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьМассивСчетовУчетаРасходов() Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПолучитьМассивСчетовУчетаРасходов() 
```
</details>

## ПолучитьМассивСчетовЕНВД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьМассивСчетовЕНВД() Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПолучитьМассивСчетовЕНВД() 
```
</details>

## ПолучитьЗаписьСтавокНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьЗаписьСтавокНалогаНаПрибыль() Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПолучитьЗаписьСтавокНалогаНаПрибыль());
```
</details>

## ЭтоНепринимаемыйРасходНУ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// ВСПОМОГАТЕЛЬНЫЕ ПРОЦЕДУРЫ И ФУНКЦИИ

Функция ЭтоНепринимаемыйРасходНУ(СубконтоНУ1, СубконтоНУ2, СубконтоНУ3) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ЭтоНепринимаемыйРасходНУ(СубконтоНУ1, СубконтоНУ2, СубконтоНУ3) 
```
</details>

## ПолучитьРасчетСписанияКосвенныхРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регламентная операция "Списание нормируемых расходов"
// Возвращает данные информационной базы для формирования движений по регистрам.
//
// Параметры:
// 	КонтекстРасчета - см. ЗакрытиеМесяца.КонтекстСписаниеКосвенныхРасходов
// 	Отказ - Булево
// Возвращаемое значение:
// 	ТаблицаЗначений - Описание:
// * СчетДт - ПланСчетовСсылка.Хозрасчетный -
// * СчетКт - ПланСчетовСсылка.Хозрасчетный -
// * СтатьяРасходов - ПланВидовХарактеристикСсылка.СтатьиРасходов -
// * Организация - СправочникСсылка.Организации -
// * Подразделение - СправочникСсылка.СтруктураПредприятия -
// * НаправлениеДеятельности - СправочникСсылка.НаправленияДеятельности -
// * Содержание - Строка -
// * СуммаНУ - Число -
// * СуммаПР - Число -
// * СуммаВР - Число -
Функция ПолучитьРасчетСписанияКосвенныхРасходов(КонтекстРасчета, Отказ) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПолучитьРасчетСписанияКосвенныхРасходов(КонтекстРасчета, Отказ) 
```
</details>

## СоздатьВременнуюТаблицуДолиСписанияКосвенныхРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает временную таблицу с долями списания косвенных расходов в разрезе статей расходов
//
// Параметры:
// 	Период - Дата - месяц, на который требуются данные
// 	Организации - СправочникСсылка.Организации, Массив из СправочникСсылка.Организации -
// 	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц -
Процедура СоздатьВременнуюТаблицуДолиСписанияКосвенныхРасходов(Период, Организации, МенеджерВременныхТаблиц) Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.СоздатьВременнуюТаблицуДолиСписанияКосвенныхРасходов(Период, Организации, МенеджерВременныхТаблиц) 
```
</details>

## ПараметрыПримененияНовогоАлгоритмаСписанияКосвенныхРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры применения нового алгоритма списания косвенных расходов
//
// Параметры:
//  Организация - СправочникСсылка.Организации -
//  Период      - Дата, Неопределено -
//
// Возвращаемое значение:
//  Структура - описание:
//  	* ПрименяетсяНовыйАлгоритм - Булево -
//  	* ДатаПрименения - Дата - Дата начала применения нового алгоритма
//
Функция ПараметрыПримененияНовогоАлгоритмаСписанияКосвенныхРасходов(Организация, Знач Период = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПараметрыПримененияНовогоАлгоритмаСписанияКосвенныхРасходов(Организация, Период);
```
</details>

## ДоляТранспортныхРасходовТекущегоМесяца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Рассчитывает долю транспортных расходов в соответствии со ст. 320 НК РФ
//
// Параметры
//	Период - Дата - месяц расчета.
//	Организация - СправочникСсылка.Организации, Массив - организация или массив организаций, по которым нужно произвести расчет.
//	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - в него помещается результат расчета, если передан массив организаций
//		ВТ ДолиТранспортныхРасходов с колонками
//			Организация
//			ДоляТранспортныхРасходов.
//
// Возвращаемое значение:
//	Число - доля транспортных расходов для организации (если передан массив, то 0).
//
Функция ДоляТранспортныхРасходовТекущегоМесяца(Период, Организация, МенеджерВременныхТаблиц = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ДоляТранспортныхРасходовТекущегоМесяца(Период, Организация, МенеджерВременныхТаблиц);
```
</details>

## СоздатьПустуюВременнуюТаблицуДолиТранспортныхРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
// Создает пустую временную таблицу ДолиТранспортныхРасходов
//
// Параметры:
// 	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - МВТ исполняемого запроса
Процедура СоздатьПустуюВременнуюТаблицуДолиТранспортныхРасходов(МенеджерВременныхТаблиц) Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.СоздатьПустуюВременнуюТаблицуДолиТранспортныхРасходов(МенеджерВременныхТаблиц) 
```
</details>

## ПодготовитьТаблицуРасчетСтавокНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПодготовитьТаблицуРасчетСтавокНалогаНаПрибыль(Отказ) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПодготовитьТаблицуРасчетСтавокНалогаНаПрибыль(Отказ) 
```
</details>

## ТекстЗапроса_НалоговаяСтавкаДляВсехОрганизаций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекстЗапроса_НалоговаяСтавкаДляВсехОрганизаций() Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ТекстЗапроса_НалоговаяСтавкаДляВсехОрганизаций());
```
</details>

## УстановитьПараметрыЗапроса_НалоговыеСтавки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьПараметрыЗапроса_НалоговыеСтавки(Запрос, Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.УстановитьПараметрыЗапроса_НалоговыеСтавки(Запрос, );
```
</details>

## ТекстЗапроса_ПроверитьРасчетНалогаПослеИзмененияСтавки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекстЗапроса_ПроверитьРасчетНалогаПослеИзмененияСтавки() Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ТекстЗапроса_ПроверитьРасчетНалогаПослеИзмененияСтавки());
```
</details>

## ПолучитьСведенияОПоказателяхОтчетаПрибыльФормаОтчета2010Кв4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьСведенияОПоказателяхОтчетаПрибыльФормаОтчета2010Кв4(ПоказателиОтчета) Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.ПолучитьСведенияОПоказателяхОтчетаПрибыльФормаОтчета2010Кв4(ПоказателиОтчета) 
```
</details>

## ПолучитьСведенияОПоказателяхОтчетаПрибыльФормаОтчета2012Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьСведенияОПоказателяхОтчетаПрибыльФормаОтчета2012Кв1(ПоказателиОтчета) Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.ПолучитьСведенияОПоказателяхОтчетаПрибыльФормаОтчета2012Кв1(ПоказателиОтчета) 
```
</details>

## ПолучитьСведенияОПоказателяхОтчетаПрибыльФормаОтчета2015Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьСведенияОПоказателяхОтчетаПрибыльФормаОтчета2015Кв1(ПоказателиОтчета) Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.ПолучитьСведенияОПоказателяхОтчетаПрибыльФормаОтчета2015Кв1(ПоказателиОтчета) 
```
</details>

## ЗаполнитьОтчетПрибыльФормаОтчета2012Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет декларацию по налогу на прибыль
//
// Параметры: - (см. РегламентированнаяОтчетностьПереопределяемый.ЗаполнитьОтчет).
//
Процедура ЗаполнитьОтчетПрибыльФормаОтчета2012Кв1(ПараметрыОтчета, Контейнер) Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.ЗаполнитьОтчетПрибыльФормаОтчета2012Кв1(ПараметрыОтчета, Контейнер) 
```
</details>

## ЗаполнитьОтчетПрибыльФормаОтчета2015Кв1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет декларацию по налогу на прибыль
//
// Параметры: - (см. РегламентированнаяОтчетностьПереопределяемый.ЗаполнитьОтчет).
//
Процедура ЗаполнитьОтчетПрибыльФормаОтчета2015Кв1(Контейнер, ТаблицаРасшифровки, ИДРедакцииОтчета, КонтекстРасчета) Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.ЗаполнитьОтчетПрибыльФормаОтчета2015Кв1(Контейнер, ТаблицаРасшифровки, ИДРедакцииОтчета, КонтекстРасчета) 
```
</details>

## ОтключитьПрименениеРазличныхСтавокПоНалогуНаПрибыльПРОФ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОтключитьПрименениеРазличныхСтавокПоНалогуНаПрибыльПРОФ() Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.ОтключитьПрименениеРазличныхСтавокПоНалогуНаПрибыльПРОФ() 
```
</details>

## УчетВРазрезеНалоговыхОрганов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определение ведения учета в разрезе налоговых органов
//
// Возвращаемое значение:
// 	Булево -
//
Функция УчетВРазрезеНалоговыхОрганов() Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.УчетВРазрезеНалоговыхОрганов() 
```
</details>

## РегистрацияОрганизацииВНалоговомОргане
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ссылку на "Регистрацию в налоговом органе" по состоянию на некоторую ДатаАктуальности
// Параметры:
//	Организация - СправочникСсылка.Организации - организации.
//	Период - Дата - дата, на которую требуется получить сведения.
//
// Возвращаемое значение:
//	СправочникСсылка.РегистрацииВНалоговомОргане - регистрация в налоговом органе.
//
Функция РегистрацияОрганизацииВНалоговомОргане(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.РегистрацияОрганизацииВНалоговомОргане(Организация, Период) 
```
</details>

## ЗначенияНастроекПоАнтикризиснымМерамПоКоронавирусу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие значений настроек по организациям.
//
// Параметры:
// 	Организации - СправочникСсылка.Организации, Массив Из СправочникСсылка.Организации -
//
// Возвращаемое значение:
// 	Соответствие - содержит:
// 		* Ключ      - СправочникСсылка.Организации -
// 		* Значение  - Структура - содержит:
// 			** НастройкаСуществует - Булево
// 			** ДеятельностьОтнесенаКПострадавшимОтКоронавируса - Булево
//
Функция ЗначенияНастроекПоАнтикризиснымМерамПоКоронавирусу(Организации) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ЗначенияНастроекПоАнтикризиснымМерамПоКоронавирусу(Организации) 
```
</details>

## ДатаВходитВПериодОсвобожденияОтНалоговПострадавшимОтКоронавируса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверка даты на вхождение в период освобождения от налогов пострадавшим от коронавируса
//
// Параметры:
// 	Период - Дата - Проверяемая дата
//
// Возвращаемое значение:
// 	Булево - Описание - Истина, если дата входит в период
//
Функция ДатаВходитВПериодОсвобожденияОтНалоговПострадавшимОтКоронавируса(Период) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ДатаВходитВПериодОсвобожденияОтНалоговПострадавшимОтКоронавируса(Период) 
```
</details>

## ДеятельностьОтнесенаКПострадавшимОтКоронавируса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, что на организацию распространяется освобождение от налогов,
// установленное статьей 2 Федерального закона № 172-ФЗ от 08.06.2020
//
// Параметры:
//  Организация - СправочникСсылка.Организации
//
// Возвращаемое значение:
//  Булево
//
Функция ДеятельностьОтнесенаКПострадавшимОтКоронавируса(Организация) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ДеятельностьОтнесенаКПострадавшимОтКоронавируса(Организация) 
```
</details>

## ПериодОсвобожденияОтНалоговПострадавшимОтКоронавируса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет период освобождения от налогов, установленный статьей 2 Федерального закона № 172-ФЗ от 08.06.2020
//
// Возвращаемое значение:
//  Структура - ключи Начало,Конец - даты
//
Функция ПериодОсвобожденияОтНалоговПострадавшимОтКоронавируса() Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПериодОсвобожденияОтНалоговПострадавшимОтКоронавируса() 
```
</details>

## НалогиОсвобождениеПострадавшихОтКоронавируса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Содержит перечень налогов, по которым предусмотрено освобождение статьей 2 Федерального закона № 172-ФЗ от 08.06.2020
//
// Возвращаемое значение:
//  Массив из Строка - идентификаторы задач из списка задач бухгалтера
//
Функция НалогиОсвобождениеПострадавшихОтКоронавируса() Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.НалогиОсвобождениеПострадавшихОтКоронавируса() 
```
</details>

## ТекстСодержанияПроводкиОсвобождениеПострадавшихОтКоронавируса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текст содержания проводки по освобождению от налога
//
// Параметры:
//  Период - Дата - дата, для которой формируется текст содержания проводки
//
// Возвращаемое значение:
//  Строка
//
Функция ТекстСодержанияПроводкиОсвобождениеПострадавшихОтКоронавируса(Период) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ТекстСодержанияПроводкиОсвобождениеПострадавшихОтКоронавируса(Период) 
```
</details>

## ВозможноОсвобождениеОтНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, возможно ли освобождение от конкретного налога в конкретном периоде.
// Для проверки, имеет ли право организация на это освобождение, следует дополнительно применять
// ДеятельностьОтнесенаКПострадавшимОтКоронавируса
//
// Параметры:
//  КодЗадачи   - Строка - код задачи по уплате налога
//  Период      - Дата - период, для которого требуется проверить, возможно ли освобождение от налога
//
// Возвращаемое значение:
//  Булево
//
Функция ВозможноОсвобождениеОтНалога(КодЗадачи, Период) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ВозможноОсвобождениеОтНалога(КодЗадачи, Период) 
```
</details>

## ДополнитьПроводкамиПоОсвобождениюОтНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет данные по освобождению от налога в таблицу проводок
//
// Параметры:
//   ТаблицаПроводок - ТаблицаЗначений - См. НоваяТаблицаНачисленияНалога()
//   Период          - Дата - Дата начисления налога
//   СчетРасчетов    - ПланСчетовСсылка.Хозрасчетный - счет начисления налога
//   Сумма           - Число - Сумма к уплате
//
Процедура ДополнитьПроводкамиПоОсвобождениюОтНалога(ТаблицаПроводок, Период, СчетРасчетов, Сумма) Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.ДополнитьПроводкамиПоОсвобождениюОтНалога(ТаблицаПроводок, Период, СчетРасчетов, Сумма) 
```
</details>

## СуммаОсвобожденияОтНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сумму налога, которая была освобождена от уплаты в бюджет
//
// Параметры:
//   Организация   - СправочникСсылка.Организации - Организация, для которой необходимо рассчитать сумму
//   НачалоПериода - Дата - начала периода, за который требуется рассчитать сумму освобожденного налога
//   КонецПериода  - Дата - конец периода, за который требуется рассчитать сумму освобожденного налога
//   СчетРасчетов  - ПланСчетовСсылка.Хозрасчетный - счет начисления налога
//
// Возвращаемое значение:
//   Число
//
Функция СуммаОсвобожденияОтНалога(Организация, НачалоПериода, КонецПериода, СчетРасчетов) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.СуммаОсвобожденияОтНалога(Организация, НачалоПериода, КонецПериода, СчетРасчетов) 
```
</details>

## ЭтоПроводкаПоНачислениюНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоПроводкаПоНачислениюНДС(Проводка) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ЭтоПроводкаПоНачислениюНДС(Проводка) 
```
</details>

## ЭтоПроводкаДоходыНеУчитываемыеДляНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоПроводкаДоходыНеУчитываемыеДляНалогаНаПрибыль(СчетКт, СубконтоКт) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ЭтоПроводкаДоходыНеУчитываемыеДляНалогаНаПрибыль(СчетКт, СубконтоКт) 
```
</details>

## ЭтоПроводкаРасходыНеУчитываемыеДляНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоПроводкаРасходыНеУчитываемыеДляНалогаНаПрибыль(СчетДт, СубконтоДт) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ЭтоПроводкаРасходыНеУчитываемыеДляНалогаНаПрибыль(СчетДт, СубконтоДт) 
```
</details>

## ЭтоРасходНаАмортизацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоРасходНаАмортизацию(СубконтоНУ1, СубконтоНУ2, СубконтоНУ3) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ЭтоРасходНаАмортизацию(СубконтоНУ1, СубконтоНУ2, СубконтоНУ3) 
```
</details>

## ОпределитьНеПринимаемыеДоходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция анализирует аналитику затрат по кредиту проводки.
// Если статья затрат не принимаемая к НУ, то возвращаемое значение "истина".
//
//	Параметры:
//		Проводка - запись регистра бухгалтерии.
//
//	Возвращаемое значение:
//		Булево - Истина, если одно из субконто по кредиту проводки является статьей затрат не принимаемой к НУ (см. функцию НалоговыйУчет.ЭтоНепринимаемаяСтатьяДоходовРасходовПоНУ).
//
Функция ОпределитьНеПринимаемыеДоходы(Проводка) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ОпределитьНеПринимаемыеДоходы(Проводка) 
```
</details>

## ОпределитьВнереализационныеДоходыРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОпределитьВнереализационныеДоходыРасходы(Проводка) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ОпределитьВнереализационныеДоходыРасходы(Проводка) 
```
</details>

## ДолиСписанияНормируемыхРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДолиСписанияНормируемыхРасходов(Период, Организация, ДоляСпециальныхРежимов, Протокол = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ДолиСписанияНормируемыхРасходов(Период, Организация, ДоляСпециальныхРежимов, Протокол);
```
</details>

## ОграниченияРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОграниченияРасходов(Период, Организация, ДоляСпециальныхРежимов) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ОграниченияРасходов(Период, Организация, ДоляСпециальныхРежимов));
```
</details>

## ЛимитРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЛимитРасходов(База, Норма) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ЛимитРасходов(База, Норма));
```
</details>

## РасходыНаОплатуТруда
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РасходыНаОплатуТруда(Период, Организация, ДоляСпециальныхРежимов) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.РасходыНаОплатуТруда(Период, Организация, ДоляСпециальныхРежимов));
```
</details>

## КоличествоЗастрахованныхОтУтратыРаботоспособности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КоличествоЗастрахованныхОтУтратыРаботоспособности(Период, Организация) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.КоличествоЗастрахованныхОтУтратыРаботоспособности(Период, Организация));
```
</details>

## СуммыНормируемыхРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СуммыНормируемыхРасходов(Период, Организация, ВидыНормируемыхРасходов, ТекущийМесяцПоДаннымОперКонтура = Истина) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.СуммыНормируемыхРасходов(Период, Организация, ВидыНормируемыхРасходов, ТекущийМесяцПоДаннымОперКонтура);
```
</details>

## МаксимальнаяДоляУменьшенияПрибылиЗаСчетУбытковПрошлыхЛет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция МаксимальнаяДоляУменьшенияПрибылиЗаСчетУбытковПрошлыхЛет(Период, ИгнорироватьОграничениеНаПереносУбытков = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.МаксимальнаяДоляУменьшенияПрибылиЗаСчетУбытковПрошлыхЛет(Период, ИгнорироватьОграничениеНаПереносУбытков);
```
</details>

## ПрименяетсяОграничениеНаПереносУбытковПрошлыхЛетПоДолеПрибыли
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, попадает ли указанный период в интервал,
// на который установлено ограничение на перенос убытков прошлых лет в 50% прибыли текущего налогового периода (п. 2.1 ст. 283 НК РФ)
//
// Параметры
//  Период - Дата - период, который проверяется на вхождение в интервал, на который установлено ограничение.
//
// Возвращаемое значение:
//   Булево - Истина - в указанном периоде применяется ограничение на перенос убытков прошлых лет.
//
Функция ПрименяетсяОграничениеНаПереносУбытковПрошлыхЛетПоДолеПрибыли(Период) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПрименяетсяОграничениеНаПереносУбытковПрошлыхЛетПоДолеПрибыли(Период) 
```
</details>

## ДобавитьСтрокуРасшифровки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьСтрокуРасшифровки(ТаблицаРасшифровок, ИмяПоказателя, НаименованиеПоказателя, ЗнакОперации, НаименованиеСлагаемого, Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.ДобавитьСтрокуРасшифровки(ТаблицаРасшифровок, ИмяПоказателя, НаименованиеПоказателя, ЗнакОперации, НаименованиеСлагаемого, );
```
</details>

## ПолучитьМассивВнереализационныхРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьМассивВнереализационныхРасходов() Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПолучитьМассивВнереализационныхРасходов());
```
</details>

## БухИтогиНайти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция БухИтогиНайти(ИмяЗначения, КлючСтроки, ТаблицаПоиска, ПолучениеИтогов = Истина) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.БухИтогиНайти(ИмяЗначения, КлючСтроки, ТаблицаПоиска, ПолучениеИтогов);
```
</details>

## МассивСписковВОбщийСписок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция МассивСписковВОбщийСписок(МассивСписков) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.МассивСписковВОбщийСписок(МассивСписков));
```
</details>

## ПолучитьДополнительныеПараметрыСубконто
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьДополнительныеПараметрыСубконто(ВидСубконто1 = Неопределено, Субконто1 = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ПолучитьДополнительныеПараметрыСубконто(ВидСубконто1, Субконто1, );
```
</details>

## ВставитьРасшифровкуКосвенныхРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВставитьРасшифровкуКосвенныхРасходов(ТаблицаРасшифровки, Запрос, СписокСтатейЗатрат, ИмяПоказателя, ВидРасходовНУ = Неопределено) Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.ВставитьРасшифровкуКосвенныхРасходов(ТаблицаРасшифровки, Запрос, СписокСтатейЗатрат, ИмяПоказателя, ВидРасходовНУ);
```
</details>

## ВставитьРасшифровкуВнереализационныхДоходовРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВставитьРасшифровкуВнереализационныхДоходовРасходов(ТаблицаРасшифровки, Запрос, ИмяПоказателя, ВидСуммы, СписокПрочихДоходовИРасходов) Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.ВставитьРасшифровкуВнереализационныхДоходовРасходов(ТаблицаРасшифровки, Запрос, ИмяПоказателя, ВидСуммы, СписокПрочихДоходовИРасходов));
```
</details>

## СоздатьДолиЕНВД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьДолиЕНВД(МенеджерВременныхТаблиц, НачалоПериода, КонецПериода, Организации) Экспорт
```

Пример вызова
```bsl
НалоговыйУчет.СоздатьДолиЕНВД(МенеджерВременныхТаблиц, НачалоПериода, КонецПериода, Организации) 
```
</details>

## ДопПараметрыСубконтоПрочихДоходовИРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДопПараметрыСубконтоПрочихДоходовИРасходов(ИмяЗначенияПеречисления, ТаблицаДляПоиска, СИтогами = Истина) Экспорт
```

Пример вызова
```bsl
Результат = НалоговыйУчет.ДопПараметрыСубконтоПрочихДоходовИРасходов(ИмяЗначенияПеречисления, ТаблицаДляПоиска, СИтогами);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
