---
title: Направления деятельности локализация
slug: erp-uh/направления-деятельности-локализация
---


## ОбработкаПроверкиЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика модуля объекта
//
// Параметры:
//  Объект - СправочникОбъект.НаправленияДеятельности - Обрабатываемый объект
//  Отказ - Булево - Если в теле процедуры-обработчика установить данному параметру значение Истина,
//                   то будет выполнен отказ от продолжения работы после выполнения проверки заполнения.
//  ПроверяемыеРеквизиты - Массив - Массив путей к реквизитам, для которых будет выполнена проверка заполнения.
//
Процедура ОбработкаПроверкиЗаполнения(Объект, Отказ, ПроверяемыеРеквизиты) Экспорт
```

Пример вызова
```bsl
НаправленияДеятельностиЛокализация.ОбработкаПроверкиЗаполнения(Объект, Отказ, ПроверяемыеРеквизиты) 
```
</details>

## ОбработкаЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика модуля объекта
//
// Параметры:
//  Объект - СправочникОбъект.НаправленияДеятельности - Обрабатываемый объект
//  ДанныеЗаполнения - Произвольный - Значение, которое используется как основание для заполнения.
//  СтандартнаяОбработка - Булево - В данный параметр передается признак выполнения стандартной (системной) обработки события.
//
Процедура ОбработкаЗаполнения(Объект, ДанныеЗаполнения, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
НаправленияДеятельностиЛокализация.ОбработкаЗаполнения(Объект, ДанныеЗаполнения, СтандартнаяОбработка) 
```
</details>

## ПередЗаписью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика модуля объекта
//
// Параметры:
//  Объект - СправочникОбъект.НаправленияДеятельности - Обрабатываемый объект
//  Отказ - Булево - Признак отказа от записи.
//                   Если в теле процедуры-обработчика установить данному параметру значение Истина,
//                   то запись выполнена не будет и будет вызвано исключение.
//
Процедура ПередЗаписью(Объект, Отказ) Экспорт
```

Пример вызова
```bsl
НаправленияДеятельностиЛокализация.ПередЗаписью(Объект, Отказ) 
```
</details>

## ПриЗаписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика модуля объекта
//
// Параметры:
//  Объект - СправочникОбъект.НаправленияДеятельности - Обрабатываемый объект
//  Отказ - Булево - Признак отказа от записи.
//                   Если в теле процедуры-обработчика установить данному параметру значение Истина, то запись выполнена не будет и будет вызвано исключение.
//
Процедура ПриЗаписи(Объект, Отказ) Экспорт
```

Пример вызова
```bsl
НаправленияДеятельностиЛокализация.ПриЗаписи(Объект, Отказ) 
```
</details>

## ДополнитьБлокируемыеРеквизитыОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет массив блокируемых реквизитов объекта (см. Справочник.НаправленияДеятельности.ПолучитьБлокируемыеРеквизитыОбъекта).
//
// Параметры:
// 	БлокируемыеРеквизиты - Массив - Блокируемые реквизиты объекта
//
Процедура ДополнитьБлокируемыеРеквизитыОбъекта(БлокируемыеРеквизиты) Экспорт
```

Пример вызова
```bsl
НаправленияДеятельностиЛокализация.ДополнитьБлокируемыеРеквизитыОбъекта(БлокируемыеРеквизиты) 
```
</details>

## ПриЧтенииСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Параметры:
//  Форма - ФормаКлиентскогоПриложения
Процедура ПриЧтенииСозданииНаСервере(Форма) Экспорт
```

Пример вызова
```bsl
НаправленияДеятельностиЛокализация.ПриЧтенииСозданииНаСервере(Форма) 
```
</details>

## ПриИзмененииРеквизита
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика формы объекта
//
// Параметры:
// 	ИмяЭлемента - Строка - Имя элемента управления
// 	Форма - ФормаКлиентскогоПриложения - Форма плана видов характеристик
//
Процедура ПриИзмененииРеквизита(ИмяЭлемента, Форма) Экспорт
```

Пример вызова
```bsl
НаправленияДеятельностиЛокализация.ПриИзмененииРеквизита(ИмяЭлемента, Форма) 
```
</details>

## ВыполнитьКоманду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика формы объекта
//
// Параметры:
// 	ИмяКоманды - Строка - Имя команды
// 	Форма - ФормаКлиентскогоПриложения - Форма плана видов характеристик
//
Процедура ВыполнитьКоманду(ИмяКоманды, Форма) Экспорт
```

Пример вызова
```bsl
НаправленияДеятельностиЛокализация.ВыполнитьКоманду(ИмяКоманды, Форма) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
