---
title: Настройка параметров сканирования служебный клиент сервер
slug: erp-uh/настройка-параметров-сканирования-служебный-клиент-сервер
---


## ПредставленияИсключения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует структуру текстового описания настроенных исключений.
//
// Параметры:
// 	ГруппаНастроек           - см. ЗначениеГруппыНастроек
// 	УровеньСокращенияДеталей - Неопределено, Число - Количество элементов для включения в описание.
// 	ТранспонироватьПоВидуОтображения - Булево - Признак перегруппировки исходных значений исключений.
// Возвращаемое значение:
// 	Структура - Описание:
// * ПолноеВОднуСтроку - Строка - Полное описание в одну строку (например, для протокола обмена).
// * Полное            - Строка - Полное описание.
// * Краткое           - Строка - Краткое (сокращенное) описание.
Функция ПредставленияИсключения(ГруппаНастроек, УровеньСокращенияДеталей = Неопределено, ТранспонироватьПоВидуОтображения = Истина) Экспорт
```

Пример вызова
```bsl
Результат = НастройкаПараметровСканированияСлужебныйКлиентСервер.ПредставленияИсключения(ГруппаНастроек, УровеньСокращенияДеталей, ТранспонироватьПоВидуОтображения);
```
</details>

## ЗначениеГруппыНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает группу настроек сканирования по имени параметра.
//
// Параметры:
// 	НастройкиСканирования - см. ОбщегоНазначенияИСМПВызовСервера.НастройкиСканированияКодовМаркировки
// 	ИмяПараметра          - Строка - Идентификатор параметра.
// Возвращаемое значение:
// 	см. НоваяГруппаПараметровНастройки
Функция ЗначениеГруппыНастроек(НастройкиСканирования, ИмяПараметра) Экспорт
```

Пример вызова
```bsl
Результат = НастройкаПараметровСканированияСлужебныйКлиентСервер.ЗначениеГруппыНастроек(НастройкиСканирования, ИмяПараметра) 
```
</details>

## НоваяГруппаПараметровНастройки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Группа настроек параметра сканирования.
//
// Параметры:
// 	РежимИсключения - Булево - Признак работы в режиме исключения.
// Возвращаемое значение:
// 	Структура - Описание:
// * Исключения         - Соответствие - Исключения по виду продукции и операциям
// * Включено           - Булево       - Признак включения настройки.
// * РежимИсключения    - Булево       - Признак работы в режиме исключения.
// * ВариантОтображения - Строка       - Вариант отображения в форме настройки.
Функция НоваяГруппаПараметровНастройки(РежимИсключения = Истина) Экспорт
```

Пример вызова
```bsl
Результат = НастройкаПараметровСканированияСлужебныйКлиентСервер.НоваяГруппаПараметровНастройки(РежимИсключения);
```
</details>

## ТранспонироватьЗначенияИсключения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описание
//
// Параметры:
// 	ВходящееЗначенияИсключения - Соответствие - поле данных см. НоваяГруппаПараметровНастройки.
// 	ПолныйСписокКлючей         - Массив - Описание
// 	ПолныйСписокВложенных      - ФиксированныйМассив из ПеречислениеСсылка.ВидыПродукцииИС - Описание
// Возвращаемое значение:
// 	Соответствие - Описание
Функция ТранспонироватьЗначенияИсключения(ВходящееЗначенияИсключения, ПолныйСписокКлючей, ПолныйСписокВложенных) Экспорт
```

Пример вызова
```bsl
Результат = НастройкаПараметровСканированияСлужебныйКлиентСервер.ТранспонироватьЗначенияИсключения(ВходящееЗначенияИсключения, ПолныйСписокКлючей, ПолныйСписокВложенных) 
```
</details>

## ДанныеСокращения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет сокращение входных данных по количеству элементов.
//
// Параметры:
// 	ВходящийСписок      - Массив - Сокращаемые элементы.
// 	КоличествоЭлементов - Число  - Сколько элементов оставить в представлении.
// Возвращаемое значение:
// 	Структура - Описание:
// * Идентификатор - Строка - Идентификатор сокращенного значения.
// * Текст         - Строка - Сокращенное значение.
Функция ДанныеСокращения(ВходящийСписок, КоличествоЭлементов = 2) Экспорт
```

Пример вызова
```bsl
Результат = НастройкаПараметровСканированияСлужебныйКлиентСервер.ДанныеСокращения(ВходящийСписок, КоличествоЭлементов);
```
</details>

## ДобавитьВИсключение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в группу настроек переданную настройку со значением.
//
// Параметры:
// 	ГруппаНастрек - см. НоваяГруппаПараметровНастройки
// 	Настройка     - ПеречислениеСсылка.ВидыОперацийИСМП, ПеречислениеСсылка.ВидыПродукцииИС               - Настройка.
// 	Значение      - ПеречислениеСсылка.ВидыПродукцииИС, ПеречислениеСсылка.ВидыОперацийИСМП, Неопределено - Значение настройки.
Процедура ДобавитьВИсключение(ГруппаНастрек, Настройка, Значение = Неопределено) Экспорт
```

Пример вызова
```bsl
НастройкаПараметровСканированияСлужебныйКлиентСервер.ДобавитьВИсключение(ГруппаНастрек, Настройка, Значение);
```
</details>

## ПрименитьОграничение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переносит множество из ограничивающей настройки во множество целевой настройки.
//
// Параметры:
// 	ЦелеваяНастройка - см. НоваяГруппаПараметровНастройки.
// 	Ограничения      - см. НоваяГруппаПараметровНастройки.
Процедура ПрименитьОграничение(ЦелеваяНастройка, Ограничения) Экспорт
```

Пример вызова
```bsl
НастройкаПараметровСканированияСлужебныйКлиентСервер.ПрименитьОграничение(ЦелеваяНастройка, Ограничения) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
