---
title: Настройка счетов учета сервер
slug: erp-uh/настройка-счетов-учета-сервер
---


## ПараметрыНастройки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров настройки счета учета операции.
//
// Возвращаемое значение:
// 	Структура - Описание:
// 	* ДоступностьПоОперации - Булево - Признак доступности настройки по хозяйственной операции документа.
//
// 	* ПутьКДанным - Строка - Путь к данным настройки счетов регл. учета (Например, "Объект" или "Объект.ПрочиеРасходы").
// 	* НастройкаСчетовУчета - Строка - Имя реквизита хранения настройки счетов учета операции. Значение по умолчанию "НастройкаСчетовУчета".
//	* СтатьяАктивовПассивов - Строка - Имя реквизита хранения статьи прочих активов пассивов. Значение по умолчанию "СтатьяАктивовПассивов".
//	* АналитикаАктивовПассивов - Строка - Имя реквизита хранения аналитики прочих активов пассивов. Значение по умолчанию "АналитикаАктивовПассивов".
// 	* ВерсияНастройкиСчетовУчета - Строка - Имя реквизита хранения версии настройки счетов учета операции.
//										Используется для корректной работы механизма выборочной регистрации к отражению в регл. учете.
//										Значение по умолчанию пустая строка.
// 	* Представление - Строка - Имя реквизита формы (Типа Строка) для хранения представления гиперссылки настройки.
// 	                       Значение по умолчанию "ПредставлениеОтраженияОперации".
// 	* ТипСтатьи - Строка - Имя реквизита ТипСтатьи (Типа Число), в котором хранится числовой индекс типа выбранной статьи.
// 	                       Заполнение реквизита обеспечивается функциями выбора статей и аналитик механизма учета доходов и расходов.
// 	                       См. ДоходыИРасходыКлиентСервер.ЗаполнитьРеквизитыСтатьи.
// 	                       Если параметр указан, то настройка счетов учета доступна только при выбранной статье прочих активов и пассивов (ТипСтатьи = 3).
//
//	* Организация - Строка - Полный путь к данным организации документа. Значение по умолчанию "ТипСтатьи".
//
//	* ИсточникиПодбораСубконто - СписокЗначений - Список источников автоматического подбора субконто
//       * Значение - Произвольный - Тип источника автоматического подбора субконто (Например, Тип("СправочникСсылка.ФизическиеЛица"))
//       * Заголовок - Строка - Путь к данным источника, (Например, "Объект.Начисление.ФизическоеЛицо").
//
//	* ЭлементыФормы - Массив - Имена элементов формы, через которые выполняется настройка счетов учета.
//
//	* УсловияДоступностиСчетаУчетаВСтроках - Структура - Дополнительные условия доступности настройки в строках таблицы.
//	                                                 Если условий несколько, то доступность определяется по "И".
//	                                                 В элементах структуры:
//	                                                 	* Ключ - Строка - Имя реквизита объекта или реквизита таблицы, определяющее доступность статьи.
//	                                                 	* Значение - Произвольный - Значение реквизита, при котором выбор статьи доступен.
//	* СкрыватьНедоступныйСчетУчетаВСтроках - Булево - Если Истина, то недоступные в строках статьи и аналитики скрываются.
//	                                               Если Ложь, то для ячеек устанавливается оформление ТолькоПросмотр. Значение по умолчанию Ложь.
//
Функция ПараметрыНастройки() Экспорт
```

Пример вызова
```bsl
Результат = НастройкаСчетовУчетаСервер.ПараметрыНастройки() 
```
</details>

## ПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует форму объекта в соответствии с свойствами элементов настройки счетов учета.
// Вызывается в обработчике формы ПриСозданииНаСервере().
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма объекта настройки
// 	ПараметрыНастройкиСчетов - Массив, Структура - Параметры настройки (См. НастройкаСчетовУчетаСервер.ПараметрыНастройки).
// 	                                         Если для объекта выполняется настройка нескольких счетов, то передается массив.
// 	                                         Каждый элемент массива - структура параметров.
//
Процедура ПриСозданииНаСервере(Форма, ПараметрыНастройкиСчетов) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.ПриСозданииНаСервере(Форма, ПараметрыНастройкиСчетов) 
```
</details>

## ПриЧтенииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает свойства элементов настройки при чтении данных объекта настройки.
// Вызывается в обработчике формы ПриЧтенииНаСервере().
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма объекта настройки
// 	ПараметрыНастройкиСчетов - Массив, Структура - Параметры настройки (См. НастройкаСчетовУчетаСервер.ПараметрыНастройки).
// 	                                         Если для объекта выполняется настройка нескольких счетов, то передается массив.
// 	                                         Каждый элемент массива - структура параметров.
//
Процедура ПриЧтенииНаСервере(Форма, ПараметрыНастройкиСчетов) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.ПриЧтенииНаСервере(Форма, ПараметрыНастройкиСчетов) 
```
</details>

## ПередЗаписьюНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет значение субконто по свойству ИсточникиПодбораСубконто (если источники указаны).
// Вызывается в обработчике формы ПередЗаписьюНаСервере().
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма объекта
// 	ТекущийОбъект - ДокументОбъект - Записываемый объект
//
Процедура ПередЗаписьюНаСервере(Форма, ТекущийОбъект) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.ПередЗаписьюНаСервере(Форма, ТекущийОбъект) 
```
</details>

## ПослеЗаписиНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает свойства элементов настройки после записи данных объекта настройки.
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма объекта настройки
//
Процедура ПослеЗаписиНаСервере(Форма) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.ПослеЗаписиНаСервере(Форма) 
```
</details>

## ПриИзмененииПараметровНастройки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет настройку формы под новые параметры.
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма объекта настройки
// 	ПараметрыНастройкиСчетов - Структура, Массив - Параметры настройки (См. НастройкаСчетовУчетаСервер.ПараметрыНастройки).
// 	                                         Если для объекта выполняется настройка нескольких счетов, то передается массив.
// 	                                         Каждый элемент массива - структура параметров.
//
Процедура ПриИзмененииПараметровНастройки(Форма, ПараметрыНастройкиСчетов) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.ПриИзмененииПараметровНастройки(Форма, ПараметрыНастройкиСчетов) 
```
</details>

## ОбновитьПредставлениеНастройки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается после программного установки счетов учета для обновления отображения на форме.
//
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Форма объекта настройки
// 	ПутьКДанным - Строка - Путь к данным настройки счетов
// 	ИдентификаторыСтрок - Число, Массив - Идентификаторы измененных строк.
// 	                               Если счет учета в таблице, а идентификаторы измененных строк не переданы, то будут обновлены данные во всей таблице.
//
Процедура ОбновитьПредставлениеНастройки(Форма, ПутьКДанным = Неопределено, ИдентификаторыСтрок = Неопределено) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.ОбновитьПредставлениеНастройки(Форма, ПутьКДанным, ИдентификаторыСтрок);
```
</details>

## ПередЗаписью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для сохранения измененных в форме данных настроек счетов учета прочих операций документа или справочника,
// пометки на удаление неиспользуемых настроек, синхронизации пометки удаления настроек и их владельца.
// Вызывается из события ПередЗаписью объекта документа или справочника. Данные настроек счетов учета
// передаются через механизм дополнительных свойств объекта в свойстве "НастройкиСчетовУчета".
//
// Параметры:
//  Объект - ДокументОбъект,
//           СправочникОбъект - записываемый объект
//  ПараметрыНастройкиСчетов - Массив, Структура - Параметры настройки (См. НастройкаСчетовУчетаСервер.ПараметрыНастройки).
// 	                                         Если для объекта выполняется настройка нескольких счетов, то передается массив.
// 	                                         Каждый элемент массива - структура параметров.
//
Процедура ПередЗаписью(Объект, ПараметрыНастройкиСчетов) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.ПередЗаписью(Объект, ПараметрыНастройкиСчетов) 
```
</details>

## СкопироватьНастройкуСчетовОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для копирования состава настроек счетов учета прочих операций из одной настройки счетов учета объекта в другую.
// Если ссылка на настройку счетов учета - приемник не заполнена, будет создан новый элемент справочника настроек счетов.
// Иначе настройка счетов учета - приемник будет перезаписана, если ее данные отличаются от настройки счетов учета - источника.
// Ограничения текущей реализации: настройки счетов источник и приемник должны иметь одинаковый путь к данным.
//
// Параметры:
//  Объект - ДокументОбъект,
//           СправочникОбъект - записываемый объект
//  ПараметрыНастройкиСчетов - Массив, Структура - Параметры настройки (См. НастройкаСчетовУчетаСервер.ПараметрыНастройки).
// 	                                         Если для объекта выполняется настройка нескольких счетов, то передается массив.
// 	                                         Каждый элемент массива - структура параметров.
//  НастройкаСчетовИсточник - Строка - имя реквизита с копируемой настройкой счетов учета
//  НастройкаСчетовПриемник - Строка - имя реквизита настройки счетов учета, в которую копируется состав настроек источника
//
Процедура СкопироватьНастройкуСчетовОбъекта(Объект, ПараметрыНастройкиСчетов, НастройкаСчетовИсточник, НастройкаСчетовПриемник) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.СкопироватьНастройкуСчетовОбъекта(Объект, ПараметрыНастройкиСчетов, НастройкаСчетовИсточник, НастройкаСчетовПриемник) 
```
</details>

## ЗаписатьНастройкиСчетовУчетаФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для сохранения созданных и измененных в форме настроек счетов учета прочих операций.
// В основном используется в дополнительнывх формах и обработках по изменению табличных частей.
// Вызывается при начале выполнения обработки или перед выполнением кода закрытия формы.
// Вновь созданные настройки счетов учета записываются без владельца, владелец записывается при записи объекта,
// в котором используются созданные настройки.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма с настройками счетов учета
//
Процедура ЗаписатьНастройкиСчетовУчетаФормы(Форма) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.ЗаписатьНастройкиСчетовУчетаФормы(Форма) 
```
</details>

## ЗаполнитьНастройкуСчетовУчетаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет настройку счетов учета по умолчанию по данным статьи активов и пассивов.
// Вызывается из механизма ОбработкаТабличнойЧасти.
//
// Параметры:
//  ТекущаяСтрока - Структура - Данные строки.
//  ПараметрыДействия - Структура - Параметры действия. (См. НастройкаСчетовУчетаКлиентСервер.ВставитьДействиеЗаполнитьНастройкуСчетовУчетаПоУмолчанию):
//   *ДействиеВФорме - Булево - признак выполнения действия в форме объекта
//   *ДанныеНастройкиСчетовУчета - Структура из см. НастройкаСчетовУчетаКлиентСервер.НовыеДанныеНастройкиСчетовУчета
//
Процедура ЗаполнитьНастройкуСчетовУчетаПоУмолчанию(ТекущаяСтрока, ПараметрыДействия) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.ЗаполнитьНастройкуСчетовУчетаПоУмолчанию(ТекущаяСтрока, ПараметрыДействия) 
```
</details>

## ЗаполнитьНастройкуСчетовУчетаПоУмолчаниюПакетно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет настройку счетов учета по умолчанию по данным статьи активов и пассивов. Вызывается из механизма пакетной
// обработки табличных частей.
//
// Параметры:
//  ТекущаяСтрока - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.ТекущаяСтрока
//  ПараметрыДействия - Структура - Параметры действия. (См. НастройкаСчетовУчетаКлиентСервер.ВставитьДействиеЗаполнитьНастройкуСчетовУчетаПоУмолчанию):
//   *ДействиеВФорме - Булево - признак выполнения действия в форме объекта
//   *ДанныеНастройкиСчетовУчета - см. НастройкаСчетовУчетаКлиентСервер.НовыеДанныеНастройкиСчетовУчета
//   КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ЗаполнитьНастройкуСчетовУчетаПоУмолчаниюПакетно(ТекущаяСтрока, ПараметрыДействия, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.ЗаполнитьНастройкуСчетовУчетаПоУмолчаниюПакетно(ТекущаяСтрока, ПараметрыДействия, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстыЗапросовНастройкуСчетовУчетаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения настройки счетов по умолчанию
// при обработке строк табличной части.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстыЗапросовНастройкуСчетовУчетаПоУмолчанию(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.ДополнитьТекстыЗапросовНастройкуСчетовУчетаПоУмолчанию(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ЗаполнитьПредставлениеНастройкиСчетовУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет представление настройки счетов учета.
// Вызывается из механизма ОбработкаТабличнойЧасти.
//
// Параметры:
//  ТекущаяСтрока - Структура - Данные строки.
//  ПараметрыДействия - Структура - Параметры действия. (См. НастройкаСчетовУчетаКлиентСервер.ВставитьДействиеЗаполнитьПредставлениеНастройкиСчетовУчета):
//   *ДанныеНастройкиСчетовУчета - Структура из см. НастройкаСчетовУчетаКлиентСервер.НовыеДанныеНастройкиСчетовУчета
//
Процедура ЗаполнитьПредставлениеНастройкиСчетовУчета(ТекущаяСтрока, ПараметрыДействия) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.ЗаполнитьПредставлениеНастройкиСчетовУчета(ТекущаяСтрока, ПараметрыДействия) 
```
</details>

## НоваяНастройкаСчетовУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для создания нового элемента справочника настроек счетов учета по переданным данным.
// Используется при программном заполнении настроек счетов учета объектов документов и справочников,
// по известным значениям счетов учета и субконто.
//
// Если создание настройки учета происходит для объекта, редактируемого в форме, обязательна
// передача формы. В этом случае данные настройки будут сохранены в кэше механизма, а запись нового элемента
// настроек произойдет перед записью редактируемого объекта формы.
//
// Если заполнение настройки учета происходит для объекта - переменной модуля, то запись нового элемента
// настроек происходит непосредственно в функции. Вновь созданная настройка счетов учета записывается
// без владельца, владелец записывается при записи объекта, в котором используется созданная настройка.
//
// Параметры:
//  ДанныеНастройки - См. НастройкаСчетовУчетаКлиентСервер.СоставНастройкиСчетовУчета
//  Форма - ФормаКлиентскогоПриложения - форма редактируемого объекта документа или справочника
//
// Возвращаемое значение:
//  СправочникСсылка.НастройкиСчетовУчетаПрочихОпераций - новый элемент настройки счетов учета с переданными данными настройки счетов.
//   При передаче формы в параметр Форма это ссылка нового (еще не существующего) элемента справочника настроек.
//   Если форма не передана, это ссылка созданного при работе функции нового элемента справочника настроек.
//
Функция НоваяНастройкаСчетовУчета(ДанныеНастройки, Форма = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НастройкаСчетовУчетаСервер.НоваяНастройкаСчетовУчета(ДанныеНастройки, Форма);
```
</details>

## КопияНастройкиСчетовУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для копирования содержимого настройки счетов учета в новый элемент справочника настроек.
// Используется при программном заполнении настроек счетов учета объектов документов и справочников,
// где простое присвоение ссылки настройки счетов, полученной из другого объекта, недопустимо.
//
// Если заполнение настройки учета происходит для объекта, редактируемого в форме, обязательна
// передача формы. В этом случае данные настройки будут сохранены в кэше механизма, а запись нового элемента
// настроек произойдет перед записью редактируемого объекта формы.
//
// Если заполнение настройки учета происходит для объекта - переменной модуля, то запись нового элемента
// настроек происходит непосредственно в функции. Вновь созданная настройка счетов учета записывается
// без владельца, владелец записывается при записи объекта, в котором используется созданная настройка.
//
// Параметры:
//  НастройкаСчетовИсточник - СправочникСсылка.НастройкиСчетовУчетаПрочихОпераций - настройка счетов учета, данные которой необходимо скопировать в новую настройку
//  Форма - ФормаКлиентскогоПриложения - форма редактируемого объекта документа или справочника
//
// Возвращаемое значение:
//  СправочникСсылка.НастройкиСчетовУчетаПрочихОпераций - новый элемент настройки счетов учета с данными настройки счетов - источника.
//   При передаче формы в параметр Форма это ссылка нового (еще не существующего) элемента справочника настроек.
//   Если форма не передана, это ссылка созданного при работе функции нового элемента справочника настроек.
//
Функция КопияНастройкиСчетовУчета(НастройкаСчетовИсточник, Форма = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НастройкаСчетовУчетаСервер.КопияНастройкиСчетовУчета(НастройкаСчетовИсточник, Форма);
```
</details>

## ОбработкаПроверкиЗаполненияСчетовУчетаНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку заполнения счетов учета в объекте.
//
// Параметры:
// 	Объект - Произвольный - Объект хранения настроек счетов
//	Отказ - Булево - Флаг Отказ
//	ПроверяемыеРеквизиты - Массив - Проверяемые реквизиты
//
Процедура ОбработкаПроверкиЗаполненияСчетовУчетаНоменклатуры(Объект, Отказ, ПроверяемыеРеквизиты) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.ОбработкаПроверкиЗаполненияСчетовУчетаНоменклатуры(Объект, Отказ, ПроверяемыеРеквизиты) 
```
</details>

## ТипыСвязанныеСОрганизацией
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает типы значений, для которых имеет смысл отбор по организации
//
// Возвращаемое значение:
//	ОписаниеТипов - Описание типов справочников, которые зависят от организации.
//
Функция ТипыСвязанныеСОрганизацией() Экспорт
```

Пример вызова
```bsl
Результат = НастройкаСчетовУчетаСервер.ТипыСвязанныеСОрганизацией() 
```
</details>

## ОбработкаПроверкиЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика формы с настраиваемыми счетами учета
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма, для которой необходимо проверить заполнение настроек счетов учета (и субконто)
//  Отказ - Булево - Если в теле процедуры-обработчика установить данному параметру значение Истина,
//                   то будет выполнен отказ от продолжения работы после выполнения проверки заполнения.
//  ПроверяемыеРеквизиты - Массив - Массив путей к реквизитам, для которых будет выполнена проверка заполнения.
//
Процедура ОбработкаПроверкиЗаполнения(Форма, Отказ, ПроверяемыеРеквизиты) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.ОбработкаПроверкиЗаполнения(Форма, Отказ, ПроверяемыеРеквизиты) 
```
</details>

## ПриЗаписиОбъектаНастройкиСчетовУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет сохранение счетов учета.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма объекта настройки;
//  Отказ - Булево - Признак отказа от записи, см. параметр "Отказ" события ПриЗаписиНаСервере;
// 	Объект - СправочникОбъект, ДанныеФормыСтруктура, Произвольный - Объект хранения настроек счетов, см. параметр "ТекущийОбъект" события ПриЗаписиНаСервере;
// 	ПараметрыЗаписи - Структура - содержит параметры записи, см. параметр "ПараметрыЗаписи" события ПриЗаписиНаСервере.
//
Процедура ПриЗаписиОбъектаНастройкиСчетовУчета(Форма, Отказ, Объект, ПараметрыЗаписи) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.ПриЗаписиОбъектаНастройкиСчетовУчета(Форма, Отказ, Объект, ПараметрыЗаписи) 
```
</details>

## ПриЧтенииСозданииОбъектаНастройкиСчетовУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет загрузку счетов учета.
//
// Параметры:
// Форма - ФормаКлиентскогоПриложения - форма объекта настройки. В форме реквизит:
// 	* Объект - ДанныеФормыСтруктура - содержит поля:
// 		** Ссылка - СправочникСсылка -
//
Процедура ПриЧтенииСозданииОбъектаНастройкиСчетовУчета(Форма) Экспорт
```

Пример вызова
```bsl
НастройкаСчетовУчетаСервер.ПриЧтенииСозданииОбъектаНастройкиСчетовУчета(Форма) 
```
</details>

## ПараметрыНастройкиСчетовУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров настройки счетов учета.
//
// Параметры:
// 	РазделыУчета - Неопределено, Массив -
// Возвращаемое значение:
// 	Структура - Параметры настройки счетов учета
//
Функция ПараметрыНастройкиСчетовУчета(РазделыУчета = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НастройкаСчетовУчетаСервер.ПараметрыНастройкиСчетовУчета(РазделыУчета);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
