---
title: Настройки налогов учетных политик
slug: erp-uh/настройки-налогов-учетных-политик
---


## ДействующиеПараметрыНалоговУчетныхПолитикНаДату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает актуальные значения настроек по организации на дату.
//
// Параметры:
// 	ИмяРегистра - Строка - имя регистра сведений.
// 	Организация - СправочникСсылка.Организации - ссылка на организацию.
// 	ДатаДействия - Дата - период действия настроек.
// 	ВозвращатьПоУмолчанию - Булево - признак заполнения значений по умолчанию,
// 		если передана ложь - вернет Неопределено, когда нет ни одной записи в регистре.
// 	ВыдаватьИсключение - Булево - выдать исключение, если параметры не установлены.
// Возвращаемое значение:
// 	Структура, Неопределено - значений ресурсов регистра. Неопределено, если регистра нет или отключен по ФО.
Функция ДействующиеПараметрыНалоговУчетныхПолитикНаДату(ИмяРегистра, Организация, Знач ДатаДействия = Неопределено, ВозвращатьПоУмолчанию = Истина, ВыдаватьИсключение = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = НастройкиНалоговУчетныхПолитик.ДействующиеПараметрыНалоговУчетныхПолитикНаДату(ИмяРегистра, Организация, ДатаДействия, ВозвращатьПоУмолчанию, ВыдаватьИсключение);
```
</details>

## ДействующиеПараметрыНалоговУчетныхПолитикПоОрганизациям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
// Возвращает таблицу актуальных значения настроек по списку организаций на дату.
//
// Параметры:
// 	ИмяРегистра - Строка - имя регистра сведений.
// 	Организации - Массив - массив ссылок на организацию.
// 	ДатаДействия - Дата - период действия настроек.
// 	ВозвращатьПоУмолчанию - Булево - признак заполнения значений по умолчанию,
// 		если передана ложь - вернет пустую таблицу.
// Возвращаемое значение:
// 	ТаблицаЗначений - таблица актуальных настроек по регистру.
Функция ДействующиеПараметрыНалоговУчетныхПолитикПоОрганизациям(ИмяРегистра, Организации, ДатаДействия = Неопределено, ВозвращатьПоУмолчанию = Истина) Экспорт
```

Пример вызова
```bsl
Результат = НастройкиНалоговУчетныхПолитик.ДействующиеПараметрыНалоговУчетныхПолитикПоОрганизациям(ИмяРегистра, Организации, ДатаДействия, ВозвращатьПоУмолчанию);
```
</details>

## ДополнитьМенеджерВременныхТаблицГоловнымиОрганизациями
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает временную таблицу с головными организациями.
//
// Параметры:
// 	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - менеджер временных таблиц запроса.
// 	Организации - Массив - массив ссылок на организации.
Процедура ДополнитьМенеджерВременныхТаблицГоловнымиОрганизациями(МенеджерВременныхТаблиц, Организации = Неопределено) Экспорт
```

Пример вызова
```bsl
НастройкиНалоговУчетныхПолитик.ДополнитьМенеджерВременныхТаблицГоловнымиОрганизациями(МенеджерВременныхТаблиц, Организации);
```
</details>

## ДополнитьМенеджерВременныхТаблицДействующимиПараметрамиНалоговУчетныхПолитик
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает временную таблицу с актуальными значениями настроек по организации на дату.
//
// Параметры:
// 	ИмяРегистра - Строка - имя регистра сведений.
// 	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - менеджер временных таблиц запроса.
// 	ДатаДействия - Дата - период действия настроек.
// 	ИмяТаблицы - Строка - имя создаваемой временной таблицы.
// 	Организации - СправочникСсылка.Организации, Массив - ссылка на организацию, либо массив ссылок.
Процедура ДополнитьМенеджерВременныхТаблицДействующимиПараметрамиНалоговУчетныхПолитик(ИмяРегистра, МенеджерВременныхТаблиц, ДатаДействия, ИмяТаблицы, Организации = Неопределено) Экспорт
```

Пример вызова
```bsl
НастройкиНалоговУчетныхПолитик.ДополнитьМенеджерВременныхТаблицДействующимиПараметрамиНалоговУчетныхПолитик(ИмяРегистра, МенеджерВременныхТаблиц, ДатаДействия, ИмяТаблицы, Организации);
```
</details>

## ТекстЗапросаГоловныеОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует текст запроса временной таблицы ВтГоловныеОрганизации
//
// Возвращаемое значение:
// 	Строка - текст запроса.
Функция ТекстЗапросаГоловныеОрганизации() Экспорт
```

Пример вызова
```bsl
Результат = НастройкиНалоговУчетныхПолитик.ТекстЗапросаГоловныеОрганизации() 
```
</details>

## КлючЗаписиДействующейУчетнойПолитики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает последнюю действующую запись и формирует для нее ключ записи регистра,
// однозначно ее идентифицирующую.
//
// Параметры:
// 	ИмяРегистра - Строка - наименование периодического регистра сведений.
// 	Организация - СправочникСсылка.Организации - ссылка на организацию-измерение записи.
// 	Период - Дата - период записи.
// Возвращаемое значение:
// 	Неопределено, РегистрСведенийКлючЗаписи - ключ записи.
Функция КлючЗаписиДействующейУчетнойПолитики(ИмяРегистра, Организация, Знач Период = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НастройкиНалоговУчетныхПолитик.КлючЗаписиДействующейУчетнойПолитики(ИмяРегистра, Организация, Период);
```
</details>

## НовыйКлючЗаписиУчетнойПолитики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новый ключ записи регистра
//
// Параметры:
// 	ИмяРегистра - Строка - наименование периодического регистра сведений.
// 	Организация - СправочникСсылка.Организации - ссылка на организацию-измерение записи.
// 	Период - Дата - период записи.
// Возвращаемое значение:
// 	Неопределено, РегистрСведенийКлючЗаписи - ключ записи.
Функция НовыйКлючЗаписиУчетнойПолитики(ИмяРегистра, Организация, Период = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НастройкиНалоговУчетныхПолитик.НовыйКлючЗаписиУчетнойПолитики(ИмяРегистра, Организация, Период);
```
</details>

## МенеджерЗаписиПериодическогоРегистра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует менеджер записи периодического регистра по переданным параметрам.
//
// Параметры:
// 	ИмяРегистра - Строка - наименование периодического регистра сведений.
// 	КлючЗаписи - РегистрСведенийКлючЗаписи - ключ записи регистра.
// 	ИмяИзмерения - Строка - имя ведущего измерения.
// 	ЗначенияЗаполнения - ДанныеФормыСтруктура, Структура - значения заполнения новой записи.
// Возвращаемое значение:
// 	РегистрСведенийКлючЗаписи - менеджер записи регистра сведений.
Функция МенеджерЗаписиПериодическогоРегистра(ИмяРегистра, КлючЗаписи, ИмяИзмерения = "Организация", ЗначенияЗаполнения=Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НастройкиНалоговУчетныхПолитик.МенеджерЗаписиПериодическогоРегистра(ИмяРегистра, КлючЗаписи, ИмяИзмерения, ЗначенияЗаполнения);
```
</details>

## ПрочитатьЗаписьРегистра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет данные формы регистра сведений по ключу записи.
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - форма записи регистра сведений:
// 	* Запись - РегистрСведенийМенеджерЗаписи - основной реквизит формы.
// 	ИмяРегистра - Строка - наименование периодического регистра сведений.
// 	Организация - СправочникСсылка.Организации - ссылка на организацию.
// 	СоздатьНовую - Булево - создать принудительно новую запись.
// 	КлючЗаписи - РегистрСведенийКлючЗаписи - ключ записи регистра сведений.
// 	ПериодЗначений - Дата - период получения данных.
// 	ДопРеквизиты - Структура - реквизиты регистра недоступные в данных формы.
Процедура ПрочитатьЗаписьРегистра(Форма, ИмяРегистра, Организация, СоздатьНовую, КлючЗаписи = Неопределено, ПериодЗначений = Неопределено, ДопРеквизиты = Неопределено) Экспорт
```

Пример вызова
```bsl
НастройкиНалоговУчетныхПолитик.ПрочитатьЗаписьРегистра(Форма, ИмяРегистра, Организация, СоздатьНовую, КлючЗаписи, ПериодЗначений, ДопРеквизиты);
```
</details>

## СкопироватьУчетнуюПолитику
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет данные формы регистра сведений по значениям копирования записи регистра.
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения:
// 		* Запись - РегистрСведенийМенеджерЗаписиИмяРегистраСведений.
// 	Отбор - Структура - ЗначениеКопирования записи регистра сведений.
// 	ИмяРегистра - Строка - наименование периодического регистра сведений.
Процедура СкопироватьУчетнуюПолитику(Форма, Отбор, ИмяРегистра) Экспорт
```

Пример вызова
```bsl
НастройкиНалоговУчетныхПолитик.СкопироватьУчетнуюПолитику(Форма, Отбор, ИмяРегистра) 
```
</details>

## ОбновитьОписаниеИстории
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует гиперссылку с описание истории.
//
// Параметры:
// 	Форма - РасширениеУправляемойФормыДляЗаписиРегистраСведений - форма записи регистра сведений.
// 	ИмяРегистра - Строка - наименование периодического регистра сведений.
// 	Организация - СправочникСсылка.Организации - ссылка на организацию.
// 	ПериодСравнения - Дата - дата для сравнения.
Процедура ОбновитьОписаниеИстории(Форма, ИмяРегистра, Организация, ПериодСравнения) Экспорт
```

Пример вызова
```bsl
НастройкиНалоговУчетныхПолитик.ОбновитьОписаниеИстории(Форма, ИмяРегистра, Организация, ПериодСравнения) 
```
</details>

## ЗаписатьИзменениеЗаписейРегистра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при записи данных формы записи регистра сведений.
//
// Параметры:
// 	Форма - РасширениеУправляемойФормыДляЗаписиРегистраСведений - форма записи регистра сведений.
// 	Закрытие - Булево - признак закрытия формы после записи.
// 	ДопРеквизиты - Структура - реквизиты регистра недоступные в данных формы.
// Возвращаемое значение:
// 	Булево - признак успешной записи
Функция ЗаписатьИзменениеЗаписейРегистра(Форма, Закрытие = Ложь, ДопРеквизиты = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НастройкиНалоговУчетныхПолитик.ЗаписатьИзменениеЗаписейРегистра(Форма, Закрытие, ДопРеквизиты);
```
</details>

## ЗаполнитьОписаниеДействующихПараметров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет описание действующих параметров учетных политик на форме.
//
// Параметры:
// 	Форма - см. Справочник.Организации.Форма.ФормаЭлемента.
// 	Организация - СправочникСсылка.Организации - ссылка на справочник Организации.
// 	ИмяРегистра - Строка - наименование периодического регистра сведений.
// 	ДатаДействия - Дата - период получения данных.
Процедура ЗаполнитьОписаниеДействующихПараметров(Форма, Организация, ИмяРегистра = "", Знач ДатаДействия = "") Экспорт
```

Пример вызова
```bsl
НастройкиНалоговУчетныхПолитик.ЗаполнитьОписаниеДействующихПараметров(Форма, Организация, ИмяРегистра, ДатаДействия);
```
</details>

## УправлениеВидимостьюЭлементовУчетныхПолитик
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Управляет видимостью элементов формы, относящихся с учетным политикам и налогам.
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - форма с элементами учетных политик.
// 	СоответствиеЭлементовФормы - Соответствие - соответствие массива элементов формы и названия регистра учетных политик.
// 	Организация - СправочникСсылка.Организации - ссылка на справочник Организации.
// 	ДатаДействия - Дата - период получения данных.
Процедура УправлениеВидимостьюЭлементовУчетныхПолитик(Форма, СоответствиеЭлементовФормы, Организация, ДатаДействия = Неопределено) Экспорт
```

Пример вызова
```bsl
НастройкиНалоговУчетныхПолитик.УправлениеВидимостьюЭлементовУчетныхПолитик(Форма, СоответствиеЭлементовФормы, Организация, ДатаДействия);
```
</details>

## ОрганизацииСЗаданнымПараметромПолитики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив организаций, у которых установлен указанный параметр учетной политики.
//
// Параметры:
//	ИмяРегистра  - Строка - наименование периодического регистра сведений.
//	ИмяПараметра 	  - Строка - имя параметра учетной политики, см. результат функции ПараметрыУчетнойПолитики()
//	ЗначениеПараметра - Произвольный - значение указанного параметра учетной политики
//	Организации 	  - Массив, СправочникСсылка.Организации - организации для проверки учетных политик
//	Период 			  - Дата - дата, на которую необходимо проверить учетные политики
//
// Возвращаемое значение:
//	Массив - подмножество параметра Организации, с установленным параметром учетной политики.
//
Функция ОрганизацииСЗаданнымПараметромПолитики(ИмяРегистра, ИмяПараметра, ЗначениеПараметра, Экспорт
```

Пример вызова
```bsl
Результат = НастройкиНалоговУчетныхПолитик.ОрганизацииСЗаданнымПараметромПолитики(ИмяРегистра, ИмяПараметра, ЗначениеПараметра, );
```
</details>

## УчетнаяПолитикаНалоговыйУчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция - агрегатор сведений о настройках налогового учета на определенную дату
//
// Параметры:
//  Период       - Дата - дата чтения настроек.
//  Организация  - СправочникСсылка.Организации - организация, для которой требуется получить настройки.
//
// Возвращаемое значение:
//  Неопределено, ТаблицаЗначений - если нет ни одной записи настроек учета неопределено,
//                                  иначе таблица.
Функция УчетнаяПолитикаНалоговыйУчет(Период, Организация) Экспорт
```

Пример вызова
```bsl
Результат = НастройкиНалоговУчетныхПолитик.УчетнаяПолитикаНалоговыйУчет(Период, Организация) 
```
</details>

## ПорядокУчетаВНА
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТ

// Возвращает порядок учета внеоборотных активов.
//
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется порядок.
//	Период - Дата - дата, на которую определяется порядок.
//
// Возвращаемое значение:
//	ПеречислениеСсылка.ПорядокУчетаВНА -  Порядок учета внеоборотных активов.
//
Функция ПорядокУчетаВНА(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = НастройкиНалоговУчетныхПолитик.ПорядокУчетаВНА(Организация, Период) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
