---
title: Настройки налогов учетных политик локализация
slug: erp-uh/настройки-налогов-учетных-политик-локализация
---


## ПоддержкаПБУ18
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак необходимости применения для организации ПБУ18.
// Параметры:
//	Организация - Массив, СписокЗначений, СправочникСсылка.Организации - организация, для которой определяется необходимость применения ПБУ18;
//	Период - Дата - дата, на начало месяца которой определяется необходимость применения ПБУ18.
//
// Возвращаемое значение:
//	Булево - Истина, если организация на дату применяет ПБУ18. В противном случае - ложь.
//
Функция ПоддержкаПБУ18(Знач Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = НастройкиНалоговУчетныхПолитикЛокализация.ПоддержкаПБУ18(Организация, Период) 
```
</details>

## ВедетсяУчетПостоянныхИВременныхРазниц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак ведения учета постоянных разниц.
//
// Параметры:
//	Организация - Массив, СписокЗначений, СправочникСсылка.Организации - организация, для которой определяется признак;
//	Период - Дата - дата, на начало месяца которой определяется признак.
//
// Возвращаемое значение:
//	Булево - Истина, если организация ведет учет постоянных разниц.
//
Функция ВедетсяУчетПостоянныхИВременныхРазниц(Знач Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = НастройкиНалоговУчетныхПолитикЛокализация.ВедетсяУчетПостоянныхИВременныхРазниц(Организация, Период) 
```
</details>

## ВариантУчетаОтложенногоНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает применяемый вариант учета отложенного налога по организации на дату
//
// Параметры:
//  Период		 - Дата - Дата, на которую требуется определение
//  Организация	 - СправочникСсылка.Организации - Организация, по которой требуется определение
//
// Возвращаемое значение:
//  ПеречислениеСсылка.ВариантыУчетаОтложенногоНалога -
//
Функция ВариантУчетаОтложенногоНалога(Период, Знач Организация) Экспорт
```

Пример вызова
```bsl
Результат = НастройкиНалоговУчетныхПолитикЛокализация.ВариантУчетаОтложенногоНалога(Период, Организация) 
```
</details>

## ВариантыНалогообложенияПрибыли
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает варианты налогообложения прибыли, настроенные для организации.
//
// Параметры:
// 	Организация - СправочникСсылка.Организации - Организация, для которой необходимо получить признак учетной политики
// 	Период 		- Дата, Неопределено - Дата действия учетной политики
// 	КодМестаПредставления - Строка - Дополнительный отбор по коду места предоставления. Необязательный
//
// Возвращаемое значение:
//  Массив из СправочникСсылка.ВариантыНалогообложенияПрибыли
//
Функция ВариантыНалогообложенияПрибыли(Организация, Период, КодМестаПредставления = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НастройкиНалоговУчетныхПолитикЛокализация.ВариантыНалогообложенияПрибыли(Организация, Период, КодМестаПредставления);
```
</details>

## ПрименяетсяФСБУ25
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак применения для организации ФСБУ 25/2018.
// Параметры:
//	Организация - Массив, СписокЗначений, СправочникСсылка.Организации - организация, для которой определяется применение ФСБУ 25/2018;
//	Период - Дата - дата, на начало месяца которой определяется применение ФСБУ 25/2018.
//
// Возвращаемое значение:
//	Булево - Истина, если организация на дату применяет ФСБУ 25/2018. В противном случае - ложь.
//
Функция ПрименяетсяФСБУ25(Знач Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = НастройкиНалоговУчетныхПолитикЛокализация.ПрименяетсяФСБУ25(Организация, Период) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
