---
title: Номенклатура клиент сервер
slug: erp-uh/номенклатура-клиент-сервер
---


## ПредставлениеНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строковое представление номенклатуры с характеристикой и другими полями для отображения в сообщениях.
//
// Параметры:
//  Номенклатура	 - Строка, СправочникСсылка.Номенклатура			 - номенклатура;
//  Характеристика	 - Строка, СправочникСсылка.ХарактеристикиНоменклатуры	 - характеристика номенклатуры;
//  Упаковка		 - Строка, СправочникСсылка.УпаковкиЕдиницыИзмерения	 - упаковка / единица измерения номенклатуры;
//  Серия			 - Строка, СправочникСсылка.СерииНоменклатуры			 - серия номенклатуры;
//  Назначение		 - Строка, СправочникСсылка.Назначения					 - назначение номенклатуры.
//
// Возвращаемое значение:
//  Строка - представление номенклатуры.
//
Функция ПредставлениеНоменклатуры(Номенклатура, Характеристика, Упаковка = "", Серия = "", Назначение = "") Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ПредставлениеНоменклатуры(Номенклатура, Характеристика, Упаковка, Серия, Назначение);
```
</details>

## ПредставлениеСерииБезРасчетаПоШаблонуНаименования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает представление серии. Расчет может производится по шаблону рабочего наименования серии - тогда
// функция должна быть вызвана с сервера. Если шаблон не задан или функция вызвана с клиента, то расчет производится
// по предопределенному шаблону.
//
// Параметры:
//	ПараметрыШаблона	 - см. Справочники.ВидыНоменклатуры.НастройкиИспользованияСерий.
//	ЗначенияРеквизитов	 - Структура, ФормаКлиентскогоПриложения, СправочникОбъект.СерииНоменклатуры, ДанныеФормыЭлементКоллекции -
//							коллекция структуры данных, хранящая значения свойств, используемых в качестве
//							источника данных для формирования представления элемента справочника 'Серии номенклатуры'.
//	ДобавитьСловоНовая	 - Булево - признак необходимости добавления предопределенного суффикса к представлению
//									элемента справочника 'Серии номенклатуры'.
//
// Возвращаемое значение:
//	Строка - представление элемента справочника 'Серии номенклатуры'.
//
Функция ПредставлениеСерииБезРасчетаПоШаблонуНаименования(ПараметрыШаблона, ЗначенияРеквизитов, ДобавитьСловоНовая = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ПредставлениеСерииБезРасчетаПоШаблонуНаименования(ПараметрыШаблона, ЗначенияРеквизитов, ДобавитьСловоНовая);
```
</details>

## ДополнительныеПараметрыПредставлениеНоменклатурыДляПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополнительные параметры функции НоменклатураКлиентСервер.ПредставлениеНоменклатурыДляПечати.
//
// Возвращаемое значение:
//  Структура - со свойствами:
//  * Содержание - Строка - если передано не пустое содержание, то представлением будет оно, остальные параметры игнорируются
//  * ВозвратнаяТара - Булево - если ИСТИНА, то к представлению будет добавлена фраза "возвратная тара" в скобках.
//  * КодТНВЭД - Строка - если указан, то к представлению будет добавлен в скобках код ТН ВЭД.
//  * Префикс - Строка - если указан, то к представлению будет добавлен префикс перед наименованием номенклатуры.
//  * КодОсновногоЯзыка - Строка - указывается для уточнения кода основного языка при выводе локализуемых строк.
//
Функция ДополнительныеПараметрыПредставлениеНоменклатурыДляПечати() Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ДополнительныеПараметрыПредставлениеНоменклатурыДляПечати() 
```
</details>

## ПредставлениеНоменклатурыДляПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление номенклатуры для печати.
//
// Параметры:
//  НаименованиеНоменклатурыДляПечати	 - Строка		 - нужно строго передать строку с наименованием для печати. Ссылка не подойдет, т.к. при
//  		получении по ней строкового представления платформа возьмет наименование, а не наименование для печати;
//  НаименованиеХарактеристикиДляПечати	 - Строка		 - нужно строго передать строку с наименованием для печати. Ссылка не подойдет, т.к. при
//  		получении по ней строкового представления платформа возьмет наименование, а не наименование для печати;
//  Упаковка							 - Строка, Неопределено	- упаковка или единица измерения;
//  Серия								 - Строка, СправочникСсылка.СерииНоменклатуры	 - серия номенклатуры;
//  ДополнительныеПараметры				 - см. НоменклатураКлиентСервер.ДополнительныеПараметрыПредставлениеНоменклатурыДляПечати.
//
// Возвращаемое значение:
//  Строка - представление номенклатуры для печати.
//
Функция ПредставлениеНоменклатурыДляПечати(НаименованиеНоменклатурыДляПечати, Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ПредставлениеНоменклатурыДляПечати(НаименованиеНоменклатурыДляПечати, );
```
</details>

## ОтборПоТоваруМногооборотнойТаре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует массив отбора по типам номенклатуры Товар и МногооборотнаяТара
//
// Параметры:
//  ВключатьНабор	 - Булево	 - признак включения в отбор набора.
//
// Возвращаемое значение:
//  Массив - состоит из элементов типа ПеречислениеСсылка.ТипыНоменклатуры.
//
Функция ОтборПоТоваруМногооборотнойТаре(ВключатьНабор = Истина) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ОтборПоТоваруМногооборотнойТаре(ВключатьНабор);
```
</details>

## ОтборПоТоваруМногооборотнойТареУслуге
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует массив отбора по типам номенклатуры Товар, МногооборотнаяТара и Услуга
//
// Параметры:
//  ВключатьНабор	 - Булево	 - признак включения в отбор набора.
//
// Возвращаемое значение:
//  Массив - состоит из элементов типа ПеречислениеСсылка.ТипыНоменклатуры.
//
Функция ОтборПоТоваруМногооборотнойТареУслуге(ВключатьНабор = Истина) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ОтборПоТоваруМногооборотнойТареУслуге(ВключатьНабор);
```
</details>

## ОтборПоТоваруМногооборотнойТареУслугеРаботе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует массив отбора по типам номенклатуры Товар и МногооборотнаяТара, Услуга, Работа.
//
// Параметры:
//  ВключатьНабор	 - Булево	 - признак включения в отбор набора.
//
// Возвращаемое значение:
//  Массив - состоит из элементов типа ПеречислениеСсылка.ТипыНоменклатуры.
//
Функция ОтборПоТоваруМногооборотнойТареУслугеРаботе(ВключатьНабор = Истина) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ОтборПоТоваруМногооборотнойТареУслугеРаботе(ВключатьНабор);
```
</details>

## ОтборПоРаботе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует массив отбора по типу номенклатуры Работа.
//
// Параметры:
//  ВключатьНабор	 - Булево	 - признак включения в отбор набора.
//
// Возвращаемое значение:
//  Массив - состоит из элементов типа ПеречислениеСсылка.ТипыНоменклатуры.
//
Функция ОтборПоРаботе(ВключатьНабор = Истина) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ОтборПоРаботе(ВключатьНабор);
```
</details>

## ОтборПоУслугеРаботе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует массив отбора по типу номенклатуры Услуга и Работа.
//
// Параметры:
//  ВключатьНабор	 - Булево	 - признак включения в отбор набора.
//
// Возвращаемое значение:
//  Массив - состоит из элементов типа ПеречислениеСсылка.ТипыНоменклатуры.
//
Функция ОтборПоУслугеРаботе(ВключатьНабор = Истина) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ОтборПоУслугеРаботе(ВключатьНабор);
```
</details>

## ПараметрыУказанияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Структура параметров указания серий, возвращаемая соответствующей процедурой модуля менеджера документа (обработки).
//
// Возвращаемое значение:
//	Структура - содержит свойства:
// 	[ОБЯЗАТЕЛЬНЫЕ].
//		* ИспользоватьСерииНоменклатуры - Булево - признак, нужно ли в документе заполнять статусы указания серий
//		* ПоляСвязиСерий - Массив из Строка - массив с именами реквизитов ТЧ Товары и ТЧ Серии,
//						по которым устанавливается связь между табличными частями
//						(поля связи "Номенклатура" и "Характеристика" присутствуют всегда, их отдельно указывать не нужно).
//		* СкладскиеОперации - Массив из ПеречислениеСсылка.СкладскиеОперации - складские операции, оформляемые документом
//		* ПолноеИмяОбъекта - Строка - полное имя объекта. Например, Документ.РеализацияТоваровУслуг.
// [НЕОБЯЗАТЕЛЬНЫЕ].
//		* ТолькоПросмотр - Булево - признак того, что серии в документе можно только просматривать (значение по умолчанию ЛОЖЬ)
//		* ТоварВШапке - Булево - признак того, что параметры указания серий определены для товара в шапке (иначе - для товара в ТЧ) (значение по умолчанию ЛОЖЬ)
//		* БлокироватьДанныеФормы - Булево - признак того, что перед открытием форму указания серий,
//								нужно заблокировать форму документа (значение по умолчанию ИСТИНА)
//								если ТолькоПросмотр = Истина, то данные формы не блокируются.
//		* ИмяТЧТовары - Строка - имя табличной части со списком товаров (значение по умолчанию - "Товары")
//		* ИмяТЧСерии - Строка - имя табличной части со списком серий (значение по умолчанию - "Серии")
//		* ИмяПоляКоличество - Строка - имя поля в ТЧ "Товары", в котором пользователь редактирует количество (значение по умолчанию - "КоличествоУпаковок")
//		* ИмяПоляСклад - Строка - имя реквизита склада (значение по умолчанию - "Склад")
//		* ИмяПоляПомещение - Строка - имя реквизита помещения, если не задано, значит в документе нет помещений
//		* ИмяПоляДокументаРаспоряжения - Строка - если серии указываются в расходном ордере,
//								то в этом параметре записывается имя поля распоряжения на отгрузку.
//								Если серии указываются в накладной на поступление, то в этом параметре записывается
//								имя поле распоряжения на поступление. Значение поля используются для отображения остатков в формах.
//		* ЭтоОрдер - Булево - признак того, что документ является ордером (значение по умолчанию ЛОЖЬ)
//		* ЭтоЗаказ - Булево - признак того, что документ является заказом (значение по умолчанию ЛОЖЬ)
//		* ЭтоНакладная - Булево - признак того, что документ является накладной (значение по умолчанию ЛОЖЬ).
//		* ТолькоСерииДляСебестоимости - Булево - нужно указывать только серии, по которым ведется учет себестоимости (значение по умолчанию ЛОЖЬ)
//		* ПланированиеОтгрузки - Булево - использование параметра политики указания серий "УказыватьПриПланированииОтгрузки" (значение по умолчанию ЛОЖЬ)
//		* ПланированиеОтбора - Булево - использование параметра политики указания серий "УказыватьПриПланированииОтбора" (значение по умолчанию ЛОЖЬ)
//		* ПроверкаОтбора - Булево - на адресном складе перед проверкой должны быть заполнены все серии, по которым ведется учет остатков
//		* ФактОтбора  - Булево - использование параметра политики указания серий "УказыватьПоФактуОтбора" (значение по умолчанию ЛОЖЬ)
//		* ПодготовкаОрдера - Булево - параметр указывает, что ордер находится в статусе,
//								когда происходит подготовка ордера и указание серий не обязательна (значение по умолчанию ЛОЖЬ).
//		* ИменаПолейССуффиксом - Структура - коллекция, содержащая имена рекизитов с суффиксом. Ключом коллекции
//												выступает имя реквизита без суффикса, например "Номенклатура",
//												а значением задается имя реквизита с суффиксом,
//												например "НоменклатураОприходование".
//		* ИменаПолейСтатусУказанияСерий - Массив из Строка - если в объекте несколько полей со статусом указания серий,
//								то нужно добавить их имена в этот массив (значение по умолчанию пустой массив).
//		* СоответствиеИмениПоляСерияСтатусуУказанияСерий - Соответствие - коллекция, содержащая соответствие имени
//															реквизита СтатусУказанияСерий имени реквизита Серия.
//															Например "СтатусУказанияСерийОприходование" - ключ,
//															а "СерияОприходование" - значение коллекции.
//		* ИменаПолейДляОпределенияРаспоряжения - Массив - имена полей для определение распоряжения,
//								по которому отображаются остатки в форме подбора серий. Имена полей табличной части
//								указываются в формате Товары_ДокументРезерваСерий (значение по умолчанию пустой массив).
//		* ИспользоватьАдресноеХранение - Булево - на складе, по которому оформлен документ, используется адресное хранение (значение по умолчанию ЛОЖЬ)
//		* ИмяИсточникаЗначенийВФормеОбъекта - Строка - значение по умолчанию "Объект", если данные хранятся в реквизитах формы, то нужно указать "ЭтоФорма"
//		* ОтборПроверяемыхСтрок -
//		* ТолькоСерииСУчетомОстатков - Булево - необходимо указывать серии только тогда, когда по ним ведется учет остатков. (значение по умолчанию - ЛОЖЬ)
//		* ОсобеннаяПроверкаСтатусовУказанияСерий - Булево - признак, что в модуле менеджера объявлена процедура
//								ТекстЗапросаПроверкиЗаполненияСерий(ПараметрыУказанияСерий)(значение по умолчанию - ЛОЖЬ).
//		* ПараметрыЗапроса - Структура - содержит параметры запроса, используемые в функции ТекстЗапросаЗаполненияСтатусовУказанияСерий.
//		* СерииПриПланированииОтгрузкиУказываютсяВТЧСерии - Булево - значение по умолчанию - ЛОЖЬ.
//
Функция ПараметрыУказанияСерий() Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ПараметрыУказанияСерий() 
```
</details>

## ВыбраннаяСерия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Структура, которую возвращает форма подбора серии
//
// Возвращаемое значение:
//  Структура - структура со следующими ключами:
//  * Значение - СправочникСсылка.СерииНоменклатуры
//  * ИдентификаторСтроки - Число - идентификатор строки таблицы формы, в которую, нужно подставить значение.
//
Функция ВыбраннаяСерия() Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ВыбраннаяСерия() 
```
</details>

## ОбновитьКешированныеЗначенияДляУчетаСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура обновляет кеш ключевых реквизитов текущей строки товаров. По ключевым реквизитам осуществляется связь
//  между ТЧ серий и ТЧ товаров.
//
// Параметры:
//  ТекущаяСтрока			 - ДанныеФормыЭлементКоллекции - строка, по которой обновляется кеш.
//  КэшированныеЗначения	 - Структура - переменная модуля формы, в которой хранятся кешируемые значения
//  ПараметрыУказанияСерий	 - см. ПараметрыУказанияСерий
//  Копирование				 - Булево - признак, что кешированная строка скопирована (параметр события ПриНачалеРедактирования).
//
Процедура ОбновитьКешированныеЗначенияДляУчетаСерий(ТекущаяСтрока,КэшированныеЗначения,ПараметрыУказанияСерий,Копирование = Ложь) Экспорт
```

Пример вызова
```bsl
НоменклатураКлиентСервер.ОбновитьКешированныеЗначенияДляУчетаСерий(ТекущаяСтрока, КэшированныеЗначения, ПараметрыУказанияСерий, Копирование);
```
</details>

## НеобходимоРегистрироватьСерии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция определяет возможность регистрации новых серий, при указании серий в документе.
//
// Параметры:
//  ПараметрыУказанияСерий - см. ПараметрыУказанияСерий
//
// Возвращаемое значение:
//  Булево - ИСТИНА - можно регистрировать новые серии, ЛОЖЬ - серии можно подбирать только по остаткам.
//
Функция НеобходимоРегистрироватьСерии(ПараметрыУказанияСерий) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.НеобходимоРегистрироватьСерии(ПараметрыУказанияСерий) 
```
</details>

## ИнформацияОСерииИзШтрихкода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Извлекает из штрихкода информацию о номере и сроке годности.
// Работает только для штрихкодов, сгенерированных обработкой печати штрихкодов и номеров
// серий, сгенерированных формой регистрации серий.
//
// Параметры:
//	Штрихкод - Строка - штрихкод, из которого нужно извлечь информацию;
//	ЕстьПолеНомер - Булево - признак, что для серии, чей штрихкод передан, используется номер;
//	ЕстьПолеГоденДо - Булево - признак, что для серии, чей штрихкод передан, используется номер.
//
// Возвращаемое значение:
//	Структура:
//		* Номер - Строка - номер, извлеченный из штрихкода, если номера у серии нет - пустая строка;
//		* ГоденДо - Дата - дата срока годности, если срока годности у серии нет - пустая дата.
//
Функция ИнформацияОСерииИзШтрихкода(Знач Штрихкод, ЕстьПолеНомер, ЕстьПолеГоденДо) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ИнформацияОСерииИзШтрихкода(Штрихкод, ЕстьПолеНомер, ЕстьПолеГоденДо) 
```
</details>

## ГоденДоПоДатеПроизводства
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция - Годен до по дате производства
//
// Параметры:
//  ДатаПроизводства				 - Дата
//  СрокГодности					 - Число
//  ЕдиницаИзмеренияСрокаГодности	 - ПеречислениеСсылка.ЕдиницыИзмеренияВремени
//
// Возвращаемое значение:
//  Дата -
//
Функция ГоденДоПоДатеПроизводства(ДатаПроизводства, СрокГодности, ЕдиницаИзмеренияСрокаГодности) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ГоденДоПоДатеПроизводства(ДатаПроизводства, СрокГодности, ЕдиницаИзмеренияСрокаГодности) 
```
</details>

## ПересчитатьДатуСерии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Ошибка платформы 00110413.
// Пересчитывает значение даты элемента справочника "СерииНоменклатуры", после выбора значения платформенными средствами.
//
// Параметры:
//	ДатаСерии - Дата - дата элемента справочника "СерииНоменклатуры", полученная платформенными средствами.
//
Процедура ПересчитатьДатуСерии(ДатаСерии) Экспорт
```

Пример вызова
```bsl
НоменклатураКлиентСервер.ПересчитатьДатуСерии(ДатаСерии) 
```
</details>

## ОтборПоТоваруМногооборотнойТареРаботе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует массив отбора по типам номенклатуры Товар и МногооборотнаяТара, Работа.
//
// Параметры:
//  ВключатьНабор	 - Булево	 - признак включения в отбор набора.
//
// Возвращаемое значение:
//  Массив - состоит из элементов типа ПеречислениеСсылка.ТипыНоменклатуры.
//
Функция ОтборПоТоваруМногооборотнойТареРаботе(ВключатьНабор = Истина) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ОтборПоТоваруМногооборотнойТареРаботе(ВключатьНабор);
```
</details>

## ПараметрыОтбораПолитикУчетаСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры отбора политик учета серий
//
// Возвращаемое значение:
//  Структура:
//  	* Склад - СправочникСсылка.Склады
//  	* ВидНоменклатуры - СправочникСсылка.ВидыНоменклатуры
//  	* ИспользоватьСерии - Булево
//  	* ИспользоватьСрокГодностиСерии - Булево
//  	* ТипНоменклатуры - ПеречислениеСсылка.ТипыНоменклатуры
//  	* ОсобенностьУчета - ПеречислениеСсылка.ОсобенностиУчетаНоменклатуры
//  	* НастройкаИспользованияСерий - ПеречислениеСсылка.НастройкиИспользованияСерийНоменклатуры
//
Функция ПараметрыОтбораПолитикУчетаСерий() Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ПараметрыОтбораПолитикУчетаСерий() 
```
</details>

## РеквизитыПрослеживаемостиПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает коллекцию реквизитов прослеживаемости инициализированных по умолчанию.
//
// Возвращаемое значение:
//	Структура - коллекция реквизитов прослеживаемости, которая содержит следующие поля:
//		* ЕдиницаИзмерения		- СправочникСсылка.УпаковкиЕдиницыИзмерения - единица измерения.
//		* ПрослеживаемыйТовар	- Булево - признак того, что товар подлежит учету в системе прослеживаемости.
//
Функция РеквизитыПрослеживаемостиПоУмолчанию() Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.РеквизитыПрослеживаемостиПоУмолчанию() 
```
</details>

## ИмяПоляШапкиТовара
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя поля шапки товара по указанному параметру имени поля.
//
// Параметры:
//	ИмяПоля - Строка - имя поля товара, для которого необходимо получить связанное имя поля шапки товара.
//
// Возвращаемое значение:
//	Строка - имя поля шапки товара, рассчитанное по указанному параметру имени поля.
//
Функция ИмяПоляШапкиТовара(ИмяПоля) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ИмяПоляШапкиТовара(ИмяПоля) 
```
</details>

## ПараметрыУстановкиСтатусаСертификатовНоменклатурыПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает коллекцию параметров по умолчанию, используемую при установке статуса сертификатов номенклатуры.
//
// Возвращаемое значение:
//	Структура - коллекцию параметров по умолчанию, содержащая следующие свойства:
//		* Статус - ПеречислениеСсылка.СтатусыСертификатовНоменклатуры - устанавливаемое значение статуса.
//																		Значение по умолчанию - Действующий.
//		* ДанныеКОбработке - Массив из СправочникСсылка.СертификатыНоменклатуры,
//								Массив из РегистрСведенийКлючЗаписи.ОбластиДействияСертификатовНоменклатуры - коллекция обрабатываемых данных.
//
Функция ПараметрыУстановкиСтатусаСертификатовНоменклатурыПоУмолчанию() Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураКлиентСервер.ПараметрыУстановкиСтатусаСертификатовНоменклатурыПоУмолчанию() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
