---
title: Номенклатура сервер
slug: erp-uh/номенклатура-сервер
---


## ФормулаНаименования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подставляет в шаблон наименования значения реквизитов.
//
// Параметры:
//  ШаблонНаименования	 - Строка								 - шаблон наименования, заданный в виде номенклатуры
//  ОбъектСправочник	 - СправочникОбъект, СправочникСсылка	 - объект, для которого нужно рассчитать наименование.
//
// Возвращаемое значение:
//  Структура - Структура с ключами:
//  * ФормулаНаименования - Строка - программный код, который нужно выполнить с помощью функции Выполнить для расчета наименования
//  * МассивЗначенийРеквизитов - Массив - значения реквизитов, используемых в формуле наименования
//  * ИндексыНаименованияВМассивеЗначенийРеквизитов - Массив - массив индексов элементов МассивЗначенийРеквизитов,
//  	которые хранят значение реквизита "Наименование".
//
Функция ФормулаНаименования(Знач ШаблонНаименования, Знач ОбъектСправочник) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.ФормулаНаименования(ШаблонНаименования, ОбъектСправочник) 
```
</details>

## УстановитьПараметрыВыбораНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает параметры выбора для номенклатуры.
// Параметры:
//	ХозяйственнаяОперация - ПеречислениеСсылка.ХозяйственныеОперации - Хозяйственная операция документа,
//	ЭлементНоменклатура - ПолеФормы - Поле для ввода номенклатуры,
//	ИспользоватьНаборы - Булево - Истина - признак использования наборов номенклатуры.
//
Процедура УстановитьПараметрыВыбораНоменклатуры(ХозяйственнаяОперация, ЭлементНоменклатура, ИспользоватьНаборы = Ложь) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.УстановитьПараметрыВыбораНоменклатуры(ХозяйственнаяОперация, ЭлементНоменклатура, ИспользоватьНаборы);
```
</details>

## СписокХозяйственныхОперацийИсключающихУслуги
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает список хозяйственных операций в которых не используется номенклатура
// с типом "Услуга".
//
// Возвращаемое значение:
//	СписокЗначений - список операций.
//
Функция СписокХозяйственныхОперацийИсключающихУслуги() Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.СписокХозяйственныхОперацийИсключающихУслуги() 
```
</details>

## СписокХозяйственныхОперацийИсключающихРаботы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает список хозяйственных операций в которых не используется номенклатура
// с типом "Работа".
//
// Возвращаемое значение:
//	СписокЗначений - список операций.
//
Функция СписокХозяйственныхОперацийИсключающихРаботы() Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.СписокХозяйственныхОперацийИсключающихРаботы() 
```
</details>

## СписокХозяйственныхОперацийИсключающихУслугиИРаботы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает список хозяйственных операций в которых не используется номенклатура
// ИС типом "Услуга", ИС типом "Работа".
//
// Возвращаемое значение:
//	СписокЗначений - список операций.
//
Функция СписокХозяйственныхОперацийИсключающихУслугиИРаботы() Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.СписокХозяйственныхОперацийИсключающихУслугиИРаботы() 
```
</details>

## ПараметрыПроверкиЗаполненияХарактеристик
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает параметры проверки заполнения характеристик номенклатуры
//
//	Возвращаемое значение:
//		Структура  - структура со следующими ключами:
//			* ИмяТЧ - Строка - значение по умолчанию "Товары".
//			* ИменаПолейССуффиксом - Структура - коллекция, содержащая имена рекизитов с суффиксом. Ключом коллекции
//													выступает имя реквизита без суффикса, например "Номенклатура",
//													а значением задается имя реквизита с суффиксом,
//													например "НоменклатураОприходование".
//			* СписокСтрок - Массив Из СтрокаТабличнойЧасти, Неопределено - значение по умолчанию Неопределенно.
//			* ВыводитьНомераСтрок - Булево - значение по умолчанию Истина.
//			* ВыдаватьСообщения - Булево - значение по умолчанию пустая ИСТИНА - если ЛОЖЬ, но не будут выдаваться сообщения, просто выставится Отказ.
//			* ПутьКДаннымТаблицыФормы - Строка - значение по умолчанию "Объект" - путь к реквизиту формы, содержащий проверяемую табличную часть.
//																					Если проверяется таблица, которая сама является реквизитом формы, нужно
//																					передать "" (т.е. пустую строку).
//			* ИмяКолонкиХарактеристикаТаблицыФормы - Строка - значение по умолчанию "Характеристика" - имя колонки таблицы формы, рядом с которой нужно
//																вывести сообщение. Нужно переопределять, когда вместо колонки характеристики отображается какая-то
//																другая колонка, например, с какими-то строковыми представлениями.
//
Функция ПараметрыПроверкиЗаполненияХарактеристик() Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.ПараметрыПроверкиЗаполненияХарактеристик() 
```
</details>

## ПроверитьЗаполнениеХарактеристик
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура проверки заполнения колонок "Характеристика" в объектах.
//
// Параметры:
//	Объект  - ДокументОбъект, СправочникОбъект - объект, для которого требуется проверить заполнение колонки "Характеристика" в табличной части;
//			- ФормаКлиентскогоПриложения - объект, для которого требуется проверить заполнение колонки "Характеристика" в табличной части, содержит в том числе:
//				* Ссылка - ДокументСсылка -
//	МассивНепроверяемыхРеквизитов - Массив - реквизиты, которые не нужно проверять платформенной проверкой;
//	Отказ - Булево - Истина - признак отказа продолжения операции;
//	ПараметрыПроверки - см. НоменклатураСервер.ПараметрыПроверкиЗаполненияХарактеристик
//
Процедура ПроверитьЗаполнениеХарактеристик(Объект,МассивНепроверяемыхРеквизитов,Отказ,ПараметрыПроверки = Неопределено) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ПроверитьЗаполнениеХарактеристик(Объект, МассивНепроверяемыхРеквизитов, Отказ, ПараметрыПроверки);
```
</details>

## ПроверитьЗаполнениеСодержания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура проверки заполнения колонок "Содержание" в формах.
//
// Параметры:
//	Объект - ДокументОбъект - объект, для которого требуется проверить заполнение колонки "Содержание" в табличной части;
//	Отказ - Булево - Истина - признак отказа продолжения операции;
//	ИмяТЧ - Строка - имя табличной части в объекте.
//
Процедура ПроверитьЗаполнениеСодержания(Объект, Отказ, ИмяТЧ) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ПроверитьЗаполнениеСодержания(Объект, Отказ, ИмяТЧ) 
```
</details>

## ПроверитьНаличиеРабот
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция определяет наличие в табличной части работ.
//
// Параметры:
//	ТЧ - ДанныеФормыКоллекция - проверяемая табличная часть.
//
// Возвращаемое значение:
//	Структура:
//		* ЕстьРаботы - Булево - Истина - в ТЧ используются работы.
//
Функция ПроверитьНаличиеРабот(ТЧ) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.ПроверитьНаличиеРабот(ТЧ) 
```
</details>

## ПараметрыПроверкиЗаполненияУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры проверки заполнения упаковок.
//
//	Возвращаемое значение:
//		Структура - структура со следующими ключами:
//			* ИмяТЧ - Строка - значение по умолчанию "Товары".
//			* ИмяПоляУпаковка - Строка - значение по умолчанию "Упаковка".
//			* ВыводитьНомераСтрок - Булево - значение по умолчанию Истина.
//			* ОтборПроверяемыхСтрок - Структура - значение по умолчанию пустая Структура.
//			* ИменаПолейССуффиксом - Структура - коллекция, содержащая имена рекизитов с суффиксом. Ключом коллекции
//													выступает имя реквизита без суффикса, например "Номенклатура",
//													а значением задается имя реквизита с суффиксом,
//													например "НоменклатураОприходование".
//
Функция ПараметрыПроверкиЗаполненияУпаковок() Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.ПараметрыПроверкиЗаполненияУпаковок() 
```
</details>

## ПроверитьЗаполнениеУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет заполнение колонок "Упаковка" в документах по адресному складу. Указание упаковок обязательно для товаров
// и необязательно для многооборотной тары.
//
// Параметры:
//	Объект	- ДокументОбъект, СправочникОбъект - объект, для которого требуется проверить заполнение колонки "Упаковка" в табличной части.
//			- ФормаКлиентскогоПриложения - объект, для которого требуется проверить заполнение колонки "Характеристика" в табличной части, содержит в том числе:
//				* Ссылка - ДокументСсылка - ссылка на документ в информационной базе.
//	МассивНепроверяемыхРеквизитов - Массив Из Строка - реквизиты, которые не нужно проверять платформенной проверкой.
//	Отказ - Булево - Истина - признак отказа продолжения операции.
//	ПараметрыПроверки - см. ПараметрыПроверкиЗаполненияУпаковок
//
Процедура ПроверитьЗаполнениеУпаковок(Объект,МассивНепроверяемыхРеквизитов,Отказ,ПараметрыПроверки = Неопределено) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ПроверитьЗаполнениеУпаковок(Объект, МассивНепроверяемыхРеквизитов, Отказ, ПараметрыПроверки);
```
</details>

## ПроверитьВидНоменклатурыОприходования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура проверки соответствия вида номенклатуры товаров другого качества виду номенклатуры исходного качества.
// Для номенклатуры, по которой ведется учет серий, товары другого качества должны быть одного вида с исходными.
//
// Параметры:
//	Объект - ДокументОбъект - документ, для которого проверяется соответствие номенклатуры;
//	Отказ - Булево - отказ продолжения операции;
//	ИмяТЧДляПроверки - Строка - значение по умолчанию "Товары";
//	ТаблицаДляПроверки - ТаблицаЗначений, Неопределено - если передана таблица значений, то проверяется она, попытка выгрузки из объекта не делается:
//		* НомерСтроки - Число
//		* Номенклатура - СправочникСсылка.Номенклатура
//		* НоменклатураОприходование - СправочникСсылка.Номенклатура.
//
Процедура ПроверитьВидНоменклатурыОприходования(Объект, Отказ, ИмяТЧДляПроверки = "Товары", ТаблицаДляПроверки = Неопределено) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ПроверитьВидНоменклатурыОприходования(Объект, Отказ, ИмяТЧДляПроверки, ТаблицаДляПроверки);
```
</details>

## КоэффициентПересчетаВТонны
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение коэффициента пересчета единицы измерения в метрические тонны.
// Например, для килограмма коэффициент = 0.001.
//
// Параметры:
//	УпаковкаЕдиницаИзмерения - СправочникСсылка.УпаковкиЕдиницыИзмерения - упаковка / единица измерения,
//		для которой осуществляется пересчет.
//
// Возвращаемое значение:
//	Число - коэффициент.
//
Функция КоэффициентПересчетаВТонны(УпаковкаЕдиницаИзмерения) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.КоэффициентПересчетаВТонны(УпаковкаЕдиницаИзмерения) 
```
</details>

## КоэффициентПересчетаВКубическиеМетры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение коэффициента единицы измерения в кубические метры.
//
// Параметры:
//  УпаковкаЕдиницаИзмерения - СправочникСсылка.УпаковкиЕдиницыИзмерения - упаковка / единица измерения,
//  	для которой осуществляется пересчет.
//
// Возвращаемое значение:
//  Число - коэффициент пересчета.
//
Функция КоэффициентПересчетаВКубическиеМетры(УпаковкаЕдиницаИзмерения) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.КоэффициентПересчетаВКубическиеМетры(УпаковкаЕдиницаИзмерения) 
```
</details>

## ЗаполнитьСтатусыУказанияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет статусы указания серий в строках ТЧ товары (комментарий содержит описание подсистемы серий).
//
//  Возможные статусы указания серий:
//
//  -1 - серии указаны в таблице уточнения (нет картинки)
//  0 - серии указывать не требуется (нет картинки)
//  первый указанный статус - количество по сериям не совпадает с количеством товаров или серии не указаны (красная картинка)
//  второй указанный статус   - количество по сериям совпадает с количеством товаров (зеленая картинка)
//  третий указанный статус   - серии не указаны, их можно указывать, а можно и не указывать (синяя картинка)
// 	 1,2,21  - серии указываются справочно
// 	 3,4,23  - по сериям учитываются остатки, серии указываются по факту отбора
// 	 5,6,25  - по сериям учитываются остатки, серии указываются при планировании отбора,
// 		 заполняются по FEFO (используются только в документах отгрузки товаров)
// 	 7,8,27  - по сериям учитываются остатки, серии указываются при планировании отбора
// 	 9,10,11 - по сериям учитываются остатки, серии указываются при планировании отгрузки,
//  	по сериям формируются движения по регистру ТоварыКОтгрузке (как при приходе, так и при расходе)
//   13,14,15 - учитываются также, как 9,10,11 + по сериям учитывается себестоимость
//   17,18,28 - по сериям учитываются товары у партнеров (товары в пути, неотфактурованные поставки)
//   19,20,22 - по сериям учитываются товары у партнеров (товары в пути, неотфактурованные поставки).
//
// Параметры:
//  Объект						 - ДанныеФормыСтруктура, ДокументОбъект - объект, в котором нужно заполнить статусы.
//  ПараметрыУказанияСерий		 - Структура - состав полей задается функцией НоменклатураКлиентСервер.ПараметрыУказанияСерий
//  	(см. описание полей в комментарии к этой функции).
//  СтрокиТоваровДляОбработки	 - Массив - строки товаров, в которых нужно заполнить статусы указания серий,
//  	если передано "Неопределено", то статусы заполняются во всех строках товаров.
//  СтрокиСерийДляОбработки		 - Массив - строки серий, по данным которых нужно заполнить статусы указания серий,
//  	если передано "Неопределено", то учитываются все строки серий.
//
Процедура ЗаполнитьСтатусыУказанияСерий(Объект, Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ЗаполнитьСтатусыУказанияСерий(Объект, );
```
</details>

## ЗаполнитьСтатусыУказанияСерийПриОкончанииРедактированияСтрокиТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура пересчитывает статусы указания серий в строках товаров, если это необходимо,
//  переподчиняет строки серий другим строкам ТЧ "Товары".
//
// Параметры:
//  Объект						 - ДанныеФормыСтруктура	 - основной реквизит формы документа.
//  ПараметрыУказанияСерий		 - Структура - структура параметров указания серий, возвращаемая соответствующей процедурой модуля менеджера документа.
//  ТекущаяСтрокаИдентификатор	 - Число - идентификатор текущей строки товаров в форме документа.
//  КэшированныеЗначения		 - Структура - структура кеша реквизитов текущей строки товаров.
//
Процедура ЗаполнитьСтатусыУказанияСерийПриОкончанииРедактированияСтрокиТЧ(Объект, Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ЗаполнитьСтатусыУказанияСерийПриОкончанииРедактированияСтрокиТЧ(Объект, );
```
</details>

## ЗаполнитьСтатусыУказанияСерийПриИзмененииТовараВШапке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура пересчитывает статусы указания серий для товара в шапке документа, если это необходимо, переподчиняет
// строки серий.
//
// Параметры:
//  Объект					 - ДанныеФормыСтруктура	 - основной реквизит формы документа.
//  ПараметрыУказанияСерий	 - Структура - структура параметров указания серий, возвращаемая соответствующей процедурой модуля менеджера документа.
//  КэшированныеЗначения	 - Структура - структура кеша реквизитов текущей строки товаров.
//
Процедура ЗаполнитьСтатусыУказанияСерийПриИзмененииТовараВШапке(Объект, Знач ПараметрыУказанияСерий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ЗаполнитьСтатусыУказанияСерийПриИзмененииТовараВШапке(Объект, ПараметрыУказанияСерий, КэшированныеЗначения) 
```
</details>

## ОчиститьНеиспользуемыеСерии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура удаляет строки ТЧ "Серии", которым по полям связи нет соответствующих строк в ТЧ "Товары"
//  или в этих строках статус указания серий равен 0 (не указывать).
//
// Параметры:
//  ДокументОбъект			 - ДанныеФормыКоллекция, ДокументОбъект - ДокументОбъект, в котором нужно удалить неиспользуемые строки серий.
//  ПараметрыУказанияСерий	 - Структура - описание см. НоменклатураКлиентСервер.ПараметрыУказанияСерий.
//
Процедура ОчиститьНеиспользуемыеСерии(ДокументОбъект, ПараметрыУказанияСерий) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ОчиститьНеиспользуемыеСерии(ДокументОбъект, ПараметрыУказанияСерий) 
```
</details>

## ПроверитьСериюРассчитатьСтатусПриИзмененииРеквизитаВТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Если по сериям для переданных Номенклатуры/Склада учитывается себестоимость, то рассчитывает статус указания серий.
//  Проверяет принадлежность уже указанной серии переданной номенклатуре.
//
// Параметры:
//  ТекущаяСтрока			 - Структура - для которой рассчитывается статус указания серий;
//  Склад					 - СправочникСсылка.Склады	 - склад, для которого осуществляется расчет статуса указания серий;
//  ПараметрыУказанияСерий	 - Структура				 - структура, описанная в функции НоменклатураКлиентСервер.ПараметрыУказанияСерий.
//
// Возвращаемое значение:
//  Структура - структура со следующими ключами:
//  * Серия - СправочникСсылка.СерииНоменклатуры - если серия указана и она может использоваться с новым значением номенклатуры,
//  	на указанном складе, то возвращается переданное значение, если нет - пустая ссылка.
//  * СтатусУказанияСерий - Число - если серии указываются в ТЧ "Товары", то возвращается рассчитанный статус,
//  	если для переданной номенклатуры/склада серии не используется - возвращается 0
//  	иначе возвращается переданный статус.
//
Функция ПроверитьСериюРассчитатьСтатусПриИзмененииРеквизитаВТЧ(ТекущаяСтрока, Склад, ПараметрыУказанияСерий) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.ПроверитьСериюРассчитатьСтатусПриИзмененииРеквизитаВТЧ(ТекущаяСтрока, Склад, ПараметрыУказанияСерий) 
```
</details>

## ЗаполнитьСерииПоFEFO
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура подбирает серии по FEFO и заполняет подобранными значениями ТЧ "Серии"
//  Учитываются движения документа, заполненные серии перезаполняются.
//
// Параметры:
//  Объект							 - ДанныеФормыКоллекция, ДокументОбъект - объект, в котором нужно заполнить статусы.
//  ПараметрыУказанияСерий			 - Структура - параметры указания серий, возвращаемые соответствующей процедурой модуля менеджера документа.
//  СтатусыУказанияСерийЗаполнены	 - Булево - если статусы указания серий в ТЧ Товары заполнены.
//
Процедура ЗаполнитьСерииПоFEFO(Объект,ПараметрыУказанияСерий, СтатусыУказанияСерийЗаполнены = Истина) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ЗаполнитьСерииПоFEFO(Объект, ПараметрыУказанияСерий, СтатусыУказанияСерийЗаполнены);
```
</details>

## ЕстьСтрокиСЗаполненнымиПоFEFOСериями
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция проверяет наличие в ТЧ "Товары" строк, по которым серии заполнены по FEFO.
//
// Параметры:
//  ТЧ	 - ДанныеФормыКоллекция	 - проверяемая ТЧ объекта.
//
// Возвращаемое значение:
//  Булево - признак наличия в ТЧ "Товары" строк, заполненных по FEFO.
//
Функция ЕстьСтрокиСЗаполненнымиПоFEFOСериями(ТЧ) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.ЕстьСтрокиСЗаполненнымиПоFEFOСериями(ТЧ) 
```
</details>

## ЕстьСтрокиСЗаполняемымиПоFEFOСериями
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция проверяет наличие в ТЧ "Товары" строк, по которым серии можно заполнить по FEFO.
//
// Параметры:
//  ТЧ	 - ДанныеФормыКоллекция	 - проверяемая ТЧ объекта.
//
// Возвращаемое значение:
//  Булево - признак наличия в ТЧ "Товары" строк, по которым серии можно заполнить по FEFO.
//
Функция ЕстьСтрокиСЗаполняемымиПоFEFOСериями(ТЧ) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.ЕстьСтрокиСЗаполняемымиПоFEFOСериями(ТЧ) 
```
</details>

## СерияУказанаКорректно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, предусматривает ли политика указания серий на переданном складе указание серий
//  и проверяет принадлежность серии.
//
// Параметры:
//  Склад							 - СправочникСсылка.Склады	 - склад, на котором хранится номенклатура;
//  Номенклатура					 - СправочникСсылка.Номенклатура - номенклатура;
//  Серия							 - СправочникСсылка.СерииНоменклатуры	 - серия номенклатуры;
//  ИмяПараметраПолитикиУчетаСерий	 - Строка								 - имя реквизита политики учета серий, по которому нужно проверить
//  								статус указания серий.
//
// Возвращаемое значение:
//  Структура - структура со следующими ключами:
//  *СтатусУказанияСерий - Строка - статус указания серий;
//  *Серия - СправочникСсылка.СерииНоменклатуры - если серия принадлежит тому же виду номенклатуры,
//  	то переданная серия, иначе - пустая ссылка.
//
Функция СерияУказанаКорректно(Склад, Номенклатура, Серия, ИмяПараметраПолитикиУчетаСерий) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.СерияУказанаКорректно(Склад, Номенклатура, Серия, ИмяПараметраПолитикиУчетаСерий) 
```
</details>

## СтатусУказанияСерии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// По указанным параметрам функция возвращает статус указания серий.
//
// Параметры:
//	Склад - СправочникСсылка.Склады - склад, для которого вычисляется статус указания серий;
//	Номенклатура - СправочникСсылка.Номенклатура - номенклатура, для которой вычисляется статус указания серий;
//	ИмяПараметраПолитикиУчетаСерий - Строка - имя параметра политики, который нужно проверить.
//
// Возвращаемое значение:
//	Число - статус указания серий.
//
Функция СтатусУказанияСерии(Склад, Номенклатура, ИмяПараметраПолитикиУчетаСерий) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.СтатусУказанияСерии(Склад, Номенклатура, ИмяПараметраПолитикиУчетаСерий) 
```
</details>

## ПараметрыПроверкиЗаполненияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает параметры проверки заполнения характеристик номенклатуры
//
//	Возвращаемое значение:
//		Структура  - структура со следующими ключами:
//			* ВыдаватьСообщения - Булево - значение по умолчанию ИСТИНА. Если ЛОЖЬ, тогда не будут выдаваться сообщения,
//											просто выставится Отказ.
//			* ПредставлениеТЧ - Строка - представление проверяемой табличной части. Если значение параметра не указано,
//											тогда представление принимает значение равное синониму реквизита объекта
//											метаданных.
//			* ИмяРеквизитаСерия - Строка - представление проверяемого реквизита серии. Если значение параметра не указано,
//											тогда представление принимает значение равное синониму реквизита объекта
//											метаданных.
//			* ПутьКДаннымТаблицыФормы - Строка - значение по умолчанию "Объект" - путь к реквизиту формы, содержащий
//													проверяемую табличную часть. Если проверяется таблица, которая сама
//													является реквизитом формы, нужно передать "" (т.е. пустую строку).
//
Функция ПараметрыПроверкиЗаполненияСерий() Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.ПараметрыПроверкиЗаполненияСерий() 
```
</details>

## ПроверитьЗаполнениеСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура проверяет правильность указания серий товаров по статусам в ТЧ "Товары"
//  Если статусы
//  	1 - количество по сериям не совпадает с количеством товаров (движения по сериям делать не нужно)
//  	3 - количество по сериям не совпадает с количеством товаров (нужно делать движения по сериям)
//  	5 - количество по сериям не совпадает с количеством товаров (нужно делать движения по сериям, серии заполняются по FEFO)
//  	7 - количество по сериям не совпадает с количеством товаров (серии указываются при планировании отбора)
//  	9 - количество по сериям не совпадает с количеством товаров (серии указываются при планировании отгрузки)
//  	13 - количество по сериям не совпадает с количеством товаров или серия не указана (учет себестоимости по сериям)
// 			то выдается ошибка.
//
// Параметры:
//  ДокументОбъект - ДокументОбъект, ФормаКлиентскогоПриложения - объект, в котором нужно проверить указание серий.
//  ПараметрыУказанияСерий - Массив - Массив из Структура параметров указания серий, возвращаемая соответствующей процедурой модуля менеджера документа.
//  Отказ - Булево - признак ошибки проверки.
//  МассивНепроверяемыхРеквизитов - Массив Из Строка, Строка - массив имен реквизитов, которые нужно исключить из платформенной проверки.
//  ВыдаватьСообщения - Булево - признак того, что нужно выдавать сообщения об ошибках проверки.
//  ПараметрыПроверки - см. ПараметрыПроверкиЗаполненияСерий
//
Процедура ПроверитьЗаполнениеСерий(ДокументОбъект, ЗНАЧ ПараметрыУказанияСерий, Отказ, МассивНепроверяемыхРеквизитов = Неопределено, ПараметрыПроверки = Неопределено) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ПроверитьЗаполнениеСерий(ДокументОбъект, ЗНАЧ ПараметрыУказанияСерий, Отказ, МассивНепроверяемыхРеквизитов, ПараметрыПроверки);
```
</details>

## ПараметрыФормыУказанияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция определяет, какую форму для указания серий нужно открыть (регистрации или подбора),
// подготавливает параметры (в т.ч. помещает нужные данные во временное хранилище) для ее открытия и возвращает их.
//
// Параметры:
//	Объект						 - ДанныеФормыСтруктура	 - основной реквизит формы документа, содержит в том числе:
//									* Ссылка - ДокументСсылка, СправочникСсылка -
//	ПараметрыУказанияСерий		 - см. НоменклатураКлиентСервер.ПараметрыУказанияСерий
//	ТекущиеДанныеИдентификатор	 - Число				 - идентификатор текущей строки товаров в форме документа;
//	Форма						 - ФормаКлиентскогоПриложения		 - форма, из которой инициировано указание серий;
//	Метаданные					 - ОбъектМетаданных 	 - метаданные объекта, для которого помещаются серии в хранилище, значение по умолчанию - Неопределено.
//															Если параметр не указан - метаданные извлекаются из ссылки (Объект.Ссылка).
//	ЗаголовокКолонкиКоличество	 - Строка				 - заголовок колонки с количеством в открываемой форме указания серий, значение по умолчанию - "".
//															Если заголовок не передан, то колонка будет называться в форме "Количество".
//
// Возвращаемое значение:
//	Структура - структура с именем и параметрами формы указания серий:
//  Основные поля.
//		* ИмяФормы - Строка - имя формы, которую нужно отрыть. Это или форма регистрации или формы подбора серий. Зависит от ПараметрыУказанияСерий
//		* АдресВоВременномХранилище - Строка - адрес во временном хранилище отобранных строк серий.
//												Если вызывается форма подбора серий, то во временном хранилище лежит структура(ТаблицаТоваров, ТаблицаСерий).
//												ТаблицаСерий - это ТЧ Серии, ТаблицаТоваров - сгруппированная по полям связи таблица товаров.
//		* РегистрироватьСерии - Булево - нужно ли согласно ПараметрыУказанияСерий давать возможность регистрировать серии (или только подбирать из имеющихся);
//		* ТолькоПросмотр - Булево - Истина - поле формы доступно только для просмотра;
//		* Количество - Число - количество товаров по срокам, для которых указываются серии. Имеет смысл, для формы регистрации серии, т.к. форма подбора открывается для всей ТЧ Товары;
//		* СерииВТЧТовары - Булево - признак, что серии указываются в той же ТЧ, что и товары;
//		* Регистратор - ДокументСсылка - имеет смысл для формы подбора серий. В этой форме отображаются остатки, при этом при отображении сторнируется
//										 изменение остатков текущим документом.
//		* ПараметрыУказанияСерий - Структура - значение параметра ПараметрыУказанияСерий данной функции для передачи в форму указания серий;
//		* ЗначенияПолейДляОпределенияРаспоряжения - Структура - имеет смысл для формы подбора серий, в которой показываются остатки. Для запроса остатков нужны
//													параметры. Возвращается функцией см. НоменклатураКлиентСервер.ЗначенияПолейДляОпределенияРаспоряжения.
//  Значения полей текущей строки или объекта, если в строке нет таких полей.
//		* Номенклатура - СправочникСсылка.Номенклатура - номенклатура;
//		* Характеристика - СправочникСсылка.ХарактеристикиНоменклатуры - характеристика номенклатуры;
//		* СтатусУказанияСерий - Число - статус указания серий;
//		* ХарактеристикиИспользуются - Булево - Истина - признак использования характеристик номенклатуры;
//		* Значения полей связи из ПараметрыУказанияСерий.ПоляСвязи;
//		* Склад - СправочникСсылка.Склады - склад;
//		* Помещение - СправочникСсылка.СкладскиеПомещения - складское помещение;
//		* УпаковкаДляПодстановки - СправочникСсылка.УпаковкиЕдиницыИзмерения, Неопределено - упаковка, в которой нужно выводить количество в форме регистрации серий.
//								Если в ТЧ "Товары" для всех строк товара одна упаковка и упаковка не входит в поля связи - передается это значение, если упаковки
//								разные - то Неопределено.
//
Функция ПараметрыФормыУказанияСерий(Объект,ПараметрыУказанияСерий,ТекущиеДанныеИдентификатор,Форма, Метаданные = Неопределено, ЗаголовокКолонкиКоличество = "") Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.ПараметрыФормыУказанияСерий(Объект, ПараметрыУказанияСерий, ТекущиеДанныеИдентификатор, Форма, Метаданные, ЗаголовокКолонкиКоличество);
```
</details>

## ОбработатьУказаниеСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Извлекает из временного хранилища серии, указанные в форме редактирования серий, помещает эти строки в ТЧ "Серии" документа,
//	перерасчитывает статусы указания серий строках товаров.
//
// Параметры:
//  Объект						 - ДанныеФормыСтруктура - основной реквизит формы документа,
//  ПараметрыУказанияСерий		 - Структура - параметры указания серий, возвращаемые соответствующей процедурой модуля менеджера документа,
//  ПараметрыФормыУказанияСерий	 - см. ПараметрыФормыУказанияСерий.
//  Действия					 - Структура - описание действий, которые необходимо выполнить со строками после указания серий, см. ОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧ
//  КешированныеЗначения		 - Структура - Сохраненные значения параметров, используемых при обработке строк.
//
Процедура ОбработатьУказаниеСерий(Объект, ПараметрыУказанияСерий,ПараметрыФормыУказанияСерий, Действия = Неопределено, КешированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ОбработатьУказаниеСерий(Объект, ПараметрыУказанияСерий, ПараметрыФормыУказанияСерий, Действия, КешированныеЗначения);
```
</details>

## ПараметрыУказанияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры указания серий для товаров, указанных в документе.
//
// Параметры:
//  Объект			 - ДокументОбъект, ДанныеФормыСтруктура - документ, для которого нужно сформировать параметры проверки,
//  МенеджерОбъекта	 - ДокументМенеджер - менеджер документа, для которого нужно сформировать параметры проверки.
//
// Возвращаемое значение:
//  Структура - параметры, уточняющие особенности указания серий в каждом документе, состав полей задается в функции НоменклатураКлиентСервер.ПараметрыУказанияСерий.
//
Функция ПараметрыУказанияСерий(Объект, МенеджерОбъекта) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.ПараметрыУказанияСерий(Объект, МенеджерОбъекта) 
```
</details>

## СохранитьНастройкуРежимСканированияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет режим сканирования серий. Используется для того, чтобы режим сканирования был един для всех форм.
//
// Параметры:
//		Форма - ФормаКлиентскогоПриложения - форма, в которой должен быть реквизит строкового типа РежимСканированияСерий.
//
Процедура СохранитьНастройкуРежимСканированияСерий(Форма) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.СохранитьНастройкуРежимСканированияСерий(Форма) 
```
</details>

## ЗагрузитьНастройкуРежимСканированияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает из настроек режим сканирования серий. Если настройка не была ранее сохранена, то используется режим ТоварВсеСерии.
//
// Параметры:
//		Форма - ФормаКлиентскогоПриложения - форма, в которой должен быть реквизит строкового типа РежимСканированияСерий.
//
Процедура ЗагрузитьНастройкуРежимСканированияСерий(Форма) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ЗагрузитьНастройкуРежимСканированияСерий(Форма) 
```
</details>

## ПроверитьВозможностьОткрытияФормыУказанияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет возможность открытия формы указания серий
//
// Параметры:
//  НастройкиИспользованияСерий	 - Структура, ФиксированнаяСтруктура - см. Справочники.ВидыНоменклатуры.НастройкиИспользованияСерий
//  ПараметрыУказанияСерий		 - Структура, ФиксированнаяСтруктура - см. НоменклатураКлиентСервер.ПараметрыУказанияСерий
//  ЗначенияПолейСвязи			 - Структура, ФиксированнаяСтруктура -
//
Процедура ПроверитьВозможностьОткрытияФормыУказанияСерий(НастройкиИспользованияСерий, ПараметрыУказанияСерий, ЗначенияПолейСвязи) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ПроверитьВозможностьОткрытияФормыУказанияСерий(НастройкиИспользованияСерий, ПараметрыУказанияСерий, ЗначенияПолейСвязи) 
```
</details>

## ПредставлениеТовараВФормеУказанияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует представление товара, по которому вводятся серии, для отображения в шапки формы указания серий
//
// Параметры:
//  ЗначенияПолейСвязи	 - Структура, ФиксированнаяСтруктура -
//
// Возвращаемое значение:
//   Строка
//
Функция ПредставлениеТовараВФормеУказанияСерий(ЗначенияПолейСвязи) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.ПредставлениеТовараВФормеУказанияСерий(ЗначенияПолейСвязи) 
```
</details>

## РеквизитыСерииИзСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Разбирает отсканированную строку штрих-кода серии и возвращает в виде значений реквизитов
//
// Параметры:
//  ВведеннаяСтрока				 - Строка
//  НастройкиИспользованияСерий	 - Структура, ФиксированнаяСтруктура - см. Справочники.ВидыНоменклатуры.НастройкиИспользованияСерий
//
// Возвращаемое значение:
//  Структура - состав полей зависит от введенной строки и НастройкиИспользованияСерий
//
Функция РеквизитыСерииИзСтроки(Знач ВведеннаяСтрока, НастройкиИспользованияСерий) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.РеквизитыСерииИзСтроки(ВведеннаяСтрока, НастройкиИспользованияСерий) 
```
</details>

## ДобавитьПоляСтатусовУказанияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет реквизиты статусов указания серий в табличную часть товаров формы клиентского приложения.
// Рекомендуется использовать в обработчике события формы ПриСозданииНаСервере.
//
// Параметры:
// Форма - ФормаКлиентскогоПриложения - форма, в табличную часть которой добавляются реквизиты.
// ПараметрыУказанияСерий - см. НоменклатураКлиентСервер.ПараметрыУказанияСерий.
//
Процедура ДобавитьПоляСтатусовУказанияСерий(Форма, ПараметрыУказанияСерий) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ДобавитьПоляСтатусовУказанияСерий(Форма, ПараметрыУказанияСерий) 
```
</details>

## ЗаполнитьСлужебныеРеквизитыПоНоменклатуреВСтруктуре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает служебные реквизиты по номенклатуре в структуре
//
// Параметры:
// 		СтруктураДанных - Структура, СтрокаТаблицыЗначений - Структура данных, в которой необходимо заполнить поля
// 		СтруктураДействий - Структура - Структура с действиями по получению служебных реквизитов.
//
Процедура ЗаполнитьСлужебныеРеквизитыПоНоменклатуреВСтруктуре(СтруктураДанных, СтруктураДействий) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ЗаполнитьСлужебныеРеквизитыПоНоменклатуреВСтруктуре(СтруктураДанных, СтруктураДействий) 
```
</details>

## ЗаполнитьСлужебныеРеквизитыПоНоменклатуреВКоллекции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет служебные реквизиты по номенклатуре в коллекции
//
// Параметры:
//  КоллекцияДанных		 - ДанныеФормыКоллекция, ТаблицаЗначений - Таблица, в которой необходимо заполнить реквизиты
//  СтруктураДействий	 - Структура							 - Структура с действиями по получению служебных реквизитов
//  СтрокиЗаполнения	 - Массив, ДанныеФормыЭлементКоллекции	 - строки, для которых требуется заполнение.
//
Процедура ЗаполнитьСлужебныеРеквизитыПоНоменклатуреВКоллекции(КоллекцияДанных, СтруктураДействий, СтрокиЗаполнения = Неопределено) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ЗаполнитьСлужебныеРеквизитыПоНоменклатуреВКоллекции(КоллекцияДанных, СтруктураДействий, СтрокиЗаполнения);
```
</details>

## ДополнитьТекстЗапросаРеквизитыПоНоменклатуре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения реквизитов по полю Номенклатура
// при обработке строк табличной части.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаРеквизитыПоНоменклатуре(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ДополнитьТекстЗапросаРеквизитыПоНоменклатуре(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаШтрихкодыНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения штрихкода номенклатуры
// при обработке строк табличной части.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаШтрихкодыНоменклатуры(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ДополнитьТекстЗапросаШтрихкодыНоменклатуры(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ЗаполнитьСлужебныеРеквизитыПоНоменклатуреВСтруктуреПакетно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет служебные реквизиты по номенклатуре при пакетной обработке строк табличной части.
//
// Параметры:
//  СтруктураДанных - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.ТекущаяСтрока
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ЗаполнитьСлужебныеРеквизитыПоНоменклатуреВСтруктуреПакетно(СтруктураДанных, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ЗаполнитьСлужебныеРеквизитыПоНоменклатуреВСтруктуреПакетно(СтруктураДанных, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ДействияЗаполненияРеквизитовПоНоменклатуре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает только те действия со строкой табличной части, которые относятся к заполнению реквизитов
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//
// Возвращаемое значение:
//  Структура - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//
Функция ДействияЗаполненияРеквизитовПоНоменклатуре(СтруктураДействий) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.ДействияЗаполненияРеквизитовПоНоменклатуре(СтруктураДействий) 
```
</details>

## ЗаполнитьПризнакИспользованияХарактеристик
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполнения колонок "ХарактеристикиИспользуются" в формах.
//
// Параметры:
//  ТаблицаФормы		 - ДанныеФормыКоллекция		 - табличная часть объекта, в котором нужно заполнить
//  		колонку "ХарактеристикиИспользуются";
//  ПараметрыЗаполнения	 - Структура, Неопределено	 - дополнительные параметры.
//
Процедура ЗаполнитьПризнакИспользованияХарактеристик(ТаблицаФормы,ПараметрыЗаполнения = Неопределено) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ЗаполнитьПризнакИспользованияХарактеристик(ТаблицаФормы, ПараметрыЗаполнения);
```
</details>

## УстановитьУсловноеОформлениеНазначенияНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление для назначений номенклатуры
//
// Параметры:
//		Форма - ФормаКлиентскогоПриложения - Содержит данную форму
//		ИмяПоляВводаНазначения - Строка - Наименование элемента формы, содержащего характеристики номенклатуры,
//											   если оно отличается от "ТоварыХарактеристика".
//		ПутьКПолюОтбораТипНоменклатуры - Строка - Полный путь к реквизиту "Тип номенклатуры",
//									если он отличается от "Объект.Товары.ТипНоменклатуры".
//		ТолькоТовары - Булево - Истина - признак того, что условное оформление применяется только в отношении товаров.
//
Процедура УстановитьУсловноеОформлениеНазначенияНоменклатуры(Форма, Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.УстановитьУсловноеОформлениеНазначенияНоменклатуры(Форма, );
```
</details>

## УстановитьУсловноеОформлениеХарактеристикНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление для характеристик номенклатуры
//
// Параметры:
// 		Форма - ФормаКлиентскогоПриложения - Содержит данную форму
// 		ИмяПоляВводаХарактеристики - Строка - Наименование элемента формы, содержащего характеристики номенклатуры,
//											   если оно отличается от "ТоварыХарактеристика".
// 		ПутьКПолюОтбора - Строка - Полный путь к реквизиту "характеристики используются",
//									если он отличается от "Объект.Товары.ХарактеристикиИспользуются".
//
Процедура УстановитьУсловноеОформлениеХарактеристикНоменклатуры(Форма, Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.УстановитьУсловноеОформлениеХарактеристикНоменклатуры(Форма, );
```
</details>

## УстановитьУсловноеОформлениеСерийНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление для серий номенклатуры
//
// Параметры:
//		Форма - ФормаКлиентскогоПриложения - Содержит данную форму
//		ОсобыйВариантУказанияСерий - Булево, Строка - Ложь, если серии указываются в отдельной ТЧ,
//			"СерииВсегдаВТЧТовары" - если у объекта нет специальной ТЧ для указания серий,
//			"СерииПриПланированииОтгрузкиУказываютсяВТЧТовары" - если серии могут указываться в разных ТЧ,
//				при этом серии с политикой учета "При планировании отгрузки" указываются в ТЧ Товары.
//		ИмяПоляВводаСерии - Строка - Наименование элемента формы, содержащего серии номенклатуры,
//									   если оно отличается от "ТоварыСерия".
//		ПутьКПолюОтбораСтатусУказанияСерий - Строка - Полный путь к реквизиту "Статус указания серий",
//														если он отличается от "Объект.Товары.СтатусУказанияСерий".
//		ПутьКПолюОтбораТипНоменклатуры - Строка - Полный путь к реквизиту "Тип номенклатуры",
//														если он отличается от "Объект.Товары.ТипНоменклатуры".
//
Процедура УстановитьУсловноеОформлениеСерийНоменклатуры(Форма, Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.УстановитьУсловноеОформлениеСерийНоменклатуры(Форма, );
```
</details>

## УстановитьУсловноеОформлениеЕдиницИзмерения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление для единиц измерения номенклатуры
//
// Параметры:
// 		Форма - ФормаКлиентскогоПриложения - Содержит данную форму
// 		ИмяПоляВводаЕдиницИзмерения - Строка - Наименование элемента формы, содержащего ед. измерения номенклатуры,
//									   			если оно отличается от "ТоварыНоменклатураЕдиницаИзмерения".
// 		ПутьКПолюОтбора - Строка - Полный путь к реквизиту "Упаковка",
//									если он отличается от "Объект.Товары.Упаковка".
//		ПутьКПолюПризнакаИспользованияАдресногоХранения - Строка - Полный путь к реквизиту "ИспользоватьАдресноеХранение".
//
Процедура УстановитьУсловноеОформлениеЕдиницИзмерения(Форма, Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.УстановитьУсловноеОформлениеЕдиницИзмерения(Форма, );
```
</details>

## ДополнительныеПараметрыУстановитьУсловноеОформлениеСодержания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополнительные параметры функции НоменклатураСервер.УстановитьУсловноеОформлениеСодержания.
//
// Возвращаемое значение:
//   Структура - свойства:
// 		* ИмяПоляВводаСодержания - Строка - Наименование элемента формы "Содержание",
//									   		значение по умолчанию "ТоварыСодержание".
// 		* ИмяПоляВводаУпаковки - Строка - Наименование элемента формы "Упаковка",
//									   		значение по умолчанию "ТоварыУпаковка".
// 		* ПутьКПолюОтбораВариантаОформления - Строка - Полный путь к реквизиту "ВариантОформленияПродажи",
//														значение по умолчанию "Объект.Товары.ВариантОформленияПродажи".
// 		* ПутьКПолюОтбораСодержания - Строка - Полный путь к реквизиту "Содержание",
//												значение по умолчанию "Объект.Товары.Содержание".
//
Функция ДополнительныеПараметрыУстановитьУсловноеОформлениеСодержания() Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.ДополнительныеПараметрыУстановитьУсловноеОформлениеСодержания() 
```
</details>

## УстановитьУсловноеОформлениеСодержания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление содержания в зависимости от варианта оформления продажи.
//
// Параметры:
//	Форма - ФормаКлиентскогоПриложения - форма, для элементов которой осуществляется настройка условного оформления;
//	ДополнительныеПараметры - Структура - описание см. НоменклатураСервер.ДополнительныеПараметрыУстановитьУсловноеОформлениеСодержания.
//
Процедура УстановитьУсловноеОформлениеСодержания(Форма, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.УстановитьУсловноеОформлениеСодержания(Форма, ДополнительныеПараметры);
```
</details>

## УстановитьУсловноеОформлениеНомераГТД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление номеров ГТД
//
// Параметры:
// 		Форма - ФормаКлиентскогоПриложения - Содержит данную форму
// 		ИмяПоляВводаНомераГТД - Строка - Наименование элемента формы, содержащего номер ГТД,
//									   		если оно отличается от "ТоварыНомерГТД".
// 		ПутьКПолюОтбора - Строка - Полный путь к реквизиту "ВедетсяУчетПоГТД",
//										если он отличается от "Объект.Товары.ВедетсяУчетПоГТД".
// 		ПутьКПолюПризнакаОтбораПоРНПТ - Строка - путь к реквизиту, который содержит признак,
//										что в документе указывается только РНПТ.
//
Процедура УстановитьУсловноеОформлениеНомераГТД(Форма, Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.УстановитьУсловноеОформлениеНомераГТД(Форма, );
```
</details>

## УстановитьУсловноеОформлениеСтатусовУказанияСерий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление для статусов указания серий
//
// Параметры:
//		Форма - ФормаКлиентскогоПриложения - Содержит данную форму
//		СерииВсегдаВТЧТовары - Булево - Истина, если у объекта нет специальной ТЧ для указания серий
//		ИмяПоляВводаСтатусаУказанияСерий - Строка - Наименование элемента формы, содержащего статус указания
//									   				серии номенклатуры,если оно отличается от "ТоварыСтатусУказанияСерий"
//		ПутьКПолюОтбора - Строка - Полный путь к реквизиту "СтатусУказанияСерий",
//									если он отличается от "Объект.Товары.СтатусУказанияСерий".
//
Процедура УстановитьУсловноеОформлениеСтатусовУказанияСерий(Форма, Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.УстановитьУсловноеОформлениеСтатусовУказанияСерий(Форма, );
```
</details>

## РазбитьТоварыПоТоварнымМестам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РазбитьТоварыПоТоварнымМестам(ТабличнаяЧастьТовары) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.РазбитьТоварыПоТоварнымМестам(ТабличнаяЧастьТовары) 
```
</details>

## ПроверитьКомплектностьТоварныхМест
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПроверитьКомплектностьТоварныхМест(ТабличнаяЧастьТоваров, Отказ, ПараметрыПроверки = Неопределено) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ПроверитьКомплектностьТоварныхМест(ТабличнаяЧастьТоваров, Отказ, ПараметрыПроверки);
```
</details>

## ПройтиРекурсивноПоПолямГруппировки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры:
// 	Выборка - ВыборкаИзРезультатаЗапроса
//
Процедура ПройтиРекурсивноПоПолямГруппировки(Выборка, ТоварныеМестаПоНоменклатуре, НомерТекущегоПоля, МаксимальныйНомерПоля, ЕстьОшибки) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ПройтиРекурсивноПоПолямГруппировки(Выборка, ТоварныеМестаПоНоменклатуре, НомерТекущегоПоля, МаксимальныйНомерПоля, ЕстьОшибки));
```
</details>

## ПродолжитьОбходПоСериям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПродолжитьОбходПоСериям(Выборка, ТоварныеМестаПоНоменклатуре, ЕстьОшибки) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ПродолжитьОбходПоСериям(Выборка, ТоварныеМестаПоНоменклатуре, ЕстьОшибки));
```
</details>

## ЗаполнитьДействиеПоКомплектностиТоварныхМест
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет комплектность товарных мест в ордерах на отгрузку
//
// Параметры:
//  Объект - ДокументОбъект.РасходныйОрдерНаТовары, ДокументОбъект.ОрдерНаПеремещениеТоваров - обрабатываемый документ.
//
Процедура ЗаполнитьДействиеПоКомплектностиТоварныхМест(Объект) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ЗаполнитьДействиеПоКомплектностиТоварныхМест(Объект) 
```
</details>

## ПараметрыПроверкиЗаполненияКоличества
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры проверки заполнения количества.
//
// Возвращаемое значение:
//	Структура - параметры проверки:
//		*ИмяТЧ - Строка - имя табличной части. Значение по умолчанию - "Товары".
//		*ИменаПолейССуффиксом - Структура - коллекция содержащая имена полей Количество и КоличествоУпаковок с суффиксом.
//											Ключом коллекции выступает имя реквизита без суффикса, например, "Количество",
//											а значением задается имя реквизита с суффиксом, например, "КоличествоФакт".
//											Если табличная часть не содержит поля с суффиксом, тогда не требуется
//											инициализировать коллекцию.
//		*ПроверитьВозможностьОкругления - Булево - признак того, что необходимо проверить возможность округления.
//		*УсловиеОтбораСтрокДляОкругления - Строка - условие выбора строк для проверки округления. В качестве имени
//													таблицы нужно использовать имя переданное в параметр ИмяТЧ.
//		*ПроверитьКомплектностьТоварныхМест - Булево - признак необходимости проверки комплектности товарных мест.
//		*УсловиеОтбораСтрокПроверкиКомплектности - Строка - условия для запроса. Например, "Не ТаблицаТовары.ЭтоУпаковочныйЛист".
//		*ПоляГруппировкиПроверкиКомплектности - Строка - поля, по которым группируются товары для формирования целых
//															товаров из товарных мест. Поля "Номенклатура",
//															"Характеристика" и "Серия" будут добавлены по умолчанию.
//															Поле "<Приставка>Назначение" нужно добавлять, если имя
//															колонки отлично от строки "Назначение". Например,
//															"НовоеНазначение".
//		*УсловиеОтбораСтрокПоДополнительнымПолям - Строка - сложное условие отбора строк, например,
//															<таблица>.<поле>.<поле>
//															или <таблица>.<поле> В (ВЫБРТАЬ ....), где
//															в качестве имени таблицы нужно использовать имя
//															переданное в параметр ИмяТЧ.
//		*ДополнительныеПоля - Структура - поля, участвующие в сложном условии отбора строк (в качестве имени таблицы нужно использовать имя переданное в параметр ИмяТЧ):
//			** Ключ - Строка - имя поля.
//			** Значение - Строка - представление поля в запросе.
//		*ПараметрыЗапроса - Структура - параметры запроса.
//										Ключом коллекции выступает имя параметра запроса,
//										а значением задается устанавливаемое значение параметра запроса.
//		*ПроверяемаяТаблица - ТаблицаЗначений, Неопределено - если передана таблица значений, то проверяется она,
//																иначе - Объект или ТЧ с именем переданным в параметр ИмяТЧ.
//
Функция ПараметрыПроверкиЗаполненияКоличества() Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.ПараметрыПроверкиЗаполненияКоличества() 
```
</details>

## ПроверитьЗаполнениеКоличества
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет заполнение реквизитов Количество и КоличествоУпаковок в документах.
//
// Параметры:
//	Объект - ДокументОбъект - проверяемый документ.
//	ПроверяемыеРеквизиты - Массив Из Строка - проверяемые реквизиты.
//	Отказ - Булево - признака отказа продолжения операции с документом.
//	ПараметрыПроверки - См. ПараметрыПроверкиЗаполненияКоличества.
//
Процедура ПроверитьЗаполнениеКоличества(Объект, ПроверяемыеРеквизиты, Отказ, ПараметрыПроверки = Неопределено) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ПроверитьЗаполнениеКоличества(Объект, ПроверяемыеРеквизиты, Отказ, ПараметрыПроверки);
```
</details>

## ПроверитьОкруглениеКоличества
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет корректность округления реквизита Количество в документах.
//
// Параметры:
//	Объект				- ДокументОбъект 			- проверяемый ДокументОбъект
//	Отказ				- Булево 					- отказ продолжения операции.
//	ПараметрыПроверки	- Структура, Неопределено	- см. ПараметрыПроверкиЗаполненияКоличества
//
Процедура ПроверитьОкруглениеКоличества(Объект, Отказ, ПараметрыПроверки = Неопределено) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ПроверитьОкруглениеКоличества(Объект, Отказ, ПараметрыПроверки);
```
</details>

## НомераСтрокСНекорректнымОкруглениемКоличества
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет корректность округления реквизита Количество в документах.
//
// Параметры:
//  Объект - ДокументОбъект - проверяемый ДокументОбъект
//  ПараметрыПроверки - Структура, Неопределено - см. ПараметрыПроверкиЗаполненияКоличества
//
// Возвращаемое значение:
//  ТаблицаЗначений - таблица с колонкой:
//   * НомерСтроки - Число - номер строки табличной части в которой количество округлено некорректно.
Функция НомераСтрокСНекорректнымОкруглениемКоличества(Объект, ПараметрыПроверки = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.НомераСтрокСНекорректнымОкруглениемКоличества(Объект, ПараметрыПроверки);
```
</details>

## ПараметрыОкругленияКоличестваШтучныхТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры для округления.
//
//	Возвращаемое значение:
//		Структура - параметры для округления:
//			*ИмяТЧ - Строка - имя табличной части. Значение по умолчанию - "Товары".
//			*ИмяПоляКоличествоСуффикс - Строка - имя поля Количетсво с суффиксом. Если в табличной части содержится два
//													реквизита "Количество", тогда второй имеет в наименовании суффикс.
//													Если параметр заполнен, тогда проверяются оба реквизита.
//													Значение по умолчанию - "".
//			*УсловиеОтбораСтрокДляОкругления - Строка - условие выбора строк для проверки округления.
//														В качестве имени таблицы нужно использовать имя переданное в
//														параметр ИмяТЧ.
//			*УсловиеОтбораСтрокПоДополнительнымПолям - Строка - сложное условие отбора строк, например,
//																<таблица>.<поле>.<поле>
//																или <таблица>.<поле> В (ВЫБРТАЬ ....), где
//																в качестве имени таблицы нужно использовать имя
//																переданное в параметр ИмяТЧ.
//			*ДополнительныеПоля - Структура - поля, участвующие в сложном условии отбора строк (в качестве имени таблицы нужно использовать имя переданное в параметр ИмяТЧ):
//				** Ключ - Строка - имя поля.
//				** Значение - Строка - представление поля в запросе.
//			*ПараметрыЗапроса - Структура - параметры запроса.
//											Ключом коллекции выступает имя параметра запроса,
//											а значением задается устанавливаемое значение параметра запроса.
//
Функция ПараметрыОкругленияКоличестваШтучныхТоваров() Экспорт
```

Пример вызова
```bsl
Результат = НоменклатураСервер.ПараметрыОкругленияКоличестваШтучныхТоваров() 
```
</details>

## ОкруглитьКоличествоШтучныхТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Округляет количество товара до целых штук при указании количества в документе в мерных единицах измерения.
//
// Параметры:
//	Объект - ДокументОбъект - объект документа.
//	РежимЗаписи - РежимЗаписиДокумента - режим записи документа.
//	ПараметрыОкругления - см. ПараметрыОкругленияКоличестваШтучныхТоваров.
//
Процедура ОкруглитьКоличествоШтучныхТоваров(Объект, РежимЗаписи = Неопределено, ПараметрыОкругления = Неопределено) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ОкруглитьКоличествоШтучныхТоваров(Объект, РежимЗаписи, ПараметрыОкругления);
```
</details>

## ДополнитьТекстЗапросаСтранаПроисхожденияНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения страны происхождения номенклатуры
// при обработке строк табличной части.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаСтранаПроисхожденияНоменклатуры(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ДополнитьТекстЗапросаСтранаПроисхожденияНоменклатуры(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаСодержаниеУслуги
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения содержания услуги по номенклатуре
// и характеристике.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаСодержаниеУслуги(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ДополнитьТекстЗапросаСодержаниеУслуги(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаКодТНВЭДПоНоменклатуре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения кода ТНВЭД по номенклатуре.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаКодТНВЭДПоНоменклатуре(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ДополнитьТекстЗапросаКодТНВЭДПоНоменклатуре(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаПроверитьКорректностьЗаполнитьХарактеристикиИУпаковки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запросы в пакет запросов для получения данных, необходимых для проверки корректности и заполнения характеристики.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - Структура
//
Процедура ДополнитьТекстЗапросаПроверитьКорректностьЗаполнитьХарактеристикиИУпаковки(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ДополнитьТекстЗапросаПроверитьКорректностьЗаполнитьХарактеристикиИУпаковки(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаЗаполнитьУчетноеКоличествоНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения учетного количества номенклатуры.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - Структура
//
Процедура ДополнитьТекстЗапросаЗаполнитьУчетноеКоличествоНоменклатуры(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ДополнитьТекстЗапросаЗаполнитьУчетноеКоличествоНоменклатуры(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаПересчитатьКоличествоУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для пересчета количества упаковок номенклатуры.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - Структура
//
Процедура ДополнитьТекстЗапросаПересчитатьКоличествоУпаковок(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ДополнитьТекстЗапросаПересчитатьКоличествоУпаковок(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаПересчитатьКоличествоУпаковокСуффикс
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для пересчета количества упаковок номенклатуры с суффиксом.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - Структура
//
Процедура ДополнитьТекстЗапросаПересчитатьКоличествоУпаковокСуффикс(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ДополнитьТекстЗапросаПересчитатьКоличествоУпаковокСуффикс(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаПересчитатьКоличествоУпаковокПоВесу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для пересчета количества упаковок номенклатуры по весу.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - Структура
//
Процедура ДополнитьТекстЗапросаПересчитатьКоличествоУпаковокПоВесу(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ДополнитьТекстЗапросаПересчитатьКоличествоУпаковокПоВесу(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаПересчитатьКоличествоУпаковокПоОбъему
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для пересчета количества упаковок номенклатуры по объему.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - Структура
//
Процедура ДополнитьТекстЗапросаПересчитатьКоличествоУпаковокПоОбъему(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
НоменклатураСервер.ДополнитьТекстЗапросаПересчитатьКоличествоУпаковокПоОбъему(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
