---
title: Обеспечение производства
slug: erp-uh/обеспечение-производства
---


## ПараметрыОбеспеченияНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры обеспечения номенклатуры
//
// Параметры:
//  Номенклатура	 - СправочникСсылка.Номенклатура - Номенклатура для которой нужно получить параметры обеспечения.
//  Характеристика	 - СправочникСсылка.ХарактеристикиНоменклатуры - Характеристика номенклатуры.
//  Подразделение	 - СправочникСсылка.СтруктураПредприятия - Подразделение для которого нужно получить параметры обеспечения.
//
// Возвращаемое значение:
//  Структура - Содержит свойства: Склад.
//
Функция ПараметрыОбеспеченияНоменклатуры(Номенклатура, Характеристика, Подразделение) Экспорт
```

Пример вызова
```bsl
Результат = ОбеспечениеПроизводства.ПараметрыОбеспеченияНоменклатуры(Номенклатура, Характеристика, Подразделение) 
```
</details>

## ПараметрыОбеспеченияСпискаНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры обеспечения списка номенклатуры
//
// Параметры:
//  ТаблицаМатериалов	 - ТаблицаЗначений - содержит колонки Номенклатура, Характеристика, Подразделение
//
// Возвращаемое значение:
//  ТаблицаЗначений - содержит колонки Склад.
//
Функция ПараметрыОбеспеченияСпискаНоменклатуры(ТаблицаМатериалов) Экспорт
```

Пример вызова
```bsl
Результат = ОбеспечениеПроизводства.ПараметрыОбеспеченияСпискаНоменклатуры(ТаблицаМатериалов) 
```
</details>

## ПараметрыОбеспеченияМатериалаЭтапа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТКА

// Возвращает параметры обеспечения материала в этапе производства
//
// Параметры:
//  Номенклатура					 - СправочникСсылка.Номенклатура												 - Номенклатура для которой нужно получить параметры обеспечения.
//  Характеристика					 - СправочникСсылка.ХарактеристикиНоменклатуры									 - Характеристика номенклатуры.
//  Производится					 - Булево																		 - Признак того что материал производится (является полуфабрикатом).
//  Подразделение					 - СправочникСсылка.СтруктураПредприятия										 - Подразделение для которого нужно получить параметры обеспечения.
//  ИсточникПолученияПолуфабриката	 - СправочникСсылка.ЭтапыПроизводства, СправочникСсылка.РесурсныеСпецификации	 - Определяет как производится полуфабрикат.
//  ЗаказНаПроизводство				 - ДокументСсылка.ЗаказНаПроизводство2_2										 - Заказ на производство, для получения списка заказов давальца и поиска в них номенклатуры.
//  										Если номенклатура найдена, возвращается вариант обеспечения "Обеспечивать обособленно".
//
// Возвращаемое значение:
//  Структура - Содержит свойства: Склад, ВариантОбеспечения.
//
Функция ПараметрыОбеспеченияМатериалаЭтапа(Номенклатура, Характеристика, Производится, Подразделение, ИсточникПолученияПолуфабриката, ЗаказНаПроизводство) Экспорт
```

Пример вызова
```bsl
Результат = ОбеспечениеПроизводства.ПараметрыОбеспеченияМатериалаЭтапа(Номенклатура, Характеристика, Производится, Подразделение, ИсточникПолученияПолуфабриката, ЗаказНаПроизводство) 
```
</details>

## ПараметрыОбеспеченияМатериаловЭтапа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры обеспечения материалов в этапах производства
//
// Параметры:
//   ТаблицаМатериалов 	- ТаблицаЗначений - таблица материалов этапа.
//							Обязательные поля: Номенклатура, Характеристика,
//									Подразделение, Производится, ИсточникПолученияПолуфабриката
//   ЗаказНаПроизводство - ДокументСсылка.ЗаказНаПроизводство2_2 - Заказ на производство, для получения списка заказов
//                         давальца и поиска в них номенклатуры. Если номенклатура найдена, возвращается вариант
//                         обеспечения "Обеспечивать обособленно".
//
// Возвращаемое значение:
//   ТаблицаЗначений - таблица материалов дополненная колонками: Склад, ВариантОбеспечения.
//
Функция ПараметрыОбеспеченияМатериаловЭтапа(ТаблицаМатериалов, ЗаказНаПроизводство) Экспорт
```

Пример вызова
```bsl
Результат = ОбеспечениеПроизводства.ПараметрыОбеспеченияМатериаловЭтапа(ТаблицаМатериалов, ЗаказНаПроизводство) 
```
</details>

## ДополнитьТекстЗапросаЗаполнитьОбеспечениеВЭтапеПроизводстваПакетно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос для получения данных, необходимых для заполнения обеспечения в этапе.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаЗаполнитьОбеспечениеВЭтапеПроизводстваПакетно(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ОбеспечениеПроизводства.ДополнитьТекстЗапросаЗаполнитьОбеспечениеВЭтапеПроизводстваПакетно(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаЗаполнитьСкладПроизводства
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос для получения данных, необходимых для заполнения склада в производственных документах.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаЗаполнитьСкладПроизводства(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ОбеспечениеПроизводства.ДополнитьТекстЗапросаЗаполнитьСкладПроизводства(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## СтруктураСпособыПолученияМатериаловПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает структуру способа получения материалов по умолчанию
//
// Возвращаемое значение:
//  Структура - способы получения материалов по умолчанию.
//
Функция СтруктураСпособыПолученияМатериаловПоУмолчанию() Экспорт
```

Пример вызова
```bsl
Результат = ОбеспечениеПроизводства.СтруктураСпособыПолученияМатериаловПоУмолчанию() 
```
</details>

## СоздатьИсточникВыбораСпособовПолученияМатериалов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает пустую таблицу, для выборки способов получения материалов в производство.
//
// Возвращаемое значение:
//  ТаблицаЗначений - таблица материалов.
//
Функция СоздатьИсточникВыбораСпособовПолученияМатериалов() Экспорт
```

Пример вызова
```bsl
Результат = ОбеспечениеПроизводства.СоздатьИсточникВыбораСпособовПолученияМатериалов() 
```
</details>

## СпособПолученияМатериалаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает способ получения материала для этапа производства по умолчанию.
//
// Параметры:
//  ДанныеЗаказа	 - Структура - структура данных заказа:
//  	* Распоряжение           - ДокументСсылка.ЗаказНаПроизводство2_2 - заказ на производство
//  	* ПодразделениеДиспетчер - СправочникСсылка.СтруктураПредприятия - Подразделение, ответственное за выполнение заказа
//  	* Назначение             - СправочникСсылка.Назначения - назначение обособленной потребности
//  	* НачатьНеРанее          - Дата - дата, не ранее которой необходимо начать производить.
//  ДанныеМатериала	 - Структура - структура данных материала:
//  	* Подразделение          - СправочникСсылка.СтруктураПредприятия - подразделение-получатель
//  	* ПроизводствоНаСтороне  - Булево - признак, что производство выполняется на стороне
//  	* Номенклатура           - СправочникСсылка.Номенклатура - материала, для которого определяется настройка
//  	* Характеристика         - СправочникСсылка.ХарактеристикиНоменклатуры - характеристика материала, для которого определяется настройка
//   МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - содержит временные таблицы используемые для получения способа обеспечения:
//        ВтСпособыПолученияМатериалов - Временная таблица с полями Номенклатура, Характеристика, Назначение, Склад, Обособленно.
//  ВариантЗаполненияОбеспечения	 - ПеречислениеСсылка.ВариантыЗаполненияОбеспеченияПроизводства - Вариант заполнения обеспечения
//
// Возвращаемое значение:
//  Структура - Содержит свойства:
//  	* Склад - СправочникСсылка.Склады - Склад, с которого передаются материалы в подразделение.
//  	* ЗаказатьНаСклад - Булево - признак, материал необходимо заказать на склад
//  	* ВариантОбеспечения - ПеречислениеСсылка.ВариантыОбеспечения - вариант обеспечения
//  	* Запланировать - Булево - признак, материал возможно.
//
Функция СпособПолученияМатериалаПоУмолчанию(ДанныеЗаказа, ДанныеМатериала, МенеджерВременныхТаблиц = Неопределено, ВариантЗаполненияОбеспечения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбеспечениеПроизводства.СпособПолученияМатериалаПоУмолчанию(ДанныеЗаказа, ДанныеМатериала, МенеджерВременныхТаблиц, ВариантЗаполненияОбеспечения);
```
</details>

## СпособыПолученияМатериаловПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает способы получения материалов для этапов производства по умолчанию.
//
// Параметры:
//   ДанныеЗаказа - Структура - структура данных заказа:
//       * Распоряжение           - ДокументСсылка.ЗаказНаПроизводство, ДокументСсылка.ЗаказНаПроизводство2_2 - заказ на
//           производство
//       * ПодразделениеДиспетчер - СправочникСсылка.СтруктураПредприятия - Подразделение, ответственное за выполнение заказа
//       * Назначение             - СправочникСсылка.Назначения - назначение обособленной потребности
//       * НачатьНеРанее          - Дата - дата, не ранее которой необходимо начать производить.
//   ТаблицаМатериалов - ТаблицаЗначений - таблица материалов этапа
//							Обязательные поля: Номенклатура, Характеристика, Подразделение, ПроизводствоНаСтороне,
//							Дополнительные поля: ПроизводитсяВПроцессе, СпособПолученияМатериала, ИсточникПолученияПолуфабриката.
//
//   МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - содержит временные таблицы используемые для получения способа обеспечения:
//        ВтСпособыПолученияМатериалов - Временная таблица с полями Номенклатура, Характеристика, Назначение, Склад, Обособленно.
//  ВариантЗаполненияОбеспечения	 - ПеречислениеСсылка.ВариантыЗаполненияОбеспеченияПроизводства - Вариант заполнения обеспечения
//
// Возвращаемое значение:
//   - ТаблицаЗначений - таблица материалов, дополненная способами получения материалов:
//       * НомерСтроки - Число - номер строки исходной таблицы
//       * Номенклатура - СправочникСсылка.Номенклатура - материала, для которого определяется настройка
//       * Характеристика - СправочникСсылка.ХарактеристикиНоменклатуры - характеристика материала, для которого
//                                                                        определяется настройка
//       * Подразделение - СправочникСсылка.СтруктураПредприятия - подразделение-получатель
//       * ПроизводствоНаСтороне - Булево - признак, что производство выполняется на стороне
//       * Склад - СправочникСсылка.Склады - Склад, с которого передаются материалы в подразделение.
//       * ЗаказатьНаСклад - Булево - признак, материал необходимо заказать на склад
//       * ВариантОбеспечения - ПеречислениеСсылка.ВариантыОбеспечения - вариант обеспечения
//       * Запланировать - Булево - признак, материал возможно.
//
Функция СпособыПолученияМатериаловПоУмолчанию(ДанныеЗаказа, ТаблицаМатериалов, МенеджерВременныхТаблиц = Неопределено, ВариантЗаполненияОбеспечения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбеспечениеПроизводства.СпособыПолученияМатериаловПоУмолчанию(ДанныеЗаказа, ТаблицаМатериалов, МенеджерВременныхТаблиц, ВариантЗаполненияОбеспечения);
```
</details>

## ПриИзмененииОбеспечения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТКА

// Обновляет данные при изменении обеспечения этапов производства
//
// Параметры:
//  МассивЗаказов	 - Массив			 - содержит ссылки на документы.
//
Процедура ПриИзмененииОбеспечения(МассивЗаказов) Экспорт
```

Пример вызова
```bsl
ОбеспечениеПроизводства.ПриИзмененииОбеспечения(МассивЗаказов) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
