---
title: Обмен данными ЕГАИС
slug: erp-uh/обмен-данными-егаис
---


## ЗапуститьОбработкуОтветовЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура запуска регламентного задания ОбработкаОтветовЕГАИС.
//
Процедура ЗапуститьОбработкуОтветовЕГАИС() Экспорт
```

Пример вызова
```bsl
ОбменДаннымиЕГАИС.ЗапуститьОбработкуОтветовЕГАИС() 
```
</details>

## СтруктураСообщенияXML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует пустую структуру сообщения XML
//
// Параметры:
//  ДляКлиента - Булево - Для клиента
//
// Возвращаемое значение:
//  Структура -- Структура со свойствами:
// * ТекстОшибки - Строка - Текст ошибки.
// * Ошибки - Соответствие из Строка - Описание ошибок.
// * Описание - Строка - Описание для отображения в форме подписания.
// * ТекстСообщенияXML - Строка - Текст сообщения XML.
// * ТипСообщения - ПеречислениеСсылка.ТипыЗапросовИС - Тип сообщения.
// * ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС.
// * Документ - ДокументСсылка, Неопределено - Документ.
// * Версия - Число - Версия сообщения.
// * ДокументОснование - ДокументСсылка - Документ основание.
// * Операция - ПеречислениеСсылка - Операция
// * ФорматОбмена - ПеречислениеСсылка.ФорматыОбменаЕГАИС - формат обмена
Функция СтруктураСообщенияXML(ДляКлиента = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.СтруктураСообщенияXML(ДляКлиента);
```
</details>

## ПараметрыОбновленияСтатуса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает доступные параметры обновления статуса:
//   * ОбновлятьДвижения- Булево - Признак необходимости обновления движений документа.
//   * ОперацияКвитанции - ПеречислениеСсылка.ВидыДокументовЕГАИС - Операция.
//   * СтатусОбработки - ПеречислениеСсылка.СтатусыОбработкиСообщенийЕГАИС - Статус обработки сообщения.
//   * ДокументОбъект - ДокументОбъект - Документ-объект.
//   * ИдентификаторЗапроса - Строка - Идентификатор запроса.
//   * ФорматОбмена - ПеречислениеСсылка.ФорматыОбменаЕГАИС - Формат обмена.
//
// Возвращаемое значение:
//  Структура - структура параметров обновления статуса.
//
Функция ПараметрыОбновленияСтатуса() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ПараметрыОбновленияСтатуса() 
```
</details>

## ПодготовитьСообщениеКПередаче
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает сообщение к передаче в сервис ЕГАИС.
//
// Параметры:
//  ТекстСообщенияXML - Строка - Текст исходящего сообщения.
//  Реквизиты - Структура - Реквизиты передаваемого сообщения:
//   * ТипСообщения - ПеречислениеСсылка.ТипыЗапросовИС - Тип сообщения.
//   * Операция - ПеречислениеСсылка.ВидыДокументовЕГАИС - Операция.
//   * Документ - ДокументСсылка - Документ.
//   * СообщениеОснование - СправочникСсылка.ЕГАИСПрисоединенныеФайлы - Сообщение-основание
//   * Описание - Строка - Описание сообщения.
//   * ИдентификаторЗапроса - Строка - Идентификатор запроса.
//   * ФорматОбмена - ПеречислениеСсылка.ФорматыОбменаЕГАИС - Формат обмена.
//   * ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС.
//   * СтатусОбработки - ПеречислениеСсылка.СтатусыОбработкиСообщенийЕГАИС - Статус обработки сообщения.
//   * Версия - Число - Номер версии.
//  Немедленно - Булево - Признак немедленной передачи сообщения в УТМ, без очереди сообщений.
//
// Возвращаемое значение:
//  Массив из Структура - содержит коллекцию структур:
//    * НовыйСтатус - ПеречислениеСсылка.СтатусыИнформированияЕГАИС - новый статус документа
//    * ИсходящееСообщение - Строка - подготовленное сообщение.
//    * ИсходящееСообщение - Строка - подготовленное сообщение.
//
Функция ПодготовитьСообщениеКПередаче(ТекстСообщенияXML, Реквизиты, Немедленно = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ПодготовитьСообщениеКПередаче(ТекстСообщенияXML, Реквизиты, Немедленно);
```
</details>

## ДобавитьСообщениеВОчередьНаПередачуДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавить сообщение в регистра сведений ОчередьПередачиДанныхЕГАИС.
//
// Параметры:
//  Сообщение - СправочникСсылка.ЕГАИСПрисоединенныеФайлы - сообщение, которое добавляется в очередь.
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - организация ЕГАИС
//
Процедура ДобавитьСообщениеВОчередьНаПередачуДанных(Сообщение, ОрганизацияЕГАИС) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиЕГАИС.ДобавитьСообщениеВОчередьНаПередачуДанных(Сообщение, ОрганизацияЕГАИС));
```
</details>

## УдалитьСообщениеИзОчередиПередачиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удалить сообщение из регистра сведений ОчередьПередачиДанныхЕГАИС.
//
// Параметры:
//  Сообщение - СправочникСсылка.ЕГАИСПрисоединенныеФайлы - сообщение, которое удаляется из очереди.
//
Процедура УдалитьСообщениеИзОчередиПередачиДанных(Сообщение) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиЕГАИС.УдалитьСообщениеИзОчередиПередачиДанных(Сообщение) 
```
</details>

## ДобавитьЗаписьВПротоколОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавить запись в протокол обмена.
//
// Параметры:
//  ТекстСообщенияXML - Строка - Текст сообщения XML.
//  Реквизиты - Структура - Значения реквизитов сообщения.
//  ПроверятьХешБезСсылки - Булево - Признак проверки хеша без ссылки.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * НовоеСообщение - Булево - Это новое сообщение.
//   * Ссылка - СправочникСсылка.ЕГАИСПрисоединенныеФайлы - Ссылка на присоединенный файл.
//
Функция ДобавитьЗаписьВПротоколОбмена(ТекстСообщенияXML, Реквизиты, ПроверятьХешБезСсылки = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ДобавитьЗаписьВПротоколОбмена(ТекстСообщенияXML, Реквизиты, ПроверятьХешБезСсылки);
```
</details>

## УстановитьВидимостьКомандыВыполнитьОбмен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает видимость команды "Выполнить обмен" в формах документов, протокола и панели обмена с ЕГАИС.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - Форма
//  ИмяЭлемента - Строка - Имя элемента формы
Процедура УстановитьВидимостьКомандыВыполнитьОбмен(Форма, ИмяЭлемента) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиЕГАИС.УстановитьВидимостьКомандыВыполнитьОбмен(Форма, ИмяЭлемента) 
```
</details>

## ЧекXDTOВXML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразует объект XDTO чека в XML.
//
// Параметры:
//  ОбъектXDTO - ОбъектXDTO - Объект XDTO
//  ПространствоИмен - Строка - Имя пространства имен.
//  ИмяТипа - Строка - Имя типа
//
// Возвращаемое значение:
//  Строка - Текст сообщения XML.
//
Функция ЧекXDTOВXML(ОбъектXDTO, ПространствоИмен, ИмяТипа) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ЧекXDTOВXML(ОбъектXDTO, ПространствоИмен, ИмяТипа) 
```
</details>

## ОписаниеОперации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сформировать описание операции для документа.
//
// Параметры:
//  Описание - Строка - Описание операции.
//  ДокументСсылка - ДокументСсылка - Документ.
//  НомерВерсии - Число - Номер версии.
//
// Возвращаемое значение:
//  Строка - Описание операции.
//
Функция ОписаниеОперации(Описание, ДокументСсылка, НомерВерсии = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ОписаниеОперации(Описание, ДокументСсылка, НомерВерсии);
```
</details>

## ОписаниеОперацииПередачиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сформировать описание операции для документа
//
// Параметры:
//  ОперацияПередачиДанных - ПеречислениеСсылка.ВидыДокументовЕГАИС - Операция обмена с ЕГАИС
//  ДокументСсылка - ДокументСсылка - Документ ссылка
//  НомерВерсии - Число - Номер версии
//
// Возвращаемое значение:
//  Строка - Описание операции
//
Функция ОписаниеОперацииПередачиДанных(ОперацияПередачиДанных, ДокументСсылка = Неопределено, НомерВерсии = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ОписаниеОперацииПередачиДанных(ОперацияПередачиДанных, ДокументСсылка, НомерВерсии);
```
</details>

## ОписаниеОперацииПолученияДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Сформировать описание операции для документа
//
//Параметры:
//   ОперацияПередачиДанных - ПеречислениеСсылка.ВидыДокументовЕГАИС - Операция обмена с ЕГАИС
//
//Возвращаемое значение:
//   Строка - Описание операции
//
Функция ОписаниеОперацииПолученияДанных(ОперацияПередачиДанных) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ОписаниеОперацииПолученияДанных(ОперацияПередачиДанных) 
```
</details>

## КатегорииОпераций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает операции обмена с ЕГАИС, разбитые на категории
//
// Возвращаемое значение:
//  Структура - со свойствами:
//    * ПередачаДанных - Соответствие Из ПеречислениеСсылка.ВидыДокументовЕГАИС - Операции передачи данных.
//    * ПолучениеДанных - Соответствие Из ПеречислениеСсылка.ВидыДокументовЕГАИС - Операции получения данных.
//
Функция КатегорииОпераций() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.КатегорииОпераций() 
```
</details>

## ПустаяТаблицаПоследовательностьОпераций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает таблицу последовательности операций.
//
// Возвращаемое значение:
//  ТаблицаЗначений - Таблица с колонками:
//   * Операция - ПеречислениеСсылка.ВидыДокументовЕГАИС - Операция.
//   * Индекс - Число - Индекс операции в последовательности.
//   * ТипСообщения - ПеречислениеСсылка.ТипыЗапросовИС - Тип сообщения.
//   * КвитанцияУТМ - Булево - Признак наличия у операции квитанции УТМ.
//   * КвитанцияПолученЕГАИС - Булево - Признак наличия у операции квитанции Получен ЕГАИС.
//   * КвитанцияПроведенЕГАИС - Булево - Признак наличия у операции квитанции Проведен ЕГАИС.
//   * ДальнейшиеДействия - Массив Из ПеречислениеСсылка - Дальнейшие действия при операции.
//
Функция ПустаяТаблицаПоследовательностьОпераций() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ПустаяТаблицаПоследовательностьОпераций() 
```
</details>

## ДобавитьОперациюВПоследовательность
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет операцию в последовательность операций.
//
// Параметры:
//  ПоследовательностьОпераций - ТаблицаЗначений - см. функцию ПустаяТаблицаПоследовательностьОпераций().
//  Индекс - Число - Индекс добавляемой операции.
//  ТипСообщения - ПеречислениеСсылка.ТипыЗапросовИС - Тип сообщения.
//  Операция - ПеречислениеСсылка.ВидыДокументовЕГАИС - Операция.
//  РассчитатьДействияДляДокумента - ДокументСсылка - Документ, для которого нужно вычислить дальнейшие действия.
//  КвитанцияПолученЕГАИС - Булево - Признак наличия у операции квитанции Получен ЕГАИС.
//  КвитанцияПроведенЕГАИС - Булево - Признак наличия у операции квитанции Проведен ЕГАИС.
//
// Возвращаемое значение:
//  СтрокаТаблицыЗначений - см. функцию ПустаяТаблицаПоследовательностьОпераций().
//
Функция ДобавитьОперациюВПоследовательность(ПоследовательностьОпераций, Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ДобавитьОперациюВПоследовательность(ПоследовательностьОпераций, );
```
</details>

## ОбработатьОтветНаЗапросПолученияДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обрабатывает ответ ЕГАИС на запрос о получении документа.
//
// Параметры:
//  ВходящиеДанные - (См. ОбменДаннымиЕГАИСКлиентСервер.СтруктураЗагрузкиВходящегоДокумента).
//  ТаблицаСоответствияДокументовТипамЕГАИС - ТаблицаЗначений - см. функцию Перечисления.ВидыДокументовЕГАИС.ТаблицаСоответствияДокументовТипамЕГАИС().
//
// Возвращаемое значение:
//  Структура:
//   * Результат         - Неопределено, Структура - результат выполнения запроса.
//   * ТекстОшибки       - Строка - текст ошибки, в случае ее возникновения.
//   * ТекстСообщенияXML - Строка - содержит ответ, полученный на запрос.
//   * СтатусОбработки   - ПеречислениеСсылка.СтатусыОбработкиСообщенийЕГАИС - Статус обработки сообщения.
//
Функция ОбработатьОтветНаЗапросПолученияДокумента(ВходящиеДанные, ТаблицаСоответствияДокументовТипамЕГАИС = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ОбработатьОтветНаЗапросПолученияДокумента(ВходящиеДанные, ТаблицаСоответствияДокументовТипамЕГАИС);
```
</details>

## ДанныеОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает объект XDTO организации, которую требуется загрузить.
//
// Параметры:
//  ДанныеОрганизации - ОбъектXDTO - Данные организации
//
// Возвращаемое значение:
//  ОбъектXDTO - Данные организации
Функция ДанныеОрганизации(ДанныеОрганизации) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ДанныеОрганизации(ДанныеОрганизации) 
```
</details>

## ЗагрузитьОрганизацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Загружает организацию ЕГАИС в базу.
//  * При загрузке запросом из классификатора - безусловно.
//  * При загрузке в составе пакета (например ТТН) - создание новых элементов и обновление контрагентов
//    (флаг "Соответствует организации" установлен в Ложь).
//
//Параметры:
//   ДанныеОрганизацииXDTO - ОбъектXDTO - данные классификатора организаций ЕГАИС
//   ЗагрузкаИзКлассификатора - Булево - признак запроса данных из классификатора
//
//Возвращаемое значение:
//   СправочникСсылка.КлассификаторОрганизацийЕГАИС - найденный или загруженный элемент классификатора.
//
Функция ЗагрузитьОрганизацию(ДанныеОрганизацииXDTO, ЗагрузкаИзКлассификатора = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ЗагрузитьОрганизацию(ДанныеОрганизацииXDTO, ЗагрузкаИзКлассификатора);
```
</details>

## НайтиОбъектПоИдентификаторуЗапроса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные последнего исходящего запроса по идентификатору.
//
// Параметры:
//  ИдентификаторЗапроса - Строка - идентификатор исходящего запроса.
//
// Возвращаемое значение:
//   Структура - данные последнего исходящего запроса. Неопределено - если запрос не найден.
//
Функция НайтиОбъектПоИдентификаторуЗапроса(ИдентификаторЗапроса, ИскатьДокументОснование = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.НайтиОбъектПоИдентификаторуЗапроса(ИдентификаторЗапроса, ИскатьДокументОснование);
```
</details>

## ПараметрыИдентификатораЗапросаV4
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПараметрыИдентификатораЗапросаV4(ИдентификаторЗапроса) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ПараметрыИдентификатораЗапросаV4(ИдентификаторЗапроса) 
```
</details>

## ИсходящееСообщение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИсходящееСообщение(ИдентификаторЗапроса) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ИсходящееСообщение(ИдентификаторЗапроса) 
```
</details>

## ЗагрузитьОтветНаЗапросДанныхОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает список организаций ЕГАИС в базу.
//
// Параметры:
//  ДанныеДокумента - см. ОбработатьОтветНаЗапросПолученияДокумента
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - организация ЕГАИС
//  ДополнительныеПараметры - Неопределено, Произвольный - дополнительные параметры
//
// Возвращаемое значение:
//  см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ЗагрузитьОтветНаЗапросДанныхОрганизации(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ЗагрузитьОтветНаЗапросДанныхОрганизации(ДанныеДокумента, ОрганизацияЕГАИС, ДополнительныеПараметры);
```
</details>

## РассчитатьСтатус
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитать статус документа ЕГАИС.
//
// Параметры:
//  ДокументСсылка - ДокументСсылка - Документ ЕГАИС.
//  ЕстьЗаписиВПротоколеОбмена - Булево - Признак наличия записей в протоколе обмена (Возвращаемый параметр).
//
// Возвращаемое значение:
//  РегистрСведенийНаборЗаписей.СтатусыДокументовЕГАИС - Набор записей регистра сведений СтатусыДокументовЕГАИС.
//
Функция РассчитатьСтатус(ДокументСсылка, ЕстьЗаписиВПротоколеОбмена = Неопределено, ЭтоОбновлениеИБ = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.РассчитатьСтатус(ДокументСсылка, ЕстьЗаписиВПротоколеОбмена, ЭтоОбновлениеИБ);
```
</details>

## ПараметрыОбновленияПослеПолученияДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры обновления после получения данных.
//
// Параметры:
//  ЗаписьНабора - Структура - Запись набора.
//  МенеджерОбъекта - ДокументМенеджер - Менеджер документа.
//  ДокументСсылка - ДокументСсылка - Ссылка на документ.
//  Операция - ПеречислениеСсылка.ВидыДокументовЕГАИС - Операция.
//  ЭтоКвитанция - Булево - Признак квитанции.
//  ОперацияКвитанции - ПеречислениеСсылка.ВидыДокументовЕГАИС - Операция квитанции.
//  СтатусОбработки - ПеречислениеСсылка.СтатусыОбработкиСообщенийЕГАИС - Статус обработки сообщения.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * НовыйСтатус - ПеречислениеСсылка.СтатусыОбработкиАктаПостановкиНаБалансЕГАИС - Новый статус.
//   * ДальнейшееДействие1 - ПеречислениеСсылка.ДальнейшиеДействияПоВзаимодействиюЕГАИС - Дальнейшее действие 1.
//   * ДальнейшееДействие2 - ПеречислениеСсылка.ДальнейшиеДействияПоВзаимодействиюЕГАИС - Дальнейшее действие 2.
//   * ДальнейшееДействие3 - ПеречислениеСсылка.ДальнейшиеДействияПоВзаимодействиюЕГАИС - Дальнейшее действие 3.
//
Функция ПараметрыОбновленияПослеПолученияДанных(ЗаписьНабора, МенеджерОбъекта, ДокументСсылка, Операция, Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ПараметрыОбновленияПослеПолученияДанных(ЗаписьНабора, МенеджерОбъекта, ДокументСсылка, Операция, );
```
</details>

## ТипОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает тип организации ЕГАИС.
//
// Параметры:
//  ДанныеОрганизации - ОбъектXDTO - Данные организации ЕГАИС.
//
// Возвращаемое значение:
//  ПеречислениеСсылка.ТипыОрганизацийЕГАИС - Тип организации ЕГАИС.
//
Функция ТипОрганизации(ДанныеОрганизации) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ТипОрганизации(ДанныеОрганизации));
```
</details>

## ДополнитьПараметрыОбновленияСтатуса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополнить параметры обновления статуса.
//
// Параметры:
//  ПараметрыОбновленияСтатуса - см. ПараметрыОбновленияСтатуса
//
// Возвращаемое значение:
//  Структура - см. ПараметрыОбновленияСтатуса
//
Функция ДополнитьПараметрыОбновленияСтатуса(ПараметрыОбновленияСтатуса = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.ДополнитьПараметрыОбновленияСтатуса(ПараметрыОбновленияСтатуса);
```
</details>

## РасширеннаяИнформацияОбОшибке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РасширеннаяИнформацияОбОшибке(КраткоеПредставлениеОшибки, ПодробноеПредставлениеОшибки) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.РасширеннаяИнформацияОбОшибке(КраткоеПредставлениеОшибки, ПодробноеПредставлениеОшибки) 
```
</details>

## ОбработатьОшибку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбработатьОшибку(ТекстОшибки, ИнформацияОбОшибке, ВозвращаемоеЗначение) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиЕГАИС.ОбработатьОшибку(ТекстОшибки, ИнформацияОбОшибке, ВозвращаемоеЗначение) 
```
</details>

## СообщатьОбОшибкахПриЗагрузкеДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сообщать об ошибках при загрузке данных.
//
// Возвращаемое значение:
//  Булево - Необходимость сообщения об ошибках при загрузке данных.
//
Функция СообщатьОбОшибкахПриЗагрузкеДанных() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.СообщатьОбОшибкахПриЗагрузкеДанных() 
```
</details>

## СлужебныеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структура данных для удаления запросов из УТМ.
//
// Параметры:
//  ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС.
//  Операция - ПеречислениеСсылка.ВидыДокументовЕГАИС - Операция.
//  АдресЗапроса - Строка - Адрес запроса.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * ОрганизацияЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС.
//   * Операция - ПеречислениеСсылка.ВидыДокументовЕГАИС - Операция.
//   * АдресЗапроса - Строка - Адрес запроса.
//
Функция СлужебныеДанные(ОрганизацияЕГАИС, Операция, АдресЗапроса) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИС.СлужебныеДанные(ОрганизацияЕГАИС, Операция, АдресЗапроса) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
