---
title: Обмен данными ЕГАИС вызов сервера
slug: erp-uh/обмен-данными-егаис-вызов-сервера
---


## НастройкиОбменаЕГАИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает доступные для текущего рабочего места настройки обмена с ЕГАИС на клиенте и на сервере
//
// Параметры:
//  ОрганизацииЕГАИС - Массив из СправочникСсылка.КлассификаторОрганизацийЕГАИС, СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организации ЕГАИС для обмена.
//  ДатыПоследнегоЗапуска - Соответствие из КлючИЗначение - Даты последнего запуска обменов на клиенте по расписанию.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * ОбменНаСервере - Соответствие из КлючИЗначение - Настройки обмена на сервере, см. функцию ОбменДаннымиЕГАИСКлиентСервер.НоваяНастройкаОбменаЕГАИС()
//   * ОбменНаКлиенте - Соответствие из КлючИЗначение - Настройки обмена на клиенте, см. функцию ОбменДаннымиЕГАИСКлиентСервер.НоваяНастройкаОбменаЕГАИС()
//   * БезНастроек - Массив из СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организации ЕГАИС для которых нет настроек обмена.
//
Функция НастройкиОбменаЕГАИС(ОрганизацииЕГАИС = Неопределено, ДатыПоследнегоЗапуска = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИСВызовСервера.НастройкиОбменаЕГАИС(ОрганизацииЕГАИС, ДатыПоследнегоЗапуска);
```
</details>

## ВыполнитьОбмен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет отправку подготовленных сообщений, загрузку новых документов, обработку ответов из ЕГАИС.
//
// Параметры:
//  ОрганизацииЕГАИС - Неопределено, Массив из СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организации ЕГАИС, по которым необходимо выполнить обмен.
//  ДатыПоследнегоЗапуска - Неопределено, Соответствие из КлючИЗначение - Даты последнего запуска обменов на клиенте по расписанию.
//  ИдентификаторВладельца - УникальныйИдентификатор - Уникальный идентификатор формы для сообщений пользователю.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * Изменения - Массив из см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения.
//   * СообщенияXMLКПередаче - Массив из см. ОбменДаннымиЕГАИС.СтруктураСообщенияXML
//   * НастройкиОбменаЕГАИС - Соответствие из КлючИЗначение - Настройки обмена ЕГАИС на клиенте по организациям:
//     ** Ключ - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС.
//     ** Значение - Структура - Настройки обмена ЕГАИС, см. ОбменДаннымиЕГАИСКлиентСервер.НоваяНастройкаОбменаЕГАИС.
//   * ВыполнитьОбменПоРасписанию - Булево - Признак необходимости выполнения обмена (по расписанию), Истина, только если ДатыПоследнегоЗапуска <> Неопределено.
//   * ИдентификаторВладельца - Неопределено, УникальныйИдентификатор - Уникальный идентификатор формы для сообщений пользователю.
Функция ВыполнитьОбмен(ОрганизацииЕГАИС = Неопределено, ДатыПоследнегоЗапуска = Неопределено, ИдентификаторВладельца = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИСВызовСервера.ВыполнитьОбмен(ОрганизацииЕГАИС, ДатыПоследнегоЗапуска, ИдентификаторВладельца);
```
</details>

## ПодготовитьКПередаче
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает сообщения к передаче в сервис ЕГАИС.
//
// Параметры:
//  ВходящиеДанные - Массив из ДокументСсылка, ДокументСсылка - Документы к передаче сообщений.
//  ДальнейшееДействие - ПеречислениеСсылка.ДальнейшиеДействияПоВзаимодействиюЕГАИС - выполняемая операция обмена.
//  ДополнительныеПараметры - Структура - Дополнительные параметры.
//  Немедленно - Булево - Признак немедленной передачи сообщения в УТМ, без очереди сообщений.
//  ИдентификаторВладельца - Неопределено - ИдентификаторВладельца
// Возвращаемое значение:
//  Структура - см. ПодготовитьСообщенияКПередаче.
Функция ПодготовитьКПередаче(ВходящиеДанные, ДальнейшееДействие, ДополнительныеПараметры = Неопределено, Немедленно = Ложь, ИдентификаторВладельца = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИСВызовСервера.ПодготовитьКПередаче(ВходящиеДанные, ДальнейшееДействие, ДополнительныеПараметры, Немедленно, ИдентификаторВладельца);
```
</details>

## ПодготовитьЗапросДанныхКлассификатораКПередаче
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет подготовку запроса данных классификаторов ЕГАИС к передаче и
// передает запрос в ЕГАИС, если есть действующее подключение к УТМ.
//
// Параметры:
//  ОрганизацииЕГАИС - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС для которой выполняется запрос.
//  Операция - ПеречислениеСсылка.ВидыДокументовЕГАИС - Запрашиваемые данные.
//   Возможные значения:
//     Перечисление.ВидыДокументовЕГАИС.ЗапросАлкогольнойПродукции .
//     Перечисление.ВидыДокументовЕГАИС.ЗапросДанныхОрганизации.
//  ИмяПараметра - Строка - Имя параметра. Возможные значения: "ИНН", "КОД", "СИО".
//  ЗначениеПараметра - Строка - Значение параметра.
//  ИдентификаторВладельца - УникальныйИдентификатор - Уникальный идентификатор формы для сообщений обмена
//
// Возвращаемое значение:
//  (См. ПодготовитьСообщенияКПередаче)
//
Функция ПодготовитьЗапросДанныхКлассификатораКПередаче(ОрганизацияЕГАИС, Операция, ИмяПараметра, ЗначениеПараметра, ИдентификаторВладельца = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИСВызовСервера.ПодготовитьЗапросДанныхКлассификатораКПередаче(ОрганизацияЕГАИС, Операция, ИмяПараметра, ЗначениеПараметра, ИдентификаторВладельца);
```
</details>

## ВходящиеСообщения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет получение списка новых сообщений.
//
// Параметры:
//  ОрганизацииЕГАИС - Неопределено, Массив из СправочникСсылка.КлассификаторОрганизацийЕГАИС, СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организации ЕГАИС, по которым необходимо выполнить обмен.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * ДокументыКЗагрузке - Соответствие из КлючИЗначение -
//   * НастройкиОбменаЕГАИС - Соответствие из КлючИЗначение - Настройки обмена ЕГАИС на клиенте по организациям:
//     ** Ключ - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС.
//     ** Значение - (См. ОбменДаннымиЕГАИСКлиентСервер.НоваяНастройкаОбменаЕГАИС).
//   * ТекстОшибки - Строка - Текст сообщения об ошибке.
Функция ВходящиеСообщения(ОрганизацииЕГАИС = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИСВызовСервера.ВходящиеСообщения(ОрганизацииЕГАИС);
```
</details>

## ОбработатьОчередьПередачиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработать очередь передачи данных в ЕГАИС
//
// Параметры:
//  НастройкиОбменаЕГАИС - Структура - Настройки обмена ЕГАИС, см. функцию НастройкиОбменаЕГАИС()
//  СообщенияXMLКПередаче - Массив из см. ОбменДаннымиЕГАИС.СтруктураСообщенияXML - Массив структур к передаче
//  Немедленно - Булево -
// Возвращаемое значение:
// Структура - со свойствами:
//  * Изменения - Массив из см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения - Результат передачи сообщений на сервере
//  * СообщенияXMLКПередаче - Массив из см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения - Массив структур к передаче на клиенте
//
Функция ОбработатьОчередьПередачиДанных(НастройкиОбменаЕГАИС, СообщенияXMLКПередаче = Неопределено, Немедленно = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИСВызовСервера.ОбработатьОчередьПередачиДанных(НастройкиОбменаЕГАИС, СообщенияXMLКПередаче, Немедленно);
```
</details>

## ОтменитьПередачу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет неотправленную операцию из очереди передачи данных в ЕГАИС.
//
// Параметры:
//  ДокументСсылка - ДокументСсылка - документ, по которому требуется отменить передачу данных.
//
// Возвращаемое значение:
//  Массив - Массив структур, см. функцию ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения().
//
Функция ОтменитьПередачу(ДокументСсылка) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИСВызовСервера.ОтменитьПередачу(ДокументСсылка) 
```
</details>

## ОтменитьПоследнююОперацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отменяет последнюю операцию (например, если возникла ошибка передачи данных).
//
// Параметры:
//  ДокументСсылка - ДокументСсылка - документ, по которому требуется отменить операцию.
//
// Возвращаемое значение:
//  Массив - Массив структур, см. функцию ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения().
//
Функция ОтменитьПоследнююОперацию(ДокументСсылка) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИСВызовСервера.ОтменитьПоследнююОперацию(ДокументСсылка) 
```
</details>

## ВосстановитьСтатусДокументаПоДаннымПротоколаОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Восстанавливает статус документа по данным протокола обмена.
//
// Параметры:
//  ДокументСсылка - ДокументСсылка - документ, по которому требуется восстановить статус.
//
Процедура ВосстановитьСтатусДокументаПоДаннымПротоколаОбмена(ДокументСсылка) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиЕГАИСВызовСервера.ВосстановитьСтатусДокументаПоДаннымПротоколаОбмена(ДокументСсылка) 
```
</details>

## УдалитьВходящиеДокументы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция УдалитьВходящиеДокументы(ДокументыКУдалению) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИСВызовСервера.УдалитьВходящиеДокументы(ДокументыКУдалению) 
```
</details>

## ПроверитьВходящиеДокументы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверить входящие документы в УТМ.
//
// Параметры:
//  ОрганизацииЕГАИС - Неопределено, Массив из СправочникСсылка.КлассификаторОрганизацийЕГАИС, СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организации ЕГАИС, по которым необходимо выполнить обмен.
//  ИдентификаторВладельца - УникальныйИдентификатор - Уникальный идентификатор формы для сообщений пользователю.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * АдресаURLВходящихДокументов - Массив из см. функцию ОбменДаннымиЕГАИСКлиентСервер.АдресаURLВходящихДокументов - массив адресов входящих документов
//   * НастройкиОбменаЕГАИС - см. ОбменДаннымиЕГАИСКлиентСервер.НоваяНастройкаОбменаЕГАИС
//   * ТекстОшибки - Строка - Текст ошибки.
//   * ИдентификаторВладельца - Неопределено,УникальныйИдентификатор - Уникальный идентификатор формы для сообщений пользователю.
Функция ПроверитьВходящиеДокументы(ОрганизацииЕГАИС = Неопределено, ИдентификаторВладельца = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИСВызовСервера.ПроверитьВходящиеДокументы(ОрганизацииЕГАИС, ИдентификаторВладельца);
```
</details>

## ПолучитьВходящиеДокументы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает новые документы из УТМ.
//
// Параметры:
//  НастройкиОбменаЕГАИС - Соответствие из КлючИЗначение - Настройки обмена ЕГАИС по организациям:
//   * Ключ - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС.
//   * Значение - см. ОбменДаннымиЕГАИСКлиентСервер.НоваяНастройкаОбменаЕГАИС
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * Изменения - Массив из см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
//   * ТекстОшибки - Строка - Текст ошибки.
//
Функция ПолучитьВходящиеДокументы(НастройкиОбменаЕГАИС) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИСВызовСервера.ПолучитьВходящиеДокументы(НастройкиОбменаЕГАИС) 
```
</details>

## ОбработатьВходящиеДокументы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает список документов, полученных из УТМ.
//
// Параметры:
//  ДокументыКЗагрузке - Соответствие из КлючИЗначение - Сообщения XML к загрузке по организациям:
//   * Ключ - СправочникСсылка.КлассификаторОрганизацийЕГАИС - Организация ЕГАИС.
//   * Значение - Массив из см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураЗагрузкиВходящегоДокумента - Сообщения XML к загрузке
//	ИдентификаторВладельца - Неопределено -
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * Изменения - Массив из см. ОбменДаннымиЕГАИСКлиентСервер.СтруктураИзменения
Функция ОбработатьВходящиеДокументы(ДокументыКЗагрузке, ИдентификаторВладельца = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиЕГАИСВызовСервера.ОбработатьВходящиеДокументы(ДокументыКЗагрузке, ИдентификаторВладельца);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
