---
title: Обмен данными УТ УП
slug: erp-uh/обмен-данными-ут-уп
---


## ЭтоСозданиеУзлаОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак доступности плана обмена, для базовой или проф версии.
// Параметры:
//  ПланОбмена - ПланОбменаОбъект - Объект плана обмена.
// Возвращаемое значение:
//  Булево - признак доступности.
//
Функция ЭтоСозданиеУзлаОбмена(ПланОбмена) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиУТУП.ЭтоСозданиеУзлаОбмена(ПланОбмена) 
```
</details>

## ПроверкаВозможностиСозданияУзлаОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак доступности плана обмена, для базовой или проф версии
//
// Параметры:
//   ПланОбмена - ОбъектМетаданных - Метаданные плана обмена, возможность создания которого необходимо проверить.
//
// Возвращаемое значение:
//   Булево - Истина, если узел плана обмена возможно создать в данной версии конфигурации.
//
Функция ПроверкаВозможностиСозданияУзлаОбмена(ПланОбмена) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиУТУП.ПроверкаВозможностиСозданияУзлаОбмена(ПланОбмена) 
```
</details>

## УстановитьДоступностьНастроекУзлаИнформационнойБазы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Блокирует изменение настроек узла плана обмена
// в подчиненном узле распределенной информационной базы.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - Форму, элементы который необходимо заблокировать.
//
Процедура УстановитьДоступностьНастроекУзлаИнформационнойБазы(Форма) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиУТУП.УстановитьДоступностьНастроекУзлаИнформационнойБазы(Форма) 
```
</details>

## ОбщиеСведенияОНастроенныхОбменах
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о том, какие типы обменов настроены.
//
// Возвращаемое значение:
//   Структура:
//       * ОбменРИБ     - Булево - используются обмены РИБ
//       * ОбменED      - Булево - используются обмены в формате EnterpriseData
//       * ОбменXML     - Булево - используются обмены по правилам xml.
//
Функция ОбщиеСведенияОНастроенныхОбменах() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиУТУП.ОбщиеСведенияОНастроенныхОбменах() 
```
</details>

## СписокПлановОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает список доступных для создания планов обмена
Процедура СписокПлановОбмена(ПланыОбменаПодсистемы) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиУТУП.СписокПлановОбмена(ПланыОбменаПодсистемы) 
```
</details>

## ИмяКонфигурацииИсточника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для точной идентификации имени этой конфигурации при настройке
// синхронизации данных в модели сервиса.
// В случае если данная конфигурация разработана на основе оригинальной конфигурации
// и должна поддерживать обмен с другими прикладными решениями с помощью плана обмена,
// взятого из оригинальной конфигурации, то следует вернуть имя оригинальной конфигурации.
// Например, для конфигурации МояБухгалтерия, которая является доработанной конфигурацией БухгалтерияПредприятия,
// следует вернуть БухгалтерияПредприятия.
//
// Используется только для планов обмена в модели сервиса.
//
// Возвращаемое значение:
//	Строка - имя этой или другой конфигурации, от имени которой выполняется обмен данными
//			(имя конфигурации как задано в метаданных).
//
// Пример:
//  Возврат "БухгалтерияПредприятия";
//
Функция ИмяКонфигурацииИсточника() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиУТУП.ИмяКонфигурацииИсточника() 
```
</details>

## РегистрацияИзмененияДляНачальнойВыгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик регистрации изменений для начальной выгрузки данных.
// Используется для переопределения стандартной обработки регистрации изменений.
// При стандартной обработке будут зарегистрированы изменения всех данных из состава плана обмена.
// Если для плана обмена предусмотрены фильтры ограничения миграции данных,
// то использование этого обработчика позволит повысить производительность начальной выгрузки данных.
// В обработчике следует реализовать регистрацию изменений с учетом фильтров ограничения миграции данных.
// Если для плана обмена используются ограничения миграции по дате или по дате и организациям,
// то можно воспользоваться универсальной процедурой
// ОбменДаннымиСервер.ЗарегистрироватьДанныеПоДатеНачалаВыгрузкиИОрганизациям.
// Обработчик используется только для универсального обмена данными с использованием правил обмена
// и для универсального обмена данными без правил обмена и не используется для обменов в РИБ.
// Использование обработчика позволяет повысить производительность
// начальной выгрузки данных в среднем в 2-4 раза.
//
// Параметры:
//   Получатель           - ПланОбменаСсылка - Узел плана обмена, в который требуется выгрузить данные.
//   СтандартнаяОбработка - Булево           - В данный параметр передается признак выполнения стандартной (системной) обработки
//                                             события. Если в теле процедуры-обработчика установить данному параметру значение Ложь,
//                                             стандартная обработка события производиться не будет. Отказ от стандартной обработки
//                                             не отменяет действие. Значение по умолчанию - Истина.
//   Отбор                - Структура        - Структура содержащая данные отбора.
//
Процедура РегистрацияИзмененияДляНачальнойВыгрузки(Получатель, СтандартнаяОбработка, Отбор) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиУТУП.РегистрацияИзмененияДляНачальнойВыгрузки(Получатель, СтандартнаяОбработка, Отбор) 
```
</details>

## ЕстьОбменыСФормированиемДоговоровПоЗаказам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак наличия действующих обменов, использующих формирование договоров по заказам.
//
// Возвращаемое значение:
//  Булево - признак наличия узлов.
//
Функция ЕстьОбменыСФормированиемДоговоровПоЗаказам() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиУТУП.ЕстьОбменыСФормированиемДоговоровПоЗаказам() 
```
</details>

## КонтрольСозданияДокументовВРаспределеннойИБ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Информирует пользователя о запрете создания или изменения объекта в этой
// информационной базе.
//
// Параметры:
//   Объект - ДокументОбъект - Документ который проверяется на возможность создания в подчиненном узле
//                             распределенной информационной базы.
//   Отказ  - Булево - Флаг отказа от создания документа. По умолчанию Ложь.
//
Процедура КонтрольСозданияДокументовВРаспределеннойИБ(Объект, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиУТУП.КонтрольСозданияДокументовВРаспределеннойИБ(Объект, Отказ) 
```
</details>

## ПриОпределенииОбъектовСЗаблокированнымиРеквизитами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определить объекты метаданных, в модулях менеджеров которых ограничивается возможность редактирования реквизитов
// с помощью экспортной функции ПолучитьБлокируемыеРеквизитыОбъекта.
//
// Параметры:
//   Объекты - Соответствие из КлючИЗначение:
//     * Ключ - Строка - полное имя объекта метаданных, подключенного к подсистеме;
//     * Значение - Строка - пустая строка.
//
// Пример:
//   Объекты.Вставить(Метаданные.Документы.ЗаказПокупателя.ПолноеИмя(), "");
//
Процедура ПриОпределенииОбъектовСЗаблокированнымиРеквизитами(Объекты) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиУТУП.ПриОпределенииОбъектовСЗаблокированнымиРеквизитами(Объекты) 
```
</details>

## СсылкаУправленческойОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение ссылки управленческой организации
// для настройки отбора, при настройке через внешнее соединение.
//
// Возвращаемое значение:
//  Строка - идентификатор ссылки управленческой организации.
//
Функция СсылкаУправленческойОрганизации() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиУТУП.СсылкаУправленческойОрганизации() 
```
</details>

## ОбъединитьМассивы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Объединяет массивы, возвращая результат объединения.
//
// Возвращаемое значение:
//   Массив - объединенный массив значений.
//
Функция ОбъединитьМассивы(Массив1, Массив2) Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиУТУП.ОбъединитьМассивы(Массив1, Массив2) 
```
</details>

## РегистрыДляСозданияЗаданийКРасчетуСебестоимости
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РегистрыДляСозданияЗаданийКРасчетуСебестоимости() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиУТУП.РегистрыДляСозданияЗаданийКРасчетуСебестоимости() 
```
</details>

## РегистрыДляСозданияЗаданийКРасчетуВзаиморасчетовСКлиентами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РегистрыДляСозданияЗаданийКРасчетуВзаиморасчетовСКлиентами() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиУТУП.РегистрыДляСозданияЗаданийКРасчетуВзаиморасчетовСКлиентами() 
```
</details>

## РегистрыДляСозданияЗаданийКРасчетуВзаиморасчетовСПоставщиками
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РегистрыДляСозданияЗаданийКРасчетуВзаиморасчетовСПоставщиками() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиУТУП.РегистрыДляСозданияЗаданийКРасчетуВзаиморасчетовСПоставщиками() 
```
</details>

## РегистрыДляПроверкиБлокировкиЗакрытияМесяца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РегистрыДляПроверкиБлокировкиЗакрытияМесяца() Экспорт
```

Пример вызова
```bsl
Результат = ОбменДаннымиУТУП.РегистрыДляПроверкиБлокировкиЗакрытияМесяца() 
```
</details>

## СоздатьЗаданияКРасчетуОффлайновыхРегистров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод создает задания, для последующего расчета оффлайновых регистров (себестоимость, взаиморасчеты и т.д.).
//
// Параметры:
//  ПолученныеДанные - РегистрНакопленияНаборЗаписей - Полученный набор записей регистра накопления,
//                                                     на основании которого необходимо создать задания.
//  ИмяРегистраДляСозданияЗаписи - Строка - Имя оффлайн регистра.
//
Процедура СоздатьЗаданияКРасчетуОффлайновыхРегистров(ПолученныеДанные, ИмяРегистраДляСозданияЗаписи) Экспорт
```

Пример вызова
```bsl
ОбменДаннымиУТУП.СоздатьЗаданияКРасчетуОффлайновыхРегистров(ПолученныеДанные, ИмяРегистраДляСозданияЗаписи) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
