---
title: Обмен с контрагентами клиент переопределяемый
slug: erp-uh/обмен-с-контрагентами-клиент-переопределяемый
---


## ПриОбработкеРезультатовПроверокФормированияДокументовЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие возникает непосредственно перед запуском формирования электронных документов, до запуска внутренних проверок.
// Позволяет выполнить дополнительные действия перед формированием электронных документов, в том числе отказаться от их формирования.
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - обработчик оповещения, который нужно вызвать после завершения
//                         обработки результатов проверок формирования электронных документов.
//   * Результат - Соответствие - коллекция ключей связи с данными электронных документов для отказа от записи.
//                                Данные, по которым не переданы ключи, считаются валидными и будут записаны.
//     ** Ключ - Число - ключ связи с данными для проверки
//                      (См. ОбменСКонтрагентамиПереопределяемый.ПриПроверкеФормированияДокументовЭДО).
//     ** Значение - Булево - признак отказа от записи данных электронного документа.
//                            Если Истина, то запись данных не выполняется.
//  ПараметрыОбработки - Структура - параметры, переданные из процедуры
//                    см. ОбменСКонтрагентамиПереопределяемый.ПриОбработкеРезультатовПроверокФормированияДокументовЭДО
//
//@skip-warning
Процедура ПриОбработкеРезультатовПроверокФормированияДокументовЭДО(ОповещениеОЗавершении, ПараметрыОбработки) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиКлиентПереопределяемый.ПриОбработкеРезультатовПроверокФормированияДокументовЭДО(ОповещениеОЗавершении, ПараметрыОбработки) 
```
</details>

## ПриОбработкеРезультатовПроверокФормированияОтветовПоДокументамЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие возникает непосредственно перед утверждением входящих электронных документов. Позволяет выполнить дополнительные
// действия перед утверждением электронных документов, в том числе отказаться от него.
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - обработчик оповещения, который нужно вызвать после завершения
//                         обработки результатов проверок формирования ответов по электронным документам.
//   * Результат - Соответствие - коллекция ключей связи с данными электронных документов для отказа от записи.
//                                Данные, по которым не переданы ключи, считаются валидными и будут записаны.
//     ** Ключ - Число - ключ связи с данными для проверки
//                      (См. ОбменСКонтрагентамиПереопределяемый.ПриПроверкеФормированияОтветовПоДокументамЭДО).
//     ** Значение - Булево - признак отказа от записи данных электронного документа.
//                            Если Истина, то запись данных не выполняется.
//  ПараметрыОбработки - Структура - параметры, переданные из процедуры
//            см. ОбменСКонтрагентамиПереопределяемый.ПриОбработкеРезультатовПроверокФормированияОтветовПоДокументамЭДО
//
//@skip-warning
Процедура ПриОбработкеРезультатовПроверокФормированияОтветовПоДокументамЭДО(ОповещениеОЗавершении, ПараметрыОбработки) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиКлиентПереопределяемый.ПриОбработкеРезультатовПроверокФормированияОтветовПоДокументамЭДО(ОповещениеОЗавершении, ПараметрыОбработки) 
```
</details>

## ОткрытьФормуПодбораТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму подбора номенклатуры с целью выбора позиций, помещаемых в формируемый электронный документ "Каталог товаров".
//
// Параметры:
//  ИдентификаторФормы   - УникальныйИдентификатор - уникальный  идентификатор формы, вызвавшей функцию.
//  ОбработкаПродолжения - ОписаниеОповещения - обработчик необходимо вызывать после закрытия формы подбора.
//  					   В качестве результата в него необходимо передать адрес временного хранилища, содержащего
//  					   таблицу подобранных позиций номенклатуры. В дальнейшем эта таблица будет передана в метод
//  					   заполнения данных для каталога товаров. См. ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПоКаталогуТоваровCML.
//  					   Если выполняется отмена операции, в обработчик должно быть передано Неопределено.
//
Процедура ОткрытьФормуПодбораТоваров(ИдентификаторФормы, ОбработкаПродолжения) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиКлиентПереопределяемый.ОткрытьФормуПодбораТоваров(ИдентификаторФормы, ОбработкаПродолжения) 
```
</details>

## ПриПодбореУчетногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняется при подборе (выборе) учетного документа.
// Позволяет отказаться от стандартного ввода значения, открыв необходимую форму.
//
// Параметры:
//  Настройки - Структура - настройки подбора учетного документа.
//   * СпособОбработки - Строка - способ обработки входящего электронного документа.
//   * ИмяОбъектаМетаданных - Строка - полное имя объекта метаданных для выбора.
//   * ИмяТипаСсылки - Строка - имя типа ссылки для выбора. Например, "ДокументСсылка.ПоступлениеТоваровУслуг".
//   * Контрагент - ОпределяемыйТип.УчастникЭДО - контрагент по электронному документу.
//   * Организация - ОпределяемыйТип.Организация - организация по электронному документу.
//  ОповещениеОВыборе - ОписаниеОповещения - оповещение, которое необходимо выполнить с результатом выбора пользователя.
//                                           Если пользователь отказался от выбора, то выполнить со значением Неопределено.
//  СтандартнаяОбработка - Булево - признак открытия стандартного выбора значения.
//                                  Если процедура переопределяется, то следует установить Ложь.
//
// Пример:
//  // Открываем форму выбора с установленным отбором по контрагенту и организации.
//  СтандартнаяОбработка = Ложь;
//  ПараметрыФормы = Новый Структура("РежимВыбора,ЗакрыватьПриВыборе", Истина, Истина);
//  Отбор = Новый Структура("Контрагент,Организация", Настройки.Контрагент, Настройки.Организация);
//  ПараметрыФормы.Вставить("Отбор", Отбор);
//  ОткрытьФорму(Настройки.ИмяОбъектаМетаданных + ".ФормаВыбора", ПараметрыФормы,,,,, ОповещениеОВыборе, РежимОткрытияОкнаФормы.БлокироватьОкноВладельца);
//
Процедура ПриПодбореУчетногоДокумента(Знач Настройки, Знач ОповещениеОВыборе, СтандартнаяОбработка = Истина) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиКлиентПереопределяемый.ПриПодбореУчетногоДокумента(Настройки, ОповещениеОВыборе, СтандартнаяОбработка);
```
</details>

## ПослеПодбораУчетногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняется после подбора учетного документа.
//
// Параметры:
//  ЭлектронныйДокумент - ДокументСсылка.ЭлектронныйДокументВходящийЭДО - ссылка на электронный документ.
//  ДокументУчета - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - выбранный учетный документ.
Процедура ПослеПодбораУчетногоДокумента(ЭлектронныйДокумент, ДокументУчета) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиКлиентПереопределяемый.ПослеПодбораУчетногоДокумента(ЭлектронныйДокумент, ДокументУчета) 
```
</details>

## ПриЗаполненииНалоговогоОргана
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму редактирования кода налогового органа, если он хранится в конфигурации
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения - обработчик оповещения о завершении.
//  	В обработчик оповещения возвращается значение:
//			Неопределено - при нажатии пользователем кнопки Отмена;
//			Число        - Номер налогового органа, введенного пользователем
//  Организация - ОпределяемыйТип.Организация - Организация для которой редактируется код налогового органа.
//  СтандартнаяОбработка - Булево - признак открытия стандартного выбора значения.
//                         Если процедура переопределяется, то следует установить Ложь.
//
//@skip-warning
Процедура ПриЗаполненииНалоговогоОргана(ОповещениеОЗавершении, Организация, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиКлиентПереопределяемый.ПриЗаполненииНалоговогоОргана(ОповещениеОЗавершении, Организация, СтандартнаяОбработка) 
```
</details>

## ПриВыбореДоговораКонтрагента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму выбора договора контрагента.
//
// Параметры:
//  Параметры - Структура - параметры формы.
//     * Организация - ОпределяемыйТип.Организация - ссылка на организацию.
//     * Контрагент  - ОпределяемыйТип.КонтрагентБЭД - ссылка на контрагента.
//  Владелец - Форма, ПолеФормы - форма или элемент управления другой формы.
//  ОповещениеОЗакрытии - ОписаниеОповещения - описание оповещения о закрытии, с которым нужно открыть форму.
//  СтандартнаяОбработка - Булево - признак открытия стандартного выбора значения.
//                         Если процедура переопределяется, то следует установить Ложь.
//
Процедура ПриВыбореДоговораКонтрагента(Параметры, Владелец, ОповещениеОЗакрытии, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиКлиентПереопределяемый.ПриВыбореДоговораКонтрагента(Параметры, Владелец, ОповещениеОЗакрытии, СтандартнаяОбработка) 
```
</details>

## СоздатьКонтрагентаИнтерактивно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму создания нового контрагента с заполненными данными.
//
// Параметры:
//  РеквизитыКонтрагента - Структура - источник заполнения реквизитов. Возможные элементы:
//   * Наименование - Строка
//   * ИНН - Строка
//   * КПП - Строка
//  ОписаниеОповещенияОСозданииКонтрагента - ОписаниеОповещения - (не является обработчиком оповещения о закрытии)
//   требуется вызвать данный обработчик со ссылкой на созданного контрагента в параметре Результат.
Процедура СоздатьКонтрагентаИнтерактивно(РеквизитыКонтрагента, ОписаниеОповещенияОСозданииКонтрагента) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиКлиентПереопределяемый.СоздатьКонтрагентаИнтерактивно(РеквизитыКонтрагента, ОписаниеОповещенияОСозданииКонтрагента) 
```
</details>

## ВыбратьКонтрагента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму выбора контрагента с отбором.
//
// Параметры:
//  РеквизитыОтбораКонтрагента - Структура - источник заполнения отбора списка контрагентов.
//   Возможные значения:
//   * Наименование - Строка
//   * ИНН - Строка
//   * КПП - Строка
//  ОписаниеОповещенияОЗакрытии - ОписаниеОповещения.
Процедура ВыбратьКонтрагента(РеквизитыОтбораКонтрагента, ОписаниеОповещенияОЗакрытии) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиКлиентПереопределяемый.ВыбратьКонтрагента(РеквизитыОтбораКонтрагента, ОписаниеОповещенияОЗакрытии) 
```
</details>

## ПриОпределенииВариантовВыбораФайлаДляДоговорногоДокументаПДФ_А3
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предоставляет возможность указать используемые варианты выбора файла для договорного документа PDF/A3.
//
// Параметры:
//  ВариантыВыбораФайла - см. Обработка.ФорматДоговорныйДокумент101.Форма.ВыполнениеКлиентскихМетодов.НовыеВариантыВыбораФайла
//  ВариантВыбораФайлаПоУмолчанию - Строка - Значение, которое будет выбрано по умолчанию в форме выбора файла PDF.
//                                           Принимает значение, соответствующие одному из ключей ВариантыВыбораФайла
//
// Пример:
//
//	ВариантыВыбораФайла.СДиска             = Ложь;
//	ВариантыВыбораФайла.ПрисоединенныйФайл = Истина;
//	ВариантыВыбораФайла.ПечатнаяФорма      = Истина;
//
//	ВариантВыбораФайлаПоУмолчанию = "ПрисоединенныйФайл";
//
Процедура ПриОпределенииВариантовВыбораФайлаДляДоговорногоДокументаПДФ_А3(ВариантыВыбораФайла, Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиКлиентПереопределяемый.ПриОпределенииВариантовВыбораФайлаДляДоговорногоДокументаПДФ_А3(ВариантыВыбораФайла, );
```
</details>

## ПриФормированииНовогоФайлаОбменаДоговорногоДокументаXML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняется в момент формирования файла договорного документа формата XML
//
// Параметры:
//  ОбъектУчета                 - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО
//  ИдентификаторОсновногоФайла - Строка - Идентификатор основного файла обмена
//  ОповещениеОЗавершении       - ОписаниеОповещения - обработчик оповещения, который нужно вызвать после завершения
//                                подготовки файла:
//   * ПараметрыФайла - Структура - коллекция с данными подготовленного файла:
//     ** Имя      - Строка - имя файла нового электронного документа.
//     ** Хранение - Строка - адрес временного хранилища, содержащего двоичные данные файла.
//
// Пример:
//
//	ПараметрыФайла = Новый Структура;
//	ПараметрыФайла.Вставить("Имя", ИдентификаторОсновногоФайла + ".xml");
//	ПараметрыФайла.Вставить("Хранение", ПоместитьВоВременноеХранилище(ДвоичныеДанные));
//
//	ВыполнитьОбработкуОповещения(ОповещениеОЗавершении, ПараметрыФайла);
//
Процедура ПриФормированииНовогоФайлаОбменаДоговорногоДокументаXML(ОбъектУчета, ИдентификаторОсновногоФайла, Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиКлиентПереопределяемый.ПриФормированииНовогоФайлаОбменаДоговорногоДокументаXML(ОбъектУчета, ИдентификаторОсновногоФайла, );
```
</details>

## ПроверитьИспользованиеИнтернетПоддержкаПользователей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет на использование в прикладном решении библиотеки интернет поддержки пользователей.
//
// Параметры:
//  Использование - булево - признак использования библиотеки БИП.
//
Процедура ПроверитьИспользованиеИнтернетПоддержкаПользователей(Использование) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиКлиентПереопределяемый.ПроверитьИспользованиеИнтернетПоддержкаПользователей(Использование) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
