---
title: Обновление информационной базы ЕХ
slug: erp-uh/обновление-информационной-базы-ех
---


## ПриДобавленииПодсистемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриДобавленииПодсистемы(Описание) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПриДобавленииПодсистемы(Описание) 
```
</details>

## ПриДобавленииОбработчиковОбновления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриДобавленииОбработчиковОбновления(Обработчики=Неопределено) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПриДобавленииОбработчиковОбновления(Обработчики);
```
</details>

## ПередОбновлениемИнформационнойБазы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПередОбновлениемИнформационнойБазы(Обработчики=Неопределено) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПередОбновлениемИнформационнойБазы(Обработчики);
```
</details>

## ПриОпределенииРежимаОбновленияДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить режим обновления данных информационной базы.
// Для использования в редких (нештатных) случаях перехода, не предусмотренных в
// стандартной процедуре определения режима обновления.
//
// Параметры:
//   РежимОбновленияДанных - Строка - в обработчике можно присвоить одно из значений:
//              "НачальноеЗаполнение"     - если это первый запуск пустой базы (области данных);
//              "ОбновлениеВерсии"        - если выполняется первый запуск после обновление конфигурации базы данных;
//              "ПереходСДругойПрограммы" - если выполняется первый запуск после обновление конфигурации базы данных,
//                                          в которой изменилось имя основной конфигурации.
//
//   СтандартнаяОбработка  - Булево - если присвоить Ложь, то стандартная процедура
//                                    определения режима обновления не выполняется,
//                                    а используется значение РежимОбновленияДанных.
//
Процедура ПриОпределенииРежимаОбновленияДанных(РежимОбновленияДанных, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПриОпределенииРежимаОбновленияДанных(РежимОбновленияДанных, СтандартнаяОбработка) 
```
</details>

## ПриДобавленииОбработчиковПереходаСДругойПрограммы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в список процедуры-обработчики перехода с другой программы (с другим именем конфигурации).
// Например, для перехода между разными, но родственными конфигурациями: базовая -> проф -> корп.
// Вызывается перед началом обновления данных ИБ.
//
//  Обработчики - ТаблицаЗначений - с колонками:
//    * ПредыдущееИмяКонфигурации - Строка - имя конфигурации, с которой выполняется переход;
//    * Процедура                 - Строка - полное имя процедуры-обработчика перехода с программы ПредыдущееИмяКонфигурации.
//                                  Например, "ОбновлениеИнформационнойБазыУПП.ЗаполнитьУчетнуюПолитику"
//                                  Обязательно должна быть экспортной.
//
// Пример добавления процедуры-обработчика в список:
//  Обработчик = Обработчики.Добавить();
//  Обработчик.ПредыдущееИмяКонфигурации  = "УправлениеТорговлей";
//  Обработчик.Процедура                  = "ОбновлениеИнформационнойБазыУПП.ЗаполнитьУчетнуюПолитику";
//
Процедура ПриДобавленииОбработчиковПереходаСДругойПрограммы(Обработчики) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПриДобавленииОбработчиковПереходаСДругойПрограммы(Обработчики) 
```
</details>

## ПриЗавершенииПереходаСДругойПрограммы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается после выполнения всех процедур-обработчиков перехода с другой программы (с другим именем конфигурации),
// и до начала выполнения обновления данных ИБ.
//
// Параметры:
//  ПредыдущееИмяКонфигурации    - Строка - имя конфигурации до перехода.
//  ПредыдущаяВерсияКонфигурации - Строка - имя предыдущей конфигурации (до перехода).
//  Параметры                    - Структура -
//    * ВыполнитьОбновлениеСВерсии   - Булево - по умолчанию Истина. Если установить Ложь,
//        то будут выполнена только обязательные обработчики обновления (с версией "*").
//    * ВерсияКонфигурации           - Строка - номер версии после перехода.
//        По умолчанию, равен значению версии конфигурации в свойствах метаданных.
//        Для того чтобы выполнить, например, все обработчики обновления с версии ПредыдущаяВерсияКонфигурации,
//        следует установить значение параметра в ПредыдущаяВерсияКонфигурации.
//        Для того чтобы выполнить вообще все обработчики обновления, установить значение "0.0.0.1".
//    * ОчиститьСведенияОПредыдущейКонфигурации - Булево - по умолчанию Истина.
//        Для случаев когда предыдущая конфигурация совпадает по имени с подсистемой текущей конфигурации, следует указать Ложь.
//
Процедура ПриЗавершенииПереходаСДругойПрограммы(Знач ПредыдущееИмяКонфигурации, Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПриЗавершенииПереходаСДругойПрограммы(ПредыдущееИмяКонфигурации, );
```
</details>

## ПриПодготовкеМакетаОписанияОбновлений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. описание в общем модуле ОбновлениеИнформационнойБазыБСП.
Процедура ПриПодготовкеМакетаОписанияОбновлений(Знач Макет) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПриПодготовкеМакетаОписанияОбновлений(Макет) 
```
</details>

## ПослеОбновленияИнформационнойБазы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. описание в общем модуле ОбновлениеИнформационнойБазыБСП.
Процедура ПослеОбновленияИнформационнойБазы(Знач ПредыдущаяВерсия, Знач ТекущаяВерсия, Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПослеОбновленияИнформационнойБазы(ПредыдущаяВерсия, ТекущаяВерсия, );
```
</details>

## ПервыйЗапуск
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает Истина если запуск информационной базы
// выполняется первый раз, иначе возвращает Ложь
//
Функция ПервыйЗапуск() Экспорт
```

Пример вызова
```bsl
Результат = ОбновлениеИнформационнойБазыЕХ.ПервыйЗапуск() 
```
</details>

## ЗадатьНастройкиДокументаПланЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьНастройкиДокументаПланЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ЗадатьНастройкиДокументаПланЗакупок() 
```
</details>

## ОбновлениеERPДоЕХ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновлениеERPДоЕХ() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновлениеERPДоЕХ() 
```
</details>

## ОбновитьОперацииФинансовыхИнструментов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьОперацииФинансовыхИнструментов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьОперацииФинансовыхИнструментов() 
```
</details>

## ЗаполнитьСуммуВзаиморасчетовВДвиженияБюджетированияПоПозициям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСуммуВзаиморасчетовВДвиженияБюджетированияПоПозициям() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ЗаполнитьСуммуВзаиморасчетовВДвиженияБюджетированияПоПозициям() 
```
</details>

## ЗаполнитьПредопределенныеСтатьиДДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


Процедура ЗаполнитьПредопределенныеСтатьиДДС() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ЗаполнитьПредопределенныеСтатьиДДС() 
```
</details>

## СформироватьВерсииСоглашений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СформироватьВерсииСоглашений() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.СформироватьВерсииСоглашений() 
```
</details>

## ДобавитьПараметрИнициаторПроцессаВШаблоны
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьПараметрИнициаторПроцессаВШаблоны() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ДобавитьПараметрИнициаторПроцессаВШаблоны() 
```
</details>

## УстановитьКонстантыЗаявокНаРасходованиеДенежныхСредств
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьКонстантыЗаявокНаРасходованиеДенежныхСредств() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.УстановитьКонстантыЗаявокНаРасходованиеДенежныхСредств() 
```
</details>

## ПерезаписатьМПБланки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПерезаписатьМПБланки() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПерезаписатьМПБланки() 
```
</details>

## ПодготовитьКэшСГруппировками
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПодготовитьКэшСГруппировками(ПолеТабличногоДокументаМакет,ОбъектАБ) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПодготовитьКэшСГруппировками(ПолеТабличногоДокументаМакет, ОбъектАБ));
```
</details>

## ОбновитьВидыСубконтоКорп
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьВидыСубконтоКорп() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьВидыСубконтоКорп() 
```
</details>

## ОбновитьШаблоныТрансформационныхКорректировок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьШаблоныТрансформационныхКорректировок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьШаблоныТрансформационныхКорректировок() 
```
</details>

## ОбновитьРеквизитыОрганизаций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьРеквизитыОрганизаций() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьРеквизитыОрганизаций() 
```
</details>

## ЗадатьНастройкиДокументаРаспоряжениеНаПеремещениеДенежныхСредств
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьНастройкиДокументаРаспоряжениеНаПеремещениеДенежныхСредств() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ЗадатьНастройкиДокументаРаспоряжениеНаПеремещениеДенежныхСредств() 
```
</details>

## ОбновитьПредопределенныеПрофили
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьПредопределенныеПрофили() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьПредопределенныеПрофили() 
```
</details>

## СброситьКонстантыКонтроляЛимитов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СброситьКонстантыКонтроляЛимитов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.СброситьКонстантыКонтроляЛимитов() 
```
</details>

## ОбновитьЗапросыИсточниковКорреспонденция
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьЗапросыИсточниковКорреспонденция() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьЗапросыИсточниковКорреспонденция() 
```
</details>

## ОбновитьПоляСоответствияДляОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьПоляСоответствияДляОбмена() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьПоляСоответствияДляОбмена() 
```
</details>

## ПеренестиДанныеШаблоновОповещений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиДанныеШаблоновОповещений() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПеренестиДанныеШаблоновОповещений() 
```
</details>

## ПеренестиШаблонОповещенийНастройкиОповещений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиШаблонОповещенийНастройкиОповещений() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПеренестиШаблонОповещенийНастройкиОповещений() 
```
</details>

## ПеренестиШаблонОповещенийСобытияОповещений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиШаблонОповещенийСобытияОповещений() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПеренестиШаблонОповещенийСобытияОповещений() 
```
</details>

## ПеренестиШаблонОповещенийШаблоныПроцессов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиШаблонОповещенийШаблоныПроцессов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПеренестиШаблонОповещенийШаблоныПроцессов() 
```
</details>

## УстановитьСуммуКонтрактаСПЗ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьСуммуКонтрактаСПЗ() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.УстановитьСуммуКонтрактаСПЗ() 
```
</details>

## ОбновитьРегламентыОтчетности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьРегламентыОтчетности() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьРегламентыОтчетности() 
```
</details>

## ЗаполнитьРежимыСценариев
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРежимыСценариев() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ЗаполнитьРежимыСценариев() 
```
</details>

## ОбновитьКодыПВХСубконтоКорп
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьКодыПВХСубконтоКорп(Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьКодыПВХСубконтоКорп(Параметры);
```
</details>

## ОбновитьСтавкиНдсЛота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСтавкиНдсЛота() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьСтавкиНдсЛота() 
```
</details>

## ОбновитьСтавкиНдсПредложенияПоставщика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСтавкиНдсПредложенияПоставщика() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьСтавкиНдсПредложенияПоставщика() 
```
</details>

## ОбновитьСтавкиНдсПротоколВыбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСтавкиНдсПротоколВыбора() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьСтавкиНдсПротоколВыбора() 
```
</details>

## ОбновитьСтавкиНдсСтрокиПланаЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСтавкиНдсСтрокиПланаЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьСтавкиНдсСтрокиПланаЗакупок() 
```
</details>

## ОбновитьСтавкиНдсПредложенияПоставщикаЭТП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСтавкиНдсПредложенияПоставщикаЭТП() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьСтавкиНдсПредложенияПоставщикаЭТП() 
```
</details>

## ОбновитьСтавкиНдсТоварныхКатегорий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСтавкиНдсТоварныхКатегорий() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьСтавкиНдсТоварныхКатегорий() 
```
</details>

## ОбновитьНдсВРегистреПотребностиВНоменклатуре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьНдсВРегистреПотребностиВНоменклатуре() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьНдсВРегистреПотребностиВНоменклатуре() 
```
</details>

## ОбновитьНдсВРегистреПоставщикиПоЛотам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьНдсВРегистреПоставщикиПоЛотам() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьНдсВРегистреПоставщикиПоЛотам() 
```
</details>

## ОбновитьНдсВРегистреПланПоставокПоДоговорам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьНдсВРегистреПланПоставокПоДоговорам() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьНдсВРегистреПланПоставокПоДоговорам() 
```
</details>

## УстановитьСпособАдресацииЭтапов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьСпособАдресацииЭтапов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.УстановитьСпособАдресацииЭтапов() 
```
</details>

## УстановитьВидЛотовойЗакупки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьВидЛотовойЗакупки(Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.УстановитьВидЛотовойЗакупки(Параметры);
```
</details>

## ДобавитьРолиПрофиляМенеджераЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьРолиПрофиляМенеджераЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ДобавитьРолиПрофиляМенеджераЗакупок() 
```
</details>

## ОбновитьТекстыЗапросовИсточниковДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьТекстыЗапросовИсточниковДанных() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьТекстыЗапросовИсточниковДанных() 
```
</details>

## ПерезаполнитьРеквизитЦФОСтруктураПредприятия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПерезаполнитьРеквизитЦФОСтруктураПредприятия() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПерезаполнитьРеквизитЦФОСтруктураПредприятия() 
```
</details>

## ЗаполнитьРеквизитыПрофильВНА
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРеквизитыПрофильВНА(Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ЗаполнитьРеквизитыПрофильВНА(Параметры);
```
</details>

## ОбновитьДанныеРегистраНастроекОбработкиОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьДанныеРегистраНастроекОбработкиОтчетов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьДанныеРегистраНастроекОбработкиОтчетов() 
```
</details>

## УстановитьРасширенныйАлгоритмПересчетаПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьРасширенныйАлгоритмПересчетаПоказателей() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.УстановитьРасширенныйАлгоритмПересчетаПоказателей() 
```
</details>

## ОбновлениеОрганизатораЗакупкиПротоколаВыбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновлениеОрганизатораЗакупкиПротоколаВыбора() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновлениеОрганизатораЗакупкиПротоколаВыбора() 
```
</details>

## УстановитьВалютуУчетаЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьВалютуУчетаЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.УстановитьВалютуУчетаЗакупок() 
```
</details>

## УстановитьАккредитациюПоставщиков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьАккредитациюПоставщиков() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.УстановитьАккредитациюПоставщиков() 
```
</details>

## ИсправитьЛокализациюСистемныхЗначений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ИсправитьЛокализациюСистемныхЗначений() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ИсправитьЛокализациюСистемныхЗначений() 
```
</details>

## ПодготовитьНастройкиТрансляцииПериодичность
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПодготовитьНастройкиТрансляцииПериодичность() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПодготовитьНастройкиТрансляцииПериодичность() 
```
</details>

## ПеренестиШаблоныОповещений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиШаблоныОповещений() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПеренестиШаблоныОповещений() 
```
</details>

## ОбновитьИзмерениеПользователи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьИзмерениеПользователи() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновитьИзмерениеПользователи() 
```
</details>

## ПерезаписатьСправочникиБДДляСогласования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПерезаписатьСправочникиБДДляСогласования() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПерезаписатьСправочникиБДДляСогласования() 
```
</details>

## ЗаполнитьКрайнююДатуВРазмещенияхЗаявок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьКрайнююДатуВРазмещенияхЗаявок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ЗаполнитьКрайнююДатуВРазмещенияхЗаявок() 
```
</details>

## ПолучитьНовогоПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьНовогоПользователя(ПользовательСтар) Экспорт
```

Пример вызова
```bsl
Результат = ОбновлениеИнформационнойБазыЕХ.ПолучитьНовогоПользователя(ПользовательСтар));
```
</details>

## ОбновлениеРегистровПоВалюте
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновлениеРегистровПоВалюте() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбновлениеРегистровПоВалюте() 
```
</details>

## УстановитьТипыАналитикВИсточникахДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьТипыАналитикВИсточникахДанных(Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.УстановитьТипыАналитикВИсточникахДанных(Параметры);
```
</details>

## ЗаполнитьИспользованиеРеквизитов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьИспользованиеРеквизитов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ЗаполнитьИспользованиеРеквизитов() 
```
</details>

## ОбработатьПредопределенныеИсточники
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбработатьПредопределенныеИсточники(Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ОбработатьПредопределенныеИсточники(Параметры);
```
</details>

## ЗадатьНастройкиСправочникаДоговорыАренды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьНастройкиСправочникаДоговорыАренды() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ЗадатьНастройкиСправочникаДоговорыАренды() 
```
</details>

## ЗадатьНастройкиДокументаЗаказКлиента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьНастройкиДокументаЗаказКлиента() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ЗадатьНастройкиДокументаЗаказКлиента() 
```
</details>

## ПерезаписатьЗадачиСогласования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПерезаписатьЗадачиСогласования() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ПерезаписатьЗадачиСогласования() 
```
</details>

## ЗаполнитьРеквизитыВводОстатковВзаиморасчетовПоАренде
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРеквизитыВводОстатковВзаиморасчетовПоАренде() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыЕХ.ЗаполнитьРеквизитыВводОстатковВзаиморасчетовПоАренде() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
