---
title: Обновление информационной базы служебный БМ
slug: erp-uh/обновление-информационной-базы-служебный-бм
---


## ДобавитьОбработчикОбновления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Добавляет новый обработчик заполнения и устанавливает его параметры.
//
// Параметры:
//	Обработчики - таблица обработчиков для добавления нового обработчика.
//		Переменная берется из одноименного аргумента функции
//		ПриДобавленииОбработчиковОбновления(Обработчики).
//	Версия - Строка - номер версии конфигурации, при обновлении на которую
//		должна быть вызвана процедура обновления, указанная в параметре
//		ИмяПроцедуры. В качестве версии можно указывать:
//			- Номер версии конфигурации в формате Р.П.В.С
//			  (Р – старший номер редакции; П – младший номер редакции;
//			   В – номер версии; С – номер сборки);
//			- если в качестве версии указан символ «*», то обработчик
//			  обновления должен выполняться каждый раз при обновлении
//			  информационной базы, независимо от номера версии конфигурации;
//			- если свойство Версия не задано, то должно быть установлено
//			  в Истина свойство НачальноеЗаполнение.
//	ИмяПроцедуры - Строка - полное имя экспортной процедуры, которая
//		будет вызвана для выполнения обновления.
//	НачальноеЗаполнение - Булево – если Истина, то процедура обновления
//		будет вызвана при первом запуске на пустой информационной базе
//		(версия «0.0.0.0»), созданной из файла поставки конфигурации
//		и не содержащей данных. Это обработчики первоначального
//		заполнения базы.
//	РежимВыполнения - Строка ("Монопольно", "Оперативно", "Отложенно").
//	ТолькоБМ - Булево - если Истина, то обработчик будет зарегистрирован
//		только для конфигурации БП МСФО. В противном случае, обработчик
//		будет зарегистрирован вне зависимости от типа конфигурации.
//	ДополнительныеПараметры - Структура|Неопределено - если передать
//		структуру, то поля обработчика будут заполнены в соотвествии
//		со значениями одноименных полей этой структуры.
//
// Возвращает:
//	Таблицу обработчиков с добавленным обработчиком.
//
Функция ДобавитьОбработчикОбновления( Экспорт
```

Пример вызова
```bsl
Результат = ОбновлениеИнформационнойБазыСлужебныйБМ.ДобавитьОбработчикОбновления();
```
</details>

## ЗаписатьДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Процедуры и функции для использования в обработчиках обновления.

// Записывает изменения в переданном объекте.
// Для использования в обработчиках обновления.
//
// Параметры:
//   Данные                            - Произвольный - объект, набор записей или менеджер константы, который
//                                                      необходимо записать.
//   РегистрироватьНаУзлахПлановОбмена - Булево       - включает регистрацию на узлах планов обмена при записи объекта.
//   ВключитьБизнесЛогику              - Булево       - включает бизнес-логику при записи объекта.
//
Процедура ЗаписатьДанные(Знач Данные, Знач РегистрироватьНаУзлахПлановОбмена = Ложь, Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыСлужебныйБМ.ЗаписатьДанные(Данные, РегистрироватьНаУзлахПлановОбмена, );
```
</details>

## ЗаписатьОбъект
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает изменения в переданном объекте ссылочного типа.
// Для использования в обработчиках обновления.
//
// Параметры:
//   Объект                            - Произвольный - записываемый объект ссылочного типа. Например, СправочникОбъект.
//   РегистрироватьНаУзлахПлановОбмена - Булево       - включает регистрацию на узлах планов обмена при записи объекта.
//   ВключитьБизнесЛогику              - Булево       - включает бизнес-логику при записи объекта.
//
Процедура ЗаписатьОбъект(Знач Объект, Знач РегистрироватьНаУзлахПлановОбмена = Неопределено, Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыСлужебныйБМ.ЗаписатьОбъект(Объект, РегистрироватьНаУзлахПлановОбмена, );
```
</details>

## ПровестиДокумент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПровестиДокумент(Данные, ТекстНачалаОшибки = "", ЗаписатьЕслиНеУдалосьПровести = Истина, ОтказЕслиНеПроведен = Ложь, ОтказЕслиНеЗаписан = Ложь) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыСлужебныйБМ.ПровестиДокумент(Данные, ТекстНачалаОшибки, ЗаписатьЕслиНеУдалосьПровести, ОтказЕслиНеПроведен, ОтказЕслиНеЗаписан);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
