---
title: Обновление информационной базы УХ
slug: erp-uh/обновление-информационной-базы-ух
---


## ПриДобавленииПодсистемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриДобавленииПодсистемы(Описание) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПриДобавленииПодсистемы(Описание) 
```
</details>

## ПриДобавленииОбработчиковОбновления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриДобавленииОбработчиковОбновления(Обработчики=Неопределено) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПриДобавленииОбработчиковОбновления(Обработчики);
```
</details>

## ПередОбновлениемИнформационнойБазы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПередОбновлениемИнформационнойБазы(Обработчики=Неопределено) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПередОбновлениемИнформационнойБазы(Обработчики);
```
</details>

## ПриОпределенииРежимаОбновленияДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет переопределить режим обновления данных информационной базы.
// Для использования в редких (нештатных) случаях перехода, не предусмотренных в
// стандартной процедуре определения режима обновления.
//
// Параметры:
//   РежимОбновленияДанных - Строка - в обработчике можно присвоить одно из значений:
//              "НачальноеЗаполнение"     - если это первый запуск пустой базы (области данных);
//              "ОбновлениеВерсии"        - если выполняется первый запуск после обновление конфигурации базы данных;
//              "ПереходСДругойПрограммы" - если выполняется первый запуск после обновление конфигурации базы данных,
//                                          в которой изменилось имя основной конфигурации.
//
//   СтандартнаяОбработка  - Булево - если присвоить Ложь, то стандартная процедура
//                                    определения режима обновления не выполняется,
//                                    а используется значение РежимОбновленияДанных.
//
Процедура ПриОпределенииРежимаОбновленияДанных(РежимОбновленияДанных, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПриОпределенииРежимаОбновленияДанных(РежимОбновленияДанных, СтандартнаяОбработка) 
```
</details>

## ПриДобавленииОбработчиковПереходаСДругойПрограммы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в список процедуры-обработчики перехода с другой программы (с другим именем конфигурации).
// Например, для перехода между разными, но родственными конфигурациями: базовая -> проф -> корп.
// Вызывается перед началом обновления данных ИБ.
//
//  Обработчики - ТаблицаЗначений - с колонками:
//    * ПредыдущееИмяКонфигурации - Строка - имя конфигурации, с которой выполняется переход;
//    * Процедура                 - Строка - полное имя процедуры-обработчика перехода с программы ПредыдущееИмяКонфигурации.
//                                  Например, "ОбновлениеИнформационнойБазыУПП.ЗаполнитьУчетнуюПолитику"
//                                  Обязательно должна быть экспортной.
//
// Пример добавления процедуры-обработчика в список:
//  Обработчик = Обработчики.Добавить();
//  Обработчик.ПредыдущееИмяКонфигурации  = "УправлениеТорговлей";
//  Обработчик.Процедура                  = "ОбновлениеИнформационнойБазыУПП.ЗаполнитьУчетнуюПолитику";
//
Процедура ПриДобавленииОбработчиковПереходаСДругойПрограммы(Обработчики) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПриДобавленииОбработчиковПереходаСДругойПрограммы(Обработчики) 
```
</details>

## ПриЗавершенииПереходаСДругойПрограммы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается после выполнения всех процедур-обработчиков перехода с другой программы (с другим именем конфигурации),
// и до начала выполнения обновления данных ИБ.
//
// Параметры:
//  ПредыдущееИмяКонфигурации    - Строка - имя конфигурации до перехода.
//  ПредыдущаяВерсияКонфигурации - Строка - имя предыдущей конфигурации (до перехода).
//  Параметры                    - Структура -
//    * ВыполнитьОбновлениеСВерсии   - Булево - по умолчанию Истина. Если установить Ложь,
//        то будут выполнена только обязательные обработчики обновления (с версией "*").
//    * ВерсияКонфигурации           - Строка - номер версии после перехода.
//        По умолчанию, равен значению версии конфигурации в свойствах метаданных.
//        Для того чтобы выполнить, например, все обработчики обновления с версии ПредыдущаяВерсияКонфигурации,
//        следует установить значение параметра в ПредыдущаяВерсияКонфигурации.
//        Для того чтобы выполнить вообще все обработчики обновления, установить значение "0.0.0.1".
//    * ОчиститьСведенияОПредыдущейКонфигурации - Булево - по умолчанию Истина.
//        Для случаев когда предыдущая конфигурация совпадает по имени с подсистемой текущей конфигурации, следует указать Ложь.
//
Процедура ПриЗавершенииПереходаСДругойПрограммы(Знач ПредыдущееИмяКонфигурации, Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПриЗавершенииПереходаСДругойПрограммы(ПредыдущееИмяКонфигурации, );
```
</details>

## ПриПодготовкеМакетаОписанияОбновлений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. описание в общем модуле ОбновлениеИнформационнойБазыБСП.
Процедура ПриПодготовкеМакетаОписанияОбновлений(Знач Макет) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПриПодготовкеМакетаОписанияОбновлений(Макет) 
```
</details>

## ПослеОбновленияИнформационнойБазы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. описание в общем модуле ОбновлениеИнформационнойБазыБСП.
Процедура ПослеОбновленияИнформационнойБазы(Знач ПредыдущаяВерсия, Знач ТекущаяВерсия, Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПослеОбновленияИнформационнойБазы(ПредыдущаяВерсия, ТекущаяВерсия, );
```
</details>

## ПервыйЗапуск
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
// Возвращает Истина если запуск информационной базы
// выполняется первый раз, иначе возвращает Ложь
//
Функция ПервыйЗапуск() Экспорт
```

Пример вызова
```bsl
Результат = ОбновлениеИнформационнойБазыУХ.ПервыйЗапуск() 
```
</details>

## ОбновитьИнформациюПоМетаданным
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьИнформациюПоМетаданным(Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьИнформациюПоМетаданным(Параметры);
```
</details>

## ОбновитьИсточникиДанныхДляТрансляции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьИсточникиДанныхДляТрансляции() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьИсточникиДанныхДляТрансляции() 
```
</details>

## УстановитьЗначениеПоМодулю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьЗначениеПоМодулю(ТекущееЗначение, ЕстьИзменение = Ложь) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьЗначениеПоМодулю(ТекущееЗначение, ЕстьИзменение);
```
</details>

## ОбновитьСправочникВерсииРегламентовПодготовкиОтчетности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСправочникВерсииРегламентовПодготовкиОтчетности() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьСправочникВерсииРегламентовПодготовкиОтчетности() 
```
</details>

## ПолучитьСоздатьКонтрагентаПоФизЛицу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьСоздатьКонтрагентаПоФизЛицу(ФизЛицо, КэшФизЛицоКонтрагент) Экспорт
```

Пример вызова
```bsl
Результат = ОбновлениеИнформационнойБазыУХ.ПолучитьСоздатьКонтрагентаПоФизЛицу(ФизЛицо, КэшФизЛицоКонтрагент));
```
</details>

## УстановитьПериодичностьБюджетирования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьПериодичностьБюджетирования() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьПериодичностьБюджетирования() 
```
</details>

## ЗаполнитьАтрибутыПроектовНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьАтрибутыПроектовНаСервере() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьАтрибутыПроектовНаСервере() 
```
</details>

## ПеренестиСостояниеОтчетовВРегистр
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиСостояниеОтчетовВРегистр() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПеренестиСостояниеОтчетовВРегистр() 
```
</details>

## УстановитьКонстантыАвтоматическогоПересчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьКонстантыАвтоматическогоПересчета() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьКонстантыАвтоматическогоПересчета() 
```
</details>

## ПроверитьУстановитьКонстантуПапкаСвязанныхФайлов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПроверитьУстановитьКонстантуПапкаСвязанныхФайлов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПроверитьУстановитьКонстантуПапкаСвязанныхФайлов() 
```
</details>

## ОбновитьПравилаРасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьПравилаРасчета() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьПравилаРасчета() 
```
</details>

## ОбновитьПравилаРасчетаПолеДругогоИсточника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьПравилаРасчетаПолеДругогоИсточника() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьПравилаРасчетаПолеДругогоИсточника() 
```
</details>

## УстановитьПроизводственныйКалендарьПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьПроизводственныйКалендарьПоУмолчанию() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьПроизводственныйКалендарьПоУмолчанию() 
```
</details>

## ЗаполнитьПроектыПредшественникиНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьПроектыПредшественникиНаСервере() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьПроектыПредшественникиНаСервере() 
```
</details>

## УстановитьПризнакиПроекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьПризнакиПроекта() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьПризнакиПроекта() 
```
</details>

## ОбновитьФИ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьФИ() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьФИ() 
```
</details>

## ПереименоватьРеквизитПревышенияБюджетовВУсловииСогласования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПереименоватьРеквизитПревышенияБюджетовВУсловииСогласования(КоллекцияСтрокДерева) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПереименоватьРеквизитПревышенияБюджетовВУсловииСогласования(КоллекцияСтрокДерева) 
```
</details>

## ЗаполнитьОпцииОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьОпцииОтчетов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьОпцииОтчетов() 
```
</details>

## ОбновитьПараметрыУчетаФИ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьПараметрыУчетаФИ() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьПараметрыУчетаФИ() 
```
</details>

## ПеренестиДополнительныеНаименования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиДополнительныеНаименования() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПеренестиДополнительныеНаименования() 
```
</details>

## ПеренестиВидыВременныхРазниц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиВидыВременныхРазниц() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПеренестиВидыВременныхРазниц() 
```
</details>

## ЗаписатьНормализованныеКодыПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаписатьНормализованныеКодыПоказателей() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаписатьНормализованныеКодыПоказателей() 
```
</details>

## ЗаписатьНормализованныеКодыСтрокКолонок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаписатьНормализованныеКодыСтрокКолонок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаписатьНормализованныеКодыСтрокКолонок() 
```
</details>

## ОбновитьПараметрыУчетаПереоценкиФИ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьПараметрыУчетаПереоценкиФИ() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьПараметрыУчетаПереоценкиФИ() 
```
</details>

## ОбновитьРеквизитКонтрагентФИ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьРеквизитКонтрагентФИ() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьРеквизитКонтрагентФИ() 
```
</details>

## УстановитьКоэффициентыЛиквидности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьКоэффициентыЛиквидности() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьКоэффициентыЛиквидности() 
```
</details>

## ПеренестиПериодическиеКурсыВРегистрСведений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиПериодическиеКурсыВРегистрСведений() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПеренестиПериодическиеКурсыВРегистрСведений() 
```
</details>

## УдалитьНеиспользуемуюПодсистемуУХ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УдалитьНеиспользуемуюПодсистемуУХ() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УдалитьНеиспользуемуюПодсистемуУХ() 
```
</details>

## УстановитьПериодичностьЦентрализованныхЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьПериодичностьЦентрализованныхЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьПериодичностьЦентрализованныхЗакупок() 
```
</details>

## ЗаполнитьРеквизитыОписанияВерсий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРеквизитыОписанияВерсий() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьРеквизитыОписанияВерсий() 
```
</details>

## ПроверитьСвернутьВерсииЗначенийПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПроверитьСвернутьВерсииЗначенийПоказателей() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПроверитьСвернутьВерсииЗначенийПоказателей() 
```
</details>

## ОбновлениеПравилРасчетаВнутренниеДанныеПоказатель
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновлениеПравилРасчетаВнутренниеДанныеПоказатель() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновлениеПравилРасчетаВнутренниеДанныеПоказатель() 
```
</details>

## ЗарегистрироватьЛотыПоЧерновикамИзПлановЗакупки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗарегистрироватьЛотыПоЧерновикамИзПлановЗакупки() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗарегистрироватьЛотыПоЧерновикамИзПлановЗакупки() 
```
</details>

## ИзменитьРазделителиПутей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ИзменитьРазделителиПутей() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ИзменитьРазделителиПутей() 
```
</details>

## ПересчитатьИтоговуюСуммуКонсолидированныхПлановПотребностей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПересчитатьИтоговуюСуммуКонсолидированныхПлановПотребностей() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПересчитатьИтоговуюСуммуКонсолидированныхПлановПотребностей() 
```
</details>

## ЗаполнитьТипыЗначенийЭлементовСтруктурыОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьТипыЗначенийЭлементовСтруктурыОтчета() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьТипыЗначенийЭлементовСтруктурыОтчета() 
```
</details>

## УстановитьТипЗначения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьТипЗначения(ЭлементНастройки) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьТипЗначения(ЭлементНастройки));
```
</details>

## УстановитьКонстантуИспользоватьУправлениеЦентрализованнымиЗакупками
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьКонстантуИспользоватьУправлениеЦентрализованнымиЗакупками() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьКонстантуИспользоватьУправлениеЦентрализованнымиЗакупками() 
```
</details>

## ЗаполнитьСтатусыЕИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСтатусыЕИС() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьСтатусыЕИС() 
```
</details>

## СвязатьИсточникиСАналитическимиОтчетами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СвязатьИсточникиСАналитическимиОтчетами() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.СвязатьИсточникиСАналитическимиОтчетами() 
```
</details>

## ЗаполнитьСтатусыЭтапов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСтатусыЭтапов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьСтатусыЭтапов() 
```
</details>

## УстановитьСтатусЧерновикВДоговоре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьСтатусЧерновикВДоговоре() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьСтатусЧерновикВДоговоре() 
```
</details>

## ЗаполнитьРеквизитыВУсловияхОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРеквизитыВУсловияхОплаты() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьРеквизитыВУсловияхОплаты() 
```
</details>

## УстановитьСостоянияИнвестиций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьСостоянияИнвестиций() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьСостоянияИнвестиций() 
```
</details>

## УстановитьВидыДоговоровУХ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьВидыДоговоровУХ() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьВидыДоговоровУХ() 
```
</details>

## ЗаполнитьДатуЗакрытияПаспортовСделок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьДатуЗакрытияПаспортовСделок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьДатуЗакрытияПаспортовСделок() 
```
</details>

## ЗаполнитьИнтервалыЗадолженностейДляКазначейства
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьИнтервалыЗадолженностейДляКазначейства() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьИнтервалыЗадолженностейДляКазначейства() 
```
</details>

## ЗаполнитьГеографическиеПризнакиНалоговогоОсвобожденияКИК
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьГеографическиеПризнакиНалоговогоОсвобожденияКИК() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьГеографическиеПризнакиНалоговогоОсвобожденияКИК() 
```
</details>

## УстановитьКонстантыСрокаОжиданияПоВалютномуКонтролю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьКонстантыСрокаОжиданияПоВалютномуКонтролю() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьКонстантыСрокаОжиданияПоВалютномуКонтролю() 
```
</details>

## ОбновитьСвойстваДокументовПериодСценария
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСвойстваДокументовПериодСценария() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьСвойстваДокументовПериодСценария() 
```
</details>

## СоздатьРакурсыПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьРакурсыПоУмолчанию() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.СоздатьРакурсыПоУмолчанию() 
```
</details>

## ЗаполнитьКатегориюОповещений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьКатегориюОповещений(Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьКатегориюОповещений(Параметры);
```
</details>

## ЗаполнитьПредставлениеДляВнешнегоПоставщикаОтраженияФакта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьПредставлениеДляВнешнегоПоставщикаОтраженияФакта() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьПредставлениеДляВнешнегоПоставщикаОтраженияФакта() 
```
</details>

## ЗаполнитьКонстантуСценарияМСФО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьКонстантуСценарияМСФО() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьКонстантуСценарияМСФО() 
```
</details>

## УстановитьМетодыОценкиЛотов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьМетодыОценкиЛотов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьМетодыОценкиЛотов() 
```
</details>

## ДобавитьВидСвязиСпецификация
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьВидСвязиСпецификация() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ДобавитьВидСвязиСпецификация() 
```
</details>

## УстановитьФлагДопущенКУчастиюПредложенийПоставщиков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьФлагДопущенКУчастиюПредложенийПоставщиков() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьФлагДопущенКУчастиюПредложенийПоставщиков() 
```
</details>

## ОбновитьЗначенияБалльныхКритериев
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьЗначенияБалльныхКритериев() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьЗначенияБалльныхКритериев() 
```
</details>

## ОбновитьДанныеОтчетныхПериодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура  ОбновитьДанныеОтчетныхПериодов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьДанныеОтчетныхПериодов() 
```
</details>

## ЗаполнитьРеквизитыРазделенияСогласования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРеквизитыРазделенияСогласования() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьРеквизитыРазделенияСогласования() 
```
</details>

## ЗаполнитьКонстантуСценарияКИК
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьКонстантуСценарияКИК() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьКонстантуСценарияКИК() 
```
</details>

## ЗаполнитьОбъектыДляСогласования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьОбъектыДляСогласования() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьОбъектыДляСогласования() 
```
</details>

## ОбновитьСценарии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСценарии() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьСценарии() 
```
</details>

## ОбновитьСценарииБезСвязанныхДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСценарииБезСвязанныхДанных() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьСценарииБезСвязанныхДанных() 
```
</details>

## ЗаполнитьКатегорииЗакупокПоДаннымПостановленияОт20160802
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьКатегорииЗакупокПоДаннымПостановленияОт20160802() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьКатегорииЗакупокПоДаннымПостановленияОт20160802() 
```
</details>

## УстановитьОсновныеБланки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьОсновныеБланки() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьОсновныеБланки() 
```
</details>

## ОбновитьДанныеОтчетныхПериодовПоПлану
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьДанныеОтчетныхПериодовПоПлану() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьДанныеОтчетныхПериодовПоПлану() 
```
</details>

## ОбновитьВалютыОтчетностиРегламентов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьВалютыОтчетностиРегламентов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьВалютыОтчетностиРегламентов() 
```
</details>

## ОбновитьКонтрагентовСвязанныхСОрганизациямиЦФО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьКонтрагентовСвязанныхСОрганизациямиЦФО() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьКонтрагентовСвязанныхСОрганизациямиЦФО() 
```
</details>

## СкорректироватьЭффективныеДоли
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СкорректироватьЭффективныеДоли() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.СкорректироватьЭффективныеДоли() 
```
</details>

## ОбновитьДанныеВидовУведомленийКИК
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьДанныеВидовУведомленийКИК() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьДанныеВидовУведомленийКИК() 
```
</details>

## УстановитьМетодСписанияЗадолженностиВДепозитах
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьМетодСписанияЗадолженностиВДепозитах() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьМетодСписанияЗадолженностиВДепозитах() 
```
</details>

## ОбновитьФлагиОтраженияВУчетеДляИнвестиций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьФлагиОтраженияВУчетеДляИнвестиций() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьФлагиОтраженияВУчетеДляИнвестиций() 
```
</details>

## ЗаполнитьКатегорииЗакупокПоДаннымПостановленияОт20161214
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьКатегорииЗакупокПоДаннымПостановленияОт20161214() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьКатегорииЗакупокПоДаннымПостановленияОт20161214() 
```
</details>

## ЗаполнитьКатегорииЗакупокДляОтчетаОбъемЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьКатегорииЗакупокДляОтчетаОбъемЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьКатегорииЗакупокДляОтчетаОбъемЗакупок() 
```
</details>

## ЗаписатьВариантыЗаполненияШаблонов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаписатьВариантыЗаполненияШаблонов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаписатьВариантыЗаполненияШаблонов() 
```
</details>

## УстановитьКонстантыАвтоматическогоФормированияОФД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьКонстантыАвтоматическогоФормированияОФД() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьКонстантыАвтоматическогоФормированияОФД() 
```
</details>

## ДобавитьМастерОрганизациюВСчетаПула
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьМастерОрганизациюВСчетаПула() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ДобавитьМастерОрганизациюВСчетаПула() 
```
</details>

## ЗаполнитьСуммуВалютуВзаиморасчетовОтраженияФактическихДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСуммуВалютуВзаиморасчетовОтраженияФактическихДанных() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьСуммуВалютуВзаиморасчетовОтраженияФактическихДанных() 
```
</details>

## ЗаполнитьРольКонтрагентаВМатрицеУсловий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРольКонтрагентаВМатрицеУсловий() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьРольКонтрагентаВМатрицеУсловий() 
```
</details>

## ЗаполнитьРолиКонтрагентовВДокументеУстановкаКлассов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРолиКонтрагентовВДокументеУстановкаКлассов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьРолиКонтрагентовВДокументеУстановкаКлассов() 
```
</details>

## ОбновитьСлужебныеРеквизитыУсловийОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСлужебныеРеквизитыУсловийОплаты() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьСлужебныеРеквизитыУсловийОплаты() 
```
</details>

## ЗаполнитьФиксированныеСчетаУчетаПоДокументам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьФиксированныеСчетаУчетаПоДокументам() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьФиксированныеСчетаУчетаПоДокументам() 
```
</details>

## ПеренестиСтавкуДисконтированияВРегистр
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиСтавкуДисконтированияВРегистр() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПеренестиСтавкуДисконтированияВРегистр() 
```
</details>

## ЗакрытьРегистрыБюджетированияПоФакту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗакрытьРегистрыБюджетированияПоФакту() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗакрытьРегистрыБюджетированияПоФакту() 
```
</details>

## УстановитьРеквизитДопУпорядочиванияПриоритетыПлатежей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьРеквизитДопУпорядочиванияПриоритетыПлатежей() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьРеквизитДопУпорядочиванияПриоритетыПлатежей() 
```
</details>

## ПроставитьНомерАналитикиЭтапаПроекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПроставитьНомерАналитикиЭтапаПроекта() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПроставитьНомерАналитикиЭтапаПроекта() 
```
</details>

## ПеренестиПериодСортировкиИсторииСогласования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиПериодСортировкиИсторииСогласования() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПеренестиПериодСортировкиИсторииСогласования() 
```
</details>

## ЗаполнитьПолеКонтрагентПлательщикВЗаявках
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьПолеКонтрагентПлательщикВЗаявках() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьПолеКонтрагентПлательщикВЗаявках() 
```
</details>

## ОбновитьНомерКорректировки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьНомерКорректировки(ИмяДокумента) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьНомерКорректировки(ИмяДокумента));
```
</details>

## ОбновитьНомераКорректировокВСправкахВалютногоКонтроля
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьНомераКорректировокВСправкахВалютногоКонтроля() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьНомераКорректировокВСправкахВалютногоКонтроля() 
```
</details>

## ПеренестиВерсииХранимыхФайловВПрисоединенныеФайлы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиВерсииХранимыхФайловВПрисоединенныеФайлы() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПеренестиВерсииХранимыхФайловВПрисоединенныеФайлы() 
```
</details>

## ВыставитьКатегорииЭтаповПодготовкиОтчетности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВыставитьКатегорииЭтаповПодготовкиОтчетности() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ВыставитьКатегорииЭтаповПодготовкиОтчетности() 
```
</details>

## ПеренестиРасшифровкиОбъектомКонфигурации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиРасшифровкиОбъектомКонфигурации() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПеренестиРасшифровкиОбъектомКонфигурации() 
```
</details>

## ЗаполнитьТЧТехническихСчетовШаблоновСверкиВГО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьТЧТехническихСчетовШаблоновСверкиВГО() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьТЧТехническихСчетовШаблоновСверкиВГО() 
```
</details>

## ОбновитьСвойстваКолонокБланковСТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСвойстваКолонокБланковСТ() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьСвойстваКолонокБланковСТ() 
```
</details>

## ОбновитьПрофилиПользователейБП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьПрофилиПользователейБП() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьПрофилиПользователейБП() 
```
</details>

## УстановитьКонстантуПериодХраненияСобытий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьКонстантуПериодХраненияСобытий() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьКонстантуПериодХраненияСобытий() 
```
</details>

## УстановитьИспользованиеЦентрализованныхЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьИспользованиеЦентрализованныхЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьИспользованиеЦентрализованныхЗакупок() 
```
</details>

## УбратьРеквизитШаблонРучныхКорректировок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УбратьРеквизитШаблонРучныхКорректировок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УбратьРеквизитШаблонРучныхКорректировок() 
```
</details>

## ЗаполнитьКонстантуСуперпользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьКонстантуСуперпользователя() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьКонстантуСуперпользователя() 
```
</details>

## УстановитьВариантМасштабаАвто
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьВариантМасштабаАвто() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьВариантМасштабаАвто() 
```
</details>

## УстановитьПризнакУправлениеХолдингом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьПризнакУправлениеХолдингом() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьПризнакУправлениеХолдингом() 
```
</details>

## УстановитьПризнакИспользованияИнтеграцииСВнешнимиСистемами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьПризнакИспользованияИнтеграцииСВнешнимиСистемами() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьПризнакИспользованияИнтеграцииСВнешнимиСистемами() 
```
</details>

## СнятьПометкуУдаленияСБывшегоПредопределенногоЭлемента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СнятьПометкуУдаленияСБывшегоПредопределенногоЭлемента() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.СнятьПометкуУдаленияСБывшегоПредопределенногоЭлемента() 
```
</details>

## УбратьПутьОбъектВНА
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УбратьПутьОбъектВНА() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УбратьПутьОбъектВНА() 
```
</details>

## ЗаполнитьРеквизитыОбъектовВНА
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРеквизитыОбъектовВНА() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьРеквизитыОбъектовВНА() 
```
</details>

## ПеренестиДвиженияЗакрытияПериодаНаДокументыТУ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиДвиженияЗакрытияПериодаНаДокументыТУ() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПеренестиДвиженияЗакрытияПериодаНаДокументыТУ() 
```
</details>

## ПеренестиРеклассыРБП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиРеклассыРБП() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПеренестиРеклассыРБП() 
```
</details>

## ЗаполнитьПериодОтчетаНачисленияАмортизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьПериодОтчетаНачисленияАмортизации() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьПериодОтчетаНачисленияАмортизации() 
```
</details>

## УстановитьОрганизациюРезервированияПоЦФО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьОрганизациюРезервированияПоЦФО() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьОрганизациюРезервированияПоЦФО() 
```
</details>

## ЗаполнитьШаблонКорректировкаРазмещенияПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьШаблонКорректировкаРазмещенияПоУмолчанию() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьШаблонКорректировкаРазмещенияПоУмолчанию() 
```
</details>

## ЗаполнитьНекорректнуюВалютуОплатыВКонвертации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьНекорректнуюВалютуОплатыВКонвертации() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьНекорректнуюВалютуОплатыВКонвертации() 
```
</details>

## ОбновитьИменаАналитикИРесурсовСверкиВГО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьИменаАналитикИРесурсовСверкиВГО() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьИменаАналитикИРесурсовСверкиВГО() 
```
</details>

## ЗаписатьКатегорииОповещений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаписатьКатегорииОповещений() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаписатьКатегорииОповещений() 
```
</details>

## ОбновитьКонстантуНалоговоеПланированиеИнвестиций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьКонстантуНалоговоеПланированиеИнвестиций() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьКонстантуНалоговоеПланированиеИнвестиций() 
```
</details>

## ЗаполнитьОрганизациюКонтрагентаРасчетыСКонтрагентамиГрафики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьОрганизациюКонтрагентаРасчетыСКонтрагентамиГрафики() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьОрганизациюКонтрагентаРасчетыСКонтрагентамиГрафики() 
```
</details>

## ЗаполнитьОрганизациюКонтрагентаРасчетыПоФинансовымИнструментамФакт
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьОрганизациюКонтрагентаРасчетыПоФинансовымИнструментамФакт() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьОрганизациюКонтрагентаРасчетыПоФинансовымИнструментамФакт() 
```
</details>

## УстановитьПризнакиБюджетовВОтраженииФактическихДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьПризнакиБюджетовВОтраженииФактическихДанных() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьПризнакиБюджетовВОтраженииФактическихДанных() 
```
</details>

## ЗаполнитьРегистрРасчетыСКонтрагентамиФактДаннымиКоммерческихДоговоров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРегистрРасчетыСКонтрагентамиФактДаннымиКоммерческихДоговоров() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьРегистрРасчетыСКонтрагентамиФактДаннымиКоммерческихДоговоров() 
```
</details>

## УстановитьИспользуемыеВПроцессахДокументы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьИспользуемыеВПроцессахДокументы() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьИспользуемыеВПроцессахДокументы() 
```
</details>

## УстановитьУИДЛотовНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьУИДЛотовНаСервере() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьУИДЛотовНаСервере() 
```
</details>

## ОбновитьПоляСоответствия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьПоляСоответствия() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьПоляСоответствия() 
```
</details>

## УдалитьДублиОписанийТабличныхЧастей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УдалитьДублиОписанийТабличныхЧастей() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УдалитьДублиОписанийТабличныхЧастей() 
```
</details>

## ЗаполнитьОписанияОбъектовТек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьОписанияОбъектовТек() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьОписанияОбъектовТек() 
```
</details>

## ОбновитьНаименованиеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьНаименованиеТЧ() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьНаименованиеТЧ() 
```
</details>

## ОбновлениеНастроекЭкземпляровОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновлениеНастроекЭкземпляровОтчетов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновлениеНастроекЭкземпляровОтчетов() 
```
</details>

## ВернутьСвязанныйУОП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ВернутьСвязанныйУОП(ЭоСсылка) Экспорт
```

Пример вызова
```bsl
Результат = ОбновлениеИнформационнойБазыУХ.ВернутьСвязанныйУОП(ЭоСсылка));
```
</details>

## ПеренестиИнициативыВМероприятия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиИнициативыВМероприятия() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПеренестиИнициативыВМероприятия() 
```
</details>

## ЗадатьНастройкиДокументаИнцидент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьНастройкиДокументаИнцидент() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗадатьНастройкиДокументаИнцидент() 
```
</details>

## ЗадатьНастройкиДокументаМероприятие
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьНастройкиДокументаМероприятие() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗадатьНастройкиДокументаМероприятие() 
```
</details>

## ЗадатьНастройкиСправочникаРиски
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьНастройкиСправочникаРиски() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗадатьНастройкиСправочникаРиски() 
```
</details>

## ПометитьПредопределенныеЛотыКакСкрытыйНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПометитьПредопределенныеЛотыКакСкрытыйНаСервере() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПометитьПредопределенныеЛотыКакСкрытыйНаСервере() 
```
</details>

## СоздатьЗакупочныеКомпанииИСтрокиПлановЗакупкиЛотов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьЗакупочныеКомпанииИСтрокиПлановЗакупкиЛотов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.СоздатьЗакупочныеКомпанииИСтрокиПлановЗакупкиЛотов() 
```
</details>

## СоздатьЗакупочнуюПроцедуруПоЛоту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СоздатьЗакупочнуюПроцедуруПоЛоту(ЛотОбъект, РеквизитыПеремещеныВЗакупку) Экспорт
```

Пример вызова
```bsl
Результат = ОбновлениеИнформационнойБазыУХ.СоздатьЗакупочнуюПроцедуруПоЛоту(ЛотОбъект, РеквизитыПеремещеныВЗакупку));
```
</details>

## СоздатьСтрокуПланаПоЛоту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СоздатьСтрокуПланаПоЛоту(ЛотОбъект, Экспорт
```

Пример вызова
```bsl
Результат = ОбновлениеИнформационнойБазыУХ.СоздатьСтрокуПланаПоЛоту(ЛотОбъект, );
```
</details>

## ПолучитьВыборкуДляЗаписиОбеспеченияПоСтрокеПланаЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьВыборкуДляЗаписиОбеспеченияПоСтрокеПланаЗакупок(Лот, СтрокаПланаОбъект) Экспорт
```

Пример вызова
```bsl
Результат = ОбновлениеИнформационнойБазыУХ.ПолучитьВыборкуДляЗаписиОбеспеченияПоСтрокеПланаЗакупок(Лот, СтрокаПланаОбъект));
```
</details>

## ЗаполнитьУдаленнымиРеквизитами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьУдаленнымиРеквизитами(Приемник, Источник, ИменаРеквизитов) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьУдаленнымиРеквизитами(Приемник, Источник, ИменаРеквизитов));
```
</details>

## ОбновитьРегистрЗаказыПоставщикам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьРегистрЗаказыПоставщикам() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьРегистрЗаказыПоставщикам() 
```
</details>

## ЗаписатьПредложенияПоставщиковВРегистры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаписатьПредложенияПоставщиковВРегистры() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаписатьПредложенияПоставщиковВРегистры() 
```
</details>

## ЗаписатьУсловияПоставокНоменклатурыВРегистры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаписатьУсловияПоставокНоменклатурыВРегистры() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаписатьУсловияПоставокНоменклатурыВРегистры() 
```
</details>

## ЗаполнитьТЧНоменклатураДоговоров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьТЧНоменклатураДоговоров() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьТЧНоменклатураДоговоров() 
```
</details>

## ЗаписатьТЧНоменклатураВерсииСоглашения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаписатьТЧНоменклатураВерсииСоглашения(ВерсияСоглашения, Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаписатьТЧНоменклатураВерсииСоглашения(ВерсияСоглашения, );
```
</details>

## ЗаписатьРегистрСведенийДоговорыПоЗакупочнымПроцедурам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаписатьРегистрСведенийДоговорыПоЗакупочнымПроцедурам( Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаписатьРегистрСведенийДоговорыПоЗакупочнымПроцедурам();
```
</details>

## ЗаполнитьЗакупочнуюПроцедуруРСДоговорыПоЗакупочнымПроцедурам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьЗакупочнуюПроцедуруРСДоговорыПоЗакупочнымПроцедурам() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьЗакупочнуюПроцедуруРСДоговорыПоЗакупочнымПроцедурам() 
```
</details>

## ЗаполнитьЗакупочнуюПроцедуруРСУчастникиКвалификации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьЗакупочнуюПроцедуруРСУчастникиКвалификации() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьЗакупочнуюПроцедуруРСУчастникиКвалификации() 
```
</details>

## ЗаполнитьЗакупочнуюПроцедуруРСУчастникиКвалифицированныеПоЛоту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьЗакупочнуюПроцедуруРСУчастникиКвалифицированныеПоЛоту() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьЗакупочнуюПроцедуруРСУчастникиКвалифицированныеПоЛоту() 
```
</details>

## ЗаполнитьРСЛотыПланаЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРСЛотыПланаЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьРСЛотыПланаЗакупок() 
```
</details>

## ОбновитьПротоколВыбораПобедителей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьПротоколВыбораПобедителей() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьПротоколВыбораПобедителей() 
```
</details>

## СоздатьДокументыВыборПобедителейЛотов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьДокументыВыборПобедителейЛотов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.СоздатьДокументыВыборПобедителейЛотов() 
```
</details>

## ЗадатьНастройкиДокументаПротоколВскрытияКонвертов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьНастройкиДокументаПротоколВскрытияКонвертов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗадатьНастройкиДокументаПротоколВскрытияКонвертов() 
```
</details>

## ЗадатьНастройкиДокументаПротоколРассмотренияЗаявок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьНастройкиДокументаПротоколРассмотренияЗаявок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗадатьНастройкиДокументаПротоколРассмотренияЗаявок() 
```
</details>

## ЗадатьНастройкиДокументаПротоколВыбораПобедителей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьНастройкиДокументаПротоколВыбораПобедителей() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗадатьНастройкиДокументаПротоколВыбораПобедителей() 
```
</details>

## УстановитьНомерВГПЗСтрокПланаЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьНомерВГПЗСтрокПланаЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьНомерВГПЗСтрокПланаЗакупок() 
```
</details>

## УстановитьНомерСтрокПланаЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьНомерСтрокПланаЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьНомерСтрокПланаЗакупок() 
```
</details>

## УстановитьЗакупочнуюПроцедуруВДокументах
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьЗакупочнуюПроцедуруВДокументах() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьЗакупочнуюПроцедуруВДокументах() 
```
</details>

## ЗадатьНастройкиСправочникаЗакупочныеПроцедуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьНастройкиСправочникаЗакупочныеПроцедуры() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗадатьНастройкиСправочникаЗакупочныеПроцедуры() 
```
</details>

## ОчиститьДвиженияПланаОбеспеченияРамочныхДоговров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОчиститьДвиженияПланаОбеспеченияРамочныхДоговров() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОчиститьДвиженияПланаОбеспеченияРамочныхДоговров() 
```
</details>

## ЗаполнитьИдентификаторыСтрокПланаЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьИдентификаторыСтрокПланаЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьИдентификаторыСтрокПланаЗакупок() 
```
</details>

## ИсправитьИдентификаторыВерсийСтрокПланаЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ИсправитьИдентификаторыВерсийСтрокПланаЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ИсправитьИдентификаторыВерсийСтрокПланаЗакупок() 
```
</details>

## ОбнулитьНомераВГПЗКопийСтрокПланаЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбнулитьНомераВГПЗКопийСтрокПланаЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбнулитьНомераВГПЗКопийСтрокПланаЗакупок() 
```
</details>

## УстановитьКонстантуУровеньКонтроляПравилНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьКонстантуУровеньКонтроляПравилНоменклатуры() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьКонстантуУровеньКонтроляПравилНоменклатуры() 
```
</details>

## ОбновитьНастройкиЗаполненияОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьНастройкиЗаполненияОтчетов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьНастройкиЗаполненияОтчетов() 
```
</details>

## УстановитьЦенаВключаетНДСДоговора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьЦенаВключаетНДСДоговора() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьЦенаВключаетНДСДоговора() 
```
</details>

## УстановитьОбязательнымиВложенияСтадийКонкурса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьОбязательнымиВложенияСтадийКонкурса() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьОбязательнымиВложенияСтадийКонкурса() 
```
</details>

## ЗаполнитьВерсииЕИСДляСтрокПланаЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьВерсииЕИСДляСтрокПланаЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьВерсииЕИСДляСтрокПланаЗакупок() 
```
</details>

## ЗаписатьВерсиюСтрокиПланаДляЕИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаписатьВерсиюСтрокиПланаДляЕИС(НаборЗаписей, ВыборкаЗаписей) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаписатьВерсиюСтрокиПланаДляЕИС(НаборЗаписей, ВыборкаЗаписей));
```
</details>

## УстановитьУИД_ЕИССтрокиПлана
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьУИД_ЕИССтрокиПлана(СтрокаПлана, УИД_ЕИС) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьУИД_ЕИССтрокиПлана(СтрокаПлана, УИД_ЕИС));
```
</details>

## ЗаполнитьРеквизитЗакупочнаяПроцедураЛота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРеквизитЗакупочнаяПроцедураЛота() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьРеквизитЗакупочнаяПроцедураЛота() 
```
</details>

## ОбновитьДокументыУОП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьДокументыУОП() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьДокументыУОП() 
```
</details>

## ОбновитьМПБланки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьМПБланки() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьМПБланки() 
```
</details>

## ЗаполнитьНомерЛотаВЗакупочнойПроцедуреНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьНомерЛотаВЗакупочнойПроцедуреНаСервере() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьНомерЛотаВЗакупочнойПроцедуреНаСервере() 
```
</details>

## ПеренестиМеждународныеАдресаВНовыеРеквизиты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиМеждународныеАдресаВНовыеРеквизиты() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПеренестиМеждународныеАдресаВНовыеРеквизиты() 
```
</details>

## ОбработатьСтрокуШаблонаЗаголовкаАналитики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОбработатьСтрокуШаблонаЗаголовкаАналитики(ИсходнаяСтрока) Экспорт
```

Пример вызова
```bsl
Результат = ОбновлениеИнформационнойБазыУХ.ОбработатьСтрокуШаблонаЗаголовкаАналитики(ИсходнаяСтрока));
```
</details>

## ОбновитьКонстантыДополнительныеЯзыки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьКонстантыДополнительныеЯзыки() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьКонстантыДополнительныеЯзыки() 
```
</details>

## ВыставитьСостоянияИТрендыАналитическойРассылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВыставитьСостоянияИТрендыАналитическойРассылки() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ВыставитьСостоянияИТрендыАналитическойРассылки() 
```
</details>

## УстановитьСогласованиеДокументПротоколОтмены
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьСогласованиеДокументПротоколОтмены() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьСогласованиеДокументПротоколОтмены() 
```
</details>

## ЗаполнитьДоступныеФормыСхемРеквизитов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьДоступныеФормыСхемРеквизитов() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьДоступныеФормыСхемРеквизитов() 
```
</details>

## ВыставитьКодыСпособовЗакупки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВыставитьКодыСпособовЗакупки() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ВыставитьКодыСпособовЗакупки() 
```
</details>

## ПерезаписатьМПБланки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПерезаписатьМПБланки() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПерезаписатьМПБланки() 
```
</details>

## ЗаполнитьСтрокиАдресаМестПоставки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСтрокиАдресаМестПоставки() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьСтрокиАдресаМестПоставки() 
```
</details>

## ЗаполнитьСтрокиАдресаАнкетПоставщиков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСтрокиАдресаАнкетПоставщиков() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьСтрокиАдресаАнкетПоставщиков() 
```
</details>

## ЗадатьНастройкиДокументаЗаказПоставщику
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьНастройкиДокументаЗаказПоставщику() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗадатьНастройкиДокументаЗаказПоставщику() 
```
</details>

## ПерезаполнитьСторноПланаПоставокВДоговорах
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПерезаполнитьСторноПланаПоставокВДоговорах() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПерезаполнитьСторноПланаПоставокВДоговорах() 
```
</details>

## ПроверкаСтандартныхПериодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПроверкаСтандартныхПериодов(Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПроверкаСтандартныхПериодов(Параметры);
```
</details>

## УстановитьКонстантуАктуализироватьЗаявкиПоГрафикам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьКонстантуАктуализироватьЗаявкиПоГрафикам() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьКонстантуАктуализироватьЗаявкиПоГрафикам() 
```
</details>

## ЗадатьНастройкиДокументаСтрокаПланаЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьНастройкиДокументаСтрокаПланаЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗадатьНастройкиДокументаСтрокаПланаЗакупок() 
```
</details>

## ЗадатьНастройкиДокументаПрограммаЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьНастройкиДокументаПрограммаЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗадатьНастройкиДокументаПрограммаЗакупок() 
```
</details>

## УстановитьСостоянияЭтаповПроцессаСтрокиПланаЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьСостоянияЭтаповПроцессаСтрокиПланаЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьСостоянияЭтаповПроцессаСтрокиПланаЗакупок() 
```
</details>

## ЗадатьНастройкиСправочникаЗакупочныеПроцедурыЕИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьНастройкиСправочникаЗакупочныеПроцедурыЕИС() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗадатьНастройкиСправочникаЗакупочныеПроцедурыЕИС() 
```
</details>

## ОбновитьСостоянияОбъектовЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСостоянияОбъектовЗакупок() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновитьСостоянияОбъектовЗакупок() 
```
</details>

## УстановитьВидЛотовойЗакупки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьВидЛотовойЗакупки(Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьВидЛотовойЗакупки(Параметры);
```
</details>

## СоздатьТипыОтчетностиОДоговорахЕИСНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьТипыОтчетностиОДоговорахЕИСНаСервере() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.СоздатьТипыОтчетностиОДоговорахЕИСНаСервере() 
```
</details>

## ИсправитьИерархиюАдресации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ИсправитьИерархиюАдресации() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ИсправитьИерархиюАдресации() 
```
</details>

## ОбновлениеИспользованиеПорталаВГО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновлениеИспользованиеПорталаВГО() Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ОбновлениеИспользованиеПорталаВГО() 
```
</details>

## ЗаписатьДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Процедуры и функции для использования в обработчиках обновления.

// Записывает изменения в переданном объекте.
// Для использования в обработчиках обновления.
//
// Параметры:
//   Данные                            - Произвольный - объект, набор записей или менеджер константы, который
//                                                      необходимо записать.
//   РегистрироватьНаУзлахПлановОбмена - Булево       - включает регистрацию на узлах планов обмена при записи объекта.
//   ВключитьБизнесЛогику              - Булево       - включает бизнес-логику при записи объекта.
//
Процедура ЗаписатьДанные(Знач Данные, Знач РегистрироватьНаУзлахПлановОбмена = Ложь, Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаписатьДанные(Данные, РегистрироватьНаУзлахПлановОбмена, );
```
</details>

## ЗаписатьОбъект
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает изменения в переданном объекте ссылочного типа.
// Для использования в обработчиках обновления.
//
// Параметры:
//   Объект                            - Произвольный - записываемый объект ссылочного типа. Например, СправочникОбъект.
//   РегистрироватьНаУзлахПлановОбмена - Булево       - включает регистрацию на узлах планов обмена при записи объекта.
//   ВключитьБизнесЛогику              - Булево       - включает бизнес-логику при записи объекта.
//
Процедура ЗаписатьОбъект(Знач Объект, Знач РегистрироватьНаУзлахПлановОбмена = Неопределено, Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаписатьОбъект(Объект, РегистрироватьНаУзлахПлановОбмена, );
```
</details>

## ПровестиДокумент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПровестиДокумент(Данные, ТекстНачалаОшибки = "", ЗаписатьЕслиНеУдалосьПровести = Истина, ОтказЕслиНеПроведен = Ложь, ОтказЕслиНеЗаписан = Ложь) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПровестиДокумент(Данные, ТекстНачалаОшибки, ЗаписатьЕслиНеУдалосьПровести, ОтказЕслиНеПроведен, ОтказЕслиНеЗаписан);
```
</details>

## ЗаполнитьРеквизитыПредопределенныхЭлементовИзМакета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРеквизитыПредопределенныхЭлементовИзМакета(ОбъектМетаданных, МакетСДанными) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ЗаполнитьРеквизитыПредопределенныхЭлементовИзМакета(ОбъектМетаданных, МакетСДанными) 
```
</details>

## ПодготовитьКэшСГруппировками
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПодготовитьКэшСГруппировками(ПолеТабличногоДокументаМакет,ОбъектАБ) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.ПодготовитьКэшСГруппировками(ПолеТабличногоДокументаМакет, ОбъектАБ));
```
</details>

## УстановитьКодЕис
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает в регистр КодыЗакупокВЕИС запись с указанными значениями полей.
Процедура УстановитьКодЕис(СпособВход, КодВход, НаименованиеВход) Экспорт
```

Пример вызова
```bsl
ОбновлениеИнформационнойБазыУХ.УстановитьКодЕис(СпособВход, КодВход, НаименованиеВход));
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
