---
title: Обработка табличной части сервер
slug: erp-uh/обработка-табличной-части-сервер
---


## ОбработатьСтрокуТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработка строки табличной части - вызывается из клиентского общего модуля при необходимости выполнения на сервере.
//
// Параметры:
//  ТекущаяСтрока	  - Структура - данные обрабатываемой строки, содержит в том числе:
//  	* НомерСтроки - Число
//  СтруктураДействий - Структура - описывает действия, где Ключ - наименование действия, Значение - Структура - параметры действия, возможно передавать следующие поля:
//		* ПроверитьХарактеристикуПоВладельцу - СправочникСсылка.ХарактеристикиНоменклатуры
//		* ПроверитьЗаполнитьУпаковкуПоВладельцу - СправочникСсылка.УпаковкиЕдиницыИзмерения
//		* ПересчитатьКоличествоЕдиниц - Неопределено
//		* ПересчитатьКоличествоЕдиницСуффикс - Строка - Суффикс
//		* ПересчитатьКоличествоУпаковок - Неопределено
//		* ПересчитатьКоличествоУпаковокСуффикс - Строка - Суффикс
//		* ПересчитатьКоличествоУпаковокСуффиксИзОтклонения - Строка - Суффикс
//		* ПересчитатьВесОбъем - Строка - Суффикс
//		* ЗаполнитьЦенуПродажи - см. ОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруЗаполненияЦеныРозницаВСтрокеТЧ
//		* ЗаполнитьПомещение - Структура:
//			** Склад - СправочникСсылка.Склады
//			** Номенклатура - СправочникСсылка.Номенклатура - (Необязательный)
//			** Характеристика - СправочникСсылка.ХарактеристикиНоменклатуры - (Необязательный)
//		* ЗаполнитьПродавца - Структура:
//			** Продавец - СправочникСсылка.Пользователи
//		* ПересчитатьСумму - Строка
//		* ПересчитатьСуммуСУчетомРучнойСкидки - Структура:
//			** Очищать - Булево
//			** ПересчитыватьСуммуРучнойСкидки - Булево
//			** ИмяКоличества - Строка
//		* ПересчитатьСуммуСУчетомАвтоматическойСкидки - Структура:
//			** Очищать - Булево
//		* ПересчитатьЦенуПоСумме - Строка
//		* ПересчитатьЦенуЗаУпаковку - Число
//		* ПересчитатьСуммуНДС - см. ОбработкаТабличнойЧастиКлиентСервер.ПараметрыПересчетаСуммыНДСВСтрокеТЧ
//		* ЗаполнитьСтавкуНДС - Структура:
//			** НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС
//			** Дата - Дата
//		* ОбработатьШтрихкоды - см. ШтрихкодированиеНоменклатурыКлиентСервер.ПараметрыОбработкиШтрихкодов
//		* ЗаполнитьНоменклатуруПоНоменклатуреПартнера - Неопределено
//		* ЗаполнитьНоменклатуруПартнераПоНоменклатуре - Неопределено
//		* ЗаполнитьФлагИзлишекПорча - Неопределено
//		* ЗаполнитьФлагРасхождение - Неопределено
//		* ПересчитатьКоличествоУпаковокОтклонение - Неопределено
//		* ОчиститьСуммуВзаиморасчетов - Неопределено
//		* ПересчитатьКоличествоНеОтгружать - Неопределено
//		* ЗаполнитьПризнакАдресногоХранения - Структура:
//			** Склад - СправочникСсылка.Склады
//			** Помещение - СправочникСсылка.СкладскиеПомещения
//			** Дата - Дата
//		* ЗаполнитьСтатьюАналитикуРасходовНоменклатуры - см. ДоходыИРасходыКлиентСервер.ВставитьДействиеЗаполнитьСтатьюАналитикуРасходовНоменклатуры.СтруктураДействий
//  КэшированныеЗначения - Структура - Сохраненные значения параметров, используемых при обработке.
//
Процедура ОбработатьСтрокуТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ОбработатьТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет обработку строк табличной части документа в соответствии с операциями, перечисленными в структуре действий.
//
// Параметры:
//	ТЧ - ДанныеФормыКоллекция - таблица товаров документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - Структура - кэшированные значения.
//
Процедура ОбработатьТЧ(ТЧ, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ОбработкаТабличнойЧастиСервер.ОбработатьТЧ(ТЧ, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## КлючЗаполненияСлужебныхРеквизитовПоддерживается
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура - Проверяет, что ключ заполнения служебных реквизитов поддерживается
//
// Параметры:
//  КлючДействия - Строка	 - проверяемый ключ.
//
// Возвращаемое значение:
//  Булево - Ключ заполнения служебных реквизитов поддерживается
Функция КлючЗаполненияСлужебныхРеквизитовПоддерживается(КлючДействия) Экспорт
```

Пример вызова
```bsl
Результат = ОбработкаТабличнойЧастиСервер.КлючЗаполненияСлужебныхРеквизитовПоддерживается(КлючДействия) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
