---
title: Общего назначения БП клиент
slug: erp-uh/общего-назначения-бп-клиент
---


## ОбработкаОповещенияФормыДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура вызывается из модуля формы документов при обработке оповещения
//
// Параметры:
//   Форма - Управляемая форма, для которой производится обработка оповещения
//   ДокументСсылка - ссылка на документ формы
//   ИмяСобытия - имя обрабатываемого события
//   Параметр - параметр, переданный в обработку оповещения
//   Источник - источник, переданный в обработку оповещения
Процедура ОбработкаОповещенияФормыДокумента(Форма, ДокументСсылка, ИмяСобытия, Параметр, Источник) Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияБПКлиент.ОбработкаОповещенияФормыДокумента(Форма, ДокументСсылка, ИмяСобытия, Параметр, Источник) 
```
</details>

## НачалоВыбораЗначенияСубконто
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывает из обработчика события "НачалоВыбора" поля субконто.
//
// Параметры:
//	Форма - ФормаКлиентскогоПриложения - Форма объекта.
//	Элемент - ПолеФормы - Поле формы.
//	СтандартнаяОбработка - Булево - Признак стандартной обработки.
//	СписокПараметров - Структура - Дополнительные параметры.
//
Процедура НачалоВыбораЗначенияСубконто(Форма, Элемент, СтандартнаяОбработка, СписокПараметров) Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияБПКлиент.НачалоВыбораЗначенияСубконто(Форма, Элемент, СтандартнаяОбработка, СписокПараметров) 
```
</details>

## ИзменитьОтборПоОсновнойОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// ПРОЦЕДУРЫ И ФУНКЦИИ МЕХАНИЗМА УСТАНОВКИ ОСНОВНОЙ ОРГАНИЗАЦИИ
//

// Изменяет значение отбора в динамическом списке.
// Поиск производится по представлению в элементах отборов верхнего уровня.
//
// Надо анализировать возвращаемое значение - и если вернется
//  Неопределено (т.е. отбор не установлен по причине того, что в списке
//  нет отбора по основной организации (он исправлен вручную и т.п.)), то не надо
//  присваивать Неопределено специальному полю "ОтборПоОрганизации" в форме списка.
//
// Параметры:
//  Список         - ДинамическийСписок - список, в котором необходимо изменить значение отбора.
//  ИмяРеквизита   - Строка - имя поля-организации в динамическом списке.
//  ЗначениеОтбора - СправочникСсылка.Организации, СписокЗначений, Массив - значение отбора.
//                   Если значение не задано, то будет подставлена основная организация из
//                   настроек пользователя.
//
// Возвращаемое значение:
//   СправочникСсылка.Организации - Если отбор установлен, то вернет значение отбора.
//
Функция ИзменитьОтборПоОсновнойОрганизации(Список, ИмяРеквизита = "Организация", Знач ЗначениеОтбора = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияБПКлиент.ИзменитьОтборПоОсновнойОрганизации(Список, ИмяРеквизита, ЗначениеОтбора);
```
</details>

## ПроверитьНаличиеОрганизаций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Проверка наличия организаций

// Возвращает признак наличия организаций.
//
// Возвращаемое значение:
//	Булево - Признак наличия организаций.
//
Функция ПроверитьНаличиеОрганизаций() Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияБПКлиент.ПроверитьНаличиеОрганизаций() 
```
</details>

## ОткрытьПроверкуДеятельностиНаКоронавирус
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает страницу проверки "Проверьте, относится ли ваша деятельность к пострадавшим от коронавируса"
//
// Параметры:
//  ОсновнойКодОКВЭД - Строка - основной код ОКВЭД, передаваемый сервису в качестве параметра
//
Процедура ОткрытьПроверкуДеятельностиНаКоронавирус(ОсновнойКодОКВЭД) Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияБПКлиент.ОткрытьПроверкуДеятельностиНаКоронавирус(ОсновнойКодОКВЭД) 
```
</details>

## ОткрытьПроверкуРеестрМСП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает страницу проверки включения организации в Реестр СМП
//
// Параметры:
//  ИНН - Строка - ИНН организации
//
Процедура ОткрытьПроверкуРеестрМСП(ИНН) Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияБПКлиент.ОткрытьПроверкуРеестрМСП(ИНН) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
