---
title: Общего назначения клиент УХ
slug: erp-uh/общего-назначения-клиент-ух
---


## ПоказатьПредупреждениеУниверсально
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
////////////////////////////////////////////////////////////////////////////////
// Клиентские процедуры общего назначения

// Устарела. Следует использовать платформенный метод ПоказатьПредупреждение
Процедура ПоказатьПредупреждениеУниверсально(ТекстПредупреждения, Заголовок = Неопределено, Оповещение = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияКлиентУХ.ПоказатьПредупреждениеУниверсально(ТекстПредупреждения, Заголовок, Оповещение);
```
</details>

## ПоказатьПомещениеФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Показывает диалог выбора файлов и помещает выбранные файлы во временное хранилище.
//  Совмещает работу методов глобального метода НачатьПомещениеФайла и ПоместитьФайлы,
//  возвращая идентичный результат вне зависимости от того, подключено расширение работы с файлами, или нет.
//
// Параметры:
//   ОбработчикЗавершения  - ОписаниеОповещения - Описание процедуры, принимающей результат выбора.
//   ИдентификаторФормы    - УникальныйИдентификатор - Уникальный идентификатор формы, из которой выполняется
//                                                     размещение файла.
//   НачальноеИмяФайла     - Строка - Полный путь и имя файла, которые будут предложены пользователю в начале выбора.
//   ПараметрыДиалога      - Структура, Неопределено - См. свойства ДиалогВыбораФайла в синтакс-помощнике.
//       Используется в случае, если удалось подключить расширение работы с файлами.
//
// Значение первого параметра, возвращаемого в ОбработчикРезультата:
//   ПомещенныеФайлы - Результат выбора.
//       * - Неопределено - Пользователь отказался от выбора.
//       * - Массив из ОписаниеПереданногоФайла, Структура - Пользователь выбрал файл.
//           ** Имя      - Строка - Полное имя выбранного файла.
//           ** Хранение - Строка - Адрес во временном хранилище, по которому размещен файл.
//
// Ограничения:
//   Используется только для интерактивного выбора в диалоге.
//   Не используется для выбора каталогов - эта опция не поддерживается веб-клиентом.
//   Не поддерживается множественный выбор в веб-клиенте, если не установлено расширение работы с файлами.
//   Не поддерживается передача адреса временного хранилища.
//
Процедура ПоказатьПомещениеФайла(ОбработчикЗавершения, ИдентификаторФормы, НачальноеИмяФайла, ПараметрыДиалога) Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияКлиентУХ.ПоказатьПомещениеФайла(ОбработчикЗавершения, ИдентификаторФормы, НачальноеИмяФайла, ПараметрыДиалога) 
```
</details>

## ПоказатьВопросОбУстановкеРасширенияРаботыСФайлами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предлагает пользователю установить расширение работы с файлами в веб-клиенте.
//
// Предназначена для использования в начале участков кода, в которых ведется работа с файлами.
// Например:
//
//    Оповещение = Новый ОписаниеОповещения("ПечатьДокументаЗавершение", ЭтотОбъект);
//    ТекстСообщения = НСтр("ru = 'Для печати документа необходимо установить расширение работы с файлами.'");
//    ОбщегоНазначенияКлиент.ПоказатьВопросОбУстановкеРасширенияРаботыСФайлами(Оповещение, ТекстСообщения);
//
//    Процедура ПечатьДокументаЗавершение(РасширениеПодключено, ДополнительныеПараметры) Экспорт
//      Если РасширениеПодключено Тогда
//        // код печати документа, рассчитывающий на то, что расширение подключено.
//        // ...
//      Иначе
//        // код печати документа, который работает без подключенного расширения.
//        // ...
//      КонецЕсли;
//
// Параметры:
//   ОписаниеОповещенияОЗакрытии    - ОписаниеОповещения - описание процедуры,
//                                    которая будет вызвана после закрытия формы со следующими параметрами:
//                                      РасширениеПодключено    - Булево - Истина, если расширение было подключено.
//                                      ДополнительныеПараметры - Произвольный - параметры, заданные в
//                                                                               ОписаниеОповещенияОЗакрытии.
//   ТекстПредложения                - Строка - текст сообщения. Если не указан, то выводится текст по умолчанию.
//   ВозможноПродолжениеБезУстановки - Булево - если Истина, будет показана кнопка ПродолжитьБезУстановки,
//                                              если Ложь, будет показана кнопка Отмена.
//
Процедура ПоказатьВопросОбУстановкеРасширенияРаботыСФайлами(ОписаниеОповещенияОЗакрытии, ТекстПредложения = "", Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияКлиентУХ.ПоказатьВопросОбУстановкеРасширенияРаботыСФайлами(ОписаниеОповещенияОЗакрытии, ТекстПредложения, );
```
</details>

## ОткрытьФормуРедактированияКомментария
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Функции для обработки действий пользователя в процессе редактирования
// многострочного текста, например комментария в документах

// Открывает форму редактирования многострочного комментария модально
//
// Параметры:
// МногострочныйТекст      - Строка - произвольный текст, который необходимо отредактировать
// РезультатРедактирования - Строка - переменная, в которую будет помещен результат редактирования
// Модифицированность       - Строка - флаг модифицированности формы
//
Процедура ОткрытьФормуРедактированияКомментария(Форма, Знач МногострочныйТекст, РезультатРедактирования, Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияКлиентУХ.ОткрытьФормуРедактированияКомментария(Форма, МногострочныйТекст, РезультатРедактирования, );
```
</details>

## ОткрытьФормуРедактированияМногострочногоТекста
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму редактирования произвольного многострочного текста модально
//
// Параметры:
// МногострочныйТекст      - Строка - произвольный текст, который необходимо отредактировать
// РезультатРедактирования - Строка - реквизит формы, в которую будет помещен результат редактирования
//	можно адресовать реквизиты через точку, а также обращаться к строкам коллекций через [].
//	ИСКЛЮЧЕНИЕ: "Комментарий" - всегда будет развернут в "Объект.Комментарий".
//	Примеры:
//		"ТекстКомменатрия"
//		"Объект.Комментарий"
//		"Объект.ТаблицаСКомментарием[3].Комментарий"
// Модифицированность       - Строка - флаг модифицированности формы
// Заголовок               - Строка - текст, который необходимо отобразить в заголовке формы
//
Процедура ОткрытьФормуРедактированияМногострочногоТекста(Форма, Знач МногострочныйТекст, РезультатРедактирования, Модифицированность = Ложь, Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияКлиентУХ.ОткрытьФормуРедактированияМногострочногоТекста(Форма, МногострочныйТекст, РезультатРедактирования, Модифицированность, );
```
</details>

## Подключаемый_УстановитьТекст
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура Подключаемый_УстановитьТекст(ТекстКомментария, ПараметрыОповещения = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияКлиентУХ.Подключаемый_УстановитьТекст(ТекстКомментария, ПараметрыОповещения);
```
</details>

## УстановитьЗнчениеРеквизитаПоПолномуПути
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проходит полный путь к реквизиту объекта через точки и устанавливает его в новое значение.
//
// Возвращает:
//	Неопределено - если не получилось найти реквизит.
//	ПроизвольноеЗначение - значение найднного реквизита.
//
Процедура УстановитьЗнчениеРеквизитаПоПолномуПути(Знач Объект, ПолныйПутьКРеквизиту, НовоеЗначение) Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияКлиентУХ.УстановитьЗнчениеРеквизитаПоПолномуПути(Объект, ПолныйПутьКРеквизиту, НовоеЗначение) 
```
</details>

## ПолучитьЗнчениеРеквизитаПоПолномуПути
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проходит полный путь к реквизиту объекта через точки и возвращает его значение.
//
// Возвращает:
//	Неопределено - если не получилось найти реквизит.
//	ПроизвольноеЗначение - значение найднного реквизита.
//
Функция ПолучитьЗнчениеРеквизитаПоПолномуПути(Знач Объект, ПолныйПутьКРеквизиту) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияКлиентУХ.ПолучитьЗнчениеРеквизитаПоПолномуПути(Объект, ПолныйПутьКРеквизиту) 
```
</details>

## ПолучитьРеквизитПоПолномуПути
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проходит полный путь к реквизиту объекта через точки и возвращает пару
// (Предпоследний объект в цепочке, Имя реквизита в предпоследнем объекте).
//
// Параметры:
//	Объект - любой объект 1С позволяющий обратиться к значению через [].
//	ПолныйПутьКРеквизиту - Строка, путь к реквизиту начиная но не включая Объект. Например, "НоменклатураПоставщиков.Поставщик".
//		Может включать "." (обращение к реквизиту реквизита) и "[]" (обращение к строке табличной части объекта по индексу строки).
//
// Возвращает:
//	Неопределено - если не получилось найти реквизит.
//	Структура:
//		Объект - объект содержащий реквизит.
//		ИмяРеквизита - имя реквизита для доступа в Объекте.
//
Функция ПолучитьРеквизитПоПолномуПути(Знач Объект, ПолныйПутьКРеквизиту) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияКлиентУХ.ПолучитьРеквизитПоПолномуПути(Объект, ПолныйПутьКРеквизиту) 
```
</details>

## ПередНачаломРаботыСистемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


Процедура ПередНачаломРаботыСистемы() Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияКлиентУХ.ПередНачаломРаботыСистемы() 
```
</details>

## ПриНачалеРаботыСистемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняется при старте системы.
Процедура ПриНачалеРаботыСистемы() Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияКлиентУХ.ПриНачалеРаботыСистемы() 
```
</details>

## ВключитьНапоминания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запускает периодическую проверку напоминаний
Процедура ВключитьНапоминания() Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияКлиентУХ.ВключитьНапоминания() 
```
</details>

## ПоискПервойПодстроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция ищет вхождение в переданную строку значений из списка значений
//
// Параметры
//  Строка - исходная строка для поиска
//  ПодстрокиПоиска - список значений с коллекцией подстрок для поиска
//  СтрокаПоиска - элемент, в который возвращается найденное значение строки подпоиска
//
// Возвращаемое значение:
//  Наименьшая позиция найденного значения
//
Функция ПоискПервойПодстроки(Строка,ПодстрокиПоиска,СтрокаПоиска) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияКлиентУХ.ПоискПервойПодстроки(Строка, ПодстрокиПоиска, СтрокаПоиска));
```
</details>

## ВернутьТекстПисьмаВФорматеHTML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает по переданному тексту строку
// в формате HTML с выделенными ссылками на ресурсы www
//
// Параметры
//  ТекстПисьма - текстовая строка
//
// Возвращаемое значение:
//  Текст в формате HTML
//
Функция ВернутьТекстПисьмаВФорматеHTML(ТекстПисьма) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияКлиентУХ.ВернутьТекстПисьмаВФорматеHTML(ТекстПисьма) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
