---
title: Общего назначения УТ вызов сервера
slug: erp-uh/общего-назначения-ут-вызов-сервера
---


## УстановитьСтатусДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает статус для списка документов
//
// Параметры:
// 		МассивДокументов - Массив - Массив документов
// 		НовыйСтатус - Строка - Имя нового статуса для документов
// 		ДополнительныеПараметры - Структура - Структура дополнительных параметров.
//
// Возвращаемое значение:
// 		Число - Количество документов у которых был изменен статус.
//
// ВАЖНО. При использования процедуры для каждого типа документа из массива должны быть объявлены функции:
// В модуле менеджера документа:
// 		Функция СформироватьЗапросПроверкиПриСменеСтатуса(МассивДокументов, НовыйСтатус, ДополнительныеПараметры) Экспорт
// 		Функция ПроверкаПередСменойСтатуса(ВыборкаПроверки, НовыйСтатус, ДополнительныеПараметры) Экспорт
// В модуле объекта документа:
// 		Функция УстановитьСтатус(НовыйСтатус, ДополнительныеПараметры) Экспорт
//
Функция УстановитьСтатусДокументов(Знач МассивДокументов, Знач НовыйСтатус, Знач ДополнительныеПараметры=Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияУТВызовСервера.УстановитьСтатусДокументов(МассивДокументов, НовыйСтатус, ДополнительныеПараметры);
```
</details>

## СсылкиОбъектовПомеченныхНаУдаление
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую массив ссылок на документы, подлежащие пометке к удалению
// или снятию пометки с удаления, а также признак пометки на удаление документов.
//
// Параметры:
// 		ВыделенныеСтроки - Массив - массив документов динамического списка,
// 		ПутьКСсылке - Строка - имя реквизита ссылки документа.
//
// Возвращаемое значение:
// 		Структура - содержит массив ссылок на документы и признак пометки на удаление документов.
//
Функция СсылкиОбъектовПомеченныхНаУдаление(ВыделенныеСтроки, ПутьКСсылке = "") Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияУТВызовСервера.СсылкиОбъектовПомеченныхНаУдаление(ВыделенныеСтроки, ПутьКСсылке);
```
</details>

## УстановитьПометкуУдаленияЗавершениеСервер
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет пометку к удалению или снятие пометки с удаления у документов.
//
// Параметры:
// 		МассивСсылок - Массив - массив ссылок на документы,
// 		ПометитьНаУдаление - Булево - Необходимость установить пометку на удаление документа.
//
Процедура УстановитьПометкуУдаленияЗавершениеСервер(МассивСсылок, ПометитьНаУдаление) Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияУТВызовСервера.УстановитьПометкуУдаленияЗавершениеСервер(МассивСсылок, ПометитьНаУдаление) 
```
</details>

## СсылкиДокументовДинамическогоСписка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив ссылок документов динамического списка.
//
// Параметры:
// 	ВыделенныеСтроки - Массив из ДанныеФормыСтруктура - где:
// 		* Ссылка - ДокументСсылка -
//
// Возвращаемое значение:
// 	Массив Из ДокументСсылка - содержит массив ссылок на документы и признак пометки на удаление документов.
//
Функция СсылкиДокументовДинамическогоСписка(ВыделенныеСтроки) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияУТВызовСервера.СсылкиДокументовДинамическогоСписка(ВыделенныеСтроки) 
```
</details>

## СсылкиДокументовДляПроведения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет заполнение переданных объектов
//
// Параметры:
// 	ВыделенныеСтроки - Массив из ДанныеФормыСтруктура - где:
// 		* Ссылка - ДокументСсылка -
//
// Возвращаемое значение:
// 	Структура - содержит:
// 		* МассивСсылок - Массив из ДокументСсылка -
//		* МожноПровести - Булево -
//		* ЕстьПомеченныеНаУдаление - Булево -
//
Функция СсылкиДокументовДляПроведения(ВыделенныеСтроки) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияУТВызовСервера.СсылкиДокументовДляПроведения(ВыделенныеСтроки) 
```
</details>

## СсылкиРаспроведенныхДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив ссылок документов, проведение которых отменено.
//
// Параметры:
// 	МассивСсылок - Массив Из ДокументСсылка - массив ссылок документов.
//
// Возвращаемое значение:
// 	Массив Из ДокументСсылка - Массив ссылок на документы, проведение которых отменено.
//
Функция СсылкиРаспроведенныхДокументов(МассивСсылок) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияУТВызовСервера.СсылкиРаспроведенныхДокументов(МассивСсылок) 
```
</details>

## БанковскийСчетОрганизацииПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает банковский счет организации, если он один в ИБ.
//
// Возвращаемое значение:
// 	СправочникСсылка.БанковскиеСчетаОрганизаций -
Функция БанковскийСчетОрганизацииПоУмолчанию() Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияУТВызовСервера.БанковскийСчетОрганизацииПоУмолчанию() 
```
</details>

## КассаОрганизацииПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает кассу организации, если она одна в ИБ.
//
// Возвращаемое значение:
// 	СправочникСсылка.Кассы -
Функция КассаОрганизацииПоУмолчанию() Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияУТВызовСервера.КассаОрганизацииПоУмолчанию() 
```
</details>

## ВариантКлассификацииЗадолженностиПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает вариант классификации по умолчанию.
//
// Возвращаемое значение:
// 	СправочникСсылка.ВариантыКлассификацииЗадолженности -
Функция ВариантКлассификацииЗадолженностиПоУмолчанию(ТолькоЕслиОдин = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияУТВызовСервера.ВариантКлассификацииЗадолженностиПоУмолчанию(ТолькоЕслиОдин);
```
</details>

## ПолноеИмяФормыОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает полное имя основной формы объекта.
//
// Параметры:
//  Ссылка	 - 	ЛюбаяСсылка - ссылка на объект. Например, ДокументСсылка или СправочникСсылка.
//
// Возвращаемое значение:
//  Строка - полное имя основной формы объекта.
//
Функция ПолноеИмяФормыОбъекта(Ссылка) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияУТВызовСервера.ПолноеИмяФормыОбъекта(Ссылка) 
```
</details>

## ПроверитьФоновоеЗадание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет статус фонового задания по указанному идентификатору.
//
// Параметры:
//  ИдентификаторЗадания - УникальныйИдентификатор - Идентификатор фонового задания.
// Возвращаемое значение:
//  Структура - Содержит статусы проверяемого фонового задания.
Функция ПроверитьФоновоеЗадание(Знач ИдентификаторЗадания) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияУТВызовСервера.ПроверитьФоновоеЗадание(ИдентификаторЗадания) 
```
</details>

## ОтменитьВыполнениеЗадания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отменяет выполнение фонового задания по переданному идентификатору.
//
// Параметры:
//  ИдентификаторЗадания - Строка - Ключ фонового задания.
//
Процедура ОтменитьВыполнениеЗадания(Знач ИдентификаторЗадания) Экспорт
```

Пример вызова
```bsl
ОбщегоНазначенияУТВызовСервера.ОтменитьВыполнениеЗадания(ИдентификаторЗадания) 
```
</details>

## ЗначениеФункциональнойОпции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение функциональной опции по имени
//
// Параметры:
// 	Имя - Строка - Имя функциональной опции
//
// Возвращаемое значение:
//	Произвольный - Значение функциональной опции
//
Функция ЗначениеФункциональнойОпции(Имя) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияУТВызовСервера.ЗначениеФункциональнойОпции(Имя) 
```
</details>

## ЗначениеКонстанты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение константы по имени
//
// Параметры:
// 	Имя - Строка - Имя константы
//
// Возвращаемое значение:
//	Произвольный - Значение константы
//
Функция ЗначениеКонстанты(Имя) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияУТВызовСервера.ЗначениеКонстанты(Имя) 
```
</details>

## СинонимДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение константы по имени
//
// Параметры:
// 	ИмяИлиИдентификаторДокумента - Строка -
// 					- СправочникСсылка.ИдентификаторыОбъектовМетаданных -
// 					- СправочникСсылка.ИдентификаторыОбъектовРасширений - Имя или идентификатор метаданных документа.
//
// Возвращаемое значение:
//	Строка - Синоним документа
//
Функция СинонимДокумента(ИмяИлиИдентификаторДокумента) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияУТВызовСервера.СинонимДокумента(ИмяИлиИдентификаторДокумента) 
```
</details>

## ЭтоОсновнойЯзык
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак того, что для пользователя установлен язык интерфейса
// соответствующий основному языку информационной базы.
//
// Возвращаемое значение:
//  Булево
//
Функция ЭтоОсновнойЯзык() Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияУТВызовСервера.ЭтоОсновнойЯзык() 
```
</details>

## ЗаписатьВЖурналСообщитьПользователюОРезультатахПроведения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записать в журнал сообщить пользователю о результатах проведения.
//
// Параметры:
//  ДанныеОНепроведенныхДокументах - см. ОбщегоНазначения.ПровестиДокументы
//
// Возвращаемое значение:
//  Массив из ДокументСсылка - Записать в журнал сообщить пользователю о результатах проведения
Функция ЗаписатьВЖурналСообщитьПользователюОРезультатахПроведения(ДанныеОНепроведенныхДокументах) Экспорт
```

Пример вызова
```bsl
Результат = ОбщегоНазначенияУТВызовСервера.ЗаписатьВЖурналСообщитьПользователюОРезультатахПроведения(ДанныеОНепроведенныхДокументах) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
