---
title: Объекты расчетов сервер
slug: erp-uh/объекты-расчетов-сервер
---


## ПроверитьОбъектыРасчетовПередЗаписью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает и заполняет/удаляет элементы справочника "Объекты расчетов" перед записью связанного объекта.
// Для платежных документов создание происходит раньше, в методе ВзаиморасчетыСервер.ПроверитьЗаполнитьРасшифровкуПлатежа.
//
// Параметры:
// 	Объект - СправочникОбъект, ДокументОбъект - Записываемый объект.
// 	МассивСтруктур - Массив из см. ВзаиморасчетыСервер.ПараметрыМеханизма - Массив структур параметров взаиморасчетов.
// 	РежимЗаписи - РежимЗаписиДокумента - Режим записи, если метод вызывается из события ПередЗаписью.
// 	Отказ - Булево - Флаг Отказ из объекта.
//
Процедура ПроверитьОбъектыРасчетовПередЗаписью(Объект, МассивСтруктур, РежимЗаписи, Отказ) Экспорт
```

Пример вызова
```bsl
ОбъектыРасчетовСервер.ПроверитьОбъектыРасчетовПередЗаписью(Объект, МассивСтруктур, РежимЗаписи, Отказ) 
```
</details>

## ПроверитьЗаполнитьОбъектРасчетовПоСтруктуре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает, перезаполняет при необходимости и возвращает ссылку на объект расчетов по параметрам механизма взаиморасчетов.
// Если в рамках одной структуры было создано несколько элементов объектов расчетов то возвращает первый.
//
// Параметры:
// 	Объект - ДокументОбъект, СправочникОбъект - Объект, по ссылке на который проверяется объект расчетов.
// 	СтруктураПараметров - Структура - Текущий набор параметров. см. ВзаиморасчетыСервер.ПараметрыМеханизма.
// 	ВернутьВсеОбъекты - Булево - Вернуть один объект расчетов или таблицу всех объектов расчетов.
// 	РежимЗаписи - РежимЗаписиДокумента - Режим записи, если метод вызывается из события ПередЗаписью.
//
// Возвращаемое значение:
// 	СправочникСсылка.ОбъектыРасчетов - Ссылка на объект расчетов.
//
Функция ПроверитьЗаполнитьОбъектРасчетовПоСтруктуре(Объект, СтруктураПараметров, ВернутьВсеОбъекты = Ложь, РежимЗаписи = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбъектыРасчетовСервер.ПроверитьЗаполнитьОбъектРасчетовПоСтруктуре(Объект, СтруктураПараметров, ВернутьВсеОбъекты, РежимЗаписи);
```
</details>

## РеквизитыОбъектаРасчетовПоСтруктуре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает, перезаполняет при необходимости и возвращает ссылку на объект расчетов по параметрам механизма взаиморасчетов.
// Если в рамках одной структуры было создано несколько элементов объектов расчетов то возвращает первый.
//
// Параметры:
// 	Объект - ДокументОбъект, СправочникОбъект - Объект, по ссылке на который проверяется объект расчетов.
// 	Ссылка - ДокументСсылка, СправочникСсылка - Ссылка на объект.
// 	СтруктураПараметров - Структура - Текущий набор параметров. см. ВзаиморасчетыСервер.ПараметрыМеханизма.
// 	РежимЗаписи - РежимЗаписиДокумента - Режим записи, если метод вызывается из события ПередЗаписью.
//
// Возвращаемое значение:
// 	Структура - Структура параметров, где:
// 		* Объект - ОпределяемыйТип.ОбъектРасчетов.
// 		* ТипРасчетов - ПеречислениеСсылка.ТипыРасчетовСПартнерами.
// 		* Организация - СправочникСсылка.Организации.
// 		* Контрагент - СправочникСсылка.Контрагенты.
// 		* Партнер - СправочникСсылка.Партнеры.
// 		* Наименование - Строка.
// 		* ТипСсылки - см. ОбщегоНазначения.ИдентификаторОбъектаМетаданных
// 		* ПометкаУдаления - Булево.
// 		* ГруппаФинансовогоУчета - СправочникСсылка.ГруппыФинансовогоУчетаРасчетов.
// 		* Менеджер - СправочникСсылка.Пользователи.
// 		* Подразделение - СправочникСсылка.СтруктураПредприятия.
// 		* ИдентификаторПлатежа - Строка.
// 		* НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС.
// 		* НомерВходящегоДокумента - Строка.
// 		* ДатаВходящегоДокумента - Дата.
// 		* НаименованиеПервичногоДокумента - Строка
// 		* Сумма - Число.
// 		* Валюта - СправочникСсылка.Валюты.
// 		* ВалютаВзаиморасчетов - СправочникСсылка.Валюты.
// 		* СуммаВзаиморасчетов - Число.
// 		* Договор - СправочникСсылка.ДоговорыКонтрагентов
// 		          - СправочникСсылка.ДоговорыМеждуОрганизациями.
// 		* НаправлениеДеятельности - СправочникСсылка.НаправленияДеятельности.
// 		* ОплатаВВалюте - Булево.
// 		* Номер - Строка.
// 		* Дата-  Дата.
// 		* Комментарий - Строка.
// 		* БанковскийСчетОрганизации - СправочникСсылка.БанковскиеСчетаОрганизаций.
// 		* БанковскийСчетКонтрагента - СправочникСсылка.БанковскиеСчетаКонтрагентов.
// 		* Касса - СправочникСсылка.Кассы.
// 		* ФормаОплаты - ПеречислениеСсылка.ФормыОплаты.
// 		* ТолькоОстатки - Булево.
//
//
Функция РеквизитыОбъектаРасчетовПоСтруктуре(Объект, Ссылка, СтруктураПараметров, РежимЗаписи) Экспорт
```

Пример вызова
```bsl
Результат = ОбъектыРасчетовСервер.РеквизитыОбъектаРасчетовПоСтруктуре(Объект, Ссылка, СтруктураПараметров, РежимЗаписи) 
```
</details>

## ПолучитьОбъектРасчетовПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ссылку на уже имеющийся объект расчетов.
// Платежи с разными партнерами и контрагентами не поддерживаются.
//
// Параметры:
// 	Ссылка - ДокументСсылка, СправочникСсылка - Ссылка на исходный объект.
// 	Организация - СправочникСсылка.Организации - Организация.
// 	ТипРасчетов - ПеречислениеСсылка.ТипыРасчетовСПартнерами - Тип расчетов объекта расчетов.
// 	ДополнительныеКритерииПоиска - см. ОбъектыРасчетовСервер.ДополнительныеКритерииПоиска.
//
// Возвращаемое значение:
// 	СправочникСсылка.ОбъектыРасчетов - Ссылка на объект расчетов.
//
Функция ПолучитьОбъектРасчетовПоСсылке(Ссылка, Организация = Неопределено, ТипРасчетов = Неопределено, ДополнительныеКритерииПоиска = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбъектыРасчетовСервер.ПолучитьОбъектРасчетовПоСсылке(Ссылка, Организация, ТипРасчетов, ДополнительныеКритерииПоиска);
```
</details>

## ПолучитьОбъектыРасчетовПоСсылкам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие ссылок имеющимся объектам расчетов.
//
// Параметры:
// 	МассивСсылок - Массив из ДокументСсылка, СправочникСсылка - Массив ссылок на исходные объекты.
// 	Организация - СправочникСсылка.Организации - Кем является организация.
// 	ТипРасчетов - ПеречислениеСсылка.ТипыРасчетовСПартнерами - Тип расчетов объектов расчетов.
// 	ДополнительныеКритерииПоиска - см. ОбъектыРасчетовСервер.ДополнительныеКритерииПоиска.
//
// Возвращаемое значение:
// 	Соответствие из КлючИЗначение:
// 		* Ключ - ДокументСсылка, СправочникСсылка - исходная ссылка.
// 		* Значение - СправочникСсылка.ОбъектыРасчетов - ссылка на объект расчетов.
//
Функция ПолучитьОбъектыРасчетовПоСсылкам(МассивСсылок, Организация = Неопределено, ТипРасчетов = Неопределено, ДополнительныеКритерииПоиска = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОбъектыРасчетовСервер.ПолучитьОбъектыРасчетовПоСсылкам(МассивСсылок, Организация, ТипРасчетов, ДополнительныеКритерииПоиска);
```
</details>

## ВсеОбъектыРасчетовПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает все объекты расчетов по ссылке.
//
// Параметры:
// 	Ссылка - ДокументСсылка - объект по которому нужно найти Объекты расчетов.
// Возвращаемое значение:
// 	Массив из СправочникСсылка.ОбъектыРасчетов - Массив объектов расчетов.
//
Функция ВсеОбъектыРасчетовПоСсылке(Ссылка) Экспорт
```

Пример вызова
```bsl
Результат = ОбъектыРасчетовСервер.ВсеОбъектыРасчетовПоСсылке(Ссылка) 
```
</details>

## ДополнительныеКритерииПоиска
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру дополнительных параметров по для поиска объектов расчета по умолчанию
//
// Возвращаемое значение:
// 	Структура - Описание:
// 		* ОбновлениеИБ - Булево - Признак, указывающий что следует производить поиск и среди некорректных объектов расчетов
// 		* ВернутьПервый - Булево - Признак, указывающий что следует вернуть первый найденный объект расчетов
// 		* Партнер - Неопределено, СправочникСсылка.Партнеры - Значение поиска по полю Партнер
// 		* ВалютаВзаиморасчетов - Неопределено, СправочникСсылка.Валюты - Значение поиска по полю Партнер
// 		* Контрагент - Неопределено, СправочникСсылка.Контрагенты - Значение поиска по полю Контрагент
Функция ДополнительныеКритерииПоиска() Экспорт
```

Пример вызова
```bsl
Результат = ОбъектыРасчетовСервер.ДополнительныеКритерииПоиска() 
```
</details>

## ПроверитьСоздатьОбъектРасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает, перезаполняет при необходимости и возвращает ссылку на объект расчетов по переданной структуре реквизитов.
//
// Параметры:
// 	РеквизитыОбъекта - Структура - Текущий набор реквизитов объекта расчетов.
// 	ДопРеквизитыИсточника - ТаблицаЗначений - Таблица дополнительных свойств и их значений объекта-источника.
// 	ОбновлениеИБ - Булево - Признак выполнения обновления информационной базы.
// 	ЕстьИзменения - Булево - Переменная передаваемая в процедуру для отметки о наличии изменений в объекте расчетов
//
// Возвращаемое значение:
// 	СправочникСсылка.ОбъектыРасчетов - Ссылка на объект расчетов.
//
Функция ПроверитьСоздатьОбъектРасчетов(РеквизитыОбъекта, ДопРеквизитыИсточника = Неопределено, ОбновлениеИБ = Ложь, ЕстьИзменения = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОбъектыРасчетовСервер.ПроверитьСоздатьОбъектРасчетов(РеквизитыОбъекта, ДопРеквизитыИсточника, ОбновлениеИБ, ЕстьИзменения);
```
</details>

## ПроверитьУдалитьОбъектРасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет наличие ссылок в объектах данных на переданный объект расчетов. Если ссылок нет, то удаляет объект непосредственно.
//
// Параметры:
// 	ОбъектРасчетов - СправочникСсылка.ОбъектыРасчетов - Ссылка на объект расчетов.
// 	Отказ - Булево - Флаг отказа из объекта.
// 	ВызыватьИсключение - Булево - Вызывать ли исключение если не удается удалить объект расчетов.
Процедура ПроверитьУдалитьОбъектРасчетов(ОбъектРасчетов, Отказ, ВызыватьИсключение) Экспорт
```

Пример вызова
```bsl
ОбъектыРасчетовСервер.ПроверитьУдалитьОбъектРасчетов(ОбъектРасчетов, Отказ, ВызыватьИсключение) 
```
</details>

## ПолучитьПараметрыОбъектаРасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру с обязательными данными для генерации/поиска объекта расчетов
//
// Возвращаемое значение:
// 	Структура - Описание:
// 		* Объект - ОпределяемыйТип.ОбъектРасчетов - Ссылка на источник объекта расчетов.
// 		* ТипРасчетов - ПеречислениеСсылка.ТипыРасчетовСПартнерами - В каких расчетах отражается, с клиентами или с поставщиками.
// 		* Организация - СправочникСсылка.Организации - Организация объекта расчетов.
// 		* Контрагент - Неопределено - Контрагент объекта расчетов.
// 		* Партнер - СправочникСсылка.Партнеры - Партнер объекта расчетов.
// 		* Договор - Неопределено - Договор объекта расчетов.
// 		* НаправлениеДеятельности - СправочникСсылка.НаправленияДеятельности - Направление деятельности, по которому отражается объект расчетов.
Функция ПолучитьПараметрыОбъектаРасчетов() Экспорт
```

Пример вызова
```bsl
Результат = ОбъектыРасчетовСервер.ПолучитьПараметрыОбъектаРасчетов() 
```
</details>

## ДополнитьСсылкамиНаОбъектыРасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет массив ссылок ссылками на связанные объекты расчетов.
//
// Параметры:
// 	МассивСсылок - Массив из ДокументСсылка, СправочникСсылка - Массив ссылок на документы и справочники.
//
Процедура ДополнитьСсылкамиНаОбъектыРасчетов(МассивСсылок) Экспорт
```

Пример вызова
```bsl
ОбъектыРасчетовСервер.ДополнитьСсылкамиНаОбъектыРасчетов(МассивСсылок) 
```
</details>

## СсылкаЯвляетсяОбъектомРасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, что ссылка указанного объекта может содержаться в объекте расчетов
//
// Параметры:
// 	Объект - СправочникОбъект, ДокументОбъект - проверяемый объект.
// 	СтруктураПараметров - Структура - Текущий набор параметров. см. ВзаиморасчетыСервер.ПараметрыМеханизма.
//
// Возвращаемое значение:
// 	Булево - Истина, если является объектом расчетов
//
Функция СсылкаЯвляетсяОбъектомРасчетов(Объект, СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
Результат = ОбъектыРасчетовСервер.СсылкаЯвляетсяОбъектомРасчетов(Объект, СтруктураПараметров) 
```
</details>

## ОбъектРасчетовИзСсылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Находит используемый объект расчетов (или несколько) по указанной ссылке
//
// Параметры:
// 	Ссылка - СправочникСсылка, ДокументСсылка - документ или справочник, использующий учетный механизм Взаиморасчеты
//
// Возвращаемое значение:
// 	- СправочникСсылка.ОбъектыРасчетов - Найденный объект расчетов
// 	- Массив из СправочникСсылка.ОбъектыРасчетов - Если найдено несколько объектов расчетов
//
Функция ОбъектРасчетовИзСсылки(Ссылка) Экспорт
```

Пример вызова
```bsl
Результат = ОбъектыРасчетовСервер.ОбъектРасчетовИзСсылки(Ссылка) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
