---
title: Онлайн оплаты
slug: erp-uh/онлайн-оплаты
---


## ПлатежнаяСсылка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ссылку на страницу оплаты через онлайн оплату.
// Если платежная ссылка уже формировалась, то обновляет данные в сервисе.
// Пустая строка, если во время выполнения обнаружена ошибка.
//
// Параметры:
//  ОснованиеПлатежа - Произвольный - основание платежа, для которого необходимо сформировать ссылку.
//  ОтсутствуетДоступ- Булево - признак отсутствия доступа к онлайн оплате у организации, для которой
//    формируется платежная ссылка. Если значение Истина, пользователю необходимо выдать доступ к онлайн оплате,
//    перейдя на страницу по адресу см. ОнлайнОплаты.АдресСтраницыПредоставленияДоступа().
// Возвращаемое значение:
//  Строка - ссылка на страницу оплаты через онлайн оплату.
//
Функция ПлатежнаяСсылка(Знач ОснованиеПлатежа, ОтсутствуетДоступ = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОнлайнОплаты.ПлатежнаяСсылка(ОснованиеПлатежа, ОтсутствуетДоступ);
```
</details>

## ОперацииОнлайнОплат
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет запрос получения операций по онлайн оплате в сервис 1С, возвращает массив структур описывающих операции.
//
// Параметры:
//  ПериодЗапроса - СтандартныйПериод, Структура - Период за который будут выбираться операции по онлайн оплате.
//    * ДатаНачала - Дата - начало периода запроса. Если не указан, дата начала будет определена автоматически.
//    * ДатаОкончания - Дата - окончание периода запроса. Если не указан, дата окончания будет равна текущей дате.
//  Организация - ОпределяемыйТип.Организация - организация, по которой нужно отобрать операции.Если не указана,
//    то будут обработаны все действительные настройки;
//  СДоговором - Булево, Неопределено - позволяет указать для каких настроек следует загружать операции:
//    Неопределено - будут загружены и операции по схемам "С договором" и "Без договора"
//    Истина - будут загружены операции по схеме "С договором"
//    Ложь - будут загружены операции по схеме "Без договора".
//    Если указан параметр Организация, этот параметр не учитывается
// Возвращаемое значение:
//  Неопределено - если параметры заданы неверно.
//  Массив - массив структур, содержащий данные об операциях по онлайн оплате.
//   * ДатаНачала - Дата - начало периода запроса операций.
//   * ДатаОкончания - Дата - окончание периода запроса операций.
//   * ДатаОтвета - Дата - дата ответа от сервиса.
//   * НастройкаОнлайнОплаты - СправочникСсылка.НастройкиОнлайнОплат - настройки онлайн оплаты,
//       для которой получены операции.
//   * ОперацииТекстовыйФормат - Строка - данные операций в текстовом формате (см. HTTP://v8.1c.ru/EDI/edi_stnd/100/).
//   * Организация - ОпределяемыйТип.Организация - организация, для которой получены операции.
//   * СДоговором - Булево - признак вида настройки интеграции с онлайн оплатой (Истина - по договору,
//       Ложь - без договора).
//   * ОтсутствуетДоступ - Булево - признак отсутствия доступа к онлайн оплате у Организации,
//       для которой запрашиваются операции. Если значение Истина, пользователю необходимо выдать доступ к онлайн оплате,
//       перейдя на страницу по адресу см. ОнлайнОплаты.АдресСтраницыПредоставленияДоступа().
//   * ОперацииМассивСтруктур - Массив из структур - операции за заданный период по соответствующей настройке (организации):
//       Общие свойства:
//         ** ИдентификаторТранзакции - Число - идентификатор операции в сервисе онлайн оплаты.
//         ** ИдентификаторПлатежа - Строка - идентификатор платежа.
//         ** ИдентификаторМагазина - Число - идентификатор магазина в сервисе онлайн оплаты.
//         ** СДоговором - Булево - признак вида настройки интеграции с онлайн оплатой (Истина - по договору,
//              Ложь - без договора).
//         ** ВидОперации - Строка - "Оплата" - для операций оплаты, "Возврат" - для операций возврата.
//       Операция оплаты:
//         ** ДатаОплаты - Дата - дата оплаты.
//         ** СуммаДокумента - Число - сумма оплаты.
//         ** ВалютаДокумента - СправочникСсылка.Валюта - валюта платежа.
//         ** СуммаКЗачислениюНаСчетОрганизации - Число, Неопределено - сумма к зачислению на счет организации
//              (за вычетом комиссии онлайн оплаты). Передается только для схемы "С договором".
//         ** ВалютаСуммыКЗачислениюНаСчетОрганизации - СправочникСсылка.Валюта - валюта зачисления на счет организации.
//         ** СпособОплаты - Строка - код способа оплаты.
//         ** ИННОрганизации - Строка, Неопределено - ИНН организации. Если не известен, то Неопределено.
//         ** НаименованиеБанкаОрганизации - Строка, Неопределено - банк, на счет которого зачислена оплата.
//              Если не известен, то Неопределено.
//         ** НаименованиеПолноеОрганизации - Строка, Неопределено - организация, на счет которой зачислена оплата.
//              Если не известен, то Неопределено.
//         ** БикБанкаОрганизации - Строка, Неопределено - БИК банка, на счет которого зачислена оплата.
//              Если не известен, то Неопределено.
//         ** КоррСчетБанкаОрганизации - Строка, Неопределено - корр. счет банка, на счет которого зачислена оплата.
//              Если не известен, то Неопределено.
//         ** НомерРасчетногоСчетаОрганизации - Строка, Неопределено - номер расчетного счета, на который зачислена оплата.
//              Если не известен, то Неопределено.
//         ** НазначениеПлатежа - Строка - назначение платежа, определенное при формирование ссылки на оплату.
//         ** ДатаФормированияЧека - Строка - дата формирования чека об оплате(в формате "дд.мм.гггг ЧЧ:мм:сс").
//         ** СуммаЧека - Число - сумма чека.
//         ** НомерФискальногоНакопителя - Строка - номер фискального накопителя.
//         ** ФискальныйНомерДокумента - Число - фискальный номер документа.
//         ** ФискальныйПризнакДокумента - Строка - фискальный признак документа
//         ** КонтактныеДанныеЭлектронногоЧека - Строка - телефон или электронная почта, на которые был отправлен чек.
//       Операция возврата:
//         ** ИдентификаторВозврата - Число - идентификатор операции возврата.
//         ** СуммаДокумента - Число - сумма возврата.
//         ** ВалютаДокумента - СправочникСсылка.Валюта - валюта возврата.
//         ** ОписаниеПричиныВозврата - Строка - причина возврата.
//         ** ДатаРегистрацииЗапросаНаВозврат - Дата - дата регистрации запроса на возврат.
//         ** ДатаИсполненияЗапросаНаВозврат - Дата - дата исполнения запроса на возврат.
//         ** ОтправительЗапросаНаВозврат - Строка - отправитель запроса на возврат.
//       ДополнительныеНастройки - ТаблицаЗначений -
//         См. ОнлайнОплатыПереопределяемый.ПриОпределенииДополнительныхНастроекОнлайнОплаты.
//
Функция ОперацииОнлайнОплат(ПериодЗапроса = Неопределено, Организация = Неопределено, СДоговором = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОнлайнОплаты.ОперацииОнлайнОплат(ПериодЗапроса, Организация, СДоговором);
```
</details>

## ЗагрузитьОперацииОнлайнОплат
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает операций по онлайн оплатам с сервера 1С и обновляет статус обменов.
//
// Параметры:
//  Период - СтандартныйПериод, Структура - Период за который будут выбираться операции по онлайн оплате.
//    * ДатаНачала - Дата - начало периода запроса. Если не указан, дата начала будет определена автоматически.
//    * ДатаОкончания - Дата - окончание периода запроса. Если не указан, дата окончания будет равна текущей дате.
//  Организация - ОпределяемыйТип.Организация - организация, по которой нужно отобрать операции. Если не указана,
//    будут обработаны все действительные настройки;
//  СДоговором - Булево, Неопределено - позволяет указать для каких настроек следует загружать операции:
//    * Неопределено - будут загружены и операции по схемам "С договором" и "Без договора"
//    * Истина - будут загружены операции по схеме "С договором"
//    * Ложь - будут загружены операции по схеме "Без договора"
//    Если указан параметр Организация, этот параметр не учитывается.
//
// Возвращаемое значение:
//  Соответствие - результаты загрузки операций для каждой настройки.
//   * Ключ - СправочникСсылка.НастройкиОнлайнОплат - настройка онлайн оплаты, по которой были загружены операции.
//   * Значение - Произвольный - результаты загрузки операций.
//       Определяются в ОнлайнОплатыПереопределяемый.ПриЗагрузкеОперацийПоОнлайнОплате.
//
Функция ЗагрузитьОперацииОнлайнОплат( Экспорт
```

Пример вызова
```bsl
Результат = ОнлайнОплаты.ЗагрузитьОперацииОнлайнОплат();
```
</details>

## ДанныеЭквайера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные эквайера онлайн оплаты.
//
// Параметры:
//  Период - Дата - дата актуальности данных.
//
// Возвращаемое значение:
//  Структура - данные эквайера:
//    * НаименованиеПолное - Строка - полное наименование эквайера.
//    * Наименование - Строка - сокращенное наименование эквайера.
//    * ИНН - Строка - ИНН эквайера.
//    * КПП - Строка - КПП эквайера.
//    * ОГРН - Строка - ОГРН эквайера.
//    * ОКВЭД - Строка - ОКВЭД эквайера.
//    * КодПоОКПО - Строка - код по ОКПО эквайера.
//
Функция ДанныеЭквайера(Период) Экспорт
```

Пример вызова
```bsl
Результат = ОнлайнОплаты.ДанныеЭквайера(Период) 
```
</details>

## ЕстьПравоНаЗагрузкуОпераций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверка права на загрузку операций по онлайн оплате.
//
// Возвращаемое значение:
//  Булево - Истина если есть право на загрузку.
//
Функция ЕстьПравоНаЗагрузкуОпераций() Экспорт
```

Пример вызова
```bsl
Результат = ОнлайнОплаты.ЕстьПравоНаЗагрузкуОпераций() 
```
</details>

## НастройкаИнтеграцииДоступна
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверка права на добавление, изменение настроек онлайн оплат.
//
// Возвращаемое значение:
//  Булево - Истина если есть право на добавление, изменение настроек онлайн оплат.
//
Функция НастройкаИнтеграцииДоступна() Экспорт
```

Пример вызова
```bsl
Результат = ОнлайнОплаты.НастройкаИнтеграцииДоступна() 
```
</details>

## ДоступноПолучениеПлатежнойСсылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверка права на формирование платежной ссылки сервисом онлайн оплат.
//
// Возвращаемое значение:
//  Булево - Истина если есть право на формирование платежной ссылки сервисом онлайн оплат.
//
Функция ДоступноПолучениеПлатежнойСсылки() Экспорт
```

Пример вызова
```bsl
Результат = ОнлайнОплаты.ДоступноПолучениеПлатежнойСсылки() 
```
</details>

## АдресСтраницыПредоставленияДоступа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает URL адреса, для предоставления доступа к онлайн оплате.
//
// Возвращаемое значение:
//  Строка - URL адрес. Если возвращается пустая строка - в системе отсутствует подключение к
//    Интернет-поддержке пользователей.
//
Функция АдресСтраницыПредоставленияДоступа() Экспорт
```

Пример вызова
```bsl
Результат = ОнлайнОплаты.АдресСтраницыПредоставленияДоступа() 
```
</details>

## НастройкаИнтеграцииВыполнена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак наличия доступа к онлайн оплате у организации. Если возвращаемое значение равно Ложь,
// пользователю необходимо выдать доступ к онлайн оплате, перейдя на страницу
// по адресу см. ОнлайнОплаты.АдресСтраницыПредоставленияДоступа().
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - организация, для которой проверяется доступ.
//
// Возвращаемое значение:
//  Булево - Истина, если доступ предоставлен.
//  Неопределено - если не удалось определить наличие доступа.
//
Функция НастройкаИнтеграцииВыполнена(Организация) Экспорт
```

Пример вызова
```bsl
Результат = ОнлайнОплаты.НастройкаИнтеграцииВыполнена(Организация) 
```
</details>

## АналитикиУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает настройки учета заданного элемента.
//
// Параметры:
//  НастройкаОнлайнОплаты - Ссылка на элемент справочника НастройкиОнлайнОплат,
//    аналитики учета которого нужно получить.
//
// Возвращаемое значение:
//  Структура - Результат выполнения:
//    * Ключ - Строка, идентификатор настройки учета.
//    * Значение - ЛюбаяСсылка, Булево, Строка, Дата, Число, содержит в себе значение настройки.
//
Функция АналитикиУчета(НастройкаОнлайнОплаты) Экспорт
```

Пример вызова
```bsl
Результат = ОнлайнОплаты.АналитикиУчета(НастройкаОнлайнОплаты) 
```
</details>

## ОбновитьАналитикиУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет обновление значений настроек учета по переданной структуре, возвращает результат выполнения операции.
//
// Параметры:
//  НастройкаОнлайнОплаты - Ссылка на  элемент справочника НастройкиОнлайнОплат:
//  АналитикиУчета - Структура, содержит в себе аналитики учета и их значения для обновления:
//    * Ключ - Строка, идентификатор обновляемой настройки учета;
//    * Значение - ЛюбаяСсылка, Булево, Строка, Дата, Число, содержит в себе значение обновляемой настройки;
//  ЗамещатьЗаполненные - Булево, признак замещения заполненных аналитик учета НастройкиОнлайнОплат
//
// Возвращаемое значение:
//  Структура - результат добавления:
//    * Ошибка - Булево -  Истина - если задание завершено с ошибкой.
//    * СообщениеОбОшибке - Строка, Форматированная строка - сообщение об ошибке для пользователя.
//    * ИнформацияОбОшибке - Строка, Форматированная строка - сообщение об ошибке для администратора.
//
Функция ОбновитьАналитикиУчета(НастройкаОнлайнОплаты, АналитикиУчета, ЗамещатьЗаполненные  = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОнлайнОплаты.ОбновитьАналитикиУчета(НастройкаОнлайнОплаты, АналитикиУчета, ЗамещатьЗаполненные);
```
</details>

## ДобавитьНастройку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает элемент справочника НастройкиОнлайнОплат, возвращается структура с результатом выполнения операции.
//
// Параметры:
//  УИД - УИД элемента создаваемой настройки,
//  ДанныеЗаполнения - Структура, содержит в себе данные для заполнения реквизитов и табличных частей элемента.
//    * Ключ - Имя реквизита элемента справочника,
//    * Значение - Значение реквизита справочника, вложенная структура для табличных частей
//
// Возвращаемое значение:
//  Структура - результат добавления:
//    * Ошибка - Булево  Истина - если задание завершено с ошибкой,
//    * СообщениеОбОшибке - Строка, Форматированная строка - сообщение об ошибке для пользователя,
//    * ИнформацияОбОшибке - Строка, Форматированная строка - сообщение об ошибке для администратора.
//
Функция ДобавитьНастройку(УИД, ДанныеЗаполнения) Экспорт
```

Пример вызова
```bsl
Результат = ОнлайнОплаты.ДобавитьНастройку(УИД, ДанныеЗаполнения) 
```
</details>

## ДатаПоследнегоУспешногоОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает дату последнего успешного обмена для указанной настройки.
//
// Параметры:
//  НастройкаОнлайнОплаты - СправочникСсылка.НастройкиОнлайнОплат - Настройка онлайн оплаты для которой необходимо вернуть дату последнего успешного обмена.
//
// Возвращаемое значение:
//   Дата - дата последнего успешного обмена, если успешных обменов не было, возвращает пустую дату.
//
Функция ДатаПоследнегоУспешногоОбмена(НастройкаОнлайнОплаты) Экспорт
```

Пример вызова
```bsl
Результат = ОнлайнОплаты.ДатаПоследнегоУспешногоОбмена(НастройкаОнлайнОплаты) 
```
</details>

## ДатаПоследнегоУспешногоОбменаПоОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает дату последнего успешного обмена для указанной организации.
//
// Параметры:
//  Организация - СправочникСсылка.Организации - Организация для которой необходимо вернуть дату последнего успешного обмена.
//
// Возвращаемое значение:
//  Дата - дата последнего успешного обмена, если успешных обменов не было, возвращает пустую дату.
//
Функция ДатаПоследнегоУспешногоОбменаПоОрганизации(Организация) Экспорт
```

Пример вызова
```bsl
Результат = ОнлайнОплаты.ДатаПоследнегоУспешногоОбменаПоОрганизации(Организация) 
```
</details>

## СписокДоступныхОрганизаций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция получения списка организаций по настройкам онлайн оплаты.
//
// Параметры:
//  ТолькоСДоговором  - Булево, Неопределено - признак того, что нужно возвращать организации только по настройкам
//    для варианта с договором и наоборот, если Неопределено будет выдано по всем.
//  ТолькоДействительные  - Булево - признак того, что нужно возвращать организации только по действующим настройкам.
//
// Возвращаемое значение:
//   Массив - Массив банковских счетов.
//
Функция СписокДоступныхОрганизаций(ТолькоСДоговором = Неопределено, ТолькоДействительные = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ОнлайнОплаты.СписокДоступныхОрганизаций(ТолькоСДоговором, ТолькоДействительные);
```
</details>

## НайтиНастройку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция позволяющая получить настройку с онлайн оплатой по переданным параметрам поиска.
//
// Параметры:
//  КлючиПоиска  - Структура, ФиксированнаяСтруктура, Соответствие, ФиксированноеСоответствие - Ключи поиска
//   по которым необходимо искать данные, поиск работает по логическому "И".
//    * Ключ - Строка - имя реквизита настройки.
//    * Значение - Произвольный - значение отбора.
//  ТолькоДействительные  - Булево - признак того, что нужно возвращать только действительные настройки.
//
// Возвращаемое значение:
//   СправочникСсылка.НастройкиОнлайнОплат - Ссылка на найденную настройку,
//     если ничего не найдено будет возвращена пустая ссылка.//
Функция НайтиНастройку(КлючиПоиска, ТолькоДействительные = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ОнлайнОплаты.НайтиНастройку(КлючиПоиска, ТолькоДействительные);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
