---
title: Оперативные взаиморасчеты сервер
slug: erp-uh/оперативные-взаиморасчеты-сервер
---


## ЗаполнитьОперативныеВзаиморасчеты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет заполнение регистров взаиморасчетов в новой архитектуре по переданной структуре параметров.
//
// Параметры:
//	ОсновныеПараметры - Структура, ТаблицаЗначений - Параметры пересчета, см. СтруктураПараметровЗаполненияВзаиморасчетов
//	ДополнительныеСвойстваПроведения - Структура
//
Процедура ЗаполнитьОперативныеВзаиморасчеты(ОсновныеПараметры, ДополнительныеСвойстваПроведения = Неопределено) Экспорт
```

Пример вызова
```bsl
ОперативныеВзаиморасчетыСервер.ЗаполнитьОперативныеВзаиморасчеты(ОсновныеПараметры, ДополнительныеСвойстваПроведения);
```
</details>

## ЗаполнитьОперативныеВзаиморасчетыПоТаблице
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Вызывает пересчет измененных и связанных расчетов по таблице заданий.
//
// Параметры:
//	Параметры - см. ПараметрыРаспределенияРасчетов
//	ДополнительныеСвойства - Структура - Дополнительные свойства проведения.
//
Процедура ЗаполнитьОперативныеВзаиморасчетыПоТаблице(Параметры, ДополнительныеСвойства = Неопределено) Экспорт
```

Пример вызова
```bsl
ОперативныеВзаиморасчетыСервер.ЗаполнитьОперативныеВзаиморасчетыПоТаблице(Параметры, ДополнительныеСвойства);
```
</details>

## ВыполнитьПереоценкуЗаПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Пересчитывает все курсовые разницы за указанный период.
//
// Параметры:
//	МассивОрганизаций - Массив из СправочникСсылка.Организации- Перечень организаций по которым необходимо выполнить переоценку.
//	НачалоПериода - Дата - Начало периода пересчета курсовых разниц.
//	КонецПериода - Дата - Конец периода пересчета курсовых разниц.
//  Параметры - см. ПараметрыПереоценки
//
Процедура ВыполнитьПереоценкуЗаПериод(МассивОрганизаций, Знач НачалоПериода, Знач КонецПериода, Параметры) Экспорт
```

Пример вызова
```bsl
ОперативныеВзаиморасчетыСервер.ВыполнитьПереоценкуЗаПериод(МассивОрганизаций, НачалоПериода, КонецПериода, Параметры) 
```
</details>

## ВыполнитьПереоценкуНаДату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Добавляет записи переоценки на одну дату.
//
// Параметры:
//	МассивОрганизаций - Массив из СправочникСсылка.Организации - Перечень организаций по которым необходимо выполнить переоценку.
//	Период - Дата - Дата, на конец которой необходимо выполнить переоценку.
//  Параметры - см. ПараметрыПереоценки
//
Процедура ВыполнитьПереоценкуНаДату(МассивОрганизаций, Период, Параметры) Экспорт
```

Пример вызова
```bsl
ОперативныеВзаиморасчетыСервер.ВыполнитьПереоценкуНаДату(МассивОрганизаций, Период, Параметры) 
```
</details>

## Порядок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Возвращает строковый порядок документа по переданным параметрам.
//
// Параметры:
// 	Дата - Дата - Дата по которой нужно сделать строковый порядок.
// 	Номер - Строка - Номер документа.
// 	ТипДокумента - Тип - Тип ссылки документа.
// 	Вид - Строка - 1 Заказы, график исполнения договора.
//									2 Накладные;
//									3 Корректировки реализации в минус;
//									4 Оплаты, возвраты.
// 	Тип - Строка,Число - см. НомерТипа.
// Возвращаемое значение:
// 	Строка - Описание
Функция Порядок(Дата, Номер, ТипДокумента, Вид, Тип = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОперативныеВзаиморасчетыСервер.Порядок(Дата, Номер, ТипДокумента, Вид, Тип);
```
</details>

## СтруктураПараметровЗаполненияВзаиморасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров, необходимых для заполнения регистров взаиморасчетов в новой архитектуре.
//
// Возвращаемое значение:
//  Структура - Структура параметров заполнения взаиморасчетов:
// * ОбъектРасчетов - СправочникСсылка.ОбъектыРасчетов - объект расчетов, в рамках которого происходит распределение взаиморасчетов.
// * АналитикаУчетаПоПартнерам - СправочникСсылка.КлючиАналитикиУчетаПоПартнерам - аналитика, в рамках которой происходит распределение взаиморасчетов.
// * ВалютаРасчетов - СправочникСсылка.Валюты - Валюта взаиморасчетов.
// * ЭтоРасчетыСКлиентами - Булево - Определяет регистры для заполнения - с клиентами или с поставщиками.
// * ПорядокФакт - Строка - Момент времени начиная с которого необходимо выполнить распределение, подробнее в ОперативныеВзаиморасчетыСервер.Порядок().
// * ПорядокПлан - Строка - Момент времени начиная с которого необходимо выполнить распределение, подробнее в ОперативныеВзаиморасчетыСервер.Порядок().
// * НачальноеЗаполнение - Булево - Истина, если это начальное заполнение.
// * Регистратор - ДокументСсылка, Неопределено - Документ регистратор, инициировавший распределение.
// * ДополнительныеСвойстваПроведения - Структура - Структура дополнительных свойств проведения, транслируемая из регистров накопления РасчетыСКлиентами РасчетыСПоставщиками:
// ** МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - Дополняется таблицей сформированных движений для дальнейшего использования в регл и упр учете
// * ЗаписыватьИзменения - Булево - Ложь, если требуется получить таблицу сформированных движений без записи документов.
Функция СтруктураПараметровЗаполненияВзаиморасчетов() Экспорт
```

Пример вызова
```bsl
Результат = ОперативныеВзаиморасчетыСервер.СтруктураПараметровЗаполненияВзаиморасчетов() 
```
</details>

## СвободныеРегистраторыРасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Возвращает таблицу служебных документов РегистраторРасчетов для перезаписи по переданным параметрам.
//
// Параметры:
//	Параметры - Структура - Описание:
//		* ОбъектРасчетов - ОпределяемыйТип.ОбъектРасчетов - Объект расчетов.
//		* АналитикаУчетаПоПартнерам - СправочникСсылка.КлючиАналитикиУчетаПоПартнерам - Аналитика взаиморасчетов.
//		* Валюта - СправочникСсылка.Валюты - Валюта взаиморасчетов.
//		* ЭтоРасчетыСКлиентами - Булево - это расчеты с клиентами, а не с поставщиками.
//		* Организация - Неопределено, СправочникСсылка.Организации - Организация расчета.
//	ИмяТаблицы - Строка - Имя регистра накопления, по которому определятся свободный регистратор или нет.
//	КоличествоЗаписей - Число - Количество записей для последующей записи в регистр.
//	ТаблицаСвободныхРегистраторов - см. ТаблицаСвободныхРегистраторовРасчета.
//
// Возвращаемое значение:
//	ТаблицаЗначений - таблица со следующими колонками:
//		* Ссылка - ДокументСсылка.РегистраторРасчетов - найденный служебный документ;
//		* ТребуетсяОчистка - Булево - У данного документа есть движения в переданной таблице.
//
Функция СвободныеРегистраторыРасчетов(Параметры, ИмяТаблицы, КоличествоЗаписей, ТаблицаСвободныхРегистраторов) Экспорт
```

Пример вызова
```bsl
Результат = ОперативныеВзаиморасчетыСервер.СвободныеРегистраторыРасчетов(Параметры, ИмяТаблицы, КоличествоЗаписей, ТаблицаСвободныхРегистраторов));
```
</details>

## ТаблицаСвободныхРегистраторовРасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Таблица свободных регистраторов расчета.
//
// Параметры:
//	Параметры - Структура - Описание:
//		* ОбъектРасчетов - ОпределяемыйТип.ОбъектРасчетов - Объект расчетов.
//		* АналитикаУчетаПоПартнерам - СправочникСсылка.КлючиАналитикиУчетаПоПартнерам - Аналитика взаиморасчетов.
//		* Валюта - СправочникСсылка.Валюты - Валюта взаиморасчетов.
//		* ЭтоРасчетыСКлиентами - Булево - это расчеты с клиентами, а не с поставщиками.
//		* Организация - Неопределено, СправочникСсылка.Организации - Организация расчета.
//
// Возвращаемое значение:
//	ТаблицаЗначений - таблица со следующими колонками:
//		* ИмяТаблицы - Строка - Имя регистра накопления;
//		* Ссылка - ДокументСсылка.РегистраторРасчетов - найденный служебный документ;
//		* ТребуетсяОчистка - Булево - У данного документа есть движения в переданной таблице.
//
//
Функция ТаблицаСвободныхРегистраторовРасчета(Параметры) Экспорт
```

Пример вызова
```bsl
Результат = ОперативныеВзаиморасчетыСервер.ТаблицаСвободныхРегистраторовРасчета(Параметры));
```
</details>

## ЗаполнитьРегистрыПриВключенииНовойАрхитектуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Выполняет первоначальное заполнение регистров новой архитектуры
//
// Параметры:
//	Параметры - Структура - параметры обработчика ожидания
//	УникальныйИдентификатор - УникальныйИдентификатор - идентификатор обработчика ожидания.
//
Процедура ЗаполнитьРегистрыПриВключенииНовойАрхитектуры(Параметры, УникальныйИдентификатор) Экспорт
```

Пример вызова
```bsl
ОперативныеВзаиморасчетыСервер.ЗаполнитьРегистрыПриВключенииНовойАрхитектуры(Параметры, УникальныйИдентификатор) 
```
</details>

## ОчиститьРегистрыПриВыключенииНовойАрхитектуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Очищает новые регистры расчетов в транзакции с блокировкой всех расчетов.
Процедура ОчиститьРегистрыПриВыключенииНовойАрхитектуры(Параметры = Неопределено, УникальныйИдентификатор = Неопределено) Экспорт
```

Пример вызова
```bsl
ОперативныеВзаиморасчетыСервер.ОчиститьРегистрыПриВыключенииНовойАрхитектуры(Параметры, УникальныйИдентификатор);
```
</details>

## ЗаполнитьПоВсемРасчетам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Заполнение новых регистров по всем объектам расчетов.
Процедура ЗаполнитьПоВсемРасчетам(НачальноеЗаполнение = Ложь) Экспорт
```

Пример вызова
```bsl
ОперативныеВзаиморасчетыСервер.ЗаполнитьПоВсемРасчетам(НачальноеЗаполнение);
```
</details>

## ЗаполнитьПлановыеРасчеты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Заполнение новых регистров плановых оплат и отгрузок по всем объектам расчетов.
Процедура ЗаполнитьПлановыеРасчеты(ПараметрыВыполнения, АдресХранилища) Экспорт
```

Пример вызова
```bsl
ОперативныеВзаиморасчетыСервер.ЗаполнитьПлановыеРасчеты(ПараметрыВыполнения, АдресХранилища) 
```
</details>

## ТекстЗапросаНекорректныхОстаткиВзаиморасчетовПоСрокам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует текст запроса для поиска некорректных данных в расчетных регистрах.
//
// Параметры:
// 	ИмяВТ - Строка - Имя временной таблицы для помещения результата
// 	БезРучныхКорректировок - Булево - необходимость исключения из результата запроса Аналитик расчетов по партнерам
// 	                                  и Объектов расчетов, по которым введены ручные корректировки регистров.
// Возвращаемое значение:
// 	Строка - Текст запроса
Функция ТекстЗапросаНекорректныхОстаткиВзаиморасчетовПоСрокам(ИмяВТ = "", БезРучныхКорректировок = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ОперативныеВзаиморасчетыСервер.ТекстЗапросаНекорректныхОстаткиВзаиморасчетовПоСрокам(ИмяВТ, БезРучныхКорректировок);
```
</details>

## ТекстЗапросаРазвернутоеСальдо
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует текст запроса для поиска записей с развернутым сальдо в расчетных регистрах.
//
// Параметры:
// 	ИмяВТ - Строка - Имя временной таблицы для помещения результата
// 	БезРучныхКорректировок - Булево - необходимость исключения из результата запроса Аналитик расчетов по партнерам
// Возвращаемое значение:
// 	Строка - Текст запроса
Функция ТекстЗапросаРазвернутоеСальдо(ИмяВт = "", БезРучныхКорректировок = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ОперативныеВзаиморасчетыСервер.ТекстЗапросаРазвернутоеСальдо(ИмяВт, БезРучныхКорректировок);
```
</details>

## ТекстЗапросаВтРучныхКорректировок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Временная таблица для определения наличичия ручных корректировок регистров
// при проверке развернутого сальдо и некорректных остатков
//
// Возвращаемое значение:
//  Строка - Текст запроса
//
Функция ТекстЗапросаВтРучныхКорректировок() Экспорт
```

Пример вызова
```bsl
Результат = ОперативныеВзаиморасчетыСервер.ТекстЗапросаВтРучныхКорректировок());
```
</details>

## ИсправитьОстаткиВзаиморасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Исправление остатков по взаиморасчетам
//
// Параметры:
// 	Период - Дата - Период проверки, на начало месяца периода будут проверены остатки,
//		если они некорректные, то будет создана корректировка на конец предыдущего месяца.
//		Если на начало периода остатки в порядке, а на начало следующего месяца - нет, то будет запущен частичный пересчет расчетов.
// 	МассивОрганизаций - Массив - Массив организация, по которым требуется исправить остатки взаиморасчетов
Процедура ИсправитьОстаткиВзаиморасчетов(Период, ЗНАЧ МассивОрганизаций = Неопределено) Экспорт
```

Пример вызова
```bsl
ОперативныеВзаиморасчетыСервер.ИсправитьОстаткиВзаиморасчетов(Период, ЗНАЧ МассивОрганизаций);
```
</details>

## ИсправитьРазвернутоеСальдо
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Исправление развернутого сальдо по взаиморасчетам
//
// Параметры:
// 	Период - Дата - Период проверки, требуется указать конец месяца
// 	МассивОрганизаций - Массив - Массив организация, по которым требуется исправить развернутое сальдо взаиморасчетов
Процедура ИсправитьРазвернутоеСальдо(Период, ЗНАЧ МассивОрганизаций = Неопределено) Экспорт
```

Пример вызова
```bsl
ОперативныеВзаиморасчетыСервер.ИсправитьРазвернутоеСальдо(Период, ЗНАЧ МассивОрганизаций);
```
</details>

## ДополнитьКорректировкуДвижениямиПоПрочимДоходамРасходам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в движения данные по прочим доходам/расходам
//
// Параметры:
// 	КорректировкаОбъект - ДокументОбъект.КорректировкаРегистров - ДокументОбъект, с уже записанными движениями по расчетам.
Процедура ДополнитьКорректировкуДвижениямиПоПрочимДоходамРасходам(КорректировкаОбъект) Экспорт
```

Пример вызова
```bsl
ОперативныеВзаиморасчетыСервер.ДополнитьКорректировкуДвижениямиПоПрочимДоходамРасходам(КорректировкаОбъект) 
```
</details>

## ПараметрыРаспределенияРасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров необходимых для регистрации документа к отложенному распределению расчетов.
//
// Возвращаемое значение:
// 	Структура - Описание:
// * Регистратор - ДокументСсылка - Документ по которому необходимо зарегистрировать отложенные расчеты.
// * РасчетПлановФоновымЗаданием - Булево - Плановые расчеты заполняются фоновым заданием.
// * Загрузка - Булево - Значение флага ОбменДанными.Загрузка
// * РаспределениеСУчетомПриемников - Булево - При запуске распределения будут учтены связи объектов расчетов
// * ТаблицаИзменений - ТаблицаЗначений - Объекты расчетов по которым есть изменения:
//                                        ** ПорядокФакт - Строка.
//                                        ** ПорядокПлан - Строка.
//                                        ** АналитикаУчетаПоПартнерам - СправочникСсылка.КлючиАналитикиУчетаПоПартнерам.
//                                        ** ОбъектРасчетов - СправочникСсылка.ОбъектыРасчетов.
//                                        ** ПоДаннымОбъектаРасчетовИсточника - Булево - Истина, если движение заполняется из приемника.
//                                        ** ВалютаРасчетов - СправочникСсылка.Валюты.
Функция ПараметрыРаспределенияРасчетов() Экспорт
```

Пример вызова
```bsl
Результат = ОперативныеВзаиморасчетыСервер.ПараметрыРаспределенияРасчетов() 
```
</details>

## ЗарегистрироватьИзмененияКОтложенномуРаспределению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует объекты расчетов для отложенного расчета по срокам и планом
//
// Параметры:
// 	Параметры - см. ПараметрыРаспределенияРасчетов
Процедура ЗарегистрироватьИзмененияКОтложенномуРаспределению(Параметры) Экспорт
```

Пример вызова
```bsl
ОперативныеВзаиморасчетыСервер.ЗарегистрироватьИзмененияКОтложенномуРаспределению(Параметры) 
```
</details>

## ВыполнитьОтложенноеРаспределение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет распределение расчетов по текущим заданиям к распределению в регистре ЗаданияКРаспределениюРасчетов
//
// Параметры:
// 	Параметры - Структура, Неопределено - В структуре передается таблица заданий для распределения:
// 	 *ДанныеКОтработке - см. ДанныеДляОбработки.
// 	АдресРезультата - Строка - адрес временного хранилища, в которое будет помещен результат работы процедуры.
Процедура ВыполнитьОтложенноеРаспределение(Параметры = Неопределено, АдресРезультата = Неопределено) Экспорт
```

Пример вызова
```bsl
ОперативныеВзаиморасчетыСервер.ВыполнитьОтложенноеРаспределение(Параметры, АдресРезультата);
```
</details>

## ЗапуститьОтложенноеРаспределениеВзаиморасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запускает распределение плановых расчетов по текущим заданиям к распределению в регистре ЗаданияКРаспределениюРасчетов
// в фоновом задании.
//
// Параметры:
// 	РаспределитьФактическиеРасчеты - Булево - Истина, запуск распределения фактических расчетов
//
Процедура ЗапуститьОтложенноеРаспределениеВзаиморасчетов(РаспределитьФактическиеРасчеты = Ложь) Экспорт
```

Пример вызова
```bsl
ОперативныеВзаиморасчетыСервер.ЗапуститьОтложенноеРаспределениеВзаиморасчетов(РаспределитьФактическиеРасчеты);
```
</details>

## ЗапуститьОтложенноеРаспределениеФактическихВзаиморасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запускает распределение фактических расчетов по текущим заданиям к распределению в регистре ЗаданияКРаспределениюРасчетов
// в фоновом задании.
//
// Метод предназначен для вызова из регламентного задания.
//
Процедура ЗапуститьОтложенноеРаспределениеФактическихВзаиморасчетов() Экспорт
```

Пример вызова
```bsl
ОперативныеВзаиморасчетыСервер.ЗапуститьОтложенноеРаспределениеФактическихВзаиморасчетов() 
```
</details>

## ПослеОбновленияРегистровВзаиморасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запускает отложенное распределение взаиморасчетов по срокам
Процедура ПослеОбновленияРегистровВзаиморасчетов() Экспорт
```

Пример вызова
```bsl
ОперативныеВзаиморасчетыСервер.ПослеОбновленияРегистровВзаиморасчетов() 
```
</details>

## МенеджерОтложенногоРаспределенияВзаиморасчетовАктивен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет активность фонового задания по распределению расчетов.
//
// Возвращаемое значение:
//   Булево - Истина, если есть активные задания.
//
Функция МенеджерОтложенногоРаспределенияВзаиморасчетовАктивен() Экспорт
```

Пример вызова
```bsl
Результат = ОперативныеВзаиморасчетыСервер.МенеджерОтложенногоРаспределенияВзаиморасчетовАктивен() 
```
</details>

## ПустыеСсылкиНаЗаказы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пустые ссылки на заказы.
//
// Возвращаемое значение:
//  Массив из Тип - Пустые ссылки на заказы
Функция ПустыеСсылкиНаЗаказы() Экспорт
```

Пример вызова
```bsl
Результат = ОперативныеВзаиморасчетыСервер.ПустыеСсылкиНаЗаказы() 
```
</details>

## СписокТиповУточняющихПланы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СписокТиповУточняющихПланы() Экспорт
```

Пример вызова
```bsl
Результат = ОперативныеВзаиморасчетыСервер.СписокТиповУточняющихПланы());
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
