---
title: Оперативный учет производства
slug: erp-uh/оперативный-учет-производства
---


## ИнтервалПланированияСтрокой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует представление интервала планирования в виде строки
//
// Параметры:
//  Период					- Дата - начало интервала планирования
//  ИнтервалПланирования	- ПеречислениеСсылка.ТочностьГрафикаПроизводства - Интервал планирования.
//
// Возвращаемое значение:
//   Строка   - представление интервала планирования.
//
Функция ИнтервалПланированияСтрокой(Период, ИнтервалПланирования) Экспорт
```

Пример вызова
```bsl
Результат = ОперативныйУчетПроизводства.ИнтервалПланированияСтрокой(Период, ИнтервалПланирования) 
```
</details>

## ГрафикРаботыВидаРабочегоЦентра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ Устарело_Производство21

// Формирует график работы вида рабочего центра
//
// Параметры:
//  ВидРабочегоЦентра	- СправочникСсылка.ВидыРабочихЦентров - Вид рабочего центра для которого нужно получить график работы
//  Начало				- Дата - Начало интервала
//  Окончание			- Дата - Окончание интервала.
//
// Возвращаемое значение:
//   ТаблицаЗначений   - График работы рабочего центра.
//
Функция ГрафикРаботыВидаРабочегоЦентра(ВидРабочегоЦентра, Начало, Окончание) Экспорт
```

Пример вызова
```bsl
Результат = ОперативныйУчетПроизводства.ГрафикРаботыВидаРабочегоЦентра(ВидРабочегоЦентра, Начало, Окончание) 
```
</details>

## СформироватьРасписаниеВыполненияМаршрутныхЛистов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует расписание выполнения маршрутных листов на выбранном рабочем центре
//  Расписание формируется с учетом порядка маршрутных листов и графика работы.
//
// Параметры:
//  Расписание						- ТаблицаЗначений, ДанныеФормыКоллекция, Массив		- расписание в котором будет рассчитан период и объем работы.
//	ПараметрыРабочегоЦентра			- Структура											- содержит параметры РЦ: РабочийЦентр,ВидРабочегоЦентра,ГрафикРаботы,ИнтервалПланирования.
//  Окончание						- Дата												- начало работы будет не позже этой даты.
//  ВариантНаладкиПрошлогоПериода	- СправочникСсылка.ВариантыНаладки					- вариант наладки прошлого периода.
//  Коэффициент						- Число												- коэффициент который нужно применить для модификации времени работы.
//  ГрафикРаботыСУчетомРасписания	- ТаблицаЗначений									- график работы с учетом занятого времени по данным расписания.
//
// Возвращаемое значение:
//  Булево - Истина, если расписание полностью рассчитано.
//
Функция СформироватьРасписаниеВыполненияМаршрутныхЛистов( Экспорт
```

Пример вызова
```bsl
Результат = ОперативныйУчетПроизводства.СформироватьРасписаниеВыполненияМаршрутныхЛистов();
```
</details>

## ОпределитьДатуОкончанияСУчетомГрафикаРаботы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает дату окончания с учетом графика работы рабочего центра
//
// Параметры:
//  Начало						- Дата - Начало работы
//  ВремяРаботы					- Число - Время работы в секундах
//  РабочийЦентр				- СправочникСсылка.РабочиеЦентры - Рабочий центр доступность которого нужно учесть
//  ВремяРаботыВРабочееВремя	- Число - Время работы в нерабочее время
//  ПериодыВыполнения			- Массив - содержит занятые периоды.
//
// Возвращаемое значение:
//   Дата	- Дата окончания работы.
//
Функция ОпределитьДатуОкончанияСУчетомГрафикаРаботы(Начало, ВремяРаботы, РабочийЦентр, ВремяРаботыВРабочееВремя = 0, ПериодыВыполнения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОперативныйУчетПроизводства.ОпределитьДатуОкончанияСУчетомГрафикаРаботы(Начало, ВремяРаботы, РабочийЦентр, ВремяРаботыВРабочееВремя, ПериодыВыполнения);
```
</details>

## ОпределитьДатуНачалаСУчетомГрафикаРаботы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает дату начала с учетом графика работы рабочего центра
//
// Параметры:
//  Окончание					- Дата - Окончание работы
//  ВремяРаботы					- Число - Время работы в секундах
//  РабочийЦентр				- СправочникСсылка.РабочиеЦентры - Рабочий центр доступность которого нужно учесть
//  НачалоПериодаПланирования	- Дата - Начало периода в котором выполняется планирование
//  ВремяРаботыВРабочееВремя	- Число - Время работы в нерабочее время
//  ПериодыВыполнения			- Массив - содержит занятые периоды.
//
// Возвращаемое значение:
//   Дата	- Дата начала работы
//
Функция ОпределитьДатуНачалаСУчетомГрафикаРаботы(Окончание, ВремяРаботы, РабочийЦентр, НачалоПериодаПланирования, ВремяРаботыВРабочееВремя = 0, ПериодыВыполнения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОперативныйУчетПроизводства.ОпределитьДатуНачалаСУчетомГрафикаРаботы(Окончание, ВремяРаботы, РабочийЦентр, НачалоПериодаПланирования, ВремяРаботыВРабочееВремя, ПериодыВыполнения);
```
</details>

## ТребуетсяСформироватьМаршрутныеЛисты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет сколько требуется сформировать маршрутных листов
//
// Параметры:
//  Подразделение					- СправочникСсылка.СтруктураПредприятия - подразделение для которого требуется сформировать МЛ
//  СписокРаспоряжений				- Массив - заказы на производство
//  СписокЭтапов					- Массив - этапы графика
//	УправлениеМаршрутнымиЛистами 	- ПеречислениеСсылка.УправлениеМаршрутнымиЛистами - ограничение по методике управления МЛ.
//
// Возвращаемое значение:
//   Число   - сколько маршрутных листов нужно сформировать.
//
Функция ТребуетсяСформироватьМаршрутныеЛисты(Подразделение, СписокРаспоряжений = Неопределено, СписокЭтапов = Неопределено, УправлениеМаршрутнымиЛистами = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОперативныйУчетПроизводства.ТребуетсяСформироватьМаршрутныеЛисты(Подразделение, СписокРаспоряжений, СписокЭтапов, УправлениеМаршрутнымиЛистами);
```
</details>

## КлючевыеВидыРабочихЦентров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует данные по ключевым видам рабочих центров
//
// Параметры:
//  СписокПодразделений				- Массив - подразделения по которому, необходимо получить данные
//									- СправочникСсылка.СтруктураПредприятия - подразделение, по которому необходимо получить данные
//  ДатаНачала						- Дата - начало периода в котором необходимо получить данные
//  ДатаОкончания					- Дата - окончание периода, в котором необходимо получить данные
//	ДобавитьИнформациюОРасписании	- Булево - Истина, если нужно добавить информацию о расписании.
//
// Возвращаемое значение:
//   ТаблицаЗначений	- содержит данные по ключевым видам рабочих центров.
//
Функция КлючевыеВидыРабочихЦентров(СписокПодразделений, ДатаНачала, ДатаОкончания, ДобавитьИнформациюОРасписании = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОперативныйУчетПроизводства.КлючевыеВидыРабочихЦентров(СписокПодразделений, ДатаНачала, ДатаОкончания, ДобавитьИнформациюОРасписании);
```
</details>

## РассчитатьПооперационноеРасписаниеМоделиВФоновомРежиме
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициирует расчет пооперационного расписания в соответствии с параметрами конкретной модели планирования.
//
// Параметры:
//  ПараметрыПланирования	 - см. Обработка.ПооперационноеПланирование.ИнициализироватьПараметрыПланирования.
//  АдресХранилища			 - УникальныйИдентификатор - адрес временного хранилища, в которое будет
//                                    					 помещен результат работы метода.
//
Процедура РассчитатьПооперационноеРасписаниеМоделиВФоновомРежиме(ПараметрыПланирования, АдресХранилища) Экспорт
```

Пример вызова
```bsl
ОперативныйУчетПроизводства.РассчитатьПооперационноеРасписаниеМоделиВФоновомРежиме(ПараметрыПланирования, АдресХранилища) 
```
</details>

## ПривязатьСтрокиВыпускаКРаспоряжениям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет поиск и заполнение распоряжений в коллекции
//
// Параметры:
// 		Ссылка - ДокументСсылка.ВыпускПродукции - заполняемый документ
// 		КоллекцияДанных - ДанныеФормыКоллекция, ТаблицаЗначений - Таблица, в которой необходимо заполнить распоряжения
// 		Распоряжение - ДокументСсылка.МаршрутныйЛистПроизводства - Распоряжение, если не по всем распоряжениям
// 		Подразделение - СправочникСсылка.СтруктураПредприятия - Подразделение, по которому выполняется подбор распоряжений
// 		НаправлениеВыпуска - ПеречислениеСсылка.ХозяйственныеОперации - Операция, определяет выпуск на склад или в подразделение.
//
Процедура ПривязатьСтрокиВыпускаКРаспоряжениям(Ссылка, КоллекцияДанных, Распоряжение, Подразделение, НаправлениеВыпуска) Экспорт
```

Пример вызова
```bsl
ОперативныйУчетПроизводства.ПривязатьСтрокиВыпускаКРаспоряжениям(Ссылка, КоллекцияДанных, Распоряжение, Подразделение, НаправлениеВыпуска) 
```
</details>

## ЗаполнитьВыборВремени
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет список для выбора времени
//
// Параметры:
//  СписокВыбора	- СписокЗначений - список в который нужно добавить время
//  Начало			- Число - час, с которого нужно начать заполнение
//  Окончание		- Число - час, по который нужно заполнить
//  ККонцуЧаса		- Булево - истина, если дату нужно привести к концу часа.
//
Процедура ЗаполнитьВыборВремени(СписокВыбора, Начало = 0, Окончание = 23, ККонцуЧаса = Ложь) Экспорт
```

Пример вызова
```bsl
ОперативныйУчетПроизводства.ЗаполнитьВыборВремени(СписокВыбора, Начало, Окончание, ККонцуЧаса);
```
</details>

## ИнтервалПланированияРаботыВидаРабочегоЦентра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет интервал планирования работы вида рабочего центра
//
// Параметры:
//  ВидРабочегоЦентра	- СправочникСсылка.ВидыРабочихЦентров - Вид рабочего центра для которого нужно интервал планирования.
//
// Возвращаемое значение:
//   ПеречислениеСсылка.ТочностьГрафикаПроизводства - интервал планирования работы вида рабочего центра.
//
Функция ИнтервалПланированияРаботыВидаРабочегоЦентра(ВидРабочегоЦентра) Экспорт
```

Пример вызова
```bsl
Результат = ОперативныйУчетПроизводства.ИнтервалПланированияРаботыВидаРабочегоЦентра(ВидРабочегоЦентра) 
```
</details>

## ПересчитатьКоличествоТабличнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает количество в табличной части.
//
// Параметры:
//  СписокСтрок - Массив - строки для обработки.
//  Коэффициент	- Число - коэффициент пересчета.
//  ЕстьУпаковки - Булево - флаг наличия упаковок в табличной части.
//  СуффиксКоличество - Строка - суффикс колонки с количеством.
//  СуффиксКоличествоНорматив - Строка - суффикс колонки с нормативным количеством.
//
Процедура ПересчитатьКоличествоТабличнойЧасти(СписокСтрок, Коэффициент, ЕстьУпаковки, СуффиксКоличество = Неопределено, СуффиксКоличествоНорматив = Неопределено) Экспорт
```

Пример вызова
```bsl
ОперативныйУчетПроизводства.ПересчитатьКоличествоТабличнойЧасти(СписокСтрок, Коэффициент, ЕстьУпаковки, СуффиксКоличество, СуффиксКоличествоНорматив);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
