---
title: Организации локализация
slug: erp-uh/организации-локализация
---


## ПолучитьПараметрыФормыВыбораДляКода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу классификатора из макета с предопределенными элементами. Применяется для классификаторов (ОКВЭД,
// ОКОПФ и т.д.) Макеты хранятся в макетах данного справочника (см. общую форму "ФормаВыбораКода").
//	Параметры:
//		НазваниеМакета - Строка - имя макета, хранящего данные с предопределенными элементами классификатора.
//		ТекущийПериод - Дата - в данном методе не используется, однако может быть обязательной в случае обращения к другим классификаторам из общей формы.
//	Возвращаемое значение:
//		Структура - структура параметров со следующими свойствами:
//			* СписокКодов - ТаблицаЗначений - таблица классификатора с колонками:
//				** Код - Строка - строковое представление кода элемента классификатора.
//				** Наименование - Строка - наименование элемента классификатора.
//
Функция ПолучитьПараметрыФормыВыбораДляКода(НазваниеМакета, ТекущийПериод) Экспорт
```

Пример вызова
```bsl
Результат = ОрганизацииЛокализация.ПолучитьПараметрыФормыВыбораДляКода(НазваниеМакета, ТекущийПериод) 
```
</details>

## СоответствиеКодовКНаименованиюИзМакета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие кодов к наименованию, указанное в макете. Применяется для классификаторов (ОКВЭД, ОКОПФ и т.д.).
//
//	Параметры:
//		ИмяМакета - Строка - Имя макета, как оно задано в конфигураторе. Если он не будет обнаружен - будет возвращено пустое соответствие.
//		ИмяОбласти - Строка - Имя анализируемой области макета.
//
//	Возвращаемое значение:
//		ФиксированноеСоответствие - Состоит из:
//			* Ключ - Строка -  код, указанный в первой колонке макета;
//			* Значение - Строка - наименование, указанное во второй колонке макета.
//
Функция СоответствиеКодовКНаименованиюИзМакета(ИмяМакета, ИмяОбласти = "Классификатор") Экспорт
```

Пример вызова
```bsl
Результат = ОрганизацииЛокализация.СоответствиеКодовКНаименованиюИзМакета(ИмяМакета, ИмяОбласти);
```
</details>

## ДополнитьСписокРеквизитовОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьСписокРеквизитовОрганизации(Реквизиты) Экспорт
```

Пример вызова
```bsl
ОрганизацииЛокализация.ДополнитьСписокРеквизитовОрганизации(Реквизиты) 
```
</details>

## ДополнитьРеквизитыОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьРеквизитыОрганизации(Организация, СтруктураРеквизитов, ВыборкаПоОрганизации) Экспорт
```

Пример вызова
```bsl
ОрганизацииЛокализация.ДополнитьРеквизитыОрганизации(Организация, СтруктураРеквизитов, ВыборкаПоОрганизации) 
```
</details>

## ЕстьОбособленныеПодразделения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет наличие у организации обособленных подразделений (выделенных на отдельный баланс).
//
// Параметры:
//  Организация - СправочникСсылка.Организации
//
// Возвращаемое значение:
//  Булево - Истина, если в информационной базе ведется учет
//           обособленных подразделений организации, выделенных на отдельный баланс
//
Функция ЕстьОбособленныеПодразделения(Организация) Экспорт
```

Пример вызова
```bsl
Результат = ОрганизацииЛокализация.ЕстьОбособленныеПодразделения(Организация) 
```
</details>

## КППНаДату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает КПП организации на указанную дату.
//
// Параметры:
//     Организация - СправочникСсылка.Организации - Организация.
//     ДатаСведений - Дата - Дата, на которую нужно получить КПП организации.
//
// Возвращаемое значение:
//     Строка - КПП.
//
Функция КППНаДату(Организация, ДатаСведений) Экспорт
```

Пример вызова
```bsl
Результат = ОрганизацииЛокализация.КППНаДату(Организация, ДатаСведений) 
```
</details>

## БуквенныеКодыРазделовОКВЭД2
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ Локализация

// Возвращает таблицу соответствия числового кода (первых 2 цифр - класса) и буквенного кода раздела ОКВЭД2
//
// Возвращаемое значение:
//   ТаблицаЗначений - Содержит колонки:
//    * Код - Строка - Первые 2 цифры числового кода из классификатора ОКВЭД2 (класс)
//    * Раздел - Строка - Буквенное обозначение раздела, в который входит указанный класс
//
Функция БуквенныеКодыРазделовОКВЭД2() Экспорт
```

Пример вызова
```bsl
Результат = ОрганизацииЛокализация.БуквенныеКодыРазделовОКВЭД2() 
```
</details>

## ОбновитьНаименованияОКВЭД2
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьНаименованияОКВЭД2() Экспорт
```

Пример вызова
```bsl
ОрганизацииЛокализация.ОбновитьНаименованияОКВЭД2() 
```
</details>

## НайтиОрганизацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет поиск организации по ИНН и КПП (если указан).
//
// Параметры:
//   ИНН - Строка - ИНН организации или индивидуального предпринимателя.
//   КПП - Строка - КПП организации.
//   БезОбособленныхПодразделений - Булево - исключает из поиска обособленные подразделения.
//
// Возвращаемое значение:
//   СправочникСсылка.Организации - ссылка на найденную организацию или ПустаяСсылка.
//
Функция НайтиОрганизацию(ИНН, КПП = Неопределено, БезОбособленныхПодразделений = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ОрганизацииЛокализация.НайтиОрганизацию(ИНН, КПП, БезОбособленныхПодразделений);
```
</details>

## ДобавитьКомандыОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет список команд отчетов.
//
// Параметры:
//   КомандыОтчетов - См. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
//   Параметры - См. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.Параметры
//
Процедура ДобавитьКомандыОтчетов(КомандыОтчетов, Параметры) Экспорт
```

Пример вызова
```bsl
ОрганизацииЛокализация.ДобавитьКомандыОтчетов(КомандыОтчетов, Параметры) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
