---
title: Ответственные лица БП
slug: erp-uh/ответственные-лица-бп
---


## ПустаяСтруктураОтветственныхЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает пустую структуру со сведениями об ответственных лицах.
//
// Возвращаемое значение:
//	Структура - Структура с ключами, соответствующими имени значений перечисления ОтветственныеЛица вида:
//		* Руководитель - СправочникСсылка.ФизическиеЛица - Ссылка на руководителя;
//		* РуководительФИО - Структура - Содержит ключи:
//			** Фамилия - Строка - Фамилия.
//			** Имя - Строка - Имя.
//			** Отчество - Строка - Отчество.
//			** Представление - Строка - Полное ФИО.
//		* РуководительПредставление - Строка - Фамилия И.О.
//		* РуководительДолжность - СправочникСсылка.Должности - Должность
//		* РуководительДолжностьПредставление - Строка - Название должности.
//
Функция ПустаяСтруктураОтветственныхЛиц() Экспорт
```

Пример вызова
```bsl
Результат = ОтветственныеЛицаБП.ПустаяСтруктураОтветственныхЛиц() 
```
</details>

## ОтветственныеЛица
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает структуру со сведениями об ответственных лицах.
//
// Параметры:
//  Организация   - СправочникСсылка.Организации - Организация, для которой нужно определить ответственных лиц.
//  ДатаСреза     - Дата - Дата со временем, на которые необходимо определить сведения.
//  Подразделение - СправочникСсылка.ПодразделенияОрганизаций - Подразделение, для которого необходимо определить ответственных лиц.
//
// Возвращаемое значение:
//	Структура - Структура с ключами, соответствующими имени значений перечисления ОтветственныеЛица вида:
//		* Руководитель - СправочникСсылка.ФизическиеЛица - Ссылка на руководителя.
//		* РуководительФИО - Структура - Содержит ключи:
//			** Фамилия - Строка - Фамилия.
//			** Имя - Строка - Имя.
//			** Отчество - Строка - Отчество.
//			** Представление - Строка - Полное ФИО.
//		* РуководительПредставление - Строка - Фамилия И.О.
//		* РуководительДолжность - СправочникСсылка.Должности - Должность.
//		* РуководительДолжностьПредставление - Строка - Название должности.
//
Функция ОтветственныеЛица(Организация, ДатаСреза, Подразделение = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОтветственныеЛицаБП.ОтветственныеЛица(Организация, ДатаСреза, Подразделение);
```
</details>

## ПустаяСтруктураУполномоченныхЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает пустую структуру с описанием реквизитов подписи по умолчанию указанного пользователя.
//
// Возвращаемое значение:
//	Структура - Содержит ключи:
//		* Руководитель - СправочникСсылка.ФизическиеЛица - Руководитель.
//		* РуководительНаОсновании - Строка - Основание действий руководителя.
//		* ГлавныйБухгалтер - СправочникСсылка.ФизическиеЛица - Главный бухгалтер.
//		* ГлавныйБухгалтерНаОсновании - Строка - Основание действий главного бухгалтера.
//		* ОтветственныйЗаОформление - СправочникСсылка.ФизическиеЛица - Лицо, ответственное за оформление.
//
Функция ПустаяСтруктураУполномоченныхЛиц() Экспорт
```

Пример вызова
```bsl
Результат = ОтветственныеЛицаБП.ПустаяСтруктураУполномоченныхЛиц() 
```
</details>

## ОтветственноеЛицоНаСкладе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ответственное лицо на складе на указанную дату.
//
// Параметры:
//	Склад - СправочникСсылка.Склады - Склад, для которого нужно получить ответственное лицо.
//	Дата - Дата - Дата, на которую нужно получить ответственное лицо.
//
// Возвращаемое значение:
//	СправочникСсылка.ФизическиеЛица - Ответственное лицо склада.
//
Функция ОтветственноеЛицоНаСкладе(Склад, Дата) Экспорт
```

Пример вызова
```bsl
Результат = ОтветственныеЛицаБП.ОтветственноеЛицоНаСкладе(Склад, Дата) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
