---
title: Ответственные лица сервер
slug: erp-uh/ответственные-лица-сервер
---


## ПолучитьДанныеОтветственногоЛица
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую информацию об ответственном лице организации.
//
// Параметры:
//	Организация - СправочникСсылка.Организации - отбор по организации
//	Дата - Дата - отбор по дате
//  ОтветственноеЛицо - ПеречислениеСсылка.ОтветственныеЛицаОрганизаций - "вид" ответственного лица.
//
// Возвращаемое значение:
// 	Структура - Содержит ключи:
//		* СтруктурнаяЕдиница - СправочникСсылка.СтруктураПредприятия -
//		* ОтветственноеЛицо - ПеречислениеСсылка.ОтветственныеЛицаОрганизаций -
//		* ФизическоеЛицо - СправочникСсылка.ФизическиеЛица -
//		* Должность - Строка, СправочникСсылка -
//
Функция ПолучитьДанныеОтветственногоЛица(Организация, Дата = Неопределено, ОтветственноеЛицо = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОтветственныеЛицаСервер.ПолучитьДанныеОтветственногоЛица(Организация, Дата, ОтветственноеЛицо);
```
</details>

## ПолучитьОтветственныеЛицаОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую информацию об ответственных лицах организации.
//
// Параметры:
//	Организация - СправочникСсылка.Организации - отбор по организации
//	Дата - Дата - отбор по дате.
//
// Возвращаемое значение:
// Структура - Содержит ключи вида:
//		%ВидОтветственного% - СправочникСсылка.ФизическиеЛица - физическое лицо, соответствующее ответственному лицу
//		%ВидОтветственного%Должность - Строка - должность ответственного лица
//
// В ключи вместо %ВидОтветственного% подставляется имя значения перечисления ОтветственныеЛицаОрганизаций как оно задано в конфигураторе.
// Количество каждого из этих ключей соответствует количеству значений перечисления ОтветственныеЛицаОрганизаций.
//
Функция ПолучитьОтветственныеЛицаОрганизации(Организация, Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОтветственныеЛицаСервер.ПолучитьОтветственныеЛицаОрганизации(Организация, Дата);
```
</details>

## ПолучитьТаблицуОтветственныхЛицПоОтбору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу ответственных лиц, сформированную в соответствии с произвольным отбором.
//
// Параметры:
//  Отбор - Структура из КлючИЗначение - структура, содержащая параметры отбора данных справочника ОтветственныеЛицаОрганизаций:
//		* Ключ - Строка - имя реквизита справочника
//		* Значение - Произвольный - значение для отбора по ключу
//	ДопустимыПомеченныеНаУдаление - Булево - выводить в результирующую таблицу помеченные на удаление элементы.
//	СтрокаПоиска - Строка - Строка поиска. Необязательный.
//
// Возвращаемое значение:
//	ТаблицаЗначений - Содержит колонки:
//		* Ссылка - СправочникСсылка.ОтветственныеЛицаОрганизаций -
//		* Владелец - СправочникСсылка.Организации -
//		* ОтветственноеЛицо - ПеречислениеСсылка.ОтветственныеЛицаОрганизаций -
//		* ФизическоеЛицо - СправочникСсылка.ФизическиеЛица -
//		* Должность - Строка -
//		* ПравоПодписиПоДоверенности - Булево -
//		* ОснованиеПраваПодписи - Строка -
//		* ДатаНачала - Дата -
//		* ДатаОкончания - Дата -
//		* ДокументПраваПодписи - Строка -
//		* НомерДокументаПраваПодписи - Строка -
//		* ДатаДокументаПраваПодписи - Дата -
//
Функция ПолучитьТаблицуОтветственныхЛицПоОтбору(Знач Отбор, ДопустимыПомеченныеНаУдаление = Ложь, СтрокаПоиска = "") Экспорт
```

Пример вызова
```bsl
Результат = ОтветственныеЛицаСервер.ПолучитьТаблицуОтветственныхЛицПоОтбору(Отбор, ДопустимыПомеченныеНаУдаление, СтрокаПоиска);
```
</details>

## ПараметрыОтветственныхЛицПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры ответственных лиц по умолчанию.
//
// Возвращаемое значение:
//  Структура - Параметры ответственных лиц по умолчанию:
// * ИмяРеквизитаОрганизация - Строка -
// * РеквизитыОтветственныеЛица - Неопределено, Структура - В структуре:
//		* Ключ - Строка - имя поля в запросе для получения значения ответственного лица
//		* Значение - ПеречислениеСсылка.ОтветственныеЛицаОрганизаций - "вид" ответственного лица
// * ИмяТаблицыОтветственныеЛица - Строка -
// * ПсевдонимыДанныхОтветственныхЛиц - Строка, Неопределено -
Функция ПараметрыОтветственныхЛицПоУмолчанию() Экспорт
```

Пример вызова
```bsl
Результат = ОтветственныеЛицаСервер.ПараметрыОтветственныхЛицПоУмолчанию() 
```
</details>

## СформироватьВременнуюТаблицуОтветственныхЛицДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует временную таблицу, содержащую информацию об ответственных лицах в разрезе документов.
// Используется для формирования печатных форм документов подсистемой печати
//	- перед выборкой данных из шапки документа вызвать эту процедуру
//	- при выборке данных создать левое соединение таблицы документов с временной таблицей ТаблицаОтветственныеЛица по полю Ссылка.
//
// Параметры:
//	ОтборДокументы - Массив Из ДокументСсылка - ссылки на документы, по которым необходимо получить ответственных лиц.
//		Важно: если передан массив, то все его элементы должны иметь одинаковый тип.
//	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - в него помещается сформированная временная таблица ТаблицаОтветственныеЛица
//	ПараметрыОтветственныхЛиц- Неопределено, Структура - В структуре:
//		* ИмяРеквизитаОрганизация - Строка - Имя поля документа для получения организации-владельца ответственного лица
//		* РеквизитыОтветственныеЛица - Неопределено, Структура - В структуре:
//			* Ключ - Строка - имя поля в запросе для получения значения ответственного лица
//			* Значение - ПеречислениеСсылка.ОтветственныеЛицаОрганизаций - "вид" ответственного лица
//		* ИмяТаблицыОтветственныеЛица - Строка - позволяет задать имя для формируемой временной таблицы
//		* ПсевдонимыДанныхОтветственныхЛиц - Неопределено - Соответствие - содержит данные:
//			* Ключ - ПеречислениеСсылка.ОтветственныеЛицаОрганизаций.
//			* Значение - см. ОтветственныеЛицаСервер.ПсевдонимыДанныхОтветственныхЛицПоУмолчанию
// Количество строк в таблице "ТаблицаОтветственныеЛица" соответствует количеству элементов в ОтборДокументы.
//
// Структура временной таблицы "ТаблицаОтветственныеЛица"
//		Ссылка - ссылка на документ из ОтборДокументы
//		%Реквизит% - СправочникСсылка.ОтветственныеЛицаОрганизаций - значение реквизита ответственного лица из документа
//		%Реквизит%ФизическоеЛицо - СправочникСсылка.ФизическиеЛица - физическое лицо, соответствующее ответственному лицу
//		%Реквизит%Наименование - Строка - наименование для печати ответственного лица
//		%Реквизит%Должность - Строка - должность ответственного лица
//		%Реквизит%ОснованиеПраваПодписи - Строка - основание права подписи для неосновного ответственного лица
// Для полей, начинающихся с %Реквизит%, вместо %Реквизит% подставляется имя реквизита ответственного лица как оно задано в конфигураторе
// Количество каждого из этих полей соответствует количеству реквизитов ответственных лиц документа.
//
// Например, если в метаданных документа есть два реквизита ответственных лиц - Руководитель и Бухгалтер,
// то таблица ТаблицаОтветственныеЛица будет иметь следующую структуру:
//	Ссылка
//	Руководитель
//	РуководительФизическоеЛицо
//	РуководительНаименование
//	РуководительДолжность
//	РуководительОснованиеПраваПодписи
//	Бухгалтер
//	БухгалтерФизическоеЛицо
//	БухгалтерНаименование
//	БухгалтерДолжность
//	БухгалтерОснованиеПраваПодписи.
//
Процедура СформироватьВременнуюТаблицуОтветственныхЛицДокументов(ОтборДокументы, МенеджерВременныхТаблиц, ПараметрыОтветственныхЛиц = Неопределено) Экспорт
```

Пример вызова
```bsl
ОтветственныеЛицаСервер.СформироватьВременнуюТаблицуОтветственныхЛицДокументов(ОтборДокументы, МенеджерВременныхТаблиц, ПараметрыОтветственныхЛиц);
```
</details>

## ЗаполнитьМенеджера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет менеджера в документе по договору, соглашению и партнеру
//
// Параметры:
//  ДокументОбъект - ДокументОбъект, ДанныеФормыСтруктура - заполняемый объект
//  Перезаполнить - Булево - если Истина, то заполнять даже заполненное значение.
//  ПоляПоиска - Строка - путь к данным, перечисленные через запятую, в которых есть значение реквизита Менеджер.
//                        Путь состоит из названия реквизита документа, точки и названия реквизита,
//                        содержащего ссылку на менеджера. Например "Клиент.ОсновнойМенеджер, Договор.Менеджер"
Процедура ЗаполнитьМенеджера(ДокументОбъект, Перезаполнить = Истина, ПоляПоиска = "") Экспорт
```

Пример вызова
```bsl
ОтветственныеЛицаСервер.ЗаполнитьМенеджера(ДокументОбъект, Перезаполнить, ПоляПоиска);
```
</details>

## ПсевдонимыДанныхОтветственныхЛицПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает пустую структуру псевдонимов данных ответственных лиц.
//
// Возвращаемое значение:
//		Структура - содержит:
//			* Наименование - Строка - Наименование.
//			* ФИО - Строка - ФИО.
//			* Должность - Строка - Должность.
//			* ОснованиеПраваПодписи - Строка - ОснованиеПраваПодписи.
Функция ПсевдонимыДанныхОтветственныхЛицПоУмолчанию() Экспорт
```

Пример вызова
```bsl
Результат = ОтветственныеЛицаСервер.ПсевдонимыДанныхОтветственныхЛицПоУмолчанию() 
```
</details>

## СведенияОбОтветственныхЛицахЗарплатаИКадры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТ

// Возвращает структуру, содержащую информацию об ответственных лицах организации для подсистемы зарплата и кадры.
//
// Параметры:
//		Организация - СправочникСсылка.Организации - Ссылка на организацию
//		Сведения - Строка - строка с идентификаторами, разделенными запятыми
//		Дата - Дата - Дата получения сведений.
//
// Возвращаемое значение:
//		Структура - структура со свойствами, совпадающими с параметром «Сведения»:
//			* Руководитель - СправочникСсылка.ФизическиеЛица - руководитель организации
//			* ДолжностьРуководителя - Строка, СправочникСсылка - должность руководителя
//			* ГлавныйБухгалтер - СправочникСсылка.ФизическиеЛица - главбух организации
//			* Кассир - СправочникСсылка.ФизическиеЛица - Кассир организации
//			* ДолжностьКассира - Строка, СправочникСсылка -должность кассира
//			* РуководительКадровойСлужбы - СправочникСсылка.ФизическиеЛица - Руководитель кадровой службы
//			* ДолжностьРуководителяКадровойСлужбы - Строка, СправочникСсылка - Должность руководителя кадровой службы
//			* ОтветственныйЗаВУР - СправочникСсылка.ФизическиеЛица - Ответственный за ВУР
//			* ДолжностьОтветственногоЗаВУР - Строка, СправочникСсылка - Должность ответственного за ВУР.
//
Функция СведенияОбОтветственныхЛицахЗарплатаИКадры(Организация, Сведения, Дата) Экспорт
```

Пример вызова
```bsl
Результат = ОтветственныеЛицаСервер.СведенияОбОтветственныхЛицахЗарплатаИКадры(Организация, Сведения, Дата) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
