---
title: Открытие форм при начале работы системы
slug: erp-uh/открытие-форм-при-начале-работы-системы
---


## ФормыОткрываемыеПриНачалеРаботыСистемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив, элементами которого являются структуры параметров форм, которые требуется открыть при начале
// работы системы.
//
// Возвращаемое значение:
//	Массив - массив, элементами которого являются структуры параметров форм, которые требуется
//		открыть при начале работы системы:
//		* ИмяЗапускаемойФормы - Строка - полное имя открываемой формы.
//		* Роль - Строка - имя роли, которая дает пользователю право на запуск формы.
//		* НеобходимыНастройки - Булево - для открываемой формы должны быть заданы настройки.
//		* ИмяФормыНастроек - Строка - если НеобходимыНастройки = ИСТИНА, то в этом параметре указывается полное имя формы
//			редактирования настроек.
//		* ПараметрЗапуска - Строка - параметр запуска, наличие которого будет проверяться при начале работы системы,
//			форма будет открыта, если передан параметр запуска или настроено, что эту форму нужно открывать по умолчанию
//			(т.е. без проверки параметра запуска).
//		* НастройкиУстановлены - Булево - Истина - настройки, необходимые для открытия формы установлены.
//		* Параметры - Структура - параметры формы, используемые при открытии формы.
//		* ОткрыватьПоУмолчанию - Булево - Истина - форма открывается по умолчанию при начале работы системы.
//
Функция ФормыОткрываемыеПриНачалеРаботыСистемы() Экспорт
```

Пример вызова
```bsl
Результат = ОткрытиеФормПриНачалеРаботыСистемы.ФормыОткрываемыеПриНачалеРаботыСистемы() 
```
</details>

## ИспользуемыеФормыПриНачалеРаботыСистемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив, элементами которого являются значения перечислений форм, открываемых при начале работы системы.
//
// Параметры:
//	ДанныеВыбора - Неопределено, СписокЗначений - список значений открываемых форм.
//	Параметры - Неопределено, Структура - параметры выбора.
//
// Возвращаемое значение:
//	Массив - массив, элементами которого являются значения перечислений форм, открываемых при начале
//		работы системы.
//
Функция ИспользуемыеФормыПриНачалеРаботыСистемы(ДанныеВыбора = Неопределено, Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОткрытиеФормПриНачалеРаботыСистемы.ИспользуемыеФормыПриНачалеРаботыСистемы(ДанныеВыбора, Параметры);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
