---
title: Отложенные задания
slug: erp-uh/отложенные-задания
---


## Обработать
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обрабатывает задания.
//
// Параметры:
//  Задания - Структура - ключ: имя регистра сведений очереди заданий
//                        значение: - Структура       - ключи совпадают с именам измерений, ресурсов
//                                                      и реквизитов регистра заданий.
//                                  - ТаблицаЗначений - имена колонок совпадают с именам измерений, ресурсов
//                                                      и реквизитов регистра сведений заданий.
//  СгенерироватьИдентификаторЗаписи - Булево - если ИСТИНА, тогда идентификатор записи будет сгенерирован
//                                              автоматически. По умолчанию ИСТИНА.
//
Процедура Обработать(Задания, СгенерироватьИдентификаторЗаписи = Истина) Экспорт
```

Пример вызова
```bsl
ОтложенныеЗадания.Обработать(Задания, СгенерироватьИдентификаторЗаписи);
```
</details>

## ОбработатьЗаданияОчереди
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обрабатывает задания очереди.
//
// Параметры:
//  Очередь - Строка - имя регистра сведений очереди заданий
//  Данные - Структура, ТаблицаЗначений - ключи структуры и имена колонок таблицы совпадают с именам измерений,
//                                        ресурсов и реквизитов регистра заданий.
//  СгенерироватьИдентификаторЗаписи - Булево - если ИСТИНА, тогда идентификатор записи будет сгенерирован
//                                              автоматически. По умолчанию ИСТИНА.
//
Процедура ОбработатьЗаданияОчереди(Очередь, Данные, СгенерироватьИдентификаторЗаписи = Истина) Экспорт
```

Пример вызова
```bsl
ОтложенныеЗадания.ОбработатьЗаданияОчереди(Очередь, Данные, СгенерироватьИдентификаторЗаписи);
```
</details>

## Добавить
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет задания.
//
// Параметры:
//  Задания - Структура - ключ: имя регистра сведений очереди заданий
//                        значение: - Структура       - ключи совпадают с именам измерений, ресурсов
//                                                      и реквизитов регистра заданий.
//                                  - ТаблицаЗначений - имена колонок совпадают с именам измерений, ресурсов
//                                                      и реквизитов регистра сведений заданий.
//  СгенерироватьИдентификаторЗаписи - Булево - если ИСТИНА, тогда идентификатор записи будет сгенерирован
//                                              автоматически. По умолчанию ЛОЖЬ.
//
// Возвращаемое значение:
//  ТаблицаЗначений - колонки:
//   * Очередь               - Строка - имя регистра сведений очереди заданий
//   * ИндексСтроки          - Число - определяет очередность выполнения очередей
//   * ИдентификаторыЗаписей - Массив из УникальныйИдентификатор - идентификаторы записей заданий (измерение
//                                                                 ИдентификаторЗаписи регистра сведений очереди
//                                                                 заданий).
//
Функция Добавить(Задания, СгенерироватьИдентификаторЗаписи = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОтложенныеЗадания.Добавить(Задания, СгенерироватьИдентификаторЗаписи);
```
</details>

## ДобавитьЗаданияВОчередь
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет задания в очередь.
//
// Параметры:
//  Очередь - Строка - имя регистра сведений очереди заданий
//  Данные - Структура, ТаблицаЗначений - ключи структуры и имена колонок таблицы совпадают с именам измерений,
//                                        ресурсов и реквизитов регистра заданий.
//  СгенерироватьИдентификаторЗаписи - Булево - если ИСТИНА, тогда идентификатор записи будет сгенерирован
//                                              автоматически. По умолчанию ЛОЖЬ.
//
// Возвращаемое значение:
//  ТаблицаЗначений - колонки:
//   * Очередь               - Строка - имя регистра сведений очереди заданий
//   * ИндексСтроки          - Число - определяет очередность выполнения очередей
//   * ИдентификаторыЗаписей - Массив из УникальныйИдентификатор - идентификаторы записей заданий (измерение
//                                                                 ИдентификаторЗаписи регистра сведений очереди
//                                                                 заданий).
//
Функция ДобавитьЗаданияВОчередь(Очередь, Данные, СгенерироватьИдентификаторЗаписи = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ОтложенныеЗадания.ДобавитьЗаданияВОчередь(Очередь, Данные, СгенерироватьИдентификаторЗаписи);
```
</details>

## Запустить
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запускает выполнения заданий.
// Для того, что бы обработать только указанные записи регистров сведений очереди заданий, нужно в параметр
// Очереди данного метода передать таблицу значений см. Добавить и в поле ИдентификаторыЗаписей добавить
// идентификаторы записей (значения ИдентификаторЗаписи из регистра сведений очереди заданий).
//
// Параметры:
//  Очереди - Строка, Массив из Строка, ТаблицаЗначений, Неопределено -
//             1. Строка           - имя регистра сведений очереди заданий
//             2. Массив из Строка - имена регистров сведений очередей заданий
//             3. ТаблицаЗаданий   - см. ИнициализироватьТаблицуЗаданий
//             4. Неопределено     - запускает все очереди.
//
Процедура Запустить(Знач Очереди = Неопределено) Экспорт
```

Пример вызова
```bsl
ОтложенныеЗадания.Запустить(Очереди);
```
</details>

## ТекстОшибкиВыполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание ошибки выполнения задания
//
// Параметры:
//  Поля          - Структура - имена и представления полей участвующих в формировании описания ошибки
//  Данные        - Структура, ВыборкаИзРезультатаЗапроса, СтрокаТаблицыЗначений - данные задания
//  ТекстОшибки   - Строка - текст ошибки
//
// Возвращаемое значение:
//  Строка - текст ошибки
//
Функция ТекстОшибкиВыполнения(Поля, Данные, ТекстОшибки) Экспорт
```

Пример вызова
```bsl
Результат = ОтложенныеЗадания.ТекстОшибкиВыполнения(Поля, Данные, ТекстОшибки) 
```
</details>

## ИнициализироватьТаблицуЗаданий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует таблицу заданий, которую можно передать на вход метода см. Запустить
//
// Возвращаемое значение:
//  ТаблицаЗначений - Таблица заданий:
//   * Очередь               - Строка - имя регистра сведений очереди заданий.
//   * ИдентификаторыЗаписей - Массив из УникальныйИдентификатор - идентификаторы записей заданий (измерение
//                                                                 ИдентификаторЗаписи регистра сведений очереди
//                                                                 заданий).
//
Функция ИнициализироватьТаблицуЗаданий() Экспорт
```

Пример вызова
```bsl
Результат = ОтложенныеЗадания.ИнициализироватьТаблицуЗаданий() 
```
</details>

## ИдентификаторыЗаписей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает идентификаторы записей регистра сведений очереди заданий.
//
// Параметры:
//  Очередь - Строка    - имя регистра сведений очереди заданий.
//  Отбор   - Структура - структура отбора записей регистра сведений очереди заданий:
//                        ключи    - имена измерений, ресурсов, реквизитов регистра сведений очереди заданий,
//                        значение - единичное значение или массив значений.
//
// Возвращаемое значение:
//  Массив из УникальныйИдентификатор - идентификаторы записей (измерение ИдентификаторЗаписи регистра сведений очереди
//                                      заданий).
//
Функция ИдентификаторыЗаписей(Очередь, Отбор) Экспорт
```

Пример вызова
```bsl
Результат = ОтложенныеЗадания.ИдентификаторыЗаписей(Очередь, Отбор) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
