---
title: Отправка почтовых сообщений
slug: erp-uh/отправка-почтовых-сообщений
---


## ПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает видимость команды отправки по электронной почте на форме.
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - форма, в которой необходимо настроить видимость команды.
//
Процедура ПриСозданииНаСервере(Форма) Экспорт
```

Пример вызова
```bsl
ОтправкаПочтовыхСообщений.ПриСозданииНаСервере(Форма) 
```
</details>

## АдресаЭлектроннойПочты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает адреса электронной почты из контактной информации контрагента и его контактных лиц.
//
// Параметры:
//  Контрагент - СправочникСсылка.Контрагенты - ссылка на контрагента.
//
// Возвращаемое значение:
//  Массив - содержит структуры с адресом электронной почты и владельцем контактной информации.
//           Состав ключей структуры см. НовыеПараметрыПолучателя().
//
Функция АдресаЭлектроннойПочты(Контрагент) Экспорт
```

Пример вызова
```bsl
Результат = ОтправкаПочтовыхСообщений.АдресаЭлектроннойПочты(Контрагент) 
```
</details>

## ПараметрыЭлектронногоПисьмаДляОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует структуру параметров электронного письма для отправки отчета.
//
// Параметры:
//  ПараметрыОтчета - Структура - см.ОтправкаПочтовыхСообщенийКлиент.ОтправитьОтчет.
//  ДополнительныеПараметры - Структура - см.ОтправкаПочтовыхСообщенийКлиент.ОтправитьОтчет.
//
// Возвращаемое значение:
//  Структура - Структура параметров для передачи в функцию РаботаСПочтовымиСообщениямиКлиент.СоздатьНовоеПисьмо.
//
Функция ПараметрыЭлектронногоПисьмаДляОтчетов(ПараметрыОтчета, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОтправкаПочтовыхСообщений.ПараметрыЭлектронногоПисьмаДляОтчетов(ПараметрыОтчета, ДополнительныеПараметры);
```
</details>

## УстановитьСоединениеССервером
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает соединение с сервером электронной почты.
//
// Параметры:
//  УчетнаяЗапись - СправочникСсылка.УчетныеЗаписиЭлектроннойПочты - учетная запись для соединения.
//  ДляПолучения - Булево - Если Истина, то соединение может быть использовано для загрузки почтовых сообщений.
//  Протокол - ПротоколИнтернетПочты - Протокол используемый для загрузки почтовых сообщений. По умолчанию - POP3.
//
// Возвращаемое значение:
//  ИнтернетПочта - если с сервером удалось установить соединение.
//  Неопределено - если при установки соединения возникло исключение.
//
Функция УстановитьСоединениеССервером(УчетнаяЗапись, ДляПолучения = Ложь, Протокол = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ОтправкаПочтовыхСообщений.УстановитьСоединениеССервером(УчетнаяЗапись, ДляПолучения, Протокол);
```
</details>

## ОписьВложенийПисьма
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает опись переданных файлов в формате HTML.
//
// Параметры:
//  Вложения - СписокЗначений, Структура, Соответствие - коллекция файлов. Для списка значений как наименование файла
//              в описи используется Представление. Для структуры или соответствия Ключ.
//
// Возвращаемое значение:
//
//  Строка - описание переданных файлов в формате HTML.
//
Функция ОписьВложенийПисьма(Вложения) Экспорт
```

Пример вызова
```bsl
Результат = ОтправкаПочтовыхСообщений.ОписьВложенийПисьма(Вложения) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
