---
title: Пакетная обработка табличной части клиент сервер
slug: erp-uh/пакетная-обработка-табличной-части-клиент-сервер
---


## ПолучитьСтруктуруКэшируемыеЗначения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля кэшируемых значений.
//
// Возвращаемое значение:
//	Структура - структура кэшируемых значений со следующими полями:
//		* КоэффициентыУпаковок - Соответствие - используется для хранения значений коэффициентов упаковок товара.
//		* ОбъемУпаковок - Соответствие - используется для хранения значений объема упаковок товара.
//		* ВесУпаковок - Соответствие - используется для хранения значений веса упаковок товара.
//		* Штрихкоды - Соответствие - используется для хранения значений штрихкодов упаковок товара.
//		* КонтролироватьЗаполнениеАналитикиРасходов - Соответствие - используется для хранения значений коэффициентов упаковок товара.
//		* РаспределятьНДСпоСтатьеРасходов - Соответствие - используется для хранения признаков распределения НДС по
//			статьям расходов.
//		* КонтролироватьЗаполнениеАналитикиДоходов - Соответствие - используется для хранения признаков контроля заполнения
//			по аналитике доходов.
//		* ИспользоватьРучныеСкидкиВПродажах - Неопределено, Булево - Истина - в продажах используется расчет скидок вручную.
//		* ИспользоватьАвтоматическиеСкидкиВПродажах - Неопределено, Булево - Истина - в продажах используется
//			автоматический расчет скидок.
//		* ПравоРегистрацииШтрихкодовНоменклатурыДоступно - Неопределено, Булево - Истина - пользователю разрешено
//			регистрировать штрихкоды номенклатуры.
//		* ПринимаетсяКНУ - Соответствие - используется для хранения признаков контроля принятия статей расходов к
//			налоговому учету.
//
Функция ПолучитьСтруктуруКэшируемыеЗначения() Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения() 
```
</details>

## СтруктураКэшируемойИнформацииПоШтрихкоду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля кэшируемой информации, получаемой по штрихкоду товара.
//
// Возвращаемое значение:
//	Структура - структура кэшируемых данных товара, получаемая по штрихкоду товара, со следующими полями:
//		* Номенклатура - СправочникСсылка.Номенклатура - информация о товаре.
//		* ТипНоменклатуры - ПеречислениеСсылка.ТипыНоменклатуры - тип товара.
//		* Характеристика - СправочникСсылка.ХарактеристикиНоменклатуры - характеристика товара.
//		* Упаковка - СправочникСсылка.УпаковкиЕдиницыИзмерения - упаковка товара.
//		* ПодакцизныйТовар - Булево - Истина - товар является подакцизным.
//		* МаркируемаяПродукция - Булево - Истина - товар является маркируемой продукцией.
//		* ХарактеристикиИспользуются - Булево - Истина - признак использования характеристик.
//		* Коэффициент - Число - коэффициент упаковки.
//		* ЕдиницаИзмерения - СправочникСсылка.УпаковкиЕдиницыИзмерения - единица измерения товара.
//		* ЕдиничнаяУпаковка - СправочникСсылка.УпаковкиЕдиницыИзмерения - единичная упаковка товара.
//		* НесколькоЕдиничныхУпаковок - Булево - Истина - товар имеет несколько видов единичных упаковок.
//		* УпаковочныйЛист - ДокументСсылка.УпаковочныйЛист - упаковочный лист.
//		* НеизвестныйШтрихкод - Булево - Истина - в информационной базе отсутствуют данные по штрихкоду.
//		* Штрихкод - Строка - штрихкод товара.
//		* КоличествоПоШтрихкоду - Число - количество товара (в единицах хранения) по штрихкоду.
//		* КоличествоУпаковок - Число - количество упаковок товара.
//		* ШтрихкодНеИзКэша - Неопределено, Булево - Истина - штрихкод не из кэша памяти.
//		* НоменклатураНабора - СправочникСсылка.Номенклатура - информация по набору.
//		* ХарактеристикаНабора - СправочникСсылка.ХарактеристикиНоменклатуры - характеристика набора.
//		* ВариантРасчетаЦеныНабора - ПеречислениеСсылка.ВариантыРасчетаЦенНаборов - вариант расчета цены набора.
//		* ВыполненныеДействия - Структура - структура действий, произведенных со строкой товара в табличной части документа:
//			** Добавлено - Булево - Истина - строка по товару добавлена.
//			** Изменено - Булево - Истина - строка по товару изменена.
//		* Назначения - Неопределено, СправочникСсылка.Назначения - назначение товара.
//
Функция СтруктураКэшируемойИнформацииПоШтрихкоду() Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.СтруктураКэшируемойИнформацииПоШтрихкоду() 
```
</details>

## ПолучитьСтруктуруКэшируемыеЗначенияУслуг
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля кэшируемых значений услуги.
//
// Возвращаемое значение:
//	Структура - структура кэшируемых данных услуг, со следующими полями:
//		* ПроцентыСтавокНДС - Соответствие - используется для хранения процентов ставок НДС.
//		* Штрихкоды - Соответствие - используется для хранения значений штрихкодов услуг.
//		* ИспользоватьРучныеСкидкиВПродажах - Неопределено, Булево - Истина - в продажах используется расчет скидок вручную.
//		* ИспользоватьАвтоматическиеСкидкиВПродажах - Неопределено, Булево - Истина - в продажах используется
//			автоматический расчет скидок.
//		* ИспользоватьРучныеСкидкиВЗакупках - Неопределено, Булево - Истина - в закупках используется расчет скидок вручную.
//
Функция ПолучитьСтруктуруКэшируемыеЗначенияУслуг() Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначенияУслуг() 
```
</details>

## ПараметрыЗаполненияЦеныВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для заполнения цен в строках табличной части документа.
//
// Параметры:
//	Объект - ДанныеФормыСтруктура - данные документа.
//	ВидЦеныВШапке - Булево - Истина - признак указания вида цены в шапке документа.
//
// Возвращаемое значение:
//	Структура - структура, используемая для заполнения цен в табличной части документа:
//		* Дата - Дата - дата документа.
//		* Валюта - СправочникСсылка.Валюты - валюта документа.
//		* ВидЦены - СправочникСсылка.ВидыЦен - Вид цены (может не быть, зависит от того есть ли вид цены в шапке документа или нет).
//
Функция ПараметрыЗаполненияЦеныВСтрокеТЧ(Объект, ВидЦеныВШапке = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПараметрыЗаполненияЦеныВСтрокеТЧ(Объект, ВидЦеныВШапке);
```
</details>

## ПараметрыПересчетаСуммыНДСВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для пересчета сумм НДС в строках табличной части
// документа.
//
// Параметры:
//	Объект - ДанныеФормыСтруктура - данные документа.
//
// Возвращаемое значение:
//	Структура - структура, используемая для пересчета сумм НДС в табличной части документа:
//		* ЦенаВключаетНДС - Булево - Истина - НДС включен в цену товара.
//		* НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - налогообложение документа.
//
Функция ПараметрыПересчетаСуммыНДСВСтрокеТЧ(Объект) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПараметрыПересчетаСуммыНДСВСтрокеТЧ(Объект) 
```
</details>

## ПараметрыЗаполненияСтавкиНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую параметры для заполнения ставки НДС
// документа.
//
// Параметры:
//	Объект - ДанныеФормыСтруктура, ДокументОбъект - данные документа.
//	ПоДатеОтгрузки - Булево - Признак того, что ставки необходимо получать на дату отгрузки
//	ВернутьМногооборотнуюТару - Булево - признак необходимости возврата многооборотной тары.
//
// Возвращаемое значение:
//	Структура - структура, используемая для пересчета сумм НДС в табличной части документа:
//		* НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Налогообложение документа.
//		* Организация - СправочникСсылка.Организации - Организация документа
//		* Дата - Дата - Дата документа
//		* ПоДатеОтгрузки - Булево - Признак того, что ставки необходимо получать на дату отгрузки
//		* ВернутьМногооборотнуюТару - Булево - Признак необходимости возврата многооборотной тары.
//		* ХозяйственнаяОперация - ПеречислениеСсылка.ХозяйственныеОперации - Хозяйственная операция документа.
//
Функция ПараметрыЗаполненияСтавкиНДС(Объект = Неопределено, ПоДатеОтгрузки = Ложь, ВернутьМногооборотнуюТару = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПараметрыЗаполненияСтавкиНДС(Объект, ПоДатеОтгрузки, ВернутьМногооборотнуюТару);
```
</details>

## ПараметрыПолученияКоэффициентаРНПТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для заполнения количества по РНПТ в строках табличной
// части документа.
//
// Параметры:
//	Объект - ДанныеФормыСтруктура - данные формы объекта.
//	ИмяПоляМестоХранения - Строка - имя поля Склад, находящегося в шапке объекта или табличной части.
//	МестоХраненияВТабличнойЧасти - Булево - признак наличия поля Склад в табличной части объекта.
//
// Возвращаемое значение:
//	см. УчетПрослеживаемыхТоваровКлиентСерверЛокализация.ПараметрыПолученияКоэффициентаРНПТ.
//
Функция ПараметрыПолученияКоэффициентаРНПТ(Объект, ИмяПоляМестоХранения = "Склад", МестоХраненияВТабличнойЧасти = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПараметрыПолученияКоэффициентаРНПТ(Объект, ИмяПоляМестоХранения, МестоХраненияВТабличнойЧасти);
```
</details>

## ПолучитьСтруктуруЗаполненияЦеныЗакупкиВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для заполнения цен закупки в строках табличной части
// документа.
//
// Параметры:
//	Объект - ДанныеФормыСтруктура - данные документа.
//	ИмяПоляВидЦены - Строка, Неопределено - Имя реквизита шапки вида цены, если имя не "ВидЦеныПоставщика".
//
// Возвращаемое значение:
//	Структура - структура, используемая для заполнения цен закупки в строках табличной части документа:
//		* Соглашение - СправочникСсылка.СоглашенияСКлиентами - соглашение по документу.
//		* Партнер - СправочникСсылка.Партнеры - партнер по документу.
//		* Дата - Дата - дата документа.
//		* Валюта - СправочникСсылка.Валюты - валюта документа.
//		* ВидЦеныПоставщика - СправочникСсылка.ВидыЦенПоставщиков - валюта документа.
//		* ИмяПоля - Строка - имя поля, в которое необходимо поместить полученную цену
//
Функция ПолучитьСтруктуруЗаполненияЦеныЗакупкиВСтрокеТЧ(Объект, ИмяПоляВидЦены = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруЗаполненияЦеныЗакупкиВСтрокеТЧ(Объект, ИмяПоляВидЦены);
```
</details>

## ПолучитьСтруктуруЗаполненияУсловийПродажВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для заполнения условий продаж в строках табличной части
// документа.
//
// Параметры:
//  Объект - ДанныеФормыСтруктура - данные документа:
// * Дата - Дата - дата документа
// * Валюта - СправочникСсылка.Валюты - валюта документа
// * Соглашение - СправочникСсылка.СоглашенияСКлиентами - соглашение по документу
// * Партнер - СправочникСсылка.Партнеры - партнер из документа
// * Ссылка - ДокументСсылка - ссылка документа
//
// Возвращаемое значение:
//  Структура - Получить структуру заполнения условий продаж в строке ТЧ:
// * Дата - Дата - дата документа
// * Валюта - СправочникСсылка.Валюты - валюта документа
// * Соглашение - СправочникСсылка.СоглашенияСКлиентами - соглашение по документу
// * Партнер - СправочникСсылка.Партнеры - партнер из документа
// * Ссылка - ДокументСсылка - ссылка документа
//
Функция ПолучитьСтруктуруЗаполненияУсловийПродажВСтрокеТЧ(Объект) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруЗаполненияУсловийПродажВСтрокеТЧ(Объект) 
```
</details>

## ПолучитьСтруктуруЗаполненияЦеныРозницаВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для заполнения цен розницы в строках табличной части
// документа.
//
// Параметры:
//	Объект - ДанныеФормыСтруктура - данные документа:
// * Дата - Дата - дата документа.
// * Валюта - СправочникСсылка.Валюты - валюта документа.
// * ВидЦены - СправочникСсылка.ВидыЦен - вид цен по документу.
//
// Возвращаемое значение:
//	Структура - структура, используемая для заполнения цен розницы в строках табличной части документа:
//		* Дата - Дата - дата документа.
//		* Валюта - СправочникСсылка.Валюты - валюта документа.
//		* ВидЦены - СправочникСсылка.ВидыЦен - вид цен по документу.
//
Функция ПолучитьСтруктуруЗаполненияЦеныРозницаВСтрокеТЧ(Объект) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруЗаполненияЦеныРозницаВСтрокеТЧ(Объект) 
```
</details>

## ПолучитьСтруктуруЗаполненияЦеныПоАссортиментуВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для заполнения цен по ассортименту в строках табличной
// части документа.
//
// Параметры:
//	Объект - ДанныеФормыСтруктура - данные документа:
// * Дата - Дата - дата документа.
// * Валюта - СправочникСсылка.Валюты - валюта документа.
// * Склад - СправочникСсылка.Склады - склад по документу.
//
// Возвращаемое значение:
//	Структура - структура, используемая для заполнения цен по ассортименту в строках табличной части документа:
//		* Дата - Дата - дата документа.
//		* Валюта - СправочникСсылка.Валюты - валюта документа.
//		* Склад - СправочникСсылка.Склады - склад по документу.
//
Функция ПолучитьСтруктуруЗаполненияЦеныПоАссортиментуВСтрокеТЧ(Объект) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруЗаполненияЦеныПоАссортиментуВСтрокеТЧ(Объект) 
```
</details>

## ПолучитьСтруктуруЗаполненияУсловийРозничныхПродажВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для заполнения цен по ассортименту в строках табличной
// части документа.
//
// Параметры:
//	Объект - ДанныеФормыСтруктура - данные документа:
// * Дата - Дата - дата документа.
// * Валюта - СправочникСсылка.Валюты - валюта документа.
//	ОбъектХраненияУсловийПродаж - Строка, СправочникСсылка.ФорматыМагазинов, СправочникСсылка.Склады -
//
// Возвращаемое значение:
//	Структура - структура, используемая для заполнения цен по ассортименту в строках табличной части документа:
//		* Дата - Дата - дата документа.
//		* Валюта - СправочникСсылка.Валюты - валюта документа.
//		* ОбъектХраненияУсловийПродаж - Строка, СправочникСсылка.ФорматыМагазинов, СправочникСсылка.Склады -
//
Функция ПолучитьСтруктуруЗаполненияУсловийРозничныхПродажВСтрокеТЧ(Объект, ОбъектХраненияУсловийПродаж) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруЗаполненияУсловийРозничныхПродажВСтрокеТЧ(Объект, ОбъектХраненияУсловийПродаж) 
```
</details>

## ПолучитьСтруктуруПересчетаЦеныСкидкиВПродажахВТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для пересчета цены скидки продажи в строках
//  табличной части документа.
//
// Параметры:
//  Объект				 - ДанныеФормыСтруктура	 - данные документа.
//  ПередачаНаКомиссию	 - Булево				 - Истина если осуществляется передача на комиссию.
//  ИмяКоличества		 - Строка				 - имя поля количества в табличной части документа.
//
// Возвращаемое значение:
//  Структура - структура, используемая для пересчета цены скидки продажи в строках табличной части документа:
//  * ИспользоватьРучныеСкидки - Булево - Истина - в продажах расчет скидок осуществляется вручную.
//  * ИспользоватьАвтоматическиеСкидки - Булево - Истина если в продажах используется автоматический расчет скидок.
//  * ИспользоватьБонусныеБаллы - Булево - Истина если в продажах используются бонусные баллы.
//  * ИмяКоличества - Строка - имя поля количества в табличной части документа.
//
Функция ПолучитьСтруктуруПересчетаЦеныСкидкиВПродажахВТЧ(Объект, ПередачаНаКомиссию = Ложь, ИмяКоличества = "КоличествоУпаковок") Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруПересчетаЦеныСкидкиВПродажахВТЧ(Объект, ПередачаНаКомиссию, ИмяКоличества);
```
</details>

## ПолучитьСтруктуруПересчетаЦеныСкидкиВЗакупкахВТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для пересчета цены скидки закупки в строках
//  табличной части документа.
//
// Параметры:
//  Объект			 - ДанныеФормыСтруктура	 - данные документа.
//  ПриемНаКомиссию	 - Булево				 - Истина если осуществляется прием на комиссию.
//
// Возвращаемое значение:
//  Структура - структура, используемая для пересчета цены скидки закупки в строках табличной части документа:
//  * ИспользоватьРучныеСкидки - Булево - Истина если расчет скидок осуществляется вручную.
//
Функция ПолучитьСтруктуруПересчетаЦеныСкидкиВЗакупкахВТЧ(Объект, ПриемНаКомиссию) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруПересчетаЦеныСкидкиВЗакупкахВТЧ(Объект, ПриемНаКомиссию) 
```
</details>

## ПолучитьСтруктуруПроверкиСопоставленнойНоменклатурыПоставщикаВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для проверки сопоставленной номенклатуры поставщика с
//  номенклатурой склада в строках табличной части документа.
//
// Параметры:
//  Объект - ДанныеФормыСтруктура - данные документа:
//  	* Ссылка - ДокументСсылка
//  	* Партнер - СправочникСсылка.Партнеры - партнер по документу.
//  НеВыполнятьПроверкуДляПользователя - Булево - Истина если не нужно проверку для текущего пользователя.
//
// Возвращаемое значение:
//  Структура - структура, используемая для проверки сопоставленной номенклатуры поставщика с номенклатурой склада в строках табличной части документа:
//  * Ссылка - ДокументСсылка - ссылка на документ.
//  * Партнер - СправочникСсылка.Партнеры - партнер по документу.
//  * НеВыполнятьПроверкуДляПользователя - Булево - Истина если не осуществлять проверку для текущего пользователя.
//
Функция ПолучитьСтруктуруПроверкиСопоставленнойНоменклатурыПоставщикаВСтрокеТЧ(Объект, НеВыполнятьПроверкуДляПользователя) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруПроверкиСопоставленнойНоменклатурыПоставщикаВСтрокеТЧ(Объект, НеВыполнятьПроверкуДляПользователя) 
```
</details>

## ПолучитьСтруктуруЗаполненияСкладаВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для заполнения сведений о складе в строках
//  табличной части документа.
//
// Параметры:
// 	Объект - ДанныеФормыСтруктура	 - данные документа.
// 	СкладГруппа - Булево - Истина, если склад является иерархическим.
// 	ИмяПоляСкладОбъекта - Строка
// 	ИмяПоляСклад - Строка
//
// Возвращаемое значение:
// 	Структура - Описание:
// * ИмяПоляСклад - Строка
// * СкладПоУмолчанию - СправочникСсылка.Склады
// * СкладГруппа - Булево
// * СкладГруппаСсылка - СправочникСсылка.Склады
//
Функция ПолучитьСтруктуруЗаполненияСкладаВСтрокеТЧ(Объект, СкладГруппа, ИмяПоляСкладОбъекта = "Склад", ИмяПоляСклад = "Склад") Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруЗаполненияСкладаВСтрокеТЧ(Объект, СкладГруппа, ИмяПоляСкладОбъекта, ИмяПоляСклад);
```
</details>

## ПолучитьСтруктуруЗаполненияСодержанияУслугиВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для заполнения сведений об услугах в строках
//  табличной части документа.
//
// Параметры:
//  Объект					 - ДанныеФормыСтруктура	 - данные документа.
//  ЗаполнятьДляВсехУслуг	 - Булево				 - Если Истина, то заполнять сведения об услугах во всей табличной части документа.
//
// Возвращаемое значение:
//  Структура - структура, используемая для заполнения сведений об услугах в строках табличной части документа:
//  * ЗаполнятьДляВсехУслуг - Булево - Истина - заполнять сведения об услугах во всей табличной части документа.
//  * УслугиПоПереработкеДавальческогоСырья - Булево - Истина - осуществляется предоставление услуг по переработке
//  давальческого сырья.
//
Функция ПолучитьСтруктуруЗаполненияСодержанияУслугиВСтрокеТЧ(Объект, ЗаполнятьДляВсехУслуг) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруЗаполненияСодержанияУслугиВСтрокеТЧ(Объект, ЗаполнятьДляВсехУслуг) 
```
</details>

## ПараметрыПересчетаСуммыНДСВТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для пересчета суммы НДС по товару в строках
//  табличной части документа.
//
// Параметры:
//  Объект	 - ДанныеФормыСтруктура	 - данные документа.
//
// Возвращаемое значение:
//  Структура - структура, используемая для пересчета суммы НДС по товару в строках табличной части документа:
//		* ЦенаВключаетНДС - Булево - Истина - сумма по НДС включена в цену товара.
//		* НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - налогообложение документа.
//
Функция ПараметрыПересчетаСуммыНДСВТЧ(Объект) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПараметрыПересчетаСуммыНДСВТЧ(Объект) 
```
</details>

## ПолучитьСтруктуруЗаполненияСтавкиНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для заполнения ставки НДС в строках
// табличной части документа.
//
// Параметры:
//	Объект - ДанныеФормыСтруктура - данные документа:
//	 * Дата - Дата - дата документа.
//	 * Организация - СправочникСсылка.Организации - организация по документу, осуществляющая хозяйственную операцию.
//
// Возвращаемое значение:
//	Структура - структура, используемая для заполнения ставки НДС в строках табличной части документа:
//		* Дата - Дата - дата документа.
//		* Организация - СправочникСсылка.Организации - организация по документу, осуществляющая хозяйственную операцию.
//
Функция ПолучитьСтруктуруЗаполненияСтавкиНДС(Объект) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруЗаполненияСтавкиНДС(Объект) 
```
</details>

## ПолучитьСтруктуруЗаполненияПризнакаБезВозвратнойТары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для заполнения признаков идентификации безвозвратной
//  многооборотной тары в строках табличной части документа.
//
// Параметры:
//  Объект	 - ДанныеФормыСтруктура	 - данные документа:
//	 * ВернутьМногооборотнуюТару - Булево - Истина - осуществлять возврат многооборотной тары.
//
// Возвращаемое значение:
//  Структура - структура, используемая для заполнения признаков идентификации безвозвратной многооборотной тары в
//  строках табличной части документа:
//  * ВернутьМногооборотнуюТару - Булево - Истина - осуществлять возврат многооборотной тары.
//
Функция ПолучитьСтруктуруЗаполненияПризнакаБезВозвратнойТары(Объект) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруЗаполненияПризнакаБезВозвратнойТары(Объект) 
```
</details>

## ПараметрыЗаполненияСтраныПроисхождения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры, используемые при заполнении страны происхождения номенклатуры в табличной части объекта.
//
// Возвращаемое значение:
//	Структура - коллекция, содержащая следующие свойства:
//		* Номенклатура - Строка - имя поля номенклатура табличной части объекта.
//		* НомерГТД - Строка - имя поля номера ГТД товара табличной части объекта.
//
Функция ПараметрыЗаполненияСтраныПроисхождения() Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПараметрыЗаполненияСтраныПроисхождения() 
```
</details>

## ЗаполнитьРасхождения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет поля, используемые для отражения расхождений, в текущей строке табличной
// части документа "АктОРасхожденияхПослеПеремещения".
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьРасхождения(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьРасхождения(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ЗаполнитьРасхожденияПослеОтгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет поля, используемые для отражения расхождений, в текущей строке табличной
// части документа "АктОРасхожденияхПослеОтгрузки".
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьРасхожденияПослеОтгрузки(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьРасхожденияПослеОтгрузки(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ЗаполнитьРасхожденияПослеПриемки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет поля, используемые для отражения расхождений, в текущей строке табличной
// части документа "АктОРасхожденияхПослеПриемки".
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьРасхожденияПослеПриемки(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьРасхожденияПослеПриемки(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ЗаполнитьПризнакНаличияКомментарияПриемка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет поля признаков использования комментариев в текущей строке табличной
// части документа "АктОРасхожденияхПослеПриемки".
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьПризнакНаличияКомментарияПриемка(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьПризнакНаличияКомментарияПриемка(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ЗаполнитьПризнакНаличияКомментарияОтгрузка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет поля признаков использования комментариев в текущей строке табличной
// части документа "АктОРасхожденияхПослеОтгрузки".
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьПризнакНаличияКомментарияОтгрузка(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьПризнакНаличияКомментарияОтгрузка(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ЗаполнитьПризнакНаличияКомментария
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет поля признаков использования комментариев в текущей строке табличной
// части документа "АктОРасхожденияхПослеПеремещения".
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьПризнакНаличияКомментария(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьПризнакНаличияКомментария(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ЗаполнитьПризнакТоварногоМестаТребуетсяОбработка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет признак необходимости обработки строки табличной части документа "ПриходныйОрдерНаТовары".
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьПризнакТоварногоМестаТребуетсяОбработка(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьПризнакТоварногоМестаТребуетсяОбработка(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## СтруктураПересчетаСуммы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля для пересчета суммы в табличной части документа.
//
// Параметры:
//  Реквизиты - Строка - Содержит имена полей, заданных через запятую,
//  ИмяПоляКоличество     - Строка - Имя поля, по которому считается коэффициент пропорциональности.
//  РазрядностиОкругления - Структура - структура, в формате ИмяПоля => Количество знаков дробной части, которая будет
//                                      использоваться при пересчете реквизитов.
//
// Возвращаемое значение:
//  Структура:
//            * Поля - Структура - содержит поля для пересчета суммы в табличной части документа
//            * Строки - Массив из ДанныеФормыЭлементКоллекции - содержит элементы типа, ссылки нас строки для пересчета сумм.
//            * ИтогКоличество - Число - сумма значений в поле "Количество" в строках переданных в параметре "Строки"
//            * ИмяПоляКоличество - Строка
//            * РазрядностиОкругления - Структура
//
Функция СтруктураПересчетаСуммы(Реквизиты, ИмяПоляКоличество = "Количество", РазрядностиОкругления = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.СтруктураПересчетаСуммы(Реквизиты, ИмяПоляКоличество, РазрядностиОкругления);
```
</details>

## ЗаполнитьСтруктуруПересчетаСуммы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует структуру для пересчета суммы в табличной части документа
//
// Параметры:
//  СтруктураПересчетаСуммы - см. СтруктураПересчетаСуммы.
//  ДанныеЗаполнения - ДанныеФормыЭлементКоллекции - строка, содержащая значения суммовых показателей,
//                     которые необходимо будет распределить между строками при пересчете сумм.
//
// Возвращаемое значение
//  Структура - Структура со следующими полями:
//              Поля - Структура - содержит поля для пересчета суммы в табличной части документа,
//              Строки - Массив - содержит элементы типа ДанныеФормыЭлементКоллекции, ссылки нас строки для пересчета сумм,
//              ИтогКоличество - Число - сумма значений в поле "Количество" в строках переданных в параметре "Строки".
//
Процедура ЗаполнитьСтруктуруПересчетаСуммы(СтруктураПересчетаСуммы, ДанныеЗаполнения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьСтруктуруПересчетаСуммы(СтруктураПересчетаСуммы, ДанныеЗаполнения) 
```
</details>

## ДобавитьСтрокуДляПересчетаСуммы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет строку для пересчета суммы в структуру пересчета суммы, описание см. функция
// СтруктураПересчетаСуммы.
//
// Параметры:
//  СтруктураПересчетаСуммы - см. СтруктураПересчетаСуммы
//  Строка - ДанныеФормыЭлементКоллекции - строка, для которой необходимо рассчитать значения сумм.
//
Процедура ДобавитьСтрокуДляПересчетаСуммы(СтруктураПересчетаСуммы, Строка) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ДобавитьСтрокуДляПересчетаСуммы(СтруктураПересчетаСуммы, Строка) 
```
</details>

## ПересчитатьСуммы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает суммы в строках, добавленных в структуру пересчета суммы, описание см. функция
// СтруктураПересчетаСуммы.
//
// Параметры:
//  СтруктураПересчетаСуммы - см. СтруктураПересчетаСуммы
//
Процедура ПересчитатьСуммы(СтруктураПересчетаСуммы) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммы(СтруктураПересчетаСуммы) 
```
</details>

## ПересчитатьКоличествоНеОтгружатьСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает количество неотгружаемых упаковок товара в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьКоличествоНеОтгружатьСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьКоличествоНеОтгружатьСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ПересчитатьРеквизитыВИзмененныхСтроках
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает реквизиты в измененных строках.
//
// Параметры:
//  ИзмененныеСтроки - Массив из Структура:
//  * Идентификатор - Число - идентификатор группы измененных строк,
//  * Строка - ДанныеФормыЭлементКоллекции,СтрокаТабличнойЧасти - строка, в которой нужно выполнить пересчет.
//  СтруктураПересчета - см. СтруктураПересчетаСуммы.
//
Процедура ПересчитатьРеквизитыВИзмененныхСтроках(ИзмененныеСтроки, СтруктураПересчета) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьРеквизитыВИзмененныхСтроках(ИзмененныеСтроки, СтруктураПересчета) 
```
</details>

## ПересчитатьКоличествоУпаковокПоФактуВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает фактическое количество упаковок товара в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьКоличествоУпаковокПоФактуВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьКоличествоУпаковокПоФактуВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьКоличествоЕдиницВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает количество товара (в единицах хранения) в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьКоличествоЕдиницВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьКоличествоЕдиницВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьКоличествоПоРНПТВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает количество товара (в единицах хранения) в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьКоличествоПоРНПТВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьКоличествоПоРНПТВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьКоличествоПоРНПТСуффиксВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает количество товара (в единицах хранения) в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьКоличествоПоРНПТСуффиксВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьКоличествоПоРНПТСуффиксВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьКоличествоЕдиницСуффиксВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает количество товара (в единицах хранения), имеющего заданный признак, в текущей строке табличной
// части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьКоличествоЕдиницСуффиксВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьКоличествоЕдиницСуффиксВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьКоличествоУпаковокВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает количество упаковок товара в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьКоличествоУпаковокВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьКоличествоУпаковокВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьКоличествоУпаковокСуффиксВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает количество упаковок товара, имеющего заданный признак, в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьКоличествоУпаковокСуффиксВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьКоличествоУпаковокСуффиксВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьКоличествоОтклонение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает отклонения по количеству упаковок товара в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьКоличествоОтклонение(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьКоличествоОтклонение(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьКоличествоУпаковокСуффиксИзОтклоненияВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает отклонения по количеству упаковок товара, имеющего заданный признак, в текущей строке
// табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьКоличествоУпаковокСуффиксИзОтклоненияВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьКоличествоУпаковокСуффиксИзОтклоненияВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ЗаполнитьВидЦеныВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет вид цен в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьВидЦеныВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьВидЦеныВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ПересчитатьЦенуЗаУпаковкуВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает цену за упаковку товара в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьЦенуЗаУпаковкуВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьЦенуЗаУпаковкуВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьЦенуЗаУпаковкуСуффиксВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает цену за упаковку товара в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьЦенуЗаУпаковкуСуффиксВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьЦенуЗаУпаковкуСуффиксВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьЦенуЗаказаЗаУпаковкуВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает цену заказа за упаковку товара в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьЦенуЗаказаЗаУпаковкуВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьЦенуЗаказаЗаУпаковкуВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ЗаполнитьСтавкуНДСВозвратнойТарыВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет значение ставки НДС возвратной тары в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьСтавкуНДСВозвратнойТарыВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьСтавкуНДСВозвратнойТарыВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьПроцентРучнойСкидкиВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает процент ручной скидки от стоимости товара в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьПроцентРучнойСкидкиВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьПроцентРучнойСкидкиВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьСуммуРучнойСкидкиВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает сумму ручной скидки на товар в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуРучнойСкидкиВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуРучнойСкидкиВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьСуммуВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает сумму товара в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьСуммуСуффиксВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает сумму товара, имеющего заданный признак, в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуСуффиксВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуСуффиксВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьСуммуНДССуффиксВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает сумму товара, имеющего заданный признак, в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуНДССуффиксВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуНДССуффиксВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьСуммуВСтрокеТЧРасхождения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает сумму товара в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуВСтрокеТЧРасхождения(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуВСтрокеТЧРасхождения(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ЦенаССуффиксом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует названия идентификаторов цены с суффиксом
//
// Параметры:
//  Суффикс - Строка
//
// Возвращаемое значение:
//  Строка - имя поля цена.
//
Функция ЦенаССуффиксом(Суффикс) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЦенаССуффиксом(Суффикс) 
```
</details>

## СуммаССуффиксом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует названия идентификаторов суммы с суффиксом
//
// Параметры:
// 	Суффикс - Строка - суффикс
//
// Возвращаемое значение:
// 	Структура - набор названий идентификаторов. Описание:
// * Сумма - Строка - "Сумма" + суффикс
// * СуммаНДС - Строка - "СуммаНДС" + суффикс
// * СуммаСНДС - Строка - "СуммаСНДС" + суффикс
//
Функция СуммаССуффиксом(Суффикс) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.СуммаССуффиксом(Суффикс) 
```
</details>

## СтавкаССуффиксом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует названия идентификаторов ставки НДС с суффиксом
//
// Параметры:
// 	Суффикс - Строка - суффикс
//
// Возвращаемое значение:
// 	Структура - набор названий идентификаторов. Описание:
// * СтавкаНДС - Строка - "СтавкаНДС" + суффикс
//
Функция СтавкаССуффиксом(Суффикс) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.СтавкаССуффиксом(Суффикс) 
```
</details>

## ПересчитатьСуммуВСтрокеТЧЗаказДавальца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТКА

// Пересчитывает сумму товара в текущей строке табличной части документа "ЗаказДавальца".
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуВСтрокеТЧЗаказДавальца(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуВСтрокеТЧЗаказДавальца(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьСуммуУслугиВСтрокеТЧЗаказДавальца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает сумму услуги в текущей строке табличной части документа "ЗаказДавальца".
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуУслугиВСтрокеТЧЗаказДавальца(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуУслугиВСтрокеТЧЗаказДавальца(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьЦенуСкидкуПоСуммеВПродажахВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
//-- НЕ УТКА

// Пересчитывает цену скидки в текущей строке.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьЦенуСкидкуПоСуммеВПродажахВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьЦенуСкидкуПоСуммеВПродажахВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьЦенуСкидкуПоСуммеВЗакупкахВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает цену и сумму ручной скидки от стоимости товара в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьЦенуСкидкуПоСуммеВЗакупкахВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьЦенуСкидкуПоСуммеВЗакупкахВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьЦенуПоСуммеВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает цену от стоимости товара в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьЦенуПоСуммеВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьЦенуПоСуммеВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьЦенуПоСуммеВСтрокеТЧЗаказДавальца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТКА

// Пересчитывает цену от стоимости товара в текущей строке табличной части документа "ЗаказДавальца".
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьЦенуПоСуммеВСтрокеТЧЗаказДавальца(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьЦенуПоСуммеВСтрокеТЧЗаказДавальца(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьЦенуПродажиПоСуммеПродажиВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
//-- НЕ УТКА

// Пересчитывает цену продажи товара от суммы продажи в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьЦенуПродажиПоСуммеПродажиВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьЦенуПродажиПоСуммеПродажиВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ПересчитатьСуммуСУчетомАвтоматическойСкидкиВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает стоимость товара с учетом скидки в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуСУчетомАвтоматическойСкидкиВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуСУчетомАвтоматическойСкидкиВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьСуммуСУчетомРучнойСкидкиВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает стоимость товара с учетом ручной скидки в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуСУчетомРучнойСкидкиВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуСУчетомРучнойСкидкиВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьСуммуСУчетомСкидкиБонуснымиБалламиВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает стоимость товара с учетом скидки по бонусным баллам в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуСУчетомСкидкиБонуснымиБалламиВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуСУчетомСкидкиБонуснымиБалламиВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьСуммуСНДСВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает стоимость товара с НДС в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуСНДСВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуСНДСВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьСуммуСНДССуффиксВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает стоимость товара с НДС, имеющего заданный признак, в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуСНДССуффиксВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуСНДССуффиксВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьСуммуБезНДСВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает стоимость товара без НДС в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуБезНДСВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуБезНДСВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ПересчитатьСуммуРеглВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает стоимость товара в валюте регламентированного учета в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуРеглВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуРеглВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьСуммуПРВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает сумму постоянной разницы в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуПРВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуПРВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьНДСРеглВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает сумму НДС в валюте регламентированного учета в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьНДСРеглВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьНДСРеглВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьСуммуПродажиВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает сумму продажи товара в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуПродажиВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуПродажиВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьСуммуПродажиНДСВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает сумму продажи НДС товара в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуПродажиНДСВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуПродажиНДСВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## УстановитьАктивностьСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает признак активности строки в табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура УстановитьАктивностьСтроки(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.УстановитьАктивностьСтроки(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ЗаполнитьДействиеПоПерерабатываемымМатериаламВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТКА

// Заполняет поле назначения товара (услуги) в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьДействиеПоПерерабатываемымМатериаламВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьДействиеПоПерерабатываемымМатериаламВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПроверитьЗаполнитьНазначениеВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//-- НЕ УТКА

// Заполняет поле назначения товара (услуги) в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПроверитьЗаполнитьНазначениеВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПроверитьЗаполнитьНазначениеВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ЗаполнитьФлагОбособленноПоНазначению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет поле назначения товара (услуги) в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьФлагОбособленноПоНазначению(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьФлагОбособленноПоНазначению(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ЗаполнитьФлагиРасхождениеИИзлишекПорча
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет поля, используемые для отражения расхождений и излишков по товару в текущей строке табличной
// части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьФлагиРасхождениеИИзлишекПорча(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьФлагиРасхождениеИИзлишекПорча(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ОчиститьСуммуВзаиморасчетовВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает нулевое значение в поле суммы взаиморасчетов по товару в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ОчиститьСуммуВзаиморасчетовВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ОчиститьСуммуВзаиморасчетовВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ОчиститьСуммуВзаиморасчетовСуффиксВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает нулевое значение в поле суммы взаиморасчетов (с суффиксом) по товару в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ОчиститьСуммуВзаиморасчетовСуффиксВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ОчиститьСуммуВзаиморасчетовСуффиксВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ОчиститьАвтоматическуюСкидкуВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает нулевое значение для процента и суммы скидки по товару в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ОчиститьАвтоматическуюСкидкуВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ОчиститьАвтоматическуюСкидкуВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ОчиститьСуммуВознагражденияВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает нулевое значение для суммы вознаграждения по товару в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ОчиститьСуммуВознагражденияВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ОчиститьСуммуВознагражденияВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ЗаполнитьПартнера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет поле партнера предопределенным значением в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьПартнера(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьПартнера(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ЗаполнитьПризнакБезВозвратнойТары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет признак безвозвратной тары в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьПризнакБезВозвратнойТары(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьПризнакБезВозвратнойТары(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ЗаполнитьПризнакОтмененоБезВозвратнойТары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет признак отмены заказа по безвозвратной таре в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьПризнакОтмененоБезВозвратнойТары(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьПризнакОтмененоБезВозвратнойТары(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ЗаполнитьПризнакАктивностьБезВозвратнойТары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает признак активности строки безвозвратной тары в табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьПризнакАктивностьБезВозвратнойТары(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьПризнакАктивностьБезВозвратнойТары(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ЗаполнитьДубликатыЗависимыхРеквизитов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет поля дубликатов зависимых реквизитов в табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьДубликатыЗависимыхРеквизитов(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьДубликатыЗависимыхРеквизитов(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ПересчитатьСуммуСверхЗаказаВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает сумму сверх заказа по товару в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуСверхЗаказаВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуСверхЗаказаВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ЗаполнитьВариантОтраженияКорректировкиРеализации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет поле варианта отражения корректировки реализации в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьВариантОтраженияКорректировкиРеализации(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьВариантОтраженияКорректировкиРеализации(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## КоличествоССуффиксом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует названия идентификаторов количества с суффиксом
//
// Параметры:
// 	Суффикс - Строка - суффикс
//
// Возвращаемое значение:
// 	Структура - набор названий идентификаторов. Описание:
// * Количество - Строка - "Количество" + суффикс
// * КоличествоУпаковок - Строка - "КоличествоУпаковок" + суффикс
// * КоличествоПоРНПТ - Строка - "КоличествоПоРНПТ" + суффикс
//
Функция КоличествоССуффиксом(Суффикс) Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.КоличествоССуффиксом(Суффикс) 
```
</details>

## ПересчитатьДолюСтоимостиВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТ

// Заполняет служебные реквизиты в строке на основании выбранного склада
//
// Параметры:
//  ТекущаяСтрока		 - Структура - данные обрабатываемой строки.
//  СтруктураДействий	 - Структура - описывает действия, где Ключ - наименование действия, Значение - Структура - параметры действия.
//  КэшированныеЗначения - Структура - сохраненные значения параметров, используемых при обработке.
//
Процедура ПересчитатьДолюСтоимостиВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьДолюСтоимостиВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ЗаполнитьСпособОпределенияСебестоимостиСтрокой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//-- НЕ УТ

// Заполняет способ определения себестоимости строкой
//
// Параметры:
//  ТекущаяСтрока		 - Структура - данные обрабатываемой строки.
//  СтруктураДействий	 - Структура - описывает действия, где Ключ - наименование действия, Значение - Структура - параметры действия.
//  КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьСпособОпределенияСебестоимостиСтрокой(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьСпособОпределенияСебестоимостиСтрокой(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ЗаполнитьСпособОпределенияСебестоимости
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет способ определения себестоимости строкой
//
// Параметры:
//  ТекущаяСтрока		 - Структура - данные обрабатываемой строки.
//  СтруктураДействий	 - Структура - описывает действия, где Ключ - наименование действия, Значение - Структура - параметры действия.
//  КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьСпособОпределенияСебестоимости(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьСпособОпределенияСебестоимости(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ПересчитатьСуммуНУВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает сумму налогового учета в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуНУВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуНУВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьСуммуВРВСтрокеТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает сумму временной разницы в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ПересчитатьСуммуВРВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьСуммуВРВСтрокеТЧ(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## СтруктураПересчетаКоличестваУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля для пересчета количества упаковок в табличной части документа.
//
// Параметры:
//  ИмяПоляКоличество         - Строка - Имя поля, по которому считается количество упаковок.
//  ИмяПоляКоличествоУпаковок - Строка - Имя поля, в которое подставляется рассчитанное количество упаковок.
//
// Возвращаемое значение:
//  Структура - содержит поля для пересчета количества упаковок в табличной части документа,
//              Строки - Массив - содержит элементы типа ДанныеФормыЭлементКоллекции, ссылки нас строки для пересчета сумм,
//              ИтогКоличество - Число - сумма значений в поле "Количество" в строках переданных в параметре "Строки".
//
Функция СтруктураПересчетаКоличестваУпаковок(ИмяПоляКоличество = "Количество", ИмяПоляКоличествоУпаковок = "КоличествоУпаковок") Экспорт
```

Пример вызова
```bsl
Результат = ПакетнаяОбработкаТабличнойЧастиКлиентСервер.СтруктураПересчетаКоличестваУпаковок(ИмяПоляКоличество, ИмяПоляКоличествоУпаковок);
```
</details>

## ЗаполнитьТипМестаХраненияПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет место хранения в текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока        - Структура - Структура со свойствами строки документа.
//	СтруктураДействий    - Структура - Структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьТипМестаХраненияПоУмолчанию(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьТипМестаХраненияПоУмолчанию(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ЗаполнитьНазначениеОбеспеченияВЭтапеПроизводства
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТКА

// Заполняет назначение обеспечения обособленной потребности в материалах и полуфабрикатов производимых в процессе для текущей строке табличной части документа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьНазначениеОбеспеченияВЭтапеПроизводства(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьНазначениеОбеспеченияВЭтапеПроизводства(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ЗаполнитьНазначениеВЭтапеПроизводства
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет Назначение в обеспечении этапа.
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьНазначениеВЭтапеПроизводства(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьНазначениеВЭтапеПроизводства(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения);
```
</details>

## ЗаполнитьНаправлениеВыпуска
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//-- НЕ УТКА

//++ НЕ УТ

// Заполняет направление выпуска для текущей строки табличной части документа "Производство без заказа"
//
// Параметры:
//	ТекущаяСтрока - Структура - структура со свойствами строки документа.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//	КэшированныеЗначения - см. ПолучитьСтруктуруКэшируемыеЗначения.
//
Процедура ЗаполнитьНаправлениеВыпуска(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьНаправлениеВыпуска(ТекущаяСтрока, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## ПересчитатьКоличествоУпаковокПриПодбореНомераГТД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//-- НЕ УТ

// Выполняет пересчет количества упаковок в строках табличной части при подборе номера ГТД комплекта.
//
// Параметры:
//	ТекущаяСтрока - ДанныеФормыСтруктура, Структура - текущая строка, для которой выполнен подбор номера ГТД комплекта.
//	НоваяСтрока - ДанныеФормыСтруктура, Структура - новая строка, для которой подобрался остаточный Номер ГТД комплекта.
//	ИмяПоляКоличествоУпаковок - Строка - имя поля количества упаковок, для которого осуществляется пересчет.
//
Процедура ПересчитатьКоличествоУпаковокПриПодбореНомераГТД(ТекущаяСтрока, Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПересчитатьКоличествоУпаковокПриПодбореНомераГТД(ТекущаяСтрока, );
```
</details>

## ЗаполнитьТипНомераГТДПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет заполнение поля 'ТипНомераГТД' значение по умолчанию.
//
// Параметры:
//	ТекущаяСтрока - ДанныеФормыСтруктура, Структура - строка, для которой требуется заполнить поле 'ТипНомераГТД'.
//	СтруктураДействий - Структура - структура с действиями, которые нужно произвести.
//
Процедура ЗаполнитьТипНомераГТДПоУмолчанию(ТекущаяСтрока, СтруктураДействий) Экспорт
```

Пример вызова
```bsl
ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ЗаполнитьТипНомераГТДПоУмолчанию(ТекущаяСтрока, СтруктураДействий) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
