---
title: Переводы СБП (c2b)
slug: erp-uh/переводы-сбп-c2b
---


## ПереводыСБПДоступны
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет доступность использования функциональности выполнения операций
// на основании прав доступа пользователя.
//
// Возвращаемое значение:
//  Булево - если Истина, оплата в Системе быстрых платежей доступна.
//
Функция ПереводыСБПДоступны() Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.ПереводыСБПДоступны() 
```
</details>

## ЧтениеПереводовСБПДоступно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет доступность использования функциональности чтения операций
// в на основании прав доступа пользователя.
//
// Возвращаемое значение:
//  Булево - если Истина, чтение операций доступно.
//
Функция ЧтениеПереводовСБПДоступно() Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.ЧтениеПереводовСБПДоступно() 
```
</details>

## УчастникиСБПДляВозврата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает список участников, в которые возможно вернуть денежные средства
// в рамках оплаты. Метод следует вызывать только в том случае, если
// УчастникСБПВозврата имеет значение Истина,
// см. СистемаБыстрыхПлатежей.НастройкиПодключения.
//
// Возвращаемое значение:
//  Соответствие - идентификатор и наименование участника СБП:
//    *Ключ - Строка - идентификатор участника СБП, который необходимо
//            передать в метод д ПереводыСБПc2b.ВозвратОплаты
//            при выполнении возврата;
//    *Значение - Строка - наименование участника СБП для отображения в пользовательских
//                интерфейсах.
//
Функция УчастникиСБПДляВозврата() Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.УчастникиСБПДляВозврата() 
```
</details>

## НастройкиПодключенияОперации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет настройки подключения к СБП, по которым были выполнена операция в платежных системах.
// Метод следует использовать для отложенного получения статуса выполнения операции.
//
// Параметры:
//  ДокументОперации - ОпределяемыйТип.ДокументОперацииСБП - документ оплаты или возврата,
//   по которому были выполнены операции в платежных системах;
//
// Возвращаемое значение:
//  Массив из СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//    настройки подключения, по которым были выполнены операции документа.
//
Функция НастройкиПодключенияОперации(ДокументОперации) Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.НастройкиПодключенияОперации(ДокументОперации) 
```
</details>

## ДинамическаяСсылка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новый заказ на оплату и получает
// идентификатор оплаты для формирования QR-кода.
//
// Параметры:
//  ДокументОперации - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//    оплату в информационной базе;
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//    настройка выполнения операции.
//  ДополнительныеПараметры - Структура, Неопределено - дополнительные настройки формирования
//    заказа на оплату.
//
// Возвращаемое значение:
//  Структура - результат создания динамической ссылки в Системе быстрых платежей:
//    * ПлатежнаяСсылка - Строка - идентификатор, по которому выполняется оплата;
//    * СуммаОплаты - Число - сумма оплаты, на которую была сформирована ссылка;
//    * КодОшибки - Строка - строковый код возникшей ошибки, который
//      может быть обработан вызывающим методом:
//        - <Пустая строка> - создание нового заказа выполнено успешно;
//        - "НеверныйФорматЗапроса" - передан некорректный запрос или настройка подключения;
//        - "УжеОплачен" - документ уже оплачен;
//        - "НеверныйЛогинИлиПароль" - неверный логин или пароль или параметры
//          подключения к участнику СБП;
//        - "ТребуетсяОплата" - требуется оплата сервиса;
//        - "ОтсутствуетДоступКСервису" - у пользователя нет доступа к сервису;
//        - "ПревышеноКоличествоПопыток" - превышено количество попыток
//          обращения к сервису с некорректным логином и паролем;
//        - "ОшибкаПодключения" - ошибка при подключении к сервису;
//        - "ОшибкаСервиса" - внутренняя ошибка сервиса;
//        - "НеизвестнаяОшибка" - при получении информации возникла
//          неизвестная (не обрабатываемая) ошибка;
//        - "СервисВременноНеДоступен" - на сервере ведутся регламентные работы;
//        - "ИнтеграцияНеИспользуется" - использование отключено в настройках;
//    * СообщениеОбОшибке  - Строка, ФорматированнаяСтрока - сообщение об ошибке для пользователя;
//    * ИнформацияОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке для администратора.
//
Функция ДинамическаяСсылка( Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.ДинамическаяСсылка();
```
</details>

## КассоваяСсылка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует новую кассовую ссылку и получает
// идентификатор оплаты для формирования QR-кода.
//
// Параметры:
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//    настройка выполнения оплаты.
//
// Возвращаемое значение:
//  Структура - результат создания кассовый ссылки в Системе быстрых платежей:
//    * КассоваяСсылка - Строка - ссылка, по которой будет выполнятся оплата;
//    * ИдентификаторОплаты - Строка - идентификатор зарегистрированной ссылки;
//    * КодОшибки - Строка - строковый код возникшей ошибки, который
//      может быть обработан вызывающим методом:
//        - <Пустая строка> - создание новой ссылки выполнено успешно;
//        - "НеверныйФорматЗапроса" - передан некорректный запрос или настройка подключения;
//        - "НеверныйЛогинИлиПароль" - неверный логин или пароль или параметры
//          подключения к Системе быстрых платежей;
//        - "ТребуетсяОплата" - требуется оплата сервиса;
//        - "ОтсутствуетДоступКСервису" - у пользователя нет доступа к сервису;
//        - "ПревышеноКоличествоПопыток" - превышено количество попыток
//          обращения к сервису с некорректным логином и паролем;
//        - "ОшибкаПодключения" - ошибка при подключении к сервису;
//        - "ОшибкаСервиса" - внутренняя ошибка сервиса;
//        - "НеизвестнаяОшибка" - при получении информации возникла
//          неизвестная (не обрабатываемая) ошибка;
//        - "СервисВременноНеДоступен" - на сервере ведутся регламентные работы;
//        - "ИнтеграцияНеИспользуется" - использование отключено в настройках;
//    * СообщениеОбОшибке  - Строка, ФорматированнаяСтрока - сообщение об ошибке для пользователя;
//    * ИнформацияОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке для администратора.
//
Функция КассоваяСсылка(НастройкаПодключения) Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.КассоваяСсылка(НастройкаПодключения) 
```
</details>

## АктивироватьКассовуюСсылку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новый заказ на оплату для ранее созданной кассовой ссылки.
//
// Параметры:
//  ДокументОперации - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//    оплату в информационной базе;
//  ДанныеСсылки - Структура - данные кассовой ссылки:
//    * КассоваяСсылка - Строка - ссылка, по которой будет выполнятся оплата;
//    * ИдентификаторОплаты - Строка - идентификатор зарегистрированной ссылки;
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//    настройка выполнения оплаты;
//  ДополнительныеПараметры - Структура, Неопределено - дополнительные настройки формирования
//    заказа на оплату.
//
// Возвращаемое значение:
//  Структура - результат создания активации кассовой ссылки в Системе быстрых платежей:
//    * КодОшибки - Строка - строковый код возникшей ошибки, который
//      может быть обработан вызывающим методом:
//        - <Пустая строка> - создание нового заказа выполнено успешно;
//        - "НеверныйФорматЗапроса" - передан некорректный запрос или настройка подключения;
//        - "УжеОплачен" - документ уже оплачен;
//        - "НеверныйЛогинИлиПароль" - неверный логин или пароль или параметры
//          подключения к Системе быстрых платежей;
//        - "ТребуетсяОплата" - требуется оплата сервиса;
//        - "ОтсутствуетДоступКСервису" - у пользователя нет доступа к сервису;
//        - "ПревышеноКоличествоПопыток" - превышено количество попыток
//          обращения к сервису с некорректным логином и паролем;
//        - "ОшибкаПодключения" - ошибка при подключении к сервису;
//        - "ОшибкаСервиса" - внутренняя ошибка сервиса;
//        - "НеизвестнаяОшибка" - при получении информации возникла
//          неизвестная (не обрабатываемая) ошибка;
//        - "СервисВременноНеДоступен" - на сервере ведутся регламентные работы;
//        - "ИнтеграцияНеИспользуется" - использование отключено в настройках;
//    * СообщениеОбОшибке  - Строка, ФорматированнаяСтрока - сообщение об ошибке для пользователя;
//    * ИнформацияОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке для администратора.
//
Функция АктивироватьКассовуюСсылку( Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.АктивироватьКассовуюСсылку();
```
</details>

## ДеактивироватьКассовуюСсылку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет активный заказ для кассовой ссылки в Системе быстрых платежей.
//
// Параметры:
//  ДанныеСсылки - Структура - данные кассовой ссылки:
//    * КассоваяСсылка - Строка - ссылка, по которой будет выполнятся оплата;
//    * ИдентификаторОплаты - Строка - идентификатор зарегистрированной ссылки;
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//    настройка выполнения оплаты.
//
// Возвращаемое значение:
//  Структура - результат создания заказа на оплату в Системе быстрых платежей:
//    * КодОшибки - Строка - строковый код возникшей ошибки, который
//      может быть обработан вызывающим методом:
//        - <Пустая строка> - создание нового заказа выполнено успешно;
//        - "НеверныйФорматЗапроса" - передан некорректный запрос или настройка подключения;
//        - "НеверныйЛогинИлиПароль" - неверный логин или пароль или параметры
//          подключения к Системе быстрых платежей;
//        - "ТребуетсяОплата" - требуется оплата сервиса;
//        - "ОтсутствуетДоступКСервису" - у пользователя нет доступа к сервису;
//        - "ПревышеноКоличествоПопыток" - превышено количество попыток
//          обращения к сервису с некорректным логином и паролем;
//        - "ОшибкаПодключения" - ошибка при подключении к сервису;
//        - "ОшибкаСервиса" - внутренняя ошибка сервиса;
//        - "НеизвестнаяОшибка" - при получении информации возникла
//          неизвестная (не обрабатываемая) ошибка;
//        - "СервисВременноНеДоступен" - на сервере ведутся регламентные работы;
//        - "ИнтеграцияНеИспользуется" - использование отключено в настройках;
//    * СообщениеОбОшибке  - Строка, ФорматированнаяСтрока - сообщение об ошибке для пользователя;
//    * ИнформацияОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке для администратора.
//
Функция ДеактивироватьКассовуюСсылку( Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.ДеактивироватьКассовуюСсылку();
```
</details>

## КарточкаКассовойСсылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует табличный документ с данными кассовой ссылки.
//
// Параметры:
//  ДанныеСсылки - Структура - данные кассовой ссылки:
//    * КассоваяСсылка - Строка - ссылка, по которой будет выполнятся оплата;
//    * ИдентификаторОплаты - Строка - идентификатор зарегистрированной ссылки;
//  ПараметрыПечати - Структура - настройки печати:
//    * ТипПечати - Число - формат печати;
//        Допустимые значения :
//          "1" - для кассовой ссылки будет сформирован макет формата А5 широкий;
//          "2" - для кассовой ссылки будет сформирован макет формата А5 только логотипы;
//          "3" - для кассовой ссылки будет сформирован макет формата А5 узкий;
//          "4" - для кассовой ссылки будет сформирован макет формата А5 узкий горизонтальный;
//          "5" - для кассовой ссылки будет сформирован макет формата А6 квадратный;
//          "6" - для кассовой ссылки будет сформирован макет формата А6 круглый.
//
// Возвращаемое значение:
//  ТабличныйДокумент - подготовленный для печати документ.
//
Функция КарточкаКассовойСсылки( Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.КарточкаКассовойСсылки();
```
</details>

## СтатусОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку статуса оплаты в Системе быстрых платежей по ранее
// сформированному идентификатору оплаты (QR-коду).
//
// Параметры:
//  ДокументОперации - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//    продажу в информационной базе;
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//    настройка выполнения операции.
//  ДлительныйВызов - Булево - если Истина, получение статуса оплаты будет выполнятся
//   в цикле. Длительность выполнения операции определяется на основании
//   данных константы ДлительностьОперацииСистемыБыстрыхПлатежей.
//
// Возвращаемое значение:
//  Структура - результат создания заказа на оплату в Системе быстрых платежей:
//    * СтатусОперации - Строка - текущее состояние операции оплаты. Для проверки статуса
//      операции, необходимо функции программного интерфейса общего модуля
//      СистемаБыстрыхПлатежейКлиентСервер. Возможные значения:
//        - "Выполняется" - подтверждение оплаты не получено;
//        - "Отменена" - оплата по ранее сформированному QR-коду невозможна;
//        - "Выполнена" - участник СБП подтвердил оплату;
//        - "Ошибка" - не удалось выполнить проверку оплаты из-за ошибки;
//    * ПараметрыОперации - Структура - дополнительные данные по оплате:
//        ** ДатаОперации - Дата - фактическая дата оплаты в UTC;
//        ** СуммаОперации - Число - фактическая суммы оплаты по документу;
//        ** ИдентификаторОперации - Строка - идентификатор выполненной операции;
//        ** ИдентификаторОплаты - Строка - идентификатор оплаты;
//    * КодОшибки - Строка - строковый код возникшей ошибки, который
//      может быть обработан вызывающим методом:
//        - <Пустая строка> - оплата успешно проведена;
//        - "НеверныйФорматЗапроса" - передан некорректный запрос или настройка подключения;
//        - "НеверныйЛогинИлиПароль" - неверный логин или пароль или параметры
//          подключения к Системе быстрых платежей;
//        - "ТребуетсяОплата" - требуется оплата сервиса;
//        - "ОтсутствуетДоступКСервису" - у пользователя нет доступа к сервису;
//        - "ПревышеноКоличествоПопыток" - превышено количество попыток
//        обращения к сервису с некорректным логином и паролем;
//        - "ОшибкаПодключения" - ошибка при подключении к сервису;
//        - "ОшибкаСервиса" - внутренняя ошибка сервиса;
//        - "НеизвестнаяОшибка" - при получении информации возникла
//          неизвестная (не обрабатываемая) ошибка;
//        - "СервисВременноНеДоступен" - на сервере ведутся регламентные работы;
//        - "ИнтеграцияНеИспользуется" - использование отключено в настройках;
//    * СообщениеОбОшибке  - Строка, ФорматированнаяСтрока - сообщение об ошибке для пользователя;
//    * ИнформацияОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке для администратора.
//
Функция СтатусОплаты( Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.СтатусОплаты();
```
</details>

## ВозвратОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет возврат оплаты покупателю по ранее созданному заказу на оплату.
//
// Параметры:
//  ДокументВозврата - ОпределяемыйТип.ДокументОперацииСБП -  документ, который отражает
//    операцию возврата в информационной базе;
//  ОбъектОплаты - ОпределяемыйТип.ДокументОперацииСБП, Строка - документ продажи или идентификатор документа
//    оплаты в Системе быстрых платежей. Идентификатор оплаты может передаваться, если в информационной
//    базе отсутствует исходный документ оплаты. Для генерации QR-кода идентификатора оплаты,
//    необходимо использовать функцию  ПереводыСБПc2b.ИдентификаторыОперацииОплаты;
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//    настройка выполнения операции.;
//  УчастникСБП - Строка, Неопределено - идентификатор участника для определения
//    расчетного счета возврата. Параметр следует передавать только в том случае,
//    если УчастникСБПВозврата имеет значение Истина, см. СистемаБыстрыхПлатежей.НастройкиПодключения;
//  ДополнительныеПараметры - Структура, Неопределено - дополнительные настройки формирования
//    заказа на возврат.
//
// Возвращаемое значение:
//  Структура - результат создания заказа на возврат в Системе быстрых платежей:
//    * СтатусОперации - Строка - Для проверки статуса
//      операции, необходимо функции программного интерфейса общего модуля
//      СистемаБыстрыхПлатежейКлиентСервер. Возможные значения:
//        - "Выполняется" - подтверждение возврата не получено. Для проверки
//          состояния возврата необходимо вызвать функцию ПереводыСБПc2b.СтатусВозврата;
//        - "ТребуетсяПодтверждение" - для завершения возврата необходимо проверить
//          реквизиты физического лица см. свойство Подтверждение и отправить запрос
//          с подтверждением в платежную систему
//          см. ПереводыСБПc2b.ПодтвердитьВозврат.
//          запрос на подтверждение необходимо отправить в течение 3-х минут после создания заказа
//          на возврат. По истечению 3-х минут заказ будет отменен автоматически;
//        - "Выполнена" - участник СБП подтвердил выполнение возврата;
//        - "Ошибка" - не удалось выполнить проверку оплаты из-за ошибки, необходимо
//          проанализировать код ошибки;
//    * ПараметрыОперации - Структура - дополнительные данные по оплате:
//        ** ДатаОперации - Дата - фактическая дата оплаты в UTC;
//        ** СуммаОперации - Число - фактическая суммы возврата по документу;
//        ** ИдентификаторОперации - Строка - идентификатор выполненной операции;
//        ** ИдентификаторОплаты - Строка - идентификатор оплаты;
//    * Подтверждение - Структура, Неопределено - данные для подтверждения возврата в Системе быстрых платежей:
//        ** ФИО - Строка - маскированное ФИО физического лица на расчетный счет, которого
//           переводятся денежные средства;
//        ** НомерСчета, Неопределено - Строка - маскированный номер счета, на который будут переведены денежные средства;
//        ** НомерТелефона, Неопределено - Строка - маскированный номер телефона, к которому привязан
//           расчетный счет в Системе быстрых платежей получателе платежа;
//    * КодОшибки - Строка - строковый код возникшей ошибки, который
//      может быть обработан вызывающим методом:
//        - <Пустая строка> - создание нового заказа выполнено успешно;
//        - "НеверныйФорматЗапроса" - передан некорректный запрос или настройка подключения;
//        - "НеверныйЛогинИлиПароль" - неверный логин или пароль или параметры
//          подключения к Системе быстрых платежей;
//        - "ВозвратУжеВыполнен" - возврат по документу продажи уже выполнен или сумма возврата
//          превышает предельно допустимую;
//        - "ТребуетсяОплата" - требуется оплата сервиса;
//        - "ОтсутствуетДоступКСервису" - у пользователя нет доступа к сервису;
//        - "ПревышеноКоличествоПопыток" - превышено количество попыток
//          обращения к сервису с некорректным логином и паролем;
//        - "ОшибкаПодключения" - ошибка при подключении к сервису;
//        - "ОшибкаСервиса" - внутренняя ошибка сервиса;
//        - "НеизвестнаяОшибка" - при получении информации возникла
//          неизвестная (не обрабатываемая) ошибка;
//        - "СервисВременноНеДоступен" - на сервере ведутся регламентные работы;
//        - "ИнтеграцияНеИспользуется" - использование отключено в настройках;
//    * СообщениеОбОшибке  - Строка, ФорматированнаяСтрока - сообщение об ошибке для пользователя;
//    * ИнформацияОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке для администратора;
//
Функция ВозвратОплаты( Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.ВозвратОплаты();
```
</details>

## ПодтвердитьВозврат
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет отправку запроса на подтверждение возврата оплаты в платежную систему
// по ранее сформированной оплате.
//
// Параметры:
//  ДокументВозврата - ОпределяемыйТип.ДокументОперацииСБП -  документ, который отражает
//    операцию возврата в информационной базе;
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//    настройка выполнения операции.
//
// Возвращаемое значение:
//  Структура - результат подтверждения возврата в Системе быстрых платежей:
//    * СтатусОперации - Строка - текущее состояние операции возврата. Для проверки статуса
//      операции, необходимо функции программного интерфейса общего модуля
//      СистемаБыстрыхПлатежейКлиентСервер. Возможные значения:
//        - "Выполняется" - подтверждение возврата не получено;
//        - "Отменена" - оплата по ранее сформированному QR-коду невозможна;
//        - "Выполнена" - участник СБП подтвердил оплату;
//        - "Ошибка" - не удалось выполнить проверку оплаты из-за ошибки.
//    * ПараметрыОперации - Структура - дополнительные данные по оплате:
//        ** ДатаОперации - Дата - фактическая дата оплаты в UTC;
//        ** СуммаОперации - Число - фактическая суммы возврата по документу;
//        ** ИдентификаторОперации - Строка - идентификатор выполненной операции;
//    * КодОшибки - Строка - строковый код возникшей ошибки, который
//      может быть обработан вызывающим методом:
//        - <Пустая строка> - создание нового заказа выполнено успешно;
//        - "НеверныйФорматЗапроса" - передан некорректный запрос или настройка подключения;
//        - "НеверныйЛогинИлиПароль" - неверный логин или пароль или параметры
//          подключения к Системе быстрых платежей;
//        - "ВозвратУжеВыполнен" - возврат по документу продажи уже выполнен или сумма возврата
//          превышает предельно допустимую;
//        - "ТребуетсяОплата" - требуется оплата сервиса;
//        - "ОтсутствуетДоступКСервису" - у пользователя нет доступа к сервису;
//        - "ПревышеноКоличествоПопыток" - превышено количество попыток
//          обращения к сервису с некорректным логином и паролем;
//        - "ОшибкаПодключения" - ошибка при подключении к сервису;
//        - "ОшибкаСервиса" - внутренняя ошибка сервиса;
//        - "НеизвестнаяОшибка" - при получении информации возникла
//          неизвестная (не обрабатываемая) ошибка;
//        - "СервисВременноНеДоступен" - на сервере ведутся регламентные работы;
//        - "ИнтеграцияНеИспользуется" - использование отключено в настройках;
//    * СообщениеОбОшибке  - Строка, ФорматированнаяСтрока - сообщение об ошибке для пользователя;
//    * ИнформацияОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке для администратора.
//
Функция ПодтвердитьВозврат(ДокументВозврата, НастройкаПодключения) Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.ПодтвердитьВозврат(ДокументВозврата, НастройкаПодключения) 
```
</details>

## СтатусВозврата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку статуса возврата в Системе быстрых платежей.
//
// Параметры:
//  ДокументВозврата - ОпределяемыйТип.ДокументОперацииСБП -  документ, который отражает
//    операцию возврата в информационной базе;
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//    настройка выполнения операции.
//  ДлительныйВызов - Булево - если Истина, получение статуса оплаты будет выполнятся
//    в цикле. Длительность выполнения операции определяется на основании
//    данных константы ДлительностьОперацииСистемыБыстрыхПлатежей.
//
// Возвращаемое значение:
//  Структура - результат проверки статуса оплаты:
//    * СтатусОперации - Строка - текущее состояние операции возврата. Для проверки статуса
//      операции, необходимо функции программного интерфейса общего модуля
//      СистемаБыстрыхПлатежейКлиентСервер. Возможные значения:
//        - "Выполняется" - подтверждение возврата не получено;
//        - "Отменена" - оплата по ранее сформированному QR-коду невозможна;
//        - "Выполнена" - участник СБП подтвердил оплату;
//        - "Ошибка" - не удалось выполнить проверку оплаты из-за ошибки.
//    * ПараметрыОперации - Структура - дополнительные данные по оплате:
//        ** ДатаОперации - Дата - фактическая дата оплаты в UTC;
//        ** СуммаОперации - Число - фактическая суммы возврата по документу;
//        ** ИдентификаторОперации - Строка - идентификатор выполненной операции;
//        ** ИдентификаторОплаты - Строка - идентификатор оплаты;
//    * КодОшибки - Строка - строковый код возникшей ошибки, который
//      может быть обработан вызывающим методом:
//        - <Пустая строка> - создание нового заказа выполнено успешно;
//        - "НеверныйФорматЗапроса" - передан некорректный запрос или настройка подключения;
//        - "НеверныйЛогинИлиПароль" - неверный логин или пароль или параметры
//          подключения к Системе быстрых платежей;
//        - "ВозвратУжеВыполнен" - возврат по документу продажи уже выполнен или сумма возврата
//          превышает предельно допустимую;
//        - "ТребуетсяОплата" - требуется оплата сервиса;
//        - "ОтсутствуетДоступКСервису" - у пользователя нет доступа к сервису;
//        - "ПревышеноКоличествоПопыток" - превышено количество попыток
//          обращения к сервису с некорректным логином и паролем;
//        - "ОшибкаПодключения" - ошибка при подключении к сервису;
//        - "ОшибкаСервиса" - внутренняя ошибка сервиса;
//        - "НеизвестнаяОшибка" - при получении информации возникла
//          неизвестная (не обрабатываемая) ошибка;
//        - "СервисВременноНеДоступен" - на сервере ведутся регламентные работы;
//        - "ИнтеграцияНеИспользуется" - использование отключено в настройках;
//    * СообщениеОбОшибке  - Строка, ФорматированнаяСтрока - сообщение об ошибке для пользователя;
//    * ИнформацияОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке для администратора.
//
Функция СтатусВозврата(ДокументВозврата, НастройкаПодключения, ДлительныйВызов = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.СтатусВозврата(ДокументВозврата, НастройкаПодключения, ДлительныйВызов);
```
</details>

## УдалитьИдентификаторыОперации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет идентификатор операции из информационной базы.
// Процедуру необходимо использовать только в том случае, если при вызове
// методов оплаты в качестве документа оплаты была передана ссылка нового
// и после выполнения оплаты объект не был записан. Во всех остальных случаях
// вызов метода не рекомендуется.
//
// Параметры:
//  ДокументОперации - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//    операцию в информационной базе.
//
Процедура УдалитьИдентификаторыОперации(ДокументОперации) Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2b.УдалитьИдентификаторыОперации(ДокументОперации) 
```
</details>

## ОперацииПоДокументу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные оплат по документу основанию платежа.
//
// Параметры:
//  ДокументОперации - ОпределяемыйТип.ДокументОперацииСБП - документ операции;
//
// Возвращаемое значение:
//  Структура - данные оплат по документу в Системе быстрых платежей:
//    * ДокументОснование - ОпределяемыйТип.ДокументОперацииСБП - документ,
//      который отражает продажу в информационной базе;
//    * Сумма - Число - сумма выполненных оплат по документу;
//    * ДанныеОпераций - Массив Из Структура - содержит перечень данных оплат по документу основанию:
//        ** ДокументОперации - ОпределяемыйТип.ДокументОперацииСБП - документ операции в СБП
//        ** СуммаОперации - Число - Сумма оплаты в СБП
//        ** СтатусОперации - Строка - текущее состояние операции оплаты. Возможные значения:
//           - "Выполняется" - подтверждение оплаты не получено;
//           - "Отменена" - оплата по ранее сформированному QR-коду невозможна;
//           - "Выполнена" - участник СБП подтвердил оплату;
//           - "Отклонена" - оплата по ранее сформированному QR-коду невозможна;
//           - "Ошибка" - неизвестный статус операции.
//        ** ДатаОперации - Дата - фактическая дата оплаты в UTC;
//        ** ИдентификаторОперации - Строка - идентификатор выполненной операции;
//        ** ИдентификаторОплаты - Строка - идентификатор оплаты;
//        ** Оплата - Булево - если Истина, была выполнена оплата.
//
Функция ОперацииПоДокументу(ДокументОперации) Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.ОперацииПоДокументу(ДокументОперации) 
```
</details>

## СтатусыОпераций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет загрузку статусов операций СБП, по которым было
// отложено получение результата.
//
// Возвращаемое значение:
//  Массив из ОпределяемыйТип.ДокументОперацииСБП - данные обработанных документов.
//
Функция СтатусыОпераций() Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.СтатусыОпераций() 
```
</details>

## УстановитьОтложенноеПолучениеСтатуса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет установку признака загрузки статуса регламентным заданием, если
// ранее под документу была сгенерирован идентификатор оплаты СБП. Установка
// признака доступна только для сформированных операций у которых текущий статус
// "Выполняется".
//
// Параметры:
//  ДокументОперации - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//    продажу в информационной базе;
//  Значение - Булево - если Истина, данные статуса будут загружены регламентным заданием.
//
// Возвращаемое значение:
//  Булево - Истина, если признак отложенной загрузки статуса установлен,
//   Ложь если операция не найдена.
//
Функция УстановитьОтложенноеПолучениеСтатуса(ДокументОперации, Значение) Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.УстановитьОтложенноеПолучениеСтатуса(ДокументОперации, Значение) 
```
</details>

## ИзображениеQRКодаВозврата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирование изображения QR-кода, в которое кодируются все необходимые идентификаторы
// платежных систем для выполнения возврата оплаты. QR-код рекомендуется размещать
// на фискальном или товарном чеке, чтобы в случае отсутствия первичного документа оплаты
// в информационной базе (например, при использовании РИБ) была возможность выполнить
// возврат оплаты.
//
// Параметры:
//  ДокументОперации - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//    оплату в информационной базе;
//  Размер - Число - размер QR-кода в пикселях;
//
// Возвращаемое значение:
//  ДвоичныеДанные - данные изображения QR-кода.
//
Функция ИзображениеQRКодаВозврата(ДокументОперации, Размер) Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.ИзображениеQRКодаВозврата(ДокументОперации, Размер) 
```
</details>

## ИдентификаторыОперацииОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует строку, в которую добавляются все необходимые идентификаторы
// СБП для выполнения возврата оплаты по документу операции.
//
// Параметры:
//  ДокументОперации - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//    оплату в информационной базе.
//
// Возвращаемое значение:
//  Строка - набор идентификаторов операции оплаты, которые должны быть переданы при возврате.
//
Функция ИдентификаторыОперацииОплаты(ДокументОперации) Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.ИдентификаторыОперацииОплаты(ДокументОперации) 
```
</details>

## ПлатежныеСсылкиПоДокументамОпераций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует коллекцию, содержащую платежные ссылки по переданным документам операций.
//
// Параметры:
//  ДокументыОпераций - Массив Из ОпределяемыйТип.ДокументОперацииСБП - документы, которые отражают
//    оплату в информационной базе.
//  СтатусыОпераций - Массив Из Строка - допустимые статусы операций (фильтруют возвращаемую коллекцию),
//    Список статусов:
//      см. СистемаБыстрыхПлатежейКлиентСервер.СтатусОперацииВыполнена - операция успешно выполнена.
//      см. СистемаБыстрыхПлатежейКлиентСервер.СтатусОперацииВыполняется - операция выполняется.
//      см. СистемаБыстрыхПлатежейКлиентСервер.СтатусОперацииОтклонена - операция отклонена.
//
// Возвращаемое значение:
//  Соответствие - данные платежных ссылок по документам операций:
//    *Ключ - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//      оплату в информационной базе.
//    *Значение - Строка - платежная ссылка по документу операции.
//
Функция ПлатежныеСсылкиПоДокументамОпераций( Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.ПлатежныеСсылкиПоДокументамОпераций();
```
</details>

## ИдентификаторыОперации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует строку, в которую добавляются все необходимые идентификаторы
// СБП для выполнения возврата оплаты по набору идентификаторов.
//
// Параметры:
//  ПараметрыОперации - Структура - идентификаторы оплаты:
//    * ИдентификаторОперации - Строка - идентификатор выполненной операции;
//    * ИдентификаторОплаты - Строка - идентификатор оплаты.
//
// Возвращаемое значение:
//  Строка - набор идентификаторов операции оплаты, которые должны быть переданы при возврате.
//
Функция ИдентификаторыОперации(ПараметрыОперации) Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.ИдентификаторыОперации(ПараметрыОперации) 
```
</details>

## ИдентификаторФункциональнойСсылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет идентификатор функциональной ссылки.
//
// Параметры:
//  ДокументОперации - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//    оплату в информационной базе.
//
// Возвращаемое значение:
//  Строка - идентификатор функциональной ссылки.
//
Функция ИдентификаторФункциональнойСсылки(ДокументОперации) Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.ИдентификаторФункциональнойСсылки(ДокументОперации) 
```
</details>

## ДанныеОперации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать ПереводыСБПc2b.ОперацииПоДокументу.
// Получает исторические данные операции СБП по документу операции.
//
// Параметры:
//  ДокументОперации - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//    операцию в информационной базе.
//
// Возвращаемое значение:
//  Структура - данные заказа на оплату:
//    *ДатаОперации - Дата - дата заказа в программе;
//    *СуммаОперации - Число - сумма операции;
//    *НазначениеПлатежа - Строка - назначение для СБП;
//    *ДокументОперации - ОпределяемыйТип.ДокументОперацииСБП - объект оплаты в информационной базе;
//    *Оплата - Булево - если Истина, была выполнена оплата.
//
Функция ДанныеОперации(ДокументОперации) Экспорт
```

Пример вызова
```bsl
Результат = ПереводыСБПc2b.ДанныеОперации(ДокументОперации) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
