---
title: Переводы СБП (c2b) клиент переопределяемый
slug: erp-uh/переводы-сбп-c2b-клиент-переопределяемый
---


## ПриЗаполненииПараметровСообщенияБезШаблонаСБП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет параметры сообщения электронной почты, отправляемого без шаблона.
// Применяется в случае, если шаблоны сообщений не используются.
//
// Параметры:
//  ПараметрыСообщения - Структура - Параметры сообщения электронной почты:
//    * Получатель - СписокЗначений - Список адресов электронной почты.
//    * Предмет - Произвольный - Ссылка на основание платежа.
//    * Тема - Строка - Тема сообщения.
//    * Текст - Строка - Текст сообщения.
//  ПараметрыОперации - Структура - Содержит дополнительные параметры для формирования текста сообщения:
//    * НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//      настройка подключения к Системе быстрых платежей.
//    * ПлатежнаяСсылка - Строка - Платежная ссылка, отправляемая в сообщении.
//    * СуммаСсылкиСБП - Число - Сумма платежной ссылки, отправляемой в сообщении.
//
//@skip-warning
Процедура ПриЗаполненииПараметровСообщенияБезШаблонаСБП(ПараметрыСообщения, ПараметрыОперации) Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bКлиентПереопределяемый.ПриЗаполненииПараметровСообщенияБезШаблонаСБП(ПараметрыСообщения, ПараметрыОперации) 
```
</details>

## ПередОткрытиемФормыОтправкиПлатежнойСсылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет алгоритм, выполняющийся перед открытием формы подготовки платежной ссылки СБП.
//
Процедура ПередОткрытиемФормыОтправкиПлатежнойСсылки() Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bКлиентПереопределяемый.ПередОткрытиемФормыОтправкиПлатежнойСсылки() 
```
</details>

## ПриОткрытииФормыQRКода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет алгоритм, выполняющийся при открытии формы QR кода на форме подготовки платежной ссылки СБП.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма отображения QR-кода.
//  ДанныеПлатежнойСсылки - Структура - содержит в себе описание платежной ссылки:
//    * ПлатежнаяСсылка - Строка - ссылка сформированная по данным документа операции.
//    * QRКод - ДвоичныеДанные - данные изображения QR-кода.
//    * ОснованиеПлатежа - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//      оплату в информационной базе.
//  ОповещениеПослеЗавершенияНастройкиФормы - ОписаниеОповещения - оповещение,
//    вызывает метод "ПриОтображенииQRКода", рекомендуется использовать для подключения оборудования.
//    Свойство "ДополнительныеПараметры" имеет тип Структура, для передачи параметров в переопределяемый метод
//    ПереводыСБПc2bКлиентПереопределяемый.ПриОтображенииQRКода.
//
Процедура ПриОткрытииФормыQRКода( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bКлиентПереопределяемый.ПриОткрытииФормыQRКода();
```
</details>

## ПриОтображенииQRКода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет алгоритм, выполняющийся при отображении QR кода на форме подготовки платежной ссылки СБП.
//
// Параметры:
//  ДанныеПлатежнойСсылки - Структура - содержит описание платежной ссылки и основания платежа:
//    * ПлатежнаяСсылка - Строка - ссылка сформированная по данным документа операции.
//    * QRКод - ДвоичныеДанные - данные изображения QR-кода.
//    * ОснованиеПлатежа - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//      оплату в информационной базе.
//  Параметры - Структура - описание параметров переданных из метода
//   ПереводыСБПc2bКлиентПереопределяемый.ПриОткрытииФормыQRКода.
//
// Пример:
//  Если ОбщегоНазначенияКлиент.ПодсистемаСуществует("ПоддержкаОборудования.ПодключаемоеОборудование.ДисплеиПокупателя") Тогда
//
//     МодульОборудованиеДисплеиПокупателяКлиент = ОбщегоНазначенияКлиент.ОбщийМодуль("ОборудованиеДисплеиПокупателяКлиент");
//
//       Если МодульОборудованиеДисплеиПокупателяКлиент.ПодключенныеДисплеиПокупателяВыводятQRКод() Тогда
//
//         ПараметрыОперации = МодульОборудованиеДисплеиПокупателяКлиент.ПараметрыОперацииДисплейПокупателя();
//         ПараметрыОперации.ЗначениеQRКода = ДанныеПлатежнойСсылки.ПлатежнаяСсылка;
//         ПараметрыОперации.КартинкаQRКода = Base64Строка(ДанныеПлатежнойСсылки.ПлатежнаяСсылка);
//
//         МодульОборудованиеДисплеиПокупателяКлиент.НачатьВыводQRКодаНаДисплейПокупателя(
//           Неопределено,
//           Новый УникальныйИдентификатор,
//           Неопределено,
//           ПараметрыОперации);
//
//         КонецЕсли;
//  КонецЕсли;
//
Процедура ПриОтображенииQRКода( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bКлиентПереопределяемый.ПриОтображенииQRКода();
```
</details>

## ПриОбработкеНажатияКоманды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет алгоритм, выполняющийся при нажатии команды на форме QR-кода.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма отображения QR-кода.
//  Команда - КомандаФормы - выполняемая команда.
//  ДанныеПлатежнойСсылки - Структура - параметры выполнения команды:
//    * ПлатежнаяСсылка - Строка - ссылка сформированная по данным документа операции.
//    * QRКод - ДвоичныеДанные - данные изображения QR-кода.
//    * ОснованиеПлатежа - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//      оплату в информационной базе.
//
Процедура ПриОбработкеНажатияКоманды( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bКлиентПереопределяемый.ПриОбработкеНажатияКоманды();
```
</details>

## ПриЗакрытииФормыQRКода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет алгоритм, выполняющийся при закрытии формы отображения QR-кода.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма отображения QR-кода.
//
Процедура ПриЗакрытииФормыQRКода(Форма) Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bКлиентПереопределяемый.ПриЗакрытииФормыQRКода(Форма) 
```
</details>

## ПриНастройкеКассовыхСсылок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет алгоритм, выполняющийся при открытии формы кассовых ссылок из формы настройки подключения СБП.
//
// Параметры:
//  ПараметрыНастройки - Структура - содержит в себе описание настроек подключения:
//    * НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//      настройка подключения к Системе быстрых платежей.
//  ПараметрыОплаты - Соответствие - содержит имена и значения полей регистра сведений,
//      хранящего данные о настройках оплат.
//  ОповещениеПослеЗакрытияФормы - ОписаниеОповещения - оповещение,вызывает метод "ПриЗакрытииФормыКассовыхСсылок",
//    необходимо передать количество кассовых ссылок по настройке интеграции.
//
Процедура ПриНастройкеКассовыхСсылок( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bКлиентПереопределяемый.ПриНастройкеКассовыхСсылок();
```
</details>

## ПриОткрытииФормыПодключенияСсылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет алгоритм, выполняющийся при открытии подключения кассовой ссылки.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма подключения кассовой ссылки.
//  Отказ - Булево - признак отказа от открытия формы.
//
Процедура ПриОткрытииФормыПодключенияСсылки( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bКлиентПереопределяемый.ПриОткрытииФормыПодключенияСсылки();
```
</details>

## ОбработкаОповещенияФормыПодключенияСсылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет алгоритм, выполняющийся при открытии подключения кассовой ссылки.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма подключения кассовой ссылки.
//  ИмяСобытия - Строка - может быть использовано для идентификации сообщений
//    принимающими их формами.
//  Параметр - Произвольный - могут быть переданы любые необходимые данные для обработки.
//  Источник - Произвольный - источник события, например, в качестве источника может быть
//   указана другая форма.
//  Подключить - Булево - если устанавливается значение Истина, будет выполнена попытка
//   подключения ссылки.
//
Процедура ОбработкаОповещенияФормыПодключенияСсылки( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bКлиентПереопределяемый.ОбработкаОповещенияФормыПодключенияСсылки();
```
</details>

## ПриЗакрытииФормыПодключенияСсылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет алгоритм, выполняющийся при закрытии формы подключения кассовой ссылки.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма подключения кассовой ссылки.
//  ЗавершениеРаботы - Булево - признак завершения работы.
//
Процедура ПриЗакрытииФормыПодключенияСсылки( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bКлиентПереопределяемый.ПриЗакрытииФормыПодключенияСсылки();
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
