---
title: Переводы СБП (c2b) переопределяемый
slug: erp-uh/переводы-сбп-c2b-переопределяемый
---


## ПриФормированииЗаказаНаОплатуСБП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяются данные для формирования запроса на оплату в платежную систему СБП.
// Все поля переменной ЗаказНаОплату обязательны для заполнения.
//
// Параметры:
//  ДокументОплаты - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//    продажу в информационной базе;
//  ЗаказНаОплату - Структура - содержит описание заказа на оплату Системы быстрых платежей:
//    * СуммаОплаты - Число - сумма оплаты в Системе быстрых платежей. Сумма, которую необходимо
//      списать со счета покупателя;
//    * ДатаОплаты - Дата - дата операции оплаты;
//    * СрокЖизниQRКода - Число - содержит значение срока действия QR-кода в целых минутах.
//      Минимальное значение - 5 минут, максимальное значение - 129 600 минут
//      (90 дней в минутах). В случае передачи значения не входящего в выше
//      описанный диапазон возвращать ошибку "НеверныйФорматЗапроса".
//      Если значение не предано используется стандартный срок использования СБП;
//    * ОтложенноеПолучениеСтатуса - Булево - признак загрузки статуса оплаты регламентным заданием;
//    * НазначениеПлатежа - Строка - информация о платеже, которая будет отображена пользователю
//      в момент сканирования QR-кода в мобильном приложении. Рекомендуется
//      делать строку не длинной и включать информацию об организации, которая
//      является получателем денежных средств, например: Оплата СБП 524,00 RUB ООО Ромашка
//      Если строка не заполнена, будет передано стандартное представление
//      назначения: Оплата СБП {ЗаказНаОплату.СуммаОплаты} RUB.
//      Длина строки не должна превышать 140 символов, в противном случае будет
//      обрезана принудительно. Система быстрых платежей имеет дополнительные требования
//      к символам и их кодировке. Возможна передача следующих значений:
//        - символы латинского алфавита (A-Z и a-z) с десятичными кодами из диапазонов
//         [065-090] и [097-122] в кодировке UTF-8;
//        - символы русского алфавита (А-Я и а-я) с десятичными кодами из диапазона
//         [1040-1103] в кодировке UTF-8;
//        - цифры 0-9 с десятичными кодами из диапазона [048-057] в кодировке UTF-8;
//        - специальные символы с десятичными кодами из диапазонов [032-047], [058-064],
//         [091-096], [123-126] в кодировке UTF-8;
//        - символ "№" под номером 8470 в кодировке UTF-8.
//    * ШаблоныНазначений - ТаблицаЗначений - настройки заполнения шаблонов платежей:
//      ** ОбъектМетаданных - Строка - имя объекта метаданных операции.
//      ** Идентификатор - Строка - идентификатор шаблона.
//      ** Наименование - Строка - наименование шаблона для пользователя.
//      ** Параметры - Структура - параметры заполнения шаблона:
//      ** Параметры - Структура - параметры заполнения шаблона:
//        *** Наименование - Строка - наименование параметра для пользователя.
//        *** Идентификатор - Строка - идентификатор параметра для заполнения.
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//    настройка выполнения операции;
//  ДополнительныеПараметры - Структура, Неопределено - дополнительные настройки формирования
//    заказа на оплату переданные при вызове функции ПереводыСБПc2b.ДинамическаяСсылка
//    или ПереводыСБПc2b.АктивироватьКассовуюСсылку.
//
Процедура ПриФормированииЗаказаНаОплатуСБП( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bПереопределяемый.ПриФормированииЗаказаНаОплатуСБП();
```
</details>

## ПриФормированииЗаказаНаЧастичнуюОплатуСБП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяются данные для формирования запроса на оплату в платежную систему СБП.
// Все поля переменной ЗаказНаОплату обязательны для заполнения.
//
// Параметры:
//  ОснованиеПлатежа - ОпределяемыйТип.ДокументОперацииСБП - документ, который является
//    основанием частичного платежа;
//  ЗаказНаОплату - Структура - содержит описание заказа на оплату Системы быстрых платежей:
//    * СрокЖизниQRКода - Число - содержит значение срока действия QR-кода в целых минутах.
//      Минимальное значение - 5 минут, максимальное значение - 129 600 минут
//      (90 дней в минутах). В случае передачи значения не входящего в выше
//      описанный диапазон возвращать ошибку "НеверныйФорматЗапроса".
//      Если значение не предано используется стандартный срок использования СБП;
//    * НазначениеПлатежа - Строка - информация о платеже, которая будет отображена пользователю
//      в момент сканирования QR-кода в мобильном приложении. Рекомендуется
//      делать строку не длинной и включать информацию об организации, которая
//      является получателем денежных средств, например: Оплата СБП 524,00 RUB ООО Ромашка
//      Если строка не заполнена, будет передано стандартное представление
//      назначения: Оплата СБП {ЗаказНаОплату.СуммаОплаты} RUB.
//      Длина строки не должна превышать 140 символов, в противном случае будет
//      обрезана принудительно. Система быстрых платежей имеет дополнительные требования
//      к символам и их кодировке. Возможна передача следующих значений:
//        - символы латинского алфавита (A-Z и a-z) с десятичными кодами из диапазонов
//         [065-090] и [097-122] в кодировке UTF-8;
//        - символы русского алфавита (А-Я и а-я) с десятичными кодами из диапазона
//         [1040-1103] в кодировке UTF-8;
//        - цифры 0-9 с десятичными кодами из диапазона [048-057] в кодировке UTF-8;
//        - специальные символы с десятичными кодами из диапазонов [032-047], [058-064],
//         [091-096], [123-126] в кодировке UTF-8;
//        - символ "№" под номером 8470 в кодировке UTF-8.
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//    настройка выполнения операции;
//  ДополнительныеПараметры - Структура, Неопределено - дополнительные настройки формирования
//    заказа на оплату переданные при вызове функции ПереводыСБПc2b.ДинамическаяСсылка
//
Процедура ПриФормированииЗаказаНаЧастичнуюОплатуСБП( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bПереопределяемый.ПриФормированииЗаказаНаЧастичнуюОплатуСБП();
```
</details>

## ПриФормированииЗаказаНаВозвратСБП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяются данные для формирования запроса на возврат в платежную систему СБП.
// Все поля переменной ЗаказНаВозврат обязательны для заполнения.
//
// Параметры:
//  ДокументВозврата - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//   возврат в информационной базе;
//  ЗаказНаВозврат - Структура - содержит описание заказа на возврат в Системе быстрых платежей:
//    * СуммаВозврата - Число - сумма возврата в Системе быстрых платежей. Сумма, которую необходимо
//      перевести на счета покупателя;
//    *ДатаВозврата - Дата - дата операции возврата;
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//   настройка выполнения операции.;
//  ДополнительныеПараметры - Структура, Неопределено - дополнительные настройки формирования
//   заказа на оплату переданные при вызове функции ПереводыСБПc2b.ВозвратОплаты.
//
Процедура ПриФормированииЗаказаНаВозвратСБП( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bПереопределяемый.ПриФормированииЗаказаНаВозвратСБП();
```
</details>

## ПриЗагрузкеСтатусаОперации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет алгоритм обработки операции, статус которых был получен регламентным заданием.
//
// Параметры:
//  ДокументОперации - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//   операцию в информационной базе;
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//    настройка выполнения операций;
//  РезультатОбработки - Структура - результат загрузки статуса операции:
//    * СтатусОперации - Строка - текущее состояние операции операции. Для проверки статуса
//      операции, необходимо функции программного интерфейса общего модуля
//      СистемаБыстрыхПлатежейКлиентСервер. Возможные значения:
//        - "Отменена" - по ранее сформированная операция отменена НСПК;
//        - "Выполнена" - участник СБП подтвердил выполнение операции;
//        - "Ошибка" - не удалось выполнить проверку статуса операции из-за ошибки
//           или участник СБП вернул ошибку;
//    * ПараметрыОперации - Структура - дополнительные данные по оплате:
//        ** ДатаОперации - Дата - фактическая дата оплаты в UTC;
//        ** СуммаОперации - Число - фактическая суммы операции по документу;
//        ** ИдентификаторОперации - Строка - идентификатор сформированной операции;
//        ** ДокументЧастичнойОплаты - Документ.ПлатежнаяСсылкаСБПc2b - документ частичной оплаты;
//        ** ИдентификаторОплаты- Строка - идентификатор оплаты;
//    * СообщениеОбОшибке - Строка - сообщение пользователю. Заполняется в случае ошибки.
//  Обработан - Булево - признак обработки операции. Необходимо установить Истина,
//   после завершения обработки.
//
Процедура ПриЗагрузкеСтатусаОперации( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bПереопределяемый.ПриЗагрузкеСтатусаОперации();
```
</details>

## ПриПроверкеИспользованияШаблоновСообщенийСБП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак использования шаблонов сообщений для работы с СБП.
//
// Параметры:
//  Используется - Булево - признак использования шаблонов сообщений.
//
//@skip-warning
Процедура ПриПроверкеИспользованияШаблоновСообщенийСБП(Используется) Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bПереопределяемый.ПриПроверкеИспользованияШаблоновСообщенийСБП(Используется) 
```
</details>

## ПриОпределенииПредопределенныхШаблоновСообщенийСБППоТипам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описывает предопределенные шаблоны писем по типу,
// с помощью которых можно будет выставлять счета для оплаты через СБП.
// Эти шаблоны будут доступны для создания из основной формы настроек и использоваться
// в форме формирования платежной ссылки СБП.
// Добавлены реквизиты:
//   * ПредставлениеСсылкиСБПQRКод - вставляет платежную ссылку в виде картинки (Base64).
//   * ПредставлениеСсылкиСБП - вставляет платежную ссылку в виде строки.
//
// Параметры:
//  Шаблоны - Массив - Массив структур данных, описывающих предопределенные шаблоны сообщения.
//    * ПолноеИмяТипаНазначения - Строка - Полное имя объекта метаданных, на основании которого по данному шаблону
//        будут создаваться письма.
//    * Текст - Строка - Текст, который будет использоваться в качестве шаблона письма в формате HTML.
//    * Тема - Строка - Текст, который будет использоваться в качестве шаблона темы письма.
//    * Наименование - Строка - Текст, наименование шаблона письма.
//    * Тип - Строка - Тип шаблона. Возможные значения:"Почта" или "SMS".
//
//@skip-warning
Процедура ПриОпределенииПредопределенныхШаблоновСообщенийСБППоТипам(Шаблоны) Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bПереопределяемый.ПриОпределенииПредопределенныхШаблоновСообщенийСБППоТипам(Шаблоны) 
```
</details>

## ПриОпределенииПараметровОтправкиСообщенийСБП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет параметры отправки сообщений с использованием шаблонов СБП.
//
// Параметры:
//  ПараметрыОтправкиСообщений - Структура - описание параметров отправки сообщений:
//    * ПараметрыОтправкиПисем - Структура - описание параметров отправки электронных писем:
//       ** ОтправлятьПисьмаВФорматеHTML - Булево, Неопределено - признак отправки электронных писем в формате HTML.
//          Если свойство не задано, в дальнейшем при наличии подсистемы "Взаимодействия" будет получено значение
//          функциональной опции "ОтправлятьПисьмаВФорматеHTML", либо Ложь при ее отсутствии.
//
//@skip-warning
Процедура ПриОпределенииПараметровОтправкиСообщенийСБП( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bПереопределяемый.ПриОпределенииПараметровОтправкиСообщенийСБП();
```
</details>

## ПриОпределенииДанныхКассовыхСсылок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет список кассовых ссылок по параметрам настройки.
//
// Параметры:
//  ПараметрыНастройки - Структура - содержит в себе описание настроек подключения:
//    * НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//      настройка подключения к Системе быстрых платежей.
//  ДанныеКассовыхСсылок -  Структура - содержит описание настроенных кассовых ссылок по параметрам настройки
//    * Количество - Число - количество кассовых ссылок по преданной настройке подключения.
//
Процедура ПриОпределенииДанныхКассовыхСсылок( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bПереопределяемый.ПриОпределенииДанныхКассовыхСсылок();
```
</details>

## ПриОпределенииОбъектовСКомандамиСБП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет объекты, которые могут выступать в качестве оснований платежа через СБП.
//
// Параметры:
//  ИменаДокументовОперации - Массив Из Строка - имена объектов метаданных оснований платежа через СБП.
//
//@skip-warning
Процедура ПриОпределенииОбъектовСКомандамиСБП(ИменаДокументовОперации) Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bПереопределяемый.ПриОпределенииОбъектовСКомандамиСБП(ИменаДокументовОперации) 
```
</details>

## ПриОпределенииДоступностиПодключенияПоДокументуОперации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет возможность формирования платежной ссылки на основании данных документа операции.
//
// Параметры:
//  ДокументОперации - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//    операцию в информационной базе.
//  Результат - Структура - результат проверки:
//    * ИнтеграцияДоступна - Булево - признак доступности работы с СБП по данным документа операции.
//    * СообщениеОбОшибке - Строка - сообщение для пользователя. Отображается в случае, если в параметр
//    ИнтеграцияДоступна установлено значение Ложь.
//
//@skip-warning
Процедура ПриОпределенииДоступностиПодключенияПоДокументуОперации( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bПереопределяемый.ПриОпределенииДоступностиПодключенияПоДокументуОперации();
```
</details>

## ПриОпределенииПараметровПодключенияДокументаОперации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет перечень возможных настроек подключения на основании данных документа операции.
//
// Параметры:
//  ДокументОперации - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//    операцию в информационной базе.
//  НастройкиПодключения - Массив Из СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//    настройка подключения к СБП.
//  ДополнительныеНастройки - Структура - дополнительные настройки подключения СБП
//   * БИК - Строка, Неопределено - идентификатор банка. Используется для автоматического
//     выбора участника СБП.
//   * ДополнительныеПараметры - Структура, Неопределено - дополнительные параметры подключения.
//     Значение будет передано в переопределяемые методы:
//       - СистемаБыстрыхПлатежейПереопределяемый.ПриНастройкеЭлементовФормыПодключения;
//       - СистемаБыстрыхПлатежейПереопределяемый.ПриНастройкеЭлементовФормыПодключения.
//   * ОтборУчастников - Строка, Неопределено - Параметры отбора участников СБП.
//     Допустимые значения - "Банки", "ПлатежныеАгрегаторы", "КассовыеСсылки", Неопределено.
//     Неопределено по умолчанию.
//   * МаксимальнаяСуммаОплаты - Число- определяет максимальную сумму оплаты по данным документа.
//  ПараметрыВопроса - Структура - настройки отображения вопроса, который будет выведен пользователю
//    перед началом формирования платежной ссылки или началом подключения к СБП.
//    Вопрос не выводится, если параметр "ТекстВопроса" имеет значение Неопределено.
//    * ТекстВопроса - Строка, Неопределено - текст вопроса для отображения.
//
//@skip-warning
Процедура ПриОпределенииПараметровПодключенияДокументаОперации( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bПереопределяемый.ПриОпределенииПараметровПодключенияДокументаОперации();
```
</details>

## ПриСозданииНаСервереФормыQRКода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет алгоритм, выполняющийся при создании формы отображения QR-кода на форме подготовки платежной ссылки СБП.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма отображения QR-кода.
//  НастройкиФормы - Структура - описание настроек формы для размещения
//    программно созданных объектов.
//    * Группа - ГруппаФормы - элемент формы для программного добавления новых элементов управления,
//        в качестве свойства "Действие" у программно создаваемых команд,
//        необходимо указать значение "Подключаемый_ПриОбработкеНажатияКоманды".
//  ДанныеПлатежнойСсылки - Структура - параметры выполнения команды:
//    * ПлатежнаяСсылка - Строка - ссылка сформированная по данным документа операции.
//    * QRКод - ДвоичныеДанные - данные изображения QR-кода.
//    * ОснованиеПлатежа - ОпределяемыйТип.ДокументОперацииСБП - документ, который отражает
//      оплату в информационной базе.
//
//@skip-warning
Процедура ПриСозданииНаСервереФормыQRКода( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bПереопределяемый.ПриСозданииНаСервереФормыQRКода();
```
</details>

## ПриСозданииНаСервереФормыПодключенияСсылки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет алгоритм, выполняющийся при создании формы подключения кассовой ссылки.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма подключения кассовой ссылки.
//  Отказ - Булево - признак отказа от открытия формы.
//
Процедура ПриСозданииНаСервереФормыПодключенияСсылки(Форма, Отказ) Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bПереопределяемый.ПриСозданииНаСервереФормыПодключенияСсылки(Форма, Отказ) 
```
</details>

## ПриФормированииСпискаПолучателейСообщенияСБП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет список получателей сообщения с платежной ссылкой.
//
// Параметры:
//  ДокументОперации - Произвольный - документ операции, для которого получена платежная ссылка.
//  ВариантОтправки - Строка - способ отправки ссылки. "ЭлектроннаяПочта" - по электронной почте, "Телефон" - по SMS.
//  Получатели - СписокЗначений - адреса электронной почты или номера телефонов получателей (строка).
//
//@skip-warning
Процедура ПриФормированииСпискаПолучателейСообщенияСБП( Экспорт
```

Пример вызова
```bsl
ПереводыСБПc2bПереопределяемый.ПриФормированииСпискаПолучателейСообщенияСБП();
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
