---
title: Передача товаров хранителю локализация
slug: erp-uh/передача-товаров-хранителю-локализация
---


## ОбработкаПроверкиЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика документа
//
// Параметры:
//  Объект - ДокументОбъект - Обрабатываемый объект
//  Отказ - Булево - Если в теле процедуры-обработчика установить данному параметру значение Истина,
//                   то будет выполнен отказ от продолжения работы после выполнения проверки заполнения.
//  ПроверяемыеРеквизиты - Массив - Массив путей к реквизитам, для которых будет выполнена проверка заполнения.
//
Процедура ОбработкаПроверкиЗаполнения(Объект, Отказ, ПроверяемыеРеквизиты) Экспорт
```

Пример вызова
```bsl
ПередачаТоваровХранителюЛокализация.ОбработкаПроверкиЗаполнения(Объект, Отказ, ПроверяемыеРеквизиты) 
```
</details>

## ОбработкаЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика документа
//
// Параметры:
//  Объект - ДокументОбъект - Обрабатываемый объект.
//  ДанныеЗаполнения - Произвольный - Значение, которое используется как основание для заполнения.
//  СтандартнаяОбработка - Булево - В данный параметр передается признак выполнения стандартной (системной) обработки события.
//
Процедура ОбработкаЗаполнения(Объект, ДанныеЗаполнения, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ПередачаТоваровХранителюЛокализация.ОбработкаЗаполнения(Объект, ДанныеЗаполнения, СтандартнаяОбработка) 
```
</details>

## ПередЗаписью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика документа
//
// Параметры:
//  Объект - ДокументОбъект - Обрабатываемый объект
//  Отказ - Булево - Признак отказа от записи.
//                   Если в теле процедуры-обработчика установить данному параметру значение Истина,
//                   то запись выполнена не будет и будет вызвано исключение.
//  РежимЗаписи - РежимЗаписиДокумента - В параметр передается текущий режим записи документа. Позволяет определить в теле процедуры режим записи.
//  РежимПроведения - РежимПроведенияДокумента - В данный параметр передается текущий режим проведения.
//
Процедура ПередЗаписью(Объект, Отказ, РежимЗаписи, РежимПроведения) Экспорт
```

Пример вызова
```bsl
ПередачаТоваровХранителюЛокализация.ПередЗаписью(Объект, Отказ, РежимЗаписи, РежимПроведения) 
```
</details>

## ОбработкаПроведения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика документа
//
// Параметры:
//  Объект - ДокументОбъект - Обрабатываемый документ.
//  Отказ - Булево - Признак проведения документа.
//                   Если в теле процедуры-обработчика установить данному параметру значение Истина,
//                   то проведение документа выполнено не будет.
//  РежимПроведения - РежимПроведенияДокумента - В данный параметр передается текущий режим проведения.
//
Процедура ОбработкаПроведения(Объект, Отказ, РежимПроведения) Экспорт
```

Пример вызова
```bsl
ПередачаТоваровХранителюЛокализация.ОбработкаПроведения(Объект, Отказ, РежимПроведения) 
```
</details>

## ОбработкаУдаленияПроведения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика документа
//
// Параметры:
//  Объект - ДокументОбъект - Обрабатываемый объект
//  Отказ - Булево - Признак отказа от записи.
//                   Если в теле процедуры-обработчика установить данному параметру значение Истина,
//                   то запись выполнена не будет и будет вызвано исключение.
//
Процедура ОбработкаУдаленияПроведения(Объект, Отказ) Экспорт
```

Пример вызова
```bsl
ПередачаТоваровХранителюЛокализация.ОбработкаУдаленияПроведения(Объект, Отказ) 
```
</details>

## ПриЗаписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика документа
//
// Параметры:
//  Объект - ДокументОбъект - Обрабатываемый объект
//  Отказ - Булево - Признак отказа от записи.
//                   Если в теле процедуры-обработчика установить данному параметру значение Истина, то запись выполнена не будет и будет вызвано исключение.
//
Процедура ПриЗаписи(Объект, Отказ) Экспорт
```

Пример вызова
```bsl
ПередачаТоваровХранителюЛокализация.ПриЗаписи(Объект, Отказ) 
```
</details>

## ПриКопировании
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается из соответствующего обработчика документа
//
// Параметры:
//  Объект - ДокументОбъект - Обрабатываемый объект
//  ОбъектКопирования - ДокументОбъект - Исходный документ, который является источником копирования.
//
Процедура ПриКопировании(Объект, ОбъектКопирования) Экспорт
```

Пример вызова
```bsl
ПередачаТоваровХранителюЛокализация.ПриКопировании(Объект, ОбъектКопирования) 
```
</details>

## ДобавитьКомандуСоздатьНаОсновании
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет команду создания документа "Авансовый отчет".
//
// Параметры:
//  КомандыСозданияНаОсновании - см. СозданиеНаОснованииПереопределяемый.ПередДобавлениемКомандСозданияНаОсновании.КомандыСозданияНаОсновании
//
Процедура ДобавитьКомандуСоздатьНаОсновании(КомандыСозданияНаОсновании) Экспорт
```

Пример вызова
```bsl
ПередачаТоваровХранителюЛокализация.ДобавитьКомандуСоздатьНаОсновании(КомандыСозданияНаОсновании) 
```
</details>

## ДобавитьКомандыОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет список команд отчетов.
//
// Параметры:
//   КомандыОтчетов - См. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.КомандыОтчетов
//   Параметры - См. ВариантыОтчетовПереопределяемый.ПередДобавлениемКомандОтчетов.Параметры
//
Процедура ДобавитьКомандыОтчетов(КомандыОтчетов, Параметры) Экспорт
```

Пример вызова
```bsl
ПередачаТоваровХранителюЛокализация.ДобавитьКомандыОтчетов(КомандыОтчетов, Параметры) 
```
</details>

## СформироватьКомплектПечатныхФорм
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СформироватьКомплектПечатныхФорм(МассивОбъектов, Экспорт
```

Пример вызова
```bsl
ПередачаТоваровХранителюЛокализация.СформироватьКомплектПечатныхФорм(МассивОбъектов, );
```
</details>

## КомплектПечатныхФорм
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура КомплектПечатныхФорм(КомплектПечатныхФорм) Экспорт
```

Пример вызова
```bsl
ПередачаТоваровХранителюЛокализация.КомплектПечатныхФорм(КомплектПечатныхФорм) 
```
</details>

## ПолучитьДанныеДляПечатнойФормыТОРГ12
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ Локализация

// Функция получает данные для формирования печатной формы ТОРГ - 12
//
// Параметры:
//	ПараметрыПечати - Структура
//	МассивОбъектов - Массив - Массив ссылок на документы, по которым необходимо получить данные.
//
// Возвращаемое значение:
// 	Структура:
// 		* РезультатПоШапке - РезультатЗапроса
// 		* РезультатПоТабличнойЧасти - РезультатЗапроса
//
Функция ПолучитьДанныеДляПечатнойФормыТОРГ12(ПараметрыПечати, МассивОбъектов) Экспорт
```

Пример вызова
```bsl
Результат = ПередачаТоваровХранителюЛокализация.ПолучитьДанныеДляПечатнойФормыТОРГ12(ПараметрыПечати, МассивОбъектов) 
```
</details>

## ПоместитьВременнуюТаблицуТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует временную таблицу, содержащую табличную часть по таблице данных документов.
//
// Параметры:
//	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - Менеджер временных таблиц, содержащий таблицу ТаблицаДанныхДокументов с полями:
//		* Ссылка 				- ДокументСсылка.ПередачаТоваровХранителю 	- ссылка на документ.
//		* Валюта 				- СправочникСсылка.Валюты 					- валюта документа.
//		* ХозяйственнаяОперация - ПеречислениеСсылка.ХозяйственныеОперации 	- операция документа.
//
//	ПараметрыЗаполнения - Структура - структура, возвращаемая функцией ПродажиСервер.ПараметрыЗаполненияВременнойТаблицыТоваров
//
Процедура ПоместитьВременнуюТаблицуТоваров(МенеджерВременныхТаблиц, ПараметрыЗаполнения = Неопределено) Экспорт
```

Пример вызова
```bsl
ПередачаТоваровХранителюЛокализация.ПоместитьВременнуюТаблицуТоваров(МенеджерВременныхТаблиц, ПараметрыЗаполнения);
```
</details>

## СформироватьПечатнуюФормуРеестрНомеровГТД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция получает данные для формирования печатной формы Реестр номеров ГТД.
//
// Параметры:
//	ПараметрыПечати - Структура - структура дополнительных параметров печати,
//	МассивОбъектов  - Массив    - массив ссылок на объекты которые нужно распечатать.
//
// Возвращаемое значение:
//	ТабличныйДокумент - печатная форма Реестр номеров ГТД документов передачи товаров хранителю.
//
Функция СформироватьПечатнуюФормуРеестрНомеровГТД(МассивОбъектов, ОбъектыПечати) Экспорт
```

Пример вызова
```bsl
Результат = ПередачаТоваровХранителюЛокализация.СформироватьПечатнуюФормуРеестрНомеровГТД(МассивОбъектов, ОбъектыПечати));
```
</details>

## УстановитьПараметр
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьПараметр(ОбластьМакета, ИмяПараметра, ЗначениеПараметра) Экспорт
```

Пример вызова
```bsl
ПередачаТоваровХранителюЛокализация.УстановитьПараметр(ОбластьМакета, ИмяПараметра, ЗначениеПараметра));
```
</details>

## ПолучитьДанныеДляПечатнойФормыМ15
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция получает данные для формирования печатной формы М15
//
// Параметры:
//	ПараметрыПечати - Структура
//	МассивОбъектов - Массив из ДокументСсылка.ПередачаТоваровХранителю - Массив ссылок на документы, по которым необходимо получить данные.
//
// Возвращаемое значение:
// 	Структура:
// 		* РезультатПоШапке - РезультатЗапроса
// 		* РезультатПоТабличнойЧасти - РезультатЗапроса
//
Функция ПолучитьДанныеДляПечатнойФормыМ15(ПараметрыПечати, МассивОбъектов) Экспорт
```

Пример вызова
```bsl
Результат = ПередачаТоваровХранителюЛокализация.ПолучитьДанныеДляПечатнойФормыМ15(ПараметрыПечати, МассивОбъектов) 
```
</details>

## ПолучитьДанныеДляПечатнойФормыМХ1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные для формирования печатной формы МХ - 1.
//
// Параметры:
//	ПараметрыПечати	- Структура -дополнительные настройки печати.
//	МассивОбъектов	- Массив из ДокументСсылка.ПередачаТоваровХранителю - коллекция значений ссылок на документы,
//																			по которым необходимо получить данные.
//
// Возвращаемое значение:
//	Структура - коллекция данных, используемых для печати, содержащая следующие следующие свойства:
//		* РезультатПоШапке			- РезультатЗапроса - данные шапки документа.
//		* РезультатПоСкладам		- РезультатЗапроса - данные о складе ответственного хранения.
//		* РезультатПоТабличнойЧасти	- РезультатЗапроса - данные табличной части документа.
//		* РезультатПоОшибкам		- Неорпеделено - данные об ошибках, возникающих при печати документа.
//
Функция ПолучитьДанныеДляПечатнойФормыМХ1(ПараметрыПечати, МассивОбъектов) Экспорт
```

Пример вызова
```bsl
Результат = ПередачаТоваровХранителюЛокализация.ПолучитьДанныеДляПечатнойФормыМХ1(ПараметрыПечати, МассивОбъектов) 
```
</details>

## ПолучитьДанныеДляПечатнойФормыУПД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТ

// Возвращает данные для формирования печатной формы УПД
//
// Параметры:
//	ПараметрыПечати - Структура
//	МассивОбъектов - Массив из ДокументСсылка.ПередачаТоваровХранителю - ссылки на документы, по которым необходимо
//																			получить данные.
//
// Возвращаемое значение:
//	Структура - коллекция данных, используемая при печати УПД, содержащая следующие свойства:
//		* РезультатПоШапке - РезультатЗапроса - общие данные накладной.
//		* РезультатПоТабличнойЧасти - РезультатЗапроса - данные табличной части накладной.
//
Функция ПолучитьДанныеДляПечатнойФормыУПД(ПараметрыПечати, МассивОбъектов) Экспорт
```

Пример вызова
```bsl
Результат = ПередачаТоваровХранителюЛокализация.ПолучитьДанныеДляПечатнойФормыУПД(ПараметрыПечати, МассивОбъектов) 
```
</details>

## ТекстОтраженияВРеглУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает текст запроса для отражения документа в регламентированном учете.
//
// Возвращаемое значение:
//	Строка - Текст запроса
//
Функция ТекстОтраженияВРеглУчете() Экспорт
```

Пример вызова
```bsl
Результат = ПередачаТоваровХранителюЛокализация.ТекстОтраженияВРеглУчете() 
```
</details>

## ТекстЗапросаВТОтраженияВРеглУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает текст запроса дополнительных временных таблиц,
// необходимых для отражения в регламентированном учете
//
// Возвращаемое значение:
//   Строка - сформированный текст запроса.
//
Функция ТекстЗапросаВТОтраженияВРеглУчете() Экспорт
```

Пример вызова
```bsl
Результат = ПередачаТоваровХранителюЛокализация.ТекстЗапросаВТОтраженияВРеглУчете() 
```
</details>

## ПараметрыФормированияТранспортныхНакладных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
//-- НЕ УТ

//++ Локализация

// Правила получения значений реквизитов ТТН
//
// Возвращаемое значение:
//  Структура -  см. Документы.ТранспортнаяНакладная.ПараметрыФормированияТранспортныхНакладных
//
Функция ПараметрыФормированияТранспортныхНакладных() Экспорт
```

Пример вызова
```bsl
Результат = ПередачаТоваровХранителюЛокализация.ПараметрыФормированияТранспортныхНакладных() 
```
</details>

## ПараметрыФормированияЭлектронныхТранспортныхНакладных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Правила получения значений реквизитов ЭТН
//
// Возвращаемое значение:
//  см. ОбменСГИСЭПДПереопределяемый.ПараметрыФормированияЭлектронныхТранспортныхНакладных
//
Функция ПараметрыФормированияЭлектронныхТранспортныхНакладных() Экспорт
```

Пример вызова
```bsl
Результат = ПередачаТоваровХранителюЛокализация.ПараметрыФормированияЭлектронныхТранспортныхНакладных() 
```
</details>

## ПараметрыФормированияЭлектронныхЗаказНарядов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Правила получения значений реквизитов ЭЗН
//
// Возвращаемое значение:
//  см. ОбменСГИСЭПДПереопределяемый.ПараметрыФормированияЭлектронныхЗаказНарядов
//
Функция ПараметрыФормированияЭлектронныхЗаказНарядов() Экспорт
```

Пример вызова
```bsl
Результат = ПередачаТоваровХранителюЛокализация.ПараметрыФормированияЭлектронныхЗаказНарядов() 
```
</details>

## ДополнитьПараметрыЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополнить параметры заполнения.
//
// Параметры:
//  ПараметрыЗаполнения - Структура -
//  РеквизитыДокумента - ВыборкаИзРезультатаЗапроса, Структура -
Процедура ДополнитьПараметрыЗаполнения(ПараметрыЗаполнения, РеквизитыДокумента) Экспорт
```

Пример вызова
```bsl
ПередачаТоваровХранителюЛокализация.ДополнитьПараметрыЗаполнения(ПараметрыЗаполнения, РеквизитыДокумента) 
```
</details>

## УстановитьПараметрыОсобенностиУчетаНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Установить параметры особенности учета номенклатуры.
//
// Параметры:
//  ПараметрыЗаполнения - Структура -
//  ПараметрыЗапроса - Структура -
Процедура УстановитьПараметрыОсобенностиУчетаНоменклатуры(ПараметрыЗаполнения, ПараметрыЗапроса) Экспорт
```

Пример вызова
```bsl
ПередачаТоваровХранителюЛокализация.УстановитьПараметрыОсобенностиУчетаНоменклатуры(ПараметрыЗаполнения, ПараметрыЗапроса) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
