---
title: Печать этикеток ИСМП клиент сервер
slug: erp-uh/печать-этикеток-исмп-клиент-сервер
---


## СтруктураПечатиЭтикетки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Структура для заполнения данными, по которым будет производится резервирование и печать кодов
// маркировки товаров.
//
// Возвращаемое значение:
// 	Структура - Описание:
// * Организация          - ОпределяемыйТип.Организация - Организация.
// * ВидПродукции         - ПеречислениеСсылка.ВидыПродукцииИС - Вид продукции.
// * СпособВводаВОборот   - ПеречислениеСсылка.СпособыВводаВОборотСУЗ - Способ ввода
// * Шаблон               - ПеречислениеСсылка.ШаблоныКодовМаркировкиСУЗ - Шаблон кода маркировки
// * ШтрихкодУпаковки     - СправочникСсылка.ШтрихкодыУпаковокТоваров - Источник получения серии и типа штрихкода,
//                          если эти параметры не заполнены в соответствующих ключах.
// * ЭтоКодМаркировки     - Булево - Признак принадлежности структуры к маркируемой продукции,
//                          так же, могут печататься логистические упаковки.
// * СодержимоеКоличество - Число - Количество элементов внутри (для логистической упаковки)
// * НомерВГруппе         - Число - Номер по порядку (для логистической упаковки)
// * Порядок              - Число - Порядок сортировки для вывода на печать в пределах формируемой упаковки
// * Количество           - Число - Количество этикеток для печати
// * УчетноеКоличество    - Число - Количество для записи в справочник "Штрихкоды упаковок и товаров"
// * ШаблонЭтикетки       - СправочникСсылка.ШаблоныЭтикетокИЦенников - Шаблон для печати
// * ТипШтрихкода         - ПеречислениеСсылка.ТипыШтрихкодов - Тип штрихкода для печати
// * Штрихкод             - Строка - Значение штрихкода (используется дла печати и отметки о печати известного кода)
// * Номенклатура         - СправочникСсылка.Номенклатура - Номенклатура для заполнения шаблона
// * Характеристика       - СправочникСсылка.ХарактеристикиНоменклатуры - Характеристика для заполнения шаблона
// * Серия                - СправочникСсылка.СерииНоменклатуры - Серия, устанавливается в новый элемент ШтрикодУпаковкиТоваров.
// * GTIN                 - ОпределяемыйТип.GTIN - GTIN товара.
//
Функция СтруктураПечатиЭтикетки() Экспорт
```

Пример вызова
```bsl
Результат = ПечатьЭтикетокИСМПКлиентСервер.СтруктураПечатиЭтикетки() 
```
</details>

## ДанныеДляПечатиЭтикеток
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает структуру исходных данных для передачи в функцию печати
// У формы вдалельцем должна выступать форма с основным реквизитом Объект.
// Для резервирования необходима ссылка,поэтому для новых объектов будет предпринята попытка записать
// Во входящей структуре могут быть заполнены не все поля. Обязательными являются Номенклатура [, Характеристика]
// Если не заполнено поле ШаблонЭтикетки - шаблон будет запрошен у пользователя.
//
// Параметры:
// 	ПараметрыПечати - См. ПечатьЭтикетокИСМПКлиентСервер.СтруктураПечатиЭтикетки
// 	Форма - ФормаКлиентскогоПриложения - Источник событий
// 	Документ - ДокументСсылка - Документ, к которому будут относиться коды маркировки
// 	ДополнитьПолныйКодМаркировки - Строка - Идентификатор применения для дополнения кода маркировки
// Возвращаемое значение:
// 	Структура - Описание:
// * КаждаяЭтикеткаНаНовомЛисте - Булево - для данной функции не актульно, потому что печатается одна этикетка
// * Документ - ОпределяемыйТип.ОснованиеЗаказНаЭмиссиюКодовМаркировкиИСМП - Документ-основание,
//     на который необходимо перерезервировать свободный код маркировки.
// * АдресВХранилище - Строка - адрес объектов печати
Функция ДанныеДляПечатиЭтикеток(ПараметрыПечати, Форма, Документ, ДополнитьПолныйКодМаркировки) Экспорт
```

Пример вызова
```bsl
Результат = ПечатьЭтикетокИСМПКлиентСервер.ДанныеДляПечатиЭтикеток(ПараметрыПечати, Форма, Документ, ДополнитьПолныйКодМаркировки) 
```
</details>

## ВладелецФормыВерхнегоУровня
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает форму, являющуюся владельцем верхнего уровня переданной формы.
// Если форма не имеет владельца или владельцем является элемент управления, тогда возвращает саму форму.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения, Неопределено - форма.
// Возвращаемое значение:
//  Форма - ФормаКлиентскогоПриложения, Форма.
//
Функция ВладелецФормыВерхнегоУровня(Форма) Экспорт
```

Пример вызова
```bsl
Результат = ПечатьЭтикетокИСМПКлиентСервер.ВладелецФормыВерхнегоУровня(Форма) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
