---
title: Планирование производства
slug: erp-uh/планирование-производства
---


## ПроверитьЗаполнениеСпецификацииВЗаказеНаПроизводство
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку заполнения спецификации в строках продукции документа "Заказ на производство".
//
// Параметры:
//  Объект				- ДокументОбъект.ЗаказНаПроизводство - заказ на производство, который нужно проверить
//  МассивКлючей		- Массив - массив ключей строк табличной части Продукция
//  Отказ				- Булево - устанавливается в значение Истина, если найдены ошибки
//  ОбновитьСостояние	- Булево - Истина, если требуется обновить состояние спецификации в строках
//  СообщитьОбОшибках	- Булево - Истина, если требуется сообщить об ошибках с привязкой к реквизитам формы.
//
Процедура ПроверитьЗаполнениеСпецификацииВЗаказеНаПроизводство(Объект, МассивКлючей, Отказ = Ложь, ОбновитьСостояние = Ложь, СообщитьОбОшибках = Истина) Экспорт
```

Пример вызова
```bsl
ПланированиеПроизводства.ПроверитьЗаполнениеСпецификацииВЗаказеНаПроизводство(Объект, МассивКлючей, Отказ, ОбновитьСостояние, СообщитьОбОшибках);
```
</details>

## ПроверитьЗаполнениеПродукция
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку заполнения табличной части "Продукция" документа "Заказ на производство".
//
// Параметры:
//	Объект - ДокументОбъект.ЗаказНаПроизводство - Объект, для которого выполняется проверка заполнения.
//	Отказ  - Булево - устанавливается в значение Истина, если найдены ошибки.
//
Процедура ПроверитьЗаполнениеПродукция(Объект, Отказ) Экспорт
```

Пример вызова
```bsl
ПланированиеПроизводства.ПроверитьЗаполнениеПродукция(Объект, Отказ) 
```
</details>

## ЗаполнитьСпецификациюЗаказа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет спецификацию заказа на производство
//
// Параметры:
//  Объект										- ДокументОбъект.ЗаказНаПроизводство - заказ на производство, который нужно заполнить
//  МассивДанных								- Массив - массив данных о продукции для которой нужно заполнить спецификацию заказа
//  КэшированныеЗначения						-  Структура
//  ЗаполнитьПризнакХарактеристикиИспользуются	- Булево - Истина, если нужно заполнить реквизит ХарактеристикиИспользуются
//  ЗаполнятьИнформациюПоАвтовыбору				- Булево - Истина, если нужно заполнить информацию об автовыборе материалов
//  ЕстьУточненияМатериалов 					- Булево.
//
Процедура ЗаполнитьСпецификациюЗаказа(Объект, Экспорт
```

Пример вызова
```bsl
ПланированиеПроизводства.ЗаполнитьСпецификациюЗаказа(Объект, );
```
</details>

## ДанныеСпецификацииЗаказа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные спецификации заказа.
//
// Параметры:
//  ЗаказОбъект			 - ДокументОбъект.ЗаказНаПроизводство	 - заказ на производство
//  КлючСвязиПродукция	 - УникальныйИдентификатор				 - Идентификатор строки продукции в заказе на производство.
//
// Возвращаемое значение:
//   - Структура - данные спецификации заказа.
//
Функция ДанныеСпецификацииЗаказа(ЗаказОбъект, КлючСвязиПродукция) Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.ДанныеСпецификацииЗаказа(ЗаказОбъект, КлючСвязиПродукция) 
```
</details>

## ДанныеСпецификацииЗаказаВХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает данные спецификации заказа в хранилище и возвращает адрес в хранилище.
//
// Параметры:
//  ЗаказНаПроизводство		 - ДокументОбъект.ЗаказНаПроизводство, ДокументСсылка.ЗаказНаПроизводство	 - заказ на производство
//  КлючСвязиПродукция		 - УникальныйИдентификатор													 - Идентификатор строки продукции в заказе на производство
//  УникальныйИдентификатор	 - УникальныйИдентификатор													 - Идентификатор формы.
//
// Возвращаемое значение:
//   - Строка - адрес во временном хранилище.
//
Функция ДанныеСпецификацииЗаказаВХранилище(Знач ЗаказНаПроизводство, КлючСвязиПродукция, УникальныйИдентификатор) Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.ДанныеСпецификацииЗаказаВХранилище(ЗаказНаПроизводство, КлючСвязиПродукция, УникальныйИдентификатор) 
```
</details>

## ЗаполнитьКоличествоЭтаповНаЕдиницуСледующегоЭтапаРекурсивно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет служебный реквизит КоличествоЭтаповНаЕдиницуСледующегоЭтапа в Заказе на производство.
//
// Параметры:
//  Объект             - ДокументОбъект.ЗаказНаПроизводство, ОбработкаОбъект.РедактированиеСпецификацииСтрокиЗаказа -
//                       заказ на производство
//  КлючСвязиПродукция - УникальныйИдентификатор - Идентификатор строки продукции в заказе на производство
//  ЭтапРодитель       - ДанныеФормыЭлементКоллекции - Ссылка на строку-родителя табличной части Этапы заказа на производство.
//
Процедура ЗаполнитьКоличествоЭтаповНаЕдиницуСледующегоЭтапаРекурсивно(Объект, КлючСвязиПродукция, ЭтапРодитель = Неопределено) Экспорт
```

Пример вызова
```bsl
ПланированиеПроизводства.ЗаполнитьКоличествоЭтаповНаЕдиницуСледующегоЭтапаРекурсивно(Объект, КлючСвязиПродукция, ЭтапРодитель);
```
</details>

## УдалитьЭтапПроизводства
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет этап из спецификации заказа.
//
// Параметры:
//	Объект - ДокументОбъект.ЗаказНаПроизводство, ОбработкаОбъект.РедактированиеСпецификацииЗаказа - Объект, в котором удаляются этапы.
//	КлючСвязи - УникальныйИдентификатор - идентификатор удаляемого этапа
//	Отказ - Булево - признак отказа от удаления
//	ОписаниеОшибки - Строка - описание ошибки при удалении этапа
//	БракПоМаршрутнымЛистам - ДанныеФормыКоллекция - Таблица с данными о браке по маршрутным листам этапов.
//
Процедура УдалитьЭтапПроизводства(Объект, КлючСвязи, Отказ = Ложь, ОписаниеОшибки = Неопределено, БракПоМаршрутнымЛистам = Неопределено) Экспорт
```

Пример вызова
```bsl
ПланированиеПроизводства.УдалитьЭтапПроизводства(Объект, КлючСвязи, Отказ, ОписаниеОшибки, БракПоМаршрутнымЛистам);
```
</details>

## ПостроитьСтруктуруЭтапов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет номер текущего и номер следующего этапа с учетом вложенных этапов производства.
//
// Параметры:
//	ТаблицаЭтапов - ДанныеФормыКоллекция - Коллекция элементов этапов производства.
//
Процедура ПостроитьСтруктуруЭтапов(ТаблицаЭтапов) Экспорт
```

Пример вызова
```bsl
ПланированиеПроизводства.ПостроитьСтруктуруЭтапов(ТаблицаЭтапов) 
```
</details>

## ЭтапыПоКоторымЗапущеноПроизводство
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает этапы, по которым уже запущено производство
//
// Параметры:
//  СписокЗаказов	- ТаблицаЗначений - таблица, содержащая данные строк заказа на производство (Заказ, КодСтроки),
//										по которым нужно получить запущенные этапы.
//
// Возвращаемое значение:
//   ТаблицаЗначений   - Содержит этапы производства.
//
Функция ЭтапыПоКоторымЗапущеноПроизводство(СписокЗаказов) Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.ЭтапыПоКоторымЗапущеноПроизводство(СписокЗаказов) 
```
</details>

## ПолучитьДанныеПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает структуру данных по продукции
//
// Параметры:
//  Ссылка		 - ДокументСсылка.ЗаказНаПроизводство	 - ссылка на заказ
//  КлючСвязи	 - УникальныйИдентификатор				 - ключ строки продукции.
//
// Возвращаемое значение:
//   См. СтруктураДанныхПродукции.
//
Функция ПолучитьДанныеПродукции(Ссылка, КлючСвязи) Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.ПолучитьДанныеПродукции(Ссылка, КлючСвязи) 
```
</details>

## СтруктураДанныхПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает пустую структуру данных по продукции
//
// Параметры:
//  ДанныеЗаполнения - Структура - структура данных строки продукции заказа на производство:
//  * КлючСвязи - УникальныйИдентификатор - Идентификатор строки продукции в заказе на производство
//  * Номенклатура - СправочникСсылка.Номенклатура - номенклатура продукции
//  * Характеристика - СправочникСсылка.ХарактеристикиНоменклатуры - характеристика продукции
//  * Подразделение - СправочникСсылка.СтруктураПредприятия - подразделение-получатель для работ
//  * Склад - СправочникСсылка.Склады - склад для продукции
//  * Назначение - СправочникСсылка.Назначения - назначение продукции заказа на производство
//  * НазначениеЗаказа - СправочникСсылка.Назначения - назначение заказа на производство.
//
// Возвращаемое значение:
//   - Структура - данные по продукции.
//
Функция СтруктураДанныхПродукции(Знач ДанныеЗаполнения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.СтруктураДанныхПродукции(ДанныеЗаполнения);
```
</details>

## ПолучитьЗначенияДополнительныхРеквизитовПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция получает значения дополнительных реквизитов продукции
//
// Параметры:
//  РеквизитыПродукции - Структура - реквизиты продукции:
//    * Номенклатура - СправочникСсылка.Номенклатура - номенклатура продукции
//    * Назначение - СправочникСсылка.Назначения - назначение продукции заказа на производство.
//
// Возвращаемое значение:
//  Структура - значения дополнительных реквизитов:
//    * РеквизитыНоменклатуры - структура - реквизиты номенклатуры:
//      ** ТипНоменклатуры
//      ** ЭтоРабота
//      ** НаборУпаковок
//      ** ИспользоватьУпаковки
//    * РеквизитыНазначения - структура - реквизиты назначения:
//      ** ЕстьНазначение
//      ** ПоЗаказуДавальца.
//
Функция ПолучитьЗначенияДополнительныхРеквизитовПродукции(Знач РеквизитыПродукции) Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.ПолучитьЗначенияДополнительныхРеквизитовПродукции(РеквизитыПродукции));
```
</details>

## ТребуетсяАктуализацияМаршрутныхЛистов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция проверяет требуется ли актуализация маршрутных листов
//
// Параметры:
//  ЗаказОбъект - ДокументОбъект.ЗаказНаПроизводство - Объект, для которого требуется выполнить проверку.
//
// Возвращаемое значение:
//   - Булево - Истина, если актуализация требуется.
//
Функция ТребуетсяАктуализацияМаршрутныхЛистов(ЗаказОбъект) Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.ТребуетсяАктуализацияМаршрутныхЛистов(ЗаказОбъект) 
```
</details>

## ПараметрыАктуализацииМаршрутныхЛистов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает параметры актуализации маршрутных листов
//
// Параметры:
//  ЗаказОбъект - ДокументОбъект.ЗаказНаПроизводство - Объект, для которого требуется получить параметры актуализации
//                                                     маршрутных листов.
//
// Возвращаемое значение:
//  Структура - параметры актуализации маршрутных листов.
//
Функция ПараметрыАктуализацииМаршрутныхЛистов(ЗаказОбъект) Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.ПараметрыАктуализацииМаршрутныхЛистов(ЗаказОбъект) 
```
</details>

## ОчиститьПараметрыАктуализацииМаршрутныхЛистов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура очищает параметры актуализации маршрутных листов
// Параметры:
//  ЗаказОбъект - ДокументОбъект.ЗаказНаПроизводство - Объект, для которого требуется выполнить очистку параметров
//                                                     актуализации МЛ.
//
Процедура ОчиститьПараметрыАктуализацииМаршрутныхЛистов(ЗаказОбъект) Экспорт
```

Пример вызова
```bsl
ПланированиеПроизводства.ОчиститьПараметрыАктуализацииМаршрутныхЛистов(ЗаказОбъект) 
```
</details>

## ДобавитьПараметрыАктуализацииМаршрутныхЛистов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура добавляет параметры актуализации маршрутных листов в структуре дополнительных свойств.
//
// Параметры:
//  ДополнительныеСвойства		 - Структура	 						 - структура доп. свойств
//  Заказ						 - ДокументСсылка.ЗаказНаПроизводство	 - ссылка на распоряжение
//  МассивКодовСтрокПродукции	 - Массив								 - массив кодов строк продукции.
//
Процедура ДобавитьПараметрыАктуализацииМаршрутныхЛистов(ДополнительныеСвойства, Заказ, МассивКодовСтрокПродукции = Неопределено) Экспорт
```

Пример вызова
```bsl
ПланированиеПроизводства.ДобавитьПараметрыАктуализацииМаршрутныхЛистов(ДополнительныеСвойства, Заказ, МассивКодовСтрокПродукции);
```
</details>

## ВыполнитьПланирование
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет расчет графика производства
//
// Параметры:
//  СтруктураПараметров		 - Структура		 - структура параметров
//  ПоследовательностьЭтапов - ТаблицаЗначений	 - матрица последовательности этапов.
//
Процедура ВыполнитьПланирование(СтруктураПараметров, ПоследовательностьЭтапов) Экспорт
```

Пример вызова
```bsl
ПланированиеПроизводства.ВыполнитьПланирование(СтруктураПараметров, ПоследовательностьЭтапов) 
```
</details>

## СкорректироватьВремяВыполненияЭтапов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Корректирует время выполнения этапов с учетом буферов и интервала планирования
//
// Параметры:
//  СтруктураПараметров	 - Структура - структура параметров.
//
Процедура СкорректироватьВремяВыполненияЭтапов(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
ПланированиеПроизводства.СкорректироватьВремяВыполненияЭтапов(СтруктураПараметров) 
```
</details>

## ПоследовательностьЭтапов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает и возвращает таблицу последовательности этапов
//
// Параметры:
//  СтруктураПараметров	 - Структура - структура параметров.
//
// Возвращаемое значение:
//   - таблица - матрица последовательности этапов.
//
Функция ПоследовательностьЭтапов(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.ПоследовательностьЭтапов(СтруктураПараметров) 
```
</details>

## СледующиеЭтапы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СледующиеЭтапы(Этап) Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.СледующиеЭтапы(Этап));
```
</details>

## ПредыдущиеЭтапы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПредыдущиеЭтапы(Этап) Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.ПредыдущиеЭтапы(Этап));
```
</details>

## НачальныйЭтап
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НачальныйЭтап(Этап) Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.НачальныйЭтап(Этап));
```
</details>

## ПериодыНедоступностиРабочихЦентров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет периоды недоступности, которые подходят сразу всем исполнителям
//
// Параметры:
//  Начало			 - Дата				 - начало периода, в котором нужно получить периоды недоступности
//  Окончание		 - Дата				 - окончание периода, в котором нужно получить периоды недоступности
//  Исполнители		 - Массив			 - список рабочих центров, видов рабочих центров, подразделений
//  РасписаниеРаботы - ТаблицаЗначений	 - в переменную помещается расписание работы.
//
// Возвращаемое значение:
//  ТаблицаЗначений - содержит начало и окончание периода недоступности.
//
Функция ПериодыНедоступностиРабочихЦентров(Начало, Окончание, Исполнители, РасписаниеРаботы = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.ПериодыНедоступностиРабочихЦентров(Начало, Окончание, Исполнители, РасписаниеРаботы);
```
</details>

## ЗаданиеРасчетГрафикаПроизводства
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет поиск предопределенного регламентного задания "Расчет графика производства" по его метаданным.
//
// Возвращаемое значение:
//  РегламентноеЗадание - регламентное задание "Расчет графика производства".
//
Функция ЗаданиеРасчетГрафикаПроизводства() Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.ЗаданиеРасчетГрафикаПроизводства() 
```
</details>

## ПроверитьОтключитьРегламентноеЗаданиеРасчетГрафикаПроизводства
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет использование и при необходимости отключает регламентное задание "Расчет графика производства".
//
Процедура ПроверитьОтключитьРегламентноеЗаданиеРасчетГрафикаПроизводства() Экспорт
```

Пример вызова
```bsl
ПланированиеПроизводства.ПроверитьОтключитьРегламентноеЗаданиеРасчетГрафикаПроизводства() 
```
</details>

## ПредопределенноеРасписание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращается предопределенное расписания для автоматического планирования графика производства в модели сервиса.
// Выполнение задания каждый день в 01:00.
//
// Возвращаемое значение:
//   - РасписаниеРегламентногоЗадания - предопределенное расписание регламентного задания.
//
Функция ПредопределенноеРасписание() Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.ПредопределенноеРасписание() 
```
</details>

## РасчетГрафикаПроизводства
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает график производства по очереди заказов с неактуальным графиком
//
//
Процедура РасчетГрафикаПроизводства() Экспорт
```

Пример вызова
```bsl
ПланированиеПроизводства.РасчетГрафикаПроизводства() 
```
</details>

## РасписаниеРаботыПоГрафику
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает расписание работы заданное в графиках работы
//
// Параметры:
//	СписокГрафиков - Массив - список календарей
//	НачалоПериода - Дата - начало периода, за который нужно составить расписания
//	ОкончаниеПериода - Дата - окончания периода.
//
// Возвращаемое значение:
//   ТаблицаЗначений   - Расписание работы.
//
Функция РасписаниеРаботыПоГрафику(СписокГрафиков, НачалоПериода, ОкончаниеПериода) Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.РасписаниеРаботыПоГрафику(СписокГрафиков, НачалоПериода, ОкончаниеПериода) 
```
</details>

## РассчитатьОграниченияГрафикаПроизводстваПоМатериалам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ Устарело_Производство21

// Выполняет "онлайн" расчет сроков обеспечения этапов материалами для задачи расчета графика производства.
//
// Параметры:
//  Ссылка - ДокументСсылка.ЗаказНаПроизводство - заказ для которого необходимо получить ограничения.
//
// Возвращаемое значение:
//	Соответствие - ключ - ключ связи этапа заказа, значение - дата обеспечения.
//
Функция РассчитатьОграниченияГрафикаПроизводстваПоМатериалам(Ссылка) Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.РассчитатьОграниченияГрафикаПроизводстваПоМатериалам(Ссылка) 
```
</details>

## ОграниченияГрафикаПроизводстваПоМатериалам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сроки обеспечения этапов в разрезе материалов.
//
// Параметры:
//  Ссылка - ДокументСсылка.ЗаказНаПроизводство - заказ для которого необходимо получить ограничения.
//
// Возвращаемое значение:
//	ТаблицаЗначений - таблица с материалами.
//
Функция ОграниченияГрафикаПроизводстваПоМатериалам(Ссылка) Экспорт
```

Пример вызова
```bsl
Результат = ПланированиеПроизводства.ОграниченияГрафикаПроизводстваПоМатериалам(Ссылка) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
