---
title: Платежи в бюджет клиент сервер
slug: erp-uh/платежи-в-бюджет-клиент-сервер
---


## СтатусыПлательщика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список статусов отправителя п/п на перечисление в бюджет
//
// Параметры:
//	ПрименениеПриказа107н - Булево - Применяется ли приказ Минфина России от 12.11.2013 №107н.
//	Период - Дата - дата формирования статусов плательщика
//
// Возвращаемое значение:
//	СписокЗначений - список статусов.
//
Функция СтатусыПлательщика(ПрименениеПриказа107н, Период = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.СтатусыПлательщика(ПрименениеПриказа107н, Период);
```
</details>

## ОснованияПлатежа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список оснований платежа на перечисление в бюджет
//
// Параметры:
//	ВидПеречисления - ПеречислениеСсылка.ВидыПеречисленийВБюджет - вид перечисления в бюджет
//	ПрименениеПриказа107н - Булево - Применяется ли приказ Минфина России от 12.11.2013 №107н.
//	Период - Дата - дата формирования списка основания платежа
//
// Возвращаемое значение:
//	СписокЗначений - Список оснований.
//
Функция ОснованияПлатежа(ВидПеречисления, ПрименениеПриказа107н, Период = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ОснованияПлатежа(ВидПеречисления, ПрименениеПриказа107н, Период);
```
</details>

## ТипыПлатежа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список типов платежа на перечисление в бюджет
//
// Параметры:
//	ВидПеречисления - ПеречислениеСсылка.ВидыПеречисленийВБюджет - вид перечисления в бюджет
//	ПрименениеПриказа107н - Булево - Применяется ли приказ Минфина России от 12.11.2013 №107н.
//
// Возвращаемое значение:
//	СписокЗначений - Список типов
//
Функция ТипыПлатежа(ВидПеречисления, ПрименениеПриказа107н) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ТипыПлатежа(ВидПеречисления, ПрименениеПриказа107н) 
```
</details>

## КорректныйОКТМО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает результат проверки ОКТМО
//
// Параметры:
//	КодТерритории - Строка - код ОКТМО.
//
// Возвращаемое значение:
//	Булево - Признак корректности
//
Функция КорректныйОКТМО(КодТерритории) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.КорректныйОКТМО(КодТерритории) 
```
</details>

## НачалоДействияУказания3844У
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дату начала действия указания 3844У
//
// Возвращаемое значение:
//	Строка - строковое представление даты.
//
Функция НачалоДействияУказания3844У() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.НачалоДействияУказания3844У() 
```
</details>

## НачалоДействияПриказа107н
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дату начала действия приказа 107н
//
// Возвращаемое значение:
//	Строка - строковое представление даты.
//
Функция НачалоДействияПриказа107н() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.НачалоДействияПриказа107н() 
```
</details>

## ДействуетПриказ107н
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак действия приказа 107н на указанную дату
//
// Параметры:
//	Период - Дата - проверяемая дата.
//
// Возвращаемое значение:
//	Булево - Признак действия
//
Функция ДействуетПриказ107н(Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДействуетПриказ107н(Период) 
```
</details>

## НачалоДействияПриказа2017_90н
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дату начала действия приказа 90н
//
// Возвращаемое значение:
//	Дата - начало действия приказа.
//
Функция НачалоДействияПриказа2017_90н() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.НачалоДействияПриказа2017_90н() 
```
</details>

## НачалоДействияПриказа2017_58н
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НачалоДействияПриказа2017_58н() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.НачалоДействияПриказа2017_58н() 
```
</details>

## НачалоОтложенногоДействияПриказа2017_58н
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НачалоОтложенногоДействияПриказа2017_58н() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.НачалоОтложенногоДействияПриказа2017_58н() 
```
</details>

## ДействуетПриказ2017_58н
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДействуетПриказ2017_58н(Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДействуетПриказ2017_58н(Период) 
```
</details>

## ДействуетПриказ2017_58н_Отложенный
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДействуетПриказ2017_58н_Отложенный(Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДействуетПриказ2017_58н_Отложенный(Период) 
```
</details>

## НачалоДействияУказания2019_5286У
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет дату начала действия указания Банка России 5286-У
//
// Возвращаемое значение:
//    Дата - Дата начала действия указания
//
Функция НачалоДействияУказания2019_5286У() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.НачалоДействияУказания2019_5286У() 
```
</details>

## ДействуетУказание2019_5286У
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, действует ли на переданную дату указание Банка России 5286-У
//
// Возвращаемое значение:
//    Булево - Признак действия указания
//
Функция ДействуетУказание2019_5286У(Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДействуетУказание2019_5286У(Период) 
```
</details>

## ДействуетПриказ126н
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДействуетПриказ126н(Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДействуетПриказ126н(Период) 
```
</details>

## ДействуетПриказ90н
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДействуетПриказ90н(Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДействуетПриказ90н(Период) 
```
</details>

## ДействуетПриказ199н_202110
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак, действует ли приказ 199н от 14.09.2020 с 01.10.2021
//
// Параметры:
//	Период - Дата - дата для проверки на действие приказа
//
// Возвращаемое значение:
//	Дата
//
Функция ДействуетПриказ199н_202110(Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДействуетПриказ199н_202110(Период) 
```
</details>

## ДействуетПриказ199н_202107
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак, действует ли приказ 199н от 14.09.2020 с 01.07.2021
//
// Параметры:
//	Период - Дата - дата для проверки на действие приказа
//
// Возвращаемое значение:
//	Дата
//
Функция ДействуетПриказ199н_202107(Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДействуетПриказ199н_202107(Период) 
```
</details>

## ДействуетПриказ199н_202101
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак, действует ли приказ 199н от 14.09.2020 с 01.01.2021
//
// Параметры:
//	Период - Дата - дата для проверки на действие приказа
//
// Возвращаемое значение:
//	Дата
//
Функция ДействуетПриказ199н_202101(Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДействуетПриказ199н_202101(Период) 
```
</details>

## ДействуетПриказ199н_202302
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак, действует ли приказ 199н от 30.12.2022 с 11.02.2023
//
// Параметры:
//	Период - Дата - дата для проверки на действие приказа
//
// Возвращаемое значение:
//	Дата
//
Функция ДействуетПриказ199н_202302(Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДействуетПриказ199н_202302(Период) 
```
</details>

## ДействуетПриказ199н_202310
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак, действует ли приказ 199н от 30.12.2022 с 01.10.2023
//
// Параметры:
//	Период - Дата - дата для проверки на действие приказа
//
// Возвращаемое значение:
//	Дата
//
Функция ДействуетПриказ199н_202310(Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДействуетПриказ199н_202310(Период) 
```
</details>

## ДействуетПриказ199н_202401
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак, действует ли приказ 199н от 30.12.2022 с 01.01.2024
//
// Параметры:
//	Период - Дата - дата для проверки на действие приказа
//
// Возвращаемое значение:
//	Дата
//
Функция ДействуетПриказ199н_202401(Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДействуетПриказ199н_202401(Период) 
```
</details>

## ДействуетУказание762П_202205
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак, действует ли указание (изменения положения 762-П от 29.06.2021) с 01.05.2022
//
// Параметры:
//	Период - Дата - дата для проверки на действие указания
//
// Возвращаемое значение:
//	Дата
//
Функция ДействуетУказание762П_202205(Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДействуетУказание762П_202205(Период) 
```
</details>

## ДействуетИзменениеПриказа107н_202206
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак, действует ли изменение приказа 107н от 12.11.2013 с 20.06.2022
//
// Параметры:
//	Период - Дата - дата для проверки на действие изменений приказа
//
// Возвращаемое значение:
//	Дата
//
Функция ДействуетИзменениеПриказа107н_202206(Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДействуетИзменениеПриказа107н_202206(Период) 
```
</details>

## КодыВидовДохода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет перечень кодов видов дохода согласно указанию Банка России 5286-У
//
// Параметры:
//     Период - Дата - дата, в зависимости от которой меняется список значений кодов.
//     ВыплатаЗарплаты - Булево - Признак выплаты зарплаты
//
// Возвращаемое значение:
//    СписокЗначений из Строка - Коды видов дохода
//
Функция КодыВидовДохода(Период, ВыплатаЗарплаты = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.КодыВидовДохода(Период, ВыплатаЗарплаты);
```
</details>

## ПроверитьУИН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет корректность переданного идентификатора платежа
//
// Параметры:
//	ИдентификаторПлатежа    - Строка - проверяемый идентификатор платежа
//	ПлатежВФедеральныйОрган - Булево - признак платежа в федеральный орган государственной власти.
//
// Возвращаемое значение:
//	Строка - описание обнаруженных ошибок в идентификаторе.
//
Функция ПроверитьУИН(ИдентификаторПлатежа, ПлатежВФедеральныйОрган = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПроверитьУИН(ИдентификаторПлатежа, ПлатежВФедеральныйОрган);
```
</details>

## АдминистраторНачисленияФедеральныйОрганГосударственнойВласти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет что получателем по указанному номеру счета является федеральным органом государственной власти.
//
// Параметры:
//	НомерСчета    - Строка - номер банковского счета.
//
// Возвращаемое значение:
//	Булево - Истина: является, Ложь:  не является.
//
Функция АдминистраторНачисленияФедеральныйОрганГосударственнойВласти(Знач НомерСчета) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.АдминистраторНачисленияФедеральныйОрганГосударственнойВласти(НомерСчета) 
```
</details>

## РасположениеЭлементаКБК
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Приказ Минфина от 01.07.13 г. N 65н

// ┌──────────────────────────────────────────────────────────────────────────────────────┐
// │                     Структура кода классификации доходов бюджетов                    │
// ├──────────────┬─────────────────────────────────────────┬───────────┬─────────────────┤
// │ Код главного │        Код вида доходов бюджетов        │Код подвида│Код классификации│
// │администратора├───────┬───────┬───────┬─────────┬───────┤  доходов  │ операций сектора│
// │   доходов    │группа │под-   │статья │подстатья│элемент│ бюджетов  │ государственного│
// │   бюджета    │доходов│группа │доходов│ доходов │доходов│           │   управления,   │
// │              │       │доходов│       │         │       │           │  относящихся к  │
// │              │       │       │       │         │       │           │ доходам бюджетов│
// ├────┬────┬────┼───────┼───┬───┼───┬───┼──┬──┬───┼───┬───┼──┬──┬──┬──┼─────┬─────┬─────┤
// │ 1  │ 2  │ 3  │   4   │ 5 │ 6 │ 7 │ 8 │9 │10│11 │12 │13 │14│15│16│17│ 18  │ 19  │  20 │
// └────┴────┴────┴───────┴───┴───┴───┴───┴──┴──┴───┴───┴───┴──┴──┴──┴──┴─────┴─────┴─────┘

Функция РасположениеЭлементаКБК(ИмяЭлементаКБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.РасположениеЭлементаКБК(ИмяЭлементаКБК) 
```
</details>

## КБКЗадан
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КБКЗадан(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.КБКЗадан(КБК) 
```
</details>

## ЭлементКБК
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭлементКБК(КБК, ИмяЭлементаКБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ЭлементКБК(КБК, ИмяЭлементаКБК) 
```
</details>

## КодГлавногоАдминистратора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КодГлавногоАдминистратора(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.КодГлавногоАдминистратора(КБК) 
```
</details>

## ПустойКодГлавногоАдминистратора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПустойКодГлавногоАдминистратора() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПустойКодГлавногоАдминистратора() 
```
</details>

## КодВидаДоходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КодВидаДоходов(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.КодВидаДоходов(КБК) 
```
</details>

## ПодгруппаДоходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПодгруппаДоходов(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПодгруппаДоходов(КБК));
```
</details>

## КодЭлементаДоходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КодЭлементаДоходов(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.КодЭлементаДоходов(КБК));
```
</details>

## КодОперацииСектораУправления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КодОперацииСектораУправления(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.КодОперацииСектораУправления(КБК) 
```
</details>

## КодПодвидаДоходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КодПодвидаДоходов(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.КодПодвидаДоходов(КБК) 
```
</details>

## ПустойКодПодвидаДоходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПустойКодПодвидаДоходов() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПустойКодПодвидаДоходов() 
```
</details>

## ШаблонКБК
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ШаблонКБК(КБК, ПустойКодПодвидаДоходов = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ШаблонКБК(КБК, ПустойКодПодвидаДоходов);
```
</details>

## ПлатежАдминистрируетсяНалоговымиОрганами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// значения отдельных элементов КБК

Функция ПлатежАдминистрируетсяНалоговымиОрганами(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПлатежАдминистрируетсяНалоговымиОрганами(КБК) 
```
</details>

## ПлатежАдминистрируетсяПенсионнымФондом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПлатежАдминистрируетсяПенсионнымФондом(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПлатежАдминистрируетсяПенсионнымФондом(КБК) 
```
</details>

## ПлатежАдминистрируетсяФСС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПлатежАдминистрируетсяФСС(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПлатежАдминистрируетсяФСС(КБК) 
```
</details>

## ПлатежАдминистрируетсяТаможеннымиОрганами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПлатежАдминистрируетсяТаможеннымиОрганами(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПлатежАдминистрируетсяТаможеннымиОрганами(КБК) 
```
</details>

## КодАдминистрированияНалоговымиОрганами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КодАдминистрированияНалоговымиОрганами() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.КодАдминистрированияНалоговымиОрганами() 
```
</details>

## КодАдминистрированияПенсионнымФондом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КодАдминистрированияПенсионнымФондом() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.КодАдминистрированияПенсионнымФондом() 
```
</details>

## КодАдминистрированияФСС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КодАдминистрированияФСС() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.КодАдминистрированияФСС() 
```
</details>

## КодАдминистрированияФТС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КодАдминистрированияФТС() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.КодАдминистрированияФТС() 
```
</details>

## ЭтоНалоговыеДоходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоНалоговыеДоходы(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ЭтоНалоговыеДоходы(КБК) 
```
</details>

## ЭтоСтраховыеВзносы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоСтраховыеВзносы(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ЭтоСтраховыеВзносы(КБК) 
```
</details>

## ЭтоКБКНалогиВзносы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоКБКНалогиВзносы(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ЭтоКБКНалогиВзносы(КБК) 
```
</details>

## ЭтоКБКПени
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоКБКПени(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ЭтоКБКПени(КБК) 
```
</details>

## ЭтоКБКПроценты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоКБКПроценты(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ЭтоКБКПроценты(КБК) 
```
</details>

## ЭтоКБКПениПроценты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоКБКПениПроценты(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ЭтоКБКПениПроценты(КБК) 
```
</details>

## ЭтоКБКШтраф
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоКБКШтраф(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ЭтоКБКШтраф(КБК) 
```
</details>

## ЭтоФедеральныйБюджет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоФедеральныйБюджет(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ЭтоФедеральныйБюджет(КБК) 
```
</details>

## ЭтоРегиональныйБюджет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоРегиональныйБюджет(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ЭтоРегиональныйБюджет(КБК) 
```
</details>

## ЭтоЕдиныйНалоговыйПлатеж
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоЕдиныйНалоговыйПлатеж(КБК) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ЭтоЕдиныйНалоговыйПлатеж(КБК) 
```
</details>

## КодЭлементаДоходаФедеральногоБюджета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КодЭлементаДоходаФедеральногоБюджета() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.КодЭлементаДоходаФедеральногоБюджета() 
```
</details>

## КодЭлементаДоходаРегиональногоБюджета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КодЭлементаДоходаРегиональногоБюджета() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.КодЭлементаДоходаРегиональногоБюджета() 
```
</details>

## КодыЭлементаДоходаМестногоБюджета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КодыЭлементаДоходаМестногоБюджета() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.КодыЭлементаДоходаМестногоБюджета() 
```
</details>

## ПрименяетсяОКТМО8Символов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// КЛАССИФИКАТОРЫ ТЕРРИТОРИИ (ОКАТО / ОКТМО)

// Проверяем, только если передан Период.
//
// Параметры:
//	Период - Дата - дата формирования ОКТМО
//
// Возвращаемое значение:
//	Булево - признак применения.
//
Функция ПрименяетсяОКТМО8Символов(Период = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПрименяетсяОКТМО8Символов(Период);
```
</details>

## ПривестиКодТерриторииКФорматуПриказа58н
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Приводит код территории для платежей в бюджет к длине, установленной приказом Минфина 58н.
//
// Параметры:
//	КодТерритории - Строка - код ОКТМО.
//	Период - Дата - дата формирования ОКТМО
//
Процедура ПривестиКодТерриторииКФорматуПриказа58н(КодТерритории, Период = Неопределено) Экспорт
```

Пример вызова
```bsl
ПлатежиВБюджетКлиентСервер.ПривестиКодТерриторииКФорматуПриказа58н(КодТерритории, Период);
```
</details>

## ВидыНалоговыхПериодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
// Налоговый период - реквизит 107
// Период, к которому относится платеж (за который уплачивается).

// Возвращает список вариантов налоговых периодов
//
// Возвращаемое значение:
//  СписокЗначений – в котором создаются элементы с вариантами налоговых периодов.
//
Функция ВидыНалоговыхПериодов() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ВидыНалоговыхПериодов() 
```
</details>

## ПериодичностьГод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПериодичностьГод() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПериодичностьГод() 
```
</details>

## ПериодичностьПолугодие
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПериодичностьПолугодие() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПериодичностьПолугодие() 
```
</details>

## ПериодичностьКвартал
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПериодичностьКвартал() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПериодичностьКвартал() 
```
</details>

## ПериодичностьМесяц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПериодичностьМесяц() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПериодичностьМесяц() 
```
</details>

## ПлатежПоКонкретнойДате
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПлатежПоКонкретнойДате() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПлатежПоКонкретнойДате() 
```
</details>

## НалоговыйПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НалоговыйПериод(Период, Знач Периодичность, Знач Год = Неопределено, Знач НомерПериода = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.НалоговыйПериод(Период, Периодичность, Год, НомерПериода);
```
</details>

## ПредставлениеНалоговогоПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПредставлениеНалоговогоПериода(НалоговыйПериод) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПредставлениеНалоговогоПериода(НалоговыйПериод) 
```
</details>

## ПривестиЭлементыНалоговогоПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПривестиЭлементыНалоговогоПериода(Периодичность, Год, НомерПериода, Дата, ТекущаяДата) Экспорт
```

Пример вызова
```bsl
ПлатежиВБюджетКлиентСервер.ПривестиЭлементыНалоговогоПериода(Периодичность, Год, НомерПериода, Дата, ТекущаяДата) 
```
</details>

## ДатаНачалаНалоговогоПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДатаНачалаНалоговогоПериода(Периодичность, Год, НомерПериода) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДатаНачалаНалоговогоПериода(Периодичность, Год, НомерПериода));
```
</details>

## РазобратьНалоговыйПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РазобратьНалоговыйПериод(Знач НалоговыйПериод) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.РазобратьНалоговыйПериод(НалоговыйПериод) 
```
</details>

## ПреобразоватьДатуКСтроке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПреобразоватьДатуКСтроке(Дата) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПреобразоватьДатуКСтроке(Дата) 
```
</details>

## НезаполненноеЗначение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает Незаполненное значение ("0")
//
// Возвращаемое значение:
//	Строка - "0".
//
Функция НезаполненноеЗначение() Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.НезаполненноеЗначение() 
```
</details>

## ПениПроцентыРаздельно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПениПроцентыРаздельно(КБК, Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ПениПроцентыРаздельно(КБК, Период) 
```
</details>

## ДействуетЭкспериментПоПрименениюЕНПСогласно379ФЗ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет действие эксперимента согласно 379ФЗ.
//
// Параметры:
//	Период - Дата - дата проверки
//
// Возвращаемое значение:
//	Булево - признак действия эксперимента согласно 379ФЗ
//
Функция ДействуетЭкспериментПоПрименениюЕНПСогласно379ФЗ(Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДействуетЭкспериментПоПрименениюЕНПСогласно379ФЗ(Период) 
```
</details>

## ДействуетФедеральныйЗакон263ФЗ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Проверяет действие 263ФЗ.
//
// Параметры:
//	Период - Дата - дата проверки
//
// Возвращаемое значение:
//	Булево - признак действия 263ФЗ
//
Функция ДействуетФедеральныйЗакон263ФЗ(Период) Экспорт
```

Пример вызова
```bsl
Результат = ПлатежиВБюджетКлиентСервер.ДействуетФедеральныйЗакон263ФЗ(Период) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
