---
title: Подарочные сертификаты вызов сервера
slug: erp-uh/подарочные-сертификаты-вызов-сервера
---


## ПолучитьДанныеПодарочногоСертификата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру с данными подарочного сертификата на конец дня текущей даты сеанса, включая границу.
//
// Параметры:
//  ПодарочныйСертификат - СправочникСсылка.ПодарочныеСертификаты - Подарочный сертификат.
//  ВидПодарочногоСертификата - СправочникСсылка.ВидыПодарочныхСертификатов - Вид подарочного сертификата.
//
// Возвращаемое значение:
//  см. ПодарочныеСертификатыВызовСервера.ИнициализироватьОписаниеПодарочногоСертификата
//
Функция ПолучитьДанныеПодарочногоСертификата(ПодарочныйСертификат, ВидПодарочногоСертификата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПодарочныеСертификатыВызовСервера.ПолучитьДанныеПодарочногоСертификата(ПодарочныйСертификат, ВидПодарочногоСертификата);
```
</details>

## ПолучитьДанныеПодарочныхСертификатов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие, где ключом является ссылка на справочник Подарочные сертификаты,
// а значением структура с данными подарочного сертификата.
//
// Параметры:
//  ПодарочныеСертификаты - Массив Из СправочникСсылка.ПодарочныеСертификаты - Подарочные сертификат.
//  ТекущаяДата - Дата, Неопределено - Если передана дата, то остатки и срез последих будут посчитаны на конец дня, включая границу,
//										иначе будет использован конец дня текущей даты сеанса.
//  ТекущийДокумент - ДокументСсылка, Неопределено - Если передана ссылка, то остатки и срез последних будут посчитаны на момент времени исключая границу;
//													При этом, если значение ТекущаяДата не задано, то будет использована ТекущаяДатаСеанса.
//
// Возвращаемое значение:
//  Соответствие из КлючИЗначение:
//  * Ключ - СправочникСсылка.ПодарочныеСертификаты
//  * Значение - см. ПодарочныеСертификатыВызовСервера.ИнициализироватьОписаниеПодарочногоСертификата
//
Функция ПолучитьДанныеПодарочныхСертификатов(ПодарочныеСертификаты, ТекущаяДата = Неопределено, ТекущийДокумент = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПодарочныеСертификатыВызовСервера.ПолучитьДанныеПодарочныхСертификатов(ПодарочныеСертификаты, ТекущаяДата, ТекущийДокумент);
```
</details>

## ПараметрыОбработкиПолученногоКода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возращает структуру параметров, которая используется при обработке кода подарочного сертификата.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * Отборы - Структура - Дополнительные отборы при поиске подарочных сертификатов;
//							может иметь свойства, например: Организация, Статус, Валюта, УчетПодарочныхСертификатов2_5;
//							если свойство РегистрироватьНовые установлено в значение Истина, то в методе ПодарочныеСертификатыВызовСервера.ОбработатьПолученныйКодНаСервере
//							отбор по полю Статус отключается, так как оно не является ключевым для проверки уникальности подарочного сертификата.
//   * РегистрироватьНовые - Булево - Необходимость регистрации подарочных сертификатов, которые не были найдены по коду.
//
Функция ПараметрыОбработкиПолученногоКода() Экспорт
```

Пример вызова
```bsl
Результат = ПодарочныеСертификатыВызовСервера.ПараметрыОбработкиПолученногоКода() 
```
</details>

## ИнициализироватьОписаниеПодарочногоСертификата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает пустую структуру данных подарочного сертификата.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * Ссылка - СправочникСсылка.ПодарочныеСертификаты - Подарочный сертификат.
//   * Штрихкод - Строка - Штрихкод.
//   * МагнитныйКод - Строка - Магнитный код.
//   * СерийныйНомер - Строка - Серийный номер.
//   * ВидПодарочногоСертификата - СправочникСсылка.ВидыПодарочныхСертификатов - Вид подарочного сертификата.
//   * ЧастичнаяОплата - Булево - Если Истина, то сертификат многоразовый
//   * Наименование - Строка - Наименование подарочного сертификата.
//   * ТипКарты - ПеречислениеСсылка.ТипыКарт - Тип карты.
//   * СтатусАктивации - Булево - Статус активации подарочного сертификата.
//   * СтатусИзИсторииПодарочныхСертификатов - ПеречислениеСсылка.СтатусыПодарочныхСертификатов - Статус подарочного сертификата из регистра История подарочных сертификатов.
//   * Аннулирован - Булево - Признак того, что сертификат аннулирован.
//   * ОформленВозврат - Булево - Признак того, что был оформлен возврат сертификата.
//   * Номинал - Число - Номинал подарочного сертификата.
//   * Остаток - Число - Остаток номинала подарочного сертификата.
//   * Валюта - СправочникСсылка.Валюты - Валюта подарочного сертификата.
//   * СегментНоменклатуры - СправочникСсылка.СегментыНоменклатуры - Сегмент номенклатуры подарочного сертификата.
//   * ПериодДействия - ПеречислениеСсылка.Периодичность - Период действия подарочного сертификата.
//   * КоличествоПериодовДействия - Число - Количество периодов действия.
//   * ДатаНачалаДействия - Дата - Дата начала действия.
//   * ДатаОкончанияДействия - Дата - Дата окончания действия.
//   * ОбъектРасчетов - СправочникСсылка.ОбъектыРасчетов - Объект расчетов
//   * Партнер - СправочникСсылка.Партнеры - Партнер из объекта расчетов
//   * СтатьяДвиженияДенежныхСредствПродажа - СправочникСсылка.СтатьиДвиженияДенежныхСредств -
//   * СтатьяДвиженияДенежныхСредствВозврат - СправочникСсылка.СтатьиДвиженияДенежныхСредств -
//   * СтатьяДоходов - ПланВидовХарактеристикСсылка.СтатьиДоходов -
//   * АналитикаДоходов - Характеристика.СтатьиДоходов -
//
Функция ИнициализироватьОписаниеПодарочногоСертификата() Экспорт
```

Пример вызова
```bsl
Результат = ПодарочныеСертификатыВызовСервера.ИнициализироватьОписаниеПодарочногоСертификата() 
```
</details>

## ЗарегистрироватьПодарочныйСертификатУпрощенно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура записывает в базу данных подарочный сертификат на основании
// передаваемых данных о коде и виде сертификата.
//
// Параметры:
//  ВидПодарочногоСертификата - СправочникСсылка.ВидыПодарочныхСертификатов - Вид подарочного сертификата.
//  ТипКода - ПеречислениеСсылка.ТипыКодовКарт - Тип кода карты.
//  МагнитныйКод - Строка - Магнитный код.
//  Штрихкод - Строка - Штрихкод.
//
// Возвращаемое значение:
//  СправочникСсылка.ПодарочныеСертификаты - Зарегистрированный подарочный сертификат.
//
Функция ЗарегистрироватьПодарочныйСертификатУпрощенно(ВидПодарочногоСертификата, ТипКода, МагнитныйКод, Штрихкод) Экспорт
```

Пример вызова
```bsl
Результат = ПодарочныеСертификатыВызовСервера.ЗарегистрироватьПодарочныйСертификатУпрощенно(ВидПодарочногоСертификата, ТипКода, МагнитныйКод, Штрихкод) 
```
</details>

## АдресТабличнойЧастиТоварыДляАнализаВозможностиОплатыПодарочнымиСертификатами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Возвращает адрес во временном хранилище с данными табличной части документа для анализа возможности оплаты подарочными сертификатами.
//
// Параметры:
//  Ссылка - ДокументСсылка, СправочникСсылка -
//  УникальныйИдентификатор - УникальныйИдентификатор - Уникальный идентификатор для привязки во временном хранилище.
//
// Возвращаемое значение:
//  Строка, Неопределено - Адрес во временном хранилище
//
Функция АдресТабличнойЧастиТоварыДляАнализаВозможностиОплатыПодарочнымиСертификатами(Знач Ссылка, Знач УникальныйИдентификатор) Экспорт
```

Пример вызова
```bsl
Результат = ПодарочныеСертификатыВызовСервера.АдресТабличнойЧастиТоварыДляАнализаВозможностиОплатыПодарочнымиСертификатами(Ссылка, УникальныйИдентификатор) 
```
</details>

## ЗарегистрироватьПодарочныйСертификат
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура записывает в базу данных подарочный сертификат на основании
// передаваемых данных о сертификате.
//
// Параметры:
//  СтруктураДанныхПодарочногоСертификата - см. ПодарочныеСертификатыВызовСервера.ИнициализироватьОписаниеПодарочногоСертификата
//
// Возвращаемое значение:
//  СправочникСсылка.ПодарочныеСертификаты - Зарегистрированный подарочный сертифика.
//
Функция ЗарегистрироватьПодарочныйСертификат(СтруктураДанныхПодарочногоСертификата) Экспорт
```

Пример вызова
```bsl
Результат = ПодарочныеСертификатыВызовСервера.ЗарегистрироватьПодарочныйСертификат(СтруктураДанныхПодарочногоСертификата) 
```
</details>

## ОбработатьПолученныйКодНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция выполняет поиск подарочных сертификатов по коду.
//
// Параметры:
//  Данные - Строка - считанный код.
//  ТипКодаКарты - ПеречислениеСсылка.ТипыКодовКарт - тип считанного кода.
//	ДополнительныеПараметры - см. ПодарочныеСертификатыВызовСервера.ПараметрыОбработкиПолученногоКода
//
// Возвращаемое значение:
//  Массив Из СправочникСсылка.ПодарочныеСертификаты - Найденные подарочные сертификаты.
//
Функция ОбработатьПолученныйКодНаСервере(Данные, ТипКодаКарты, ДополнительныеПараметры) Экспорт
```

Пример вызова
```bsl
Результат = ПодарочныеСертификатыВызовСервера.ОбработатьПолученныйКодНаСервере(Данные, ТипКодаКарты, ДополнительныеПараметры) 
```
</details>

## НайтиПодарочныеСертификатыПоДаннымСоСчитывателяМагнитныхКарт
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция выполняет поиск подарочных сертификатов по данным, полученным из считывателя
// магнитных карт.
//
// Параметры:
//  Данные - Массив из Строка - Данные, полученные из считывателя магнитных карт.
//  Отборы - Структура -
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * ЗарегистрированныеПодарочныеСертификаты - Массив из см. ИнициализироватьОписаниеПодарочногоСертификата
//   * НеЗарегистрированныеПодарочныеСертификаты - Массив из см. ИнициализироватьОписаниеПодарочногоСертификата
//
Функция НайтиПодарочныеСертификатыПоДаннымСоСчитывателяМагнитныхКарт(Данные, Отборы = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПодарочныеСертификатыВызовСервера.НайтиПодарочныеСертификатыПоДаннымСоСчитывателяМагнитныхКарт(Данные, Отборы);
```
</details>

## НайтиПодарочныеСертификатыПоШтрихкоду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция выполняет поиск подарочных сертификатов по штрихкоду.
//
// Параметры:
//  Штрихкод - Строка - Штрихкод.
//	Отборы - Структура -
//
// Возвращаемое значение:
//  см. ПодарочныеСертификатыСервер.НайтиПодарочныеСертификаты
//
Функция НайтиПодарочныеСертификатыПоШтрихкоду(Штрихкод, Отборы = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПодарочныеСертификатыВызовСервера.НайтиПодарочныеСертификатыПоШтрихкоду(Штрихкод, Отборы);
```
</details>

## НайтиПодарочныеСертификатыПоМагнитномуКоду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция выполняет поиск подарочных сертификатов по магнитному коду.
//
// Параметры:
//  МагнитныйКод - Строка - Магнитный код.
//	Отборы - Структура -
//
// Возвращаемое значение:
// 	см. ПодарочныеСертификатыСервер.НайтиПодарочныеСертификаты
//
Функция НайтиПодарочныеСертификатыПоМагнитномуКоду(МагнитныйКод, Отборы = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПодарочныеСертификатыВызовСервера.НайтиПодарочныеСертификатыПоМагнитномуКоду(МагнитныйКод, Отборы);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
