---
title: Подключаемое оборудование OFFLINE вызов сервера
slug: erp-uh/подключаемое-оборудование-offline-вызов-сервера
---


## ПриОчисткеТоваровВУстройстве
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура вызывается при очистке товаров в устройстве.
// Выполняет запись информации в узел плана обмена.
//
// Параметры:
//  Устройство       - СправочникСсылка.ПодключаемоеОборудование - Ссылка на устройство.
//  ВыполненоУспешно - Булево - Признак успешного выполнения операции.
//
Процедура ПриОчисткеТоваровВУстройстве(Устройство, ВыполненоУспешно = Истина) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервера.ПриОчисткеТоваровВУстройстве(Устройство, ВыполненоУспешно);
```
</details>

## ПриВыгрузкеТоваровВУстройство
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура вызывается при выгрузке товаров в устройство.
// Выполняет запись информации в узел плана обмена.
//
// Параметры:
//  Устройство       - СправочникСсылка.ПодключаемоеОборудование - Ссылка на устройство.
//  СтруктураДанные - Структура -
//  ВыполненоУспешно - Булево - Признак успешного выполнения операции.
//  РасширеннаяВыгрузка - Булево -
//
Процедура ПриВыгрузкеТоваровВУстройство(Устройство, СтруктураДанные, ВыполненоУспешно = Истина, РасширеннаяВыгрузка = Ложь) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервера.ПриВыгрузкеТоваровВУстройство(Устройство, СтруктураДанные, ВыполненоУспешно, РасширеннаяВыгрузка);
```
</details>

## ПолучитьДанныеДляВесов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает структуру с данными в формате, необходимом для выгрузки списка товаров в весы с печатью этикеток.
//
// Параметры:
//  Устройство - СправочникСсылка.ПодключаемоеОборудование - Устройство для которого необходимо получить данные.
//  ТолькоИзмененные - Булево - Флаг получения только измененных данных.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//  * Данные - Массив - Выгружаемые данные.
//  * КоличествоНеВыгруженныхСтрокСОшибками - Число - Количество строк с ошибками.
//  * ЧастичнаяВыгрузка - Булево - Признак частичной выгрузки.
//  * Параметры - Структура - см. функцию ПолучитьПараметрыУстройства.
//
Функция ПолучитьДанныеДляВесов(Устройство, ТолькоИзмененные = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ПодключаемоеОборудованиеOfflineВызовСервера.ПолучитьДанныеДляВесов(Устройство, ТолькоИзмененные);
```
</details>

## ПолучитьПараметрыУстройства
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция получает параметры устройства
//
// Параметры:
//  Устройство - СправочникСсылка.ПодключаемоеОборудование - Ссылка на устройство.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//  * ПравилоОбмена - СправочникСсылка.ПравилаОбменаСПодключаемымОборудованиемOffline - Правило обмена.
//  * УзелИнформационнойБазы - ПланОбменаСсылка - узел информационной базы.
//  * Склад - СправочникСсылка.Склады - Склад.
//  * ВидЦены - СправочникСсылка.ВидыЦен - Вид цены.
//  * ТипОборудования - ПеречислениеСсылка.ТипыПодключаемогоОборудования - тип оборудования.
//  * МаксимальныйКод - Число - Максимальный код.
//  * ВыгружатьИзменения - Булево - Признак необходимости выгрузки изменений.
//
Функция ПолучитьПараметрыУстройства(Устройство) Экспорт
```

Пример вызова
```bsl
Результат = ПодключаемоеОборудованиеOfflineВызовСервера.ПолучитьПараметрыУстройства(Устройство) 
```
</details>

## ЗарегистрироватьИзменения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция регистрирует изменения для устройства.
//
// Параметры:
//  Устройство - СправочникСсылка.ПодключаемоеОборудование - Ссылка на устройство.
//
Процедура ЗарегистрироватьИзменения(Устройство) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервера.ЗарегистрироватьИзменения(Устройство) 
```
</details>

## ЗаполнитьСтруктуруПрайсЛистаИзДанныхКВыгрузке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет структуру прайс-листа для выгрузке на ККМ Offline в расширенном формате (с группами товаров)
//
Процедура ЗаполнитьСтруктуруПрайсЛистаИзДанныхКВыгрузке(СтруктураПрайсЛиста, ТоварыКВыгрузке) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервера.ЗаполнитьСтруктуруПрайсЛистаИзДанныхКВыгрузке(СтруктураПрайсЛиста, ТоварыКВыгрузке) 
```
</details>

## МаксимальныйКодВесовогоТовара
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Максимальный код весового товара.
//
// Возвращаемое значение:
//  Число - Максимальный код весового товара.
//
Функция МаксимальныйКодВесовогоТовара() Экспорт
```

Пример вызова
```bsl
Результат = ПодключаемоеОборудованиеOfflineВызовСервера.МаксимальныйКодВесовогоТовара() 
```
</details>

## ПолучитьМаксимальныйКод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает максимальный код товара в регистре КодыТоваровПодключаемогоОборудованияOffline
// для заданного правила обмена.
//
// Параметры:
//  ПравилоОбмена - СправочникСсылка.ПравилаОбменаСПодключаемымОборудованиемOffline - Правило обмена.
//
// Возвращаемое значение:
//  Число - Максимальный код товара для заданного правила обмена.
//
Функция ПолучитьМаксимальныйКод(ПравилоОбмена) Экспорт
```

Пример вызова
```bsl
Результат = ПодключаемоеОборудованиеOfflineВызовСервера.ПолучитьМаксимальныйКод(ПравилоОбмена) 
```
</details>

## ПолучитьСвободныеКоды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает таблицу свободных кодов товара в регистре КодыТоваровПодключаемогоОборудованияOffline
// для заданного правила обмена. Свободными являются коды, для которых не задана соответствующая номенклатура.
//
// Параметры:
//  ПравилоОбмена - СправочникСсылка.ПравилаОбменаСПодключаемымОборудованиемOffline - Правило обмена.
//  Количество - Число - Необходимое количество свободных кодов.
//
// Возвращаемое значение:
//  ТаблицаЗначений - Таблица свободных кодов товаров с колонками:
//  * Код - Число - свободный код.
//
Функция ПолучитьСвободныеКоды(ПравилоОбмена, Количество = 0) Экспорт
```

Пример вызова
```bsl
Результат = ПодключаемоеОборудованиеOfflineВызовСервера.ПолучитьСвободныеКоды(ПравилоОбмена, Количество);
```
</details>

## ЗаписатьКод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура записывает в регистр КодыТоваровПодключаемогоОборудованияOffline
// код для заданного правила обмена и соответствующие ему параметры номенклатуры.
//
// Параметры:
//  Данные        - Структура - Структура, содержащая поля:
//   * Номенклатура - СправочникСсылка.Номенклатура - Номенклатура.
//   * Характеристика - СправочникСсылка.ХарактеристикиНоменклатуры - характеристика.
//   * Упаковка - СправочникСсылка.УпаковкиЕдиницыИзмерения - Упаковка.
//  ПравилоОбмена - СправочникСсылка.ПравилаОбменаСПодключаемымОборудованиемOffline
//  Код           - Число - Код товара в разрезе правила обмена.
//  Используется  - Число - Признак того, что товар соответствует заданному в правиле обмена отбору.
//
Процедура ЗаписатьКод(Данные, ПравилоОбмена, Код, Используется) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервера.ЗаписатьКод(Данные, ПравилоОбмена, Код, Используется) 
```
</details>

## УдалитьКод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура очищает параметры номенклатуры для записи, соответствующей коду в пределах правила обмена
// в регистре КодыТоваровПодключаемогоОборудованияOffline.
// Такая запись становится свободной.
//
// Параметры:
//  ПравилоОбмена - СправочникСсылка.ПравилаОбменаСПодключаемымОборудованиемOffline - Правило обмена.
//  Код           - Число - Код товара в разрезе правила обмена.
//
Процедура УдалитьКод(ПравилоОбмена, Код) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервера.УдалитьКод(ПравилоОбмена, Код) 
```
</details>

## ОбновитьКодыТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура обновляет записи в регистре КодыТоваровПодключаемогоОборудованияOffline
// в соответствии с правилом обмена. Записи, не соответствующие отбору правила становятся
// неиспользуемыми. Добавляются новые записи, соответствующие отбору, если такие будут найдены.
//
// Параметры:
//  ПравилоОбмена - СправочникСсылка.ПравилаОбменаСПодключаемымОборудованиемOffline - Правило обмена.
//
Процедура ОбновитьКодыТоваров(ПравилоОбмена) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервера.ОбновитьКодыТоваров(ПравилоОбмена) 
```
</details>

## РегламентноеЗаданиеОбновитьКодыТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура выполняет обновление кодов товаров для всех правил обмена.
//
Процедура РегламентноеЗаданиеОбновитьКодыТоваров() Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервера.РегламентноеЗаданиеОбновитьКодыТоваров() 
```
</details>

## ДанныеТоваровДляВыгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает таблицу товаров с данными к выгрузке в устройство.
//
// Параметры:
//  Устройство - СправочникСсылка.ПодключаемоеОборудование - Устройство для которого необходимо получить данные
//  Параметры - Структура -
//  ОбновитьКодыТоваров - Булево - Флаг обновления кодов товаров перед получением данных.
//  Штрихкод - Строка
//
// Возвращаемое значение:
//  ТаблицаЗначений - Таблица товаров к выгрузке.
//
Функция ДанныеТоваровДляВыгрузки(Устройство, Параметры, ОбновитьКодыТоваров = Ложь, Штрихкод = "") Экспорт
```

Пример вызова
```bsl
Результат = ПодключаемоеОборудованиеOfflineВызовСервера.ДанныеТоваровДляВыгрузки(Устройство, Параметры, ОбновитьКодыТоваров, Штрихкод);
```
</details>

## ДанныеТоваровПоПравилуОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает таблицу товаров с данными о товарам для правила выгрузки с ценами
//
// Параметры:
//  ПравилоОбмена - СправочникСсылка.ПравилаОбменаСПодключаемымОборудованиемOffline - Правило обмена.
//  ВидЦены - СправочникСсылка.ВидыЦен - Вид цены.
//  ИндивидуальныйВидЦены - СправочникСсылка.ВидыЦен - Индивидуальный вид цены.
//
// Возвращаемое значение:
//  ТаблицаЗначений - Таблица товаров
//
Функция ДанныеТоваровПоПравилуОбмена(ПравилоОбмена, ВидЦены, ИндивидуальныйВидЦены) Экспорт
```

Пример вызова
```bsl
Результат = ПодключаемоеОборудованиеOfflineВызовСервера.ДанныеТоваровПоПравилуОбмена(ПравилоОбмена, ВидЦены, ИндивидуальныйВидЦены) 
```
</details>

## ЗаполнитьНастройкиККМ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// заполнение переопределяемых процедур модуля МенеджерОфлайнОборудованияПереопределяемый

Процедура ЗаполнитьНастройкиККМ(ОфлайнОборудование, НастройкиОборудования) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервера.ЗаполнитьНастройкиККМ(ОфлайнОборудование, НастройкиОборудования) 
```
</details>

## ЗаполнитьПрайсЛистККМ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьПрайсЛистККМ(ОфлайнОборудование, ПрайсЛист, ПолнаяВыгрузка) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервера.ЗаполнитьПрайсЛистККМ(ОфлайнОборудование, ПрайсЛист, ПолнаяВыгрузка) 
```
</details>

## ЗаполнитьПрайсЛистККМПоШтрихкоду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьПрайсЛистККМПоШтрихкоду(ОфлайнОборудование, ПрайсЛист, Штрихкод) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервера.ЗаполнитьПрайсЛистККМПоШтрихкоду(ОфлайнОборудование, ПрайсЛист, Штрихкод) 
```
</details>

## УдалитьРегистрациюПрайсЛистаПослеВыгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УдалитьРегистрациюПрайсЛистаПослеВыгрузки(ОфлайнОборудование) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервера.УдалитьРегистрациюПрайсЛистаПослеВыгрузки(ОфлайнОборудование) 
```
</details>

## ЗагрузитьОтчетыОПродажахИзККМ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗагрузитьОтчетыОПродажахИзККМ(Устройство, ДанныеОПродажах, Отказ, СообщениеОбОшибке) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервера.ЗагрузитьОтчетыОПродажахИзККМ(Устройство, ДанныеОПродажах, Отказ, СообщениеОбОшибке) 
```
</details>

## ЗагрузитьДанныеОВскрытияхТарыИзККМ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗагрузитьДанныеОВскрытияхТарыИзККМ(Устройство, ДанныеОВскрытияхТары, Отказ, СообщениеОбОшибке) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервера.ЗагрузитьДанныеОВскрытияхТарыИзККМ(Устройство, ДанныеОВскрытияхТары, Отказ, СообщениеОбОшибке) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
