---
title: Подключаемое оборудование OFFLINE вызов сервера локализация
slug: erp-uh/подключаемое-оборудование-offline-вызов-сервера-локализация
---


## ПриОчисткеТоваровВУстройстве
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура вызывается при очистке товаров в устройстве.
// Выполняет запись информации в узел плана обмена.
//
// Параметры:
//  Устройство       - СправочникСсылка.ПодключаемоеОборудование - Ссылка на устройство.
//  ВыполненоУспешно - Булево - Признак успешного выполнения операции.
//
Процедура ПриОчисткеТоваровВУстройстве(Устройство, ВыполненоУспешно = Истина) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервераЛокализация.ПриОчисткеТоваровВУстройстве(Устройство, ВыполненоУспешно);
```
</details>

## ПриВыгрузкеТоваровВУстройство
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура вызывается при выгрузке товаров в устройство.
// Выполняет запись информации в узел плана обмена.
//
// Параметры:
//  Устройство       - СправочникСсылка.ПодключаемоеОборудование - Ссылка на устройство.
//  СтруктураДанные - Структура
//  ВыполненоУспешно - Булево - Признак успешного выполнения операции.
//  РасширеннаяВыгрузка - Булево - Признак использования расширенной выгрузки.
//
Процедура ПриВыгрузкеТоваровВУстройство(Устройство, СтруктураДанные, ВыполненоУспешно = Истина, РасширеннаяВыгрузка = Ложь) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервераЛокализация.ПриВыгрузкеТоваровВУстройство(Устройство, СтруктураДанные, ВыполненоУспешно, РасширеннаяВыгрузка);
```
</details>

## ПолучитьДанныеДляВесов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура возвращает структуру с данными в формате, необходимом для выгрузки списка товаров в весы с печатью этикеток.
//
// Параметры:
//  ПараметрыУстройства - Структура - перезаполняемое значение, см. функцию ПолучитьПараметрыУстройства.
//  Устройство - СправочникСсылка.ПодключаемоеОборудование - Устройство для которого необходимо получить данные.
//  ТолькоИзмененные - Булево - Флаг получения только измененных данных.
//
Процедура ПолучитьДанныеДляВесов(ПараметрыУстройства, Устройство, ТолькоИзмененные = Истина) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервераЛокализация.ПолучитьДанныеДляВесов(ПараметрыУстройства, Устройство, ТолькоИзмененные);
```
</details>

## ПолучитьПараметрыУстройства
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура возвращает параметры устройства
//
// Параметры:
//  ПараметрыУстройства - Структура:
//  * ПравилоОбмена - СправочникСсылка.ПравилаОбменаСПодключаемымОборудованиемOffline - Правило обмена.
//  * УзелИнформационнойБазы - ПланОбменаСсылка - узел информационной базы.
//  * Склад - СправочникСсылка.Склады - Склад.
//  * ВидЦены - СправочникСсылка.ВидыЦен - Вид цены.
//  * ИндивидуальныйВидЦены - СправочникСсылка.ВидыЦен - Индивидулаьный вид цены.
//  * ТипОборудования - ПеречислениеСсылка.ТипыПодключаемогоОборудования, ПеречислениеСсылка.ТипыОфлайнОборудования - тип оборудования.
//  * МаксимальныйКод - Число - Максимальный код.
//  * ВыгружатьИзменения - Булево - Признак необходимости выгрузки изменений.
//  Устройство - СправочникСсылка.ПодключаемоеОборудование - Ссылка на устройство.
//
Процедура ПолучитьПараметрыУстройства(ПараметрыУстройства, Устройство) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервераЛокализация.ПолучитьПараметрыУстройства(ПараметрыУстройства, Устройство) 
```
</details>

## ЗарегистрироватьИзменения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура регистрирует изменения для устройства.
//
// Параметры:
//  Устройство - СправочникСсылка.ПодключаемоеОборудование, СправочникСсылка.ОфлайнОборудование - Ссылка на устройство.
//
Процедура ЗарегистрироватьИзменения(Устройство) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервераЛокализация.ЗарегистрироватьИзменения(Устройство) 
```
</details>

## ЗаполнитьСтруктуруПрайсЛистаИзДанныхКВыгрузке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет структуру прайс-листа для выгрузке на ККМ Offline в расширенном формате (с группами товаров)
//
Процедура ЗаполнитьСтруктуруПрайсЛистаИзДанныхКВыгрузке(СтруктураПрайсЛиста, ТоварыКВыгрузке) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервераЛокализация.ЗаполнитьСтруктуруПрайсЛистаИзДанныхКВыгрузке(СтруктураПрайсЛиста, ТоварыКВыгрузке) 
```
</details>

## ДанныеТоваровДляВыгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура обновляет таблицу товаров с данными к выгрузке в устройство.
//
// Параметры:
//  ТаблицаТоваров - ТаблицаЗначений - Таблица товаров к выгрузке.
//  Устройство - СправочникСсылка.ПодключаемоеОборудование - Устройство для которого необходимо получить данные
//  Параметры - Структура - ПАраметры выгрузки.
//  ОбновитьКодыТоваров - Булево - Флаг обновления кодов товаров перед получением данных.
//  Штрихкод - Строка -.
//
Процедура ДанныеТоваровДляВыгрузки(ТаблицаТоваров, Устройство, Параметры, ОбновитьКодыТоваров = Ложь, Штрихкод = "") Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервераЛокализация.ДанныеТоваровДляВыгрузки(ТаблицаТоваров, Устройство, Параметры, ОбновитьКодыТоваров, Штрихкод);
```
</details>

## ДанныеТоваровПоПравилуОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура обновляет таблицу товаров с данными о товарам для правила выгрузки с ценами
//
// Параметры:
//  ТаблицаТоваров - ТаблицаЗначений - Таблица товаров
//  ПравилоОбмена - СправочникСсылка.ПравилаОбменаСПодключаемымОборудованиемOffline - Правило обмена.
//  ВидЦены - СправочникСсылка.ВидыЦен - Вид цены.
//  ИндивидуальныйВидЦены - СправочникСсылка.ВидыЦен - индивидуальный вид цены.
//
Процедура ДанныеТоваровПоПравилуОбмена(ТаблицаТоваров, ПравилоОбмена, ВидЦены, ИндивидуальныйВидЦены) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервераЛокализация.ДанныеТоваровПоПравилуОбмена(ТаблицаТоваров, ПравилоОбмена, ВидЦены, ИндивидуальныйВидЦены) 
```
</details>

## ЗаполнитьНастройкиККМ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// заполнение переопределяемых процедур модуля МенеджерОфлайнОборудованияПереопределяемый

Процедура ЗаполнитьНастройкиККМ(ОфлайнОборудование, НастройкиОборудования) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервераЛокализация.ЗаполнитьНастройкиККМ(ОфлайнОборудование, НастройкиОборудования) 
```
</details>

## ЗаполнитьПрайсЛистККМ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьПрайсЛистККМ(ОфлайнОборудование, ПрайсЛист, ПолнаяВыгрузка) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервераЛокализация.ЗаполнитьПрайсЛистККМ(ОфлайнОборудование, ПрайсЛист, ПолнаяВыгрузка) 
```
</details>

## ЗаполнитьПрайсЛистККМПоШтрихкоду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьПрайсЛистККМПоШтрихкоду(ОфлайнОборудование, ПрайсЛист, Штрихкод) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервераЛокализация.ЗаполнитьПрайсЛистККМПоШтрихкоду(ОфлайнОборудование, ПрайсЛист, Штрихкод) 
```
</details>

## УдалитьРегистрациюПрайсЛистаПослеВыгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УдалитьРегистрациюПрайсЛистаПослеВыгрузки(ОфлайнОборудование) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервераЛокализация.УдалитьРегистрациюПрайсЛистаПослеВыгрузки(ОфлайнОборудование) 
```
</details>

## ЗагрузитьОтчетыОПродажахИзККМ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗагрузитьОтчетыОПродажахИзККМ(Устройство, ДанныеОПродажах, Отказ, СообщениеОбОшибке) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервераЛокализация.ЗагрузитьОтчетыОПродажахИзККМ(Устройство, ДанныеОПродажах, Отказ, СообщениеОбОшибке) 
```
</details>

## ЗагрузитьДанныеОВскрытияхТарыИзККМ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗагрузитьДанныеОВскрытияхТарыИзККМ(Устройство, ДанныеОВскрытияхТары, Отказ, СообщениеОбОшибке) Экспорт
```

Пример вызова
```bsl
ПодключаемоеОборудованиеOfflineВызовСервераЛокализация.ЗагрузитьДанныеОВскрытияхТарыИзККМ(Устройство, ДанныеОВскрытияхТары, Отказ, СообщениеОбОшибке) 
```
</details>

## ЭтоТипОфлайнОборудованияККМ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет что переданное значение это тип офлайн оборудования ККМ.
//
// Параметры:
//  ТипПодключаемогоОборудования - ПеречислениеСсылка
//
// Возвращаемое значение:
//  Булево
//
Функция ЭтоТипОфлайнОборудованияККМ(ТипПодключаемогоОборудования) Экспорт
```

Пример вызова
```bsl
Результат = ПодключаемоеОборудованиеOfflineВызовСервераЛокализация.ЭтоТипОфлайнОборудованияККМ(ТипПодключаемогоОборудования) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
