---
title: Подключение сервисов сопровождения
slug: erp-uh/подключение-сервисов-сопровождения
---


## НовыйОписательСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает описатель сервиса сопровождения, который используется
// при подключении тестового периода.
//
// Возвращаемое значение:
//   Структура - содержит перечень значений, необходимых для  подключения тестового периода:
//     *Идентификатор - Строка - идентификатор сервиса в системе Портал 1С:ИТС. Поле обязательно для заполнения.
//                      Если передана пустая строка, при переходе на новую версию будет вызвано исключение.
//                      Длина не более 255 символов;
//     *Картинка      - Метаданные.ОбщиеКартинки, Неопределено - картинка сервиса. Если значение не будет
//                      передано, видимость элемента формы отключается. Рекомендуемый размер картинки 48х48 пикселей;
//     *Наименование  - Строка - наименование сервиса. Поле обязательно для заполнения,
//                      если передана пустая строка, при переходе на новую версию будет вызвано исключение.
//                      Длина не более 150 символов;
//     *Описание      - Строка - краткое описание сервиса. Поле обязательно для заполнения,
//                      если передана пустая строка, при переходе на новую версию будет вызвано исключение.
//                      Длина не более 150 символов.
//
Функция НовыйОписательСервиса() Экспорт
```

Пример вызова
```bsl
Результат = ПодключениеСервисовСопровождения.НовыйОписательСервиса() 
```
</details>

## ДоступноПодключениеТестовогоПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку возможности подключения тестового периода для пользователя.
// Перед запросом доступных тестовых периодов происходит проверка кэша. Если данные
// о доступных тестовых периодах были получены в течение 24 часов, используется информация
// из кэша. В противном случае производится запрос на получение обновленной информации
// из сервисов Портала 1С:ИТС. Функцию необходимо использовать для определения
// потребности в отображении элемента управления подключения тестового периода.
// Функцию следует использовать, если целевой сервис не подключен.
//
// Параметры:
//  Идентификаторы - Массив из Строка - содержит идентификаторы сервисов в системе Портал 1С:ИТС.
//
// Возвращаемое значение:
//  Структура - содержит информацию о доступных тестовых периодах сервисов сопровождения:
//    *Ошибка - Булево - Истина, если при обновлении кэша были ошибки;
//              Ошибка может возникнуть в случае:
//               - на текущий момент существуют запросы на подключение тестового периода;
//               - ошибка при получении данных из сервиса;
//               - передан некорректный идентификатор сервиса;
//    *СообщениеОбОшибке - Строка - информация об ошибке для пользователя;
//    *СервисыСопровождения - Соответствие - информация о доступности подключения сервисов:
//      **Ключ - Строка - идентификатор сервиса;
//      **Значение - Строка - содержит результат проверки возможности подключения. Возможны значения:
//                    - "Подключение" если в текущий момент обрабатываются запросы
//                      на подключение тестового периода.
//                    - "Доступно" если подключение тестового периода доступно;
//                    - "Недоступно" если подключение тестового периода недоступно;
//                      Подключение может быть недоступно:
//                       - пользователь уже использовал тестовый период;
//                       - у сервиса отсутствуют тестовые периоды;
//                       - у пользователя нет прав для подключения тестового периода.
//
// Пример:
//
//  ИдентификаторСервиса = СПАРКРискиКлиентСервер.ИдентификаторСервиса();
//  Идентификаторы       = Новый Массив;
//  Идентификаторы.Добавить(ИдентификаторСервиса);
//  РезультатПроверки = ПодключениеСервисовСопровождения.ДоступноПодключениеТестовогоПериода(Идентификаторы);
//  СтатусПодключения = РезультатПроверки.СервисыСопровождения.Получить(ИдентификаторСервиса);
//  Если СтатусПодключения = "Подключение" Тогда
//    Элементы.ДекорацияПодключить.Видимость  = Ложь;
//    Элементы.ДекорацияПодключение.Видимость = Истина;
//  ИначеЕсли СтатусПодключения = "Доступно" Тогда
//    Элементы.ДекорацияПодключить.Видимость  = Истина;
//    Элементы.ДекорацияПодключение.Видимость = Ложь;
//  ИначеЕсли СтатусПодключения = "Недоступно" Тогда
//    Элементы.ДекорацияПодключить.Видимость  = Ложь;
//    Элементы.ДекорацияПодключение.Видимость = Ложь;
//  КонецЕсли;
//
Функция ДоступноПодключениеТестовогоПериода(Идентификаторы) Экспорт
```

Пример вызова
```bsl
Результат = ПодключениеСервисовСопровождения.ДоступноПодключениеТестовогоПериода(Идентификаторы) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
