---
title: Получение регламентированных отчетов
slug: erp-uh/получение-регламентированных-отчетов
---


## ОбновитьРегламентированныеОтчеты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет загрузку, обновление регламентированных отчетов и обработку данных.
//
// Возвращаемое значение:
//  Структура - содержит результат обновления регламентированного отчета:
//    * КодОшибки - Строка - строковый код возникшей ошибки, который
//                  может быть обработан вызывающим функционалом:
//          <Пустая строка> - обновление выполнено успешно;
//          "ОбновлениеНеТребуется" - обновление не обнаружено;
//          "НеверныйЛогинИлиПароль" - неверный логин или пароль;
//          "ОшибкаПодключения" - ошибка при подключении к сервису;
//          "ОшибкаСервиса" - внутренняя ошибка сервиса;
//          "НеизвестнаяОшибка" - при получении информации возникла
//          неизвестная (необрабатываемая) ошибка;
//          "НеОбработан" - файл регламентированного отчета успешно загружен, но не обработан.
//          Ошибка может возникнуть, если отсутствуют алгоритмы обработки файла
//          см. процедуру ПриЗагрузкеРегламентированногоОтчета;
//          "СервисВременноНедоступен" - на сервер ведутся регламентные работы;
//          "НеизвестныйРегламентированныйОтчетИлиПрограмма" - регламентированный отчет или программа
//          в сервисе не обнаружены по переданному идентификатору;
//          "ФайлНеЗагружен" - при загрузке файлов регламентированного отчета возникли ошибки;
//          "НетДоступаКПрограмме" - отсутствует доступ к программе на Портале 1С:ИТС;
//    * СообщениеОбОшибке  - Строка, ФорматированнаяСтрока - сообщение об ошибке для пользователя;
//    * ИнформацияОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке для администратора.
//
Функция ОбновитьРегламентированныеОтчеты() Экспорт
```

Пример вызова
```bsl
Результат = ПолучениеРегламентированныхОтчетов.ОбновитьРегламентированныеОтчеты() 
```
</details>

## ОписаниеВерсииРегламентированногоОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает описание версии регламентированного отчета, которая используется в программе.
//
// Возвращаемое значение:
//  Структура - содержит перечень значений необходимых для обновления версии регламентированного отчета:
//    *Наименование            - Строка - пользовательское представление регламентированного отчета.
//                               Длина не более 150 символов;
//    *Идентификатор           - Строка - идентификатор регламентированного отчета в сервисе.
//                               Поле обязательно для заполнения.
//                               Если передана пустая строка, тогда будет вызвано исключение.
//                               Длина не более 50 символов;
//    *Версия                  - Число - номер актуальной версии регламентированного отчета.
//                               Если передан 0, тогда будет вызвано исключение.
//                               Длина не более 11 символов;
//    *ИдентификаторВидаОтчета - Строка - идентификатор вида регламентированного отчета в сервисе.
//                               Поле обязательно для заполнения.
//                               Если передана пустая строка, тогда будет вызвано исключение.
//                               Длина не более 50 символов;
//
Функция ОписаниеВерсииРегламентированногоОтчета() Экспорт
```

Пример вызова
```bsl
Результат = ПолучениеРегламентированныхОтчетов.ОписаниеВерсииРегламентированногоОтчета() 
```
</details>

## УстановитьВерсиюРегламентированногоОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет информацию о новой версии регламентированного отчета или изменяет номер загруженной версии.
// Процедуру следует использовать, если выполняется обновление данных не из сервиса регламентированных отчетов.
//
// Параметры:
//  ОписаниеВерсии - Структура - описание версии регламентированного отчета.
//                               См. ОписаниеВерсииРегламентированногоОтчета.
//
Процедура УстановитьВерсиюРегламентированногоОтчета(ОписаниеВерсии) Экспорт
```

Пример вызова
```bsl
ПолучениеРегламентированныхОтчетов.УстановитьВерсиюРегламентированногоОтчета(ОписаниеВерсии) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
