---
title: Правила проверки УХ
slug: erp-uh/правила-проверки-ух
---


## Проверить
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
// Проверяет текущие значения показателей по указанному правилу проверки.
// ОбъектРасчета: структура, содержащая:
//	- ключевые реквизиты
//  - правило проверки
//	- мПоказатели: таблица текущих синтетических значений показателей с колонками:
//		- Ссылка (ссылка на показатель)
//		- ПериодОтчета (в случае проверки по нескольким периодам)
//		- Наименование - (наименование показателя)
//		- Значение (текущее значение показателя)
//	- мПоказателиРаскрытия: таблица текущих аналитических раскрытий с колонками:
//		- Показатель (ссылка на показатель)
//		- ПериодОтчета (в случае проверки по нескольким периодам)
//		- Аналитика1
//		- Аналитика2
//		- Аналитика3
//		- Аналитика4
//		- Аналитика5
//		- Аналитика6
//		- АналитикаВалюта
//		- Значение (текущее значение строки аналитического раскрытия)
//
// Возвращаемое значение: структура, содаржащая:
// 	- Протокол: табличный документ с результатом проверки
//	- СтатусПроверки: истина, если проверка пройдена, или ложь
//
Функция Проверить(ОбъектРасчета,ПротоколироватьОшибки=Ложь,РежимВывода="",СтруктураВозврата=Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПравилаПроверкиУХ.Проверить(ОбъектРасчета, ПротоколироватьОшибки, РежимВывода, СтруктураВозврата);
```
</details>

## ПроверитьКонтролируемыеПоказатели
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура отрабатывает при расчете контрольных соотношений
//
Функция ПроверитьКонтролируемыеПоказатели(ОбъектРасчета,ПротоколироватьОшибки=Ложь,ТабПротоколаПроверок) Экспорт
```

Пример вызова
```bsl
Результат = ПравилаПроверкиУХ.ПроверитьКонтролируемыеПоказатели(ОбъектРасчета, ПротоколироватьОшибки, ТабПротоколаПроверок));
```
</details>

## ВыполнитьПроверкуПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВыполнитьПроверкуПоказателей(ОбъектРасчета,Результат,ТабПротоколаПроверок,ПроверкаПройдена,ПериодОтчета=Неопределено) Экспорт
```

Пример вызова
```bsl
ПравилаПроверкиУХ.ВыполнитьПроверкуПоказателей(ОбъектРасчета, Результат, ТабПротоколаПроверок, ПроверкаПройдена, ПериодОтчета);
```
</details>

## ПроверитьКонтрольныйПоказатель
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПроверитьКонтрольныйПоказатель(ЗначениеПоказателя,КонтрольноеЗначение,ВидСравнения) Экспорт
```

Пример вызова
```bsl
Результат = ПравилаПроверкиУХ.ПроверитьКонтрольныйПоказатель(ЗначениеПоказателя, КонтрольноеЗначение, ВидСравнения));
```
</details>

## ПолучитьПротоколПроверки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция формирует табличный документ протокола отчета.
//
// Параметры:
//  РезультатПроверки  – Булево - результат метода Проверить()
//
//  РежимВывода		   – Строка "ТолькоОшибочные", ""
//
// Возвращаемое значение:
//   ТабличныйДокумент - Результирующий документ.
//
Функция ПолучитьПротоколПроверки(ОбъектРасчета,РезультатПроверки,ТабПротоколаПроверок,РежимВывода = "") Экспорт
```

Пример вызова
```bsl
Результат = ПравилаПроверкиУХ.ПолучитьПротоколПроверки(ОбъектРасчета, РезультатПроверки, ТабПротоколаПроверок, РежимВывода);
```
</details>

## ВывестиОбластьРеквизита
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВывестиОбластьРеквизита(ИмяРеквизита,ЗначениеРеквизита,ОбластьРеквизита,ТабДокумент) Экспорт
```

Пример вызова
```bsl
ПравилаПроверкиУХ.ВывестиОбластьРеквизита(ИмяРеквизита, ЗначениеРеквизита, ОбластьРеквизита, ТабДокумент));
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
