---
title: Проверка документов сервер
slug: erp-uh/проверка-документов-сервер
---


## ПриСозданииФормыНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура, вызываемая из одноименного обработчика события формы.
//
// Параметры:
//  Форма					- ФормаКлиентскогоПриложения - форма, из обработчика события которой происходит вызов процедуры;
//  Отказ					- Булево - признак отказа от создания формы;
//  СтандартнаяОбработка	- Булево - признак выполнения стандартной (системной) обработки события;
//  ДополнительныеПараметры	- Структура - дополнительные параметры.
//
Процедура ПриСозданииФормыНаСервере(Форма, Отказ, СтандартнаяОбработка, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ПроверкаДокументовСервер.ПриСозданииФормыНаСервере(Форма, Отказ, СтандартнаяОбработка, ДополнительныеПараметры);
```
</details>

## ПриЧтенииФормыНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура, вызываемая из одноименного обработчика события формы.
//
// Параметры:
//	Форма					- ФормаКлиентскогоПриложения - форма, из обработчика события которой происходит вызов процедуры;
//	ТекущийОбъект			- ДокументОбъект - обрабатываемый объект, который будет прочитан.
//
Процедура ПриЧтенииФормыНаСервере(Форма, ТекущийОбъект) Экспорт
```

Пример вызова
```bsl
ПроверкаДокументовСервер.ПриЧтенииФормыНаСервере(Форма, ТекущийОбъект) 
```
</details>

## ПослеЗаписиНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура, вызываемая из одноименного обработчика события формы.
//
// Параметры:
//	Форма					- ФормаКлиентскогоПриложения - форма, из обработчика события которой происходит вызов процедуры.
//	ТекущийОбъект			- ДокументОбъект - записываемый объект.
//	ПараметрыЗаписи			- Структура - дополнительные параметры записи.
//
Процедура ПослеЗаписиНаСервере(Форма,  ТекущийОбъект, ПараметрыЗаписи) Экспорт
```

Пример вызова
```bsl
ПроверкаДокументовСервер.ПослеЗаписиНаСервере(Форма, ТекущийОбъект, ПараметрыЗаписи) 
```
</details>

## ДоработатьЗапросДинамическогоСпискаЖурналаДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В случае использования проверки документов по регл. учету, добавляет в запрос динамического списка журнала документов,
//	условное соединение с регистром сведений "СтатусыПроверкиДокументов" и параметры-шаблоны заменяет на выражения.
//
//	Параметры:
//		ТекстЗапроса - Строка - обрабатываемый текст запроса динамического списка;
//		ИмяОсновнойТаблицы - Строка - служит для определения подстановки условного соединения и для определения условия соединения.
//
Процедура ДоработатьЗапросДинамическогоСпискаЖурналаДокументов(ТекстЗапроса, ИмяОсновнойТаблицы) Экспорт
```

Пример вызова
```bsl
ПроверкаДокументовСервер.ДоработатьЗапросДинамическогоСпискаЖурналаДокументов(ТекстЗапроса, ИмяОсновнойТаблицы) 
```
</details>

## ПередЗаписьюДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура, вызываемая при срабатывании подписки на событие "ПередЗаписью" (см. подписку на событие "ПроверкаДокументовПередЗаписьюДокумента").
// Проверяет, можно ли записывать документ (отказывает в записи, в случае если документ был проверен и стоит жесткая
// блокировка объекта при проверке).
//
//	Параметры:
//		Источник - ДокументОбъект - см. подписку на событие "ПроверкаДокументовПередЗаписьюДокумента";
//		Отказ - Булево - параметр, определяющий будет ли записываться объект;
//		РежимЗаписи - Булево - режим записи документа;
//		РежимПроведения - Булево - режим проведения документа.
//
Процедура ПередЗаписьюДокумента(Источник, Отказ, РежимЗаписи, РежимПроведения) Экспорт
```

Пример вызова
```bsl
ПроверкаДокументовСервер.ПередЗаписьюДокумента(Источник, Отказ, РежимЗаписи, РежимПроведения) 
```
</details>

## ПередИзменениемДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет необходимость в отказе изменения объекта (отказ будет срабатывать если документ был проверен и стоит
// запрет на редактирование проверенных).
//
//	Параметры:
//		Источник - ДокументОбъект - документ, который изменяется;
//		Отказ - Булево - параметр, определяющий будет ли записываться объект;
//		Удаление - Булево - признак того, что документ удаляется.
//
Процедура ПередИзменениемДокумента(Источник, Отказ, Удаление = Ложь) Экспорт
```

Пример вызова
```bsl
ПроверкаДокументовСервер.ПередИзменениемДокумента(Источник, Отказ, Удаление);
```
</details>

## ПриПроведенииДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура, вызываемая при срабатывании подписки на событие "ОбработкаПроведения" (см. подписку на событие "ПроверкаДокументовОбработкаПроведенияДокумента").
// Устанавливает статус проверки документа на "НеПроверен".
//
//	Параметры:
//		Источник - ДокументОбъект - см. подписку на событие "ПроверкаДокументовОбработкаПроведенияДокумента";
//		Отказ - Булево - параметр, определяющий будет ли проводиться объект;
//		РежимПроведения - Булево - режим проведения документа.
//
Процедура ПриПроведенииДокумента(Источник, Отказ, РежимПроведения) Экспорт
```

Пример вызова
```bsl
ПроверкаДокументовСервер.ПриПроведенииДокумента(Источник, Отказ, РежимПроведения) 
```
</details>

## ПриОтменеПроведенияДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура, вызываемая при срабатывании подписки на событие "ОбработкаУдаленияПроведения" (см. подписку на событие "ПроверкаДокументовОбработкаУдаленияПроведенияДокумента").
// Устанавливает статус проверки документа на "НеПроверен".
//
//	Параметры:
//		Источник - ДокументОбъект - см. подписку на событие "ПроверкаДокументовОбработкаУдаленияПроведенияДокумента";
//		Отказ - Булево - параметр, определяющий будет ли распроводиться объект;
//
Процедура ПриОтменеПроведенияДокумента(Источник, Отказ) Экспорт
```

Пример вызова
```bsl
ПроверкаДокументовСервер.ПриОтменеПроведенияДокумента(Источник, Отказ) 
```
</details>

## ПриИзмененииДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменяет статус проверки документа на "НеПроверен", при условии что данный тип документа проверяется и ФО проверки
// документов включена.
//
//	Параметры:
//		Источник - ДокументОбъект - документ, который изменяется;
//		Отказ - Булево - параметр, определяющий будет ли проводиться (распроводиться) объект.
//
Процедура ПриИзмененииДокумента(Источник, Отказ) Экспорт
```

Пример вызова
```bsl
ПроверкаДокументовСервер.ПриИзмененииДокумента(Источник, Отказ) 
```
</details>

## ОбновитьДанныеПроверкиДокументаНаФорме
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//	Обновляет форму в зависимости от данных проверки документа.
//
//	Параметры:
//		Форма - ФормаКлиентскогоПриложения - форма, которая должна обновляться:
//			* Объект - ДанныеФормыКоллекция - Объект:
//				** Ссылка - ДокументСсылка -
//		ДанныеПроверки - см. РегистрыСведений.СтатусыПроверкиДокументов.ИнициализироватьДанныеПроверкиДокумента.
//
Процедура ОбновитьДанныеПроверкиДокументаНаФорме(Форма, ДанныеПроверки = Неопределено) Экспорт
```

Пример вызова
```bsl
ПроверкаДокументовСервер.ОбновитьДанныеПроверкиДокументаНаФорме(Форма, ДанныеПроверки);
```
</details>

## ЭтотТипДокументаДолженПроверяться
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//	Определяет, проверяется ли документ данного типа,
//	определяется на основании наличия данного документа в измерении регистра "СтатусыПроверкиДокументов").
//
//	Параметры:
//		ТипДокумента - Тип - проверяемый тип.
//
//	Возвращаемое значение:
//		Булево - Истина, если документ должен проверяться.
//
Функция ЭтотТипДокументаДолженПроверяться(ТипДокумента) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаДокументовСервер.ЭтотТипДокументаДолженПроверяться(ТипДокумента) 
```
</details>

## ПроверяемыеТипыДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив типов документов, которые участвуют в проверке.
//
// Возвращаемое значение:
//	Массив Из Тип - Типы значения, которые должны проверяться
Функция ПроверяемыеТипыДокументов() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаДокументовСервер.ПроверяемыеТипыДокументов() 
```
</details>

## ИсключаемыеТипыДляПроверки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает документы, которые не должны учитываться как проверяемые. По ним данные могут храниться в инф. базе, но
// более они не учитываются.
//
// Возвращаемое значение:
//	Массив Из Тип - Типы значения, которые не должны проверяться.
//
Функция ИсключаемыеТипыДляПроверки() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаДокументовСервер.ИсключаемыеТипыДляПроверки() 
```
</details>

## ТипыНеПроверяемыхДокументовСтрокой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает перечисление типов, непроверяемых документов строкой
//
//	Параметры:
// 		ТолькоБезВозможностиИзменения - Булево - принак того, что необходимо вернуть только те документы,
// 			настройки по которым не задаются вручную пользователем (нужно, когда результат функции используется в запросе
// 			с отдельным получением данных по таблице исключений). Значение по умолчанию - Ложь.
//		Разделитель - Строка - разделитель, который будет использоваться для разделения типов.
//			Значение по умолчанию: "," + Символы.ПС + Символы.Таб + Символы.Таб.
//
//	Возвращаемое значение:
//		Строка - строка вида Тип(ПервыйДокумент)<Разделитель>...<Разделитель>Тип(ПоследнийДокумент).
//
Функция ТипыНеПроверяемыхДокументовСтрокой(ТолькоБезВозможностиИзменения = Ложь, Разделитель = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаДокументовСервер.ТипыНеПроверяемыхДокументовСтрокой(ТолькоБезВозможностиИзменения, Разделитель);
```
</details>

## ПереопределитьВТекстеЗапросаСтатусыПроверкиСУчетомИсключений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет обращение к временной таблице "ПроверкаДокументовПереопределяемый" на обращение к регистрам сведений проверки
// (СтатусыПроверкиДокументов и НастройкиИсключенийПроверкиДокументов) с отбором только по тем документам, которые должны
// проверяться (на основании предопределенных типов непроверяемых документов и документов добавленных в исключения пользователем).
//
//	Параметры:
//		ТекстЗапроса - Строка - текст запроса, в котором встречается обращение к таблице которую необходимо переопределить.
//			Условия:
//			-	в тексте запроса должно быть только одно обращение к таблице "ПроверкаДокументовПереопределяемый", в противном случае текст необходимо разделить;
//			-	в тексте запроса должны быть перечислены все измерения регистра сведений статусов проверки документа, обращения к измерениям должно находиться справа, например:
//					"И ПроверкаДокументовПереопределяемый.Документ = ПсевдонимТаблицыСвязи.ИмяДокументаСвязи".
//		ПутьКРегистратору - Строка - текст обращения к регистратору вида "ПсевдонимТаблицыСвязи.ИмяДокументаСвязи" для связи с настройкой исключений.
//
Процедура ПереопределитьВТекстеЗапросаСтатусыПроверкиСУчетомИсключений(ТекстЗапроса, ПутьКРегистратору) Экспорт
```

Пример вызова
```bsl
ПроверкаДокументовСервер.ПереопределитьВТекстеЗапросаСтатусыПроверкиСУчетомИсключений(ТекстЗапроса, ПутьКРегистратору) 
```
</details>

## ПереопределитьВТекстеЗапросаСтатусыПроверкиСУчетомБлокировок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет обращение к временной таблице "ПроверкаДокументовПереопределяемый" на обращение к регистрам сведений проверки
// (СтатусыПроверкиДокументов и НастройкиИсключенийПроверкиДокументов) с отбором только по тем документам, которые должны
// проверяться (на основании предопределенных типов непроверяемых документов и документов добавленных в исключения пользователем),
// а так же по тем документов, для которых стоит условие блокировки проверенных (на основании общей ФО и документов добавленных в исключения пользователем).
//
//	Параметры:
//		ТекстЗапроса - Строка - текст запроса, в котором встречается обращение к таблице которую необходимо переопределить.
//			Условия:
//			-	в тексте запроса должно быть только одно обращение к таблице "ПроверкаДокументовПереопределяемый", в противном случае текст необходимо разделить;
//			-	в тексте запроса должны быть перечислены все измерения регистра сведений статусов проверки документа, обращения к измерениям должно находиться справа, например:
//					"И ПроверкаДокументовПереопределяемый.Документ = ПсевдонимТаблицыСвязи.ИмяДокументаСвязи".
//		ПутьКРегистратору - Строка - текст обращения к регистратору вида "ПсевдонимТаблицыСвязи.ИмяДокументаСвязи" для связи с настройкой исключений.
//
Процедура ПереопределитьВТекстеЗапросаСтатусыПроверкиСУчетомБлокировок(ТекстЗапроса, ПутьКРегистратору) Экспорт
```

Пример вызова
```bsl
ПроверкаДокументовСервер.ПереопределитьВТекстеЗапросаСтатусыПроверкиСУчетомБлокировок(ТекстЗапроса, ПутьКРегистратору) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
