---
title: Проверка и подбор продукции МОТП
slug: erp-uh/проверка-и-подбор-продукции-мотп
---


## ПересчитатьХешСуммыВсехУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает хеш-суммы всех упаковок формы и проверяется необходимость перемаркировки.
//
// Параметры:
//	Форма - ФормаКлиентскогоПриложения - форма проверки и подбора маркируемой продукции.
//
Процедура ПересчитатьХешСуммыВсехУпаковок(Форма) Экспорт
```

Пример вызова
```bsl
ПроверкаИПодборПродукцииМОТП.ПересчитатьХешСуммыВсехУпаковок(Форма) 
```
</details>

## ДопустимыеДетализацииСтруктурыХранения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает допустимые детализации структуры хранения по документу, доступные при открытии формы проверки и подбора.
// Параметры:
//  ПоДокументу - Булево - делализация с учетом документа.
//  ПроверяемыйДокумент - ДокументСсылка - ссылка на проверяемый документ, для которого производится открытие формы.
//
// Возвращаемое значение:
//  Массив - массив из ПеречислениеСсылка.ДетализацияСтруктурыХраненияИС.
Функция ДопустимыеДетализацииСтруктурыХранения(ПоДокументу = Ложь, ПроверяемыйДокумент = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаИПодборПродукцииМОТП.ДопустимыеДетализацииСтруктурыХранения(ПоДокументу, ПроверяемыйДокумент);
```
</details>

## ДетализацияТребуетЗапросаКСервису
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список допустимых детализаций по фактической детализации документа
//
// Параметры:
//  ФактическаяДетализация - ПеречислениеСсылка.ДетализацияСтруктурыХраненияИС - Фактическая детализация.
// Возвращаемое значение:
//  Массив Из ПеречислениеСсылка.ДетализацияСтруктурыХраненияИС - Допустимые детализации
Функция ДетализацияТребуетЗапросаКСервису(ФактическаяДетализация) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаИПодборПродукцииМОТП.ДетализацияТребуетЗапросаКСервису(ФактическаяДетализация) 
```
</details>

## ДетализацияНаОснованииСтатистикиПоШтрихкодам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает детализацию структуры хранения, рассчитанную по данным статистики по документу.
//
// Параметры:
//  ДанныеШтрихкодовСписок - ТаблицаЗначений - таблица штрихкодов упаковок проверяемого документа. (См ШтрихкодированиеМОТП.ШтрихкодыУпаковокИзДокумента).
//  ПараметрыСканирования - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования).
//  ПроверяемыйДокумент - ДокументСсылка - ссылка на проверяемый документ.
//  ВидПродукции - ПеречислениеСсылка.ВидыПродукцииИС - вид продукции.
//  Кэш - Неопределено, Соответствие - кэш.
//
// Возвращаемое значение:
//  ПеречислениеСсылка.ДетализацияСтруктурыХраненияИС - детализация структуры хранения.
Функция ДетализацияНаОснованииСтатистикиПоШтрихкодам(ДанныеШтрихкодовСписок, ПараметрыСканирования, ПроверяемыйДокумент, ВидПродукции, Кэш = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаИПодборПродукцииМОТП.ДетализацияНаОснованииСтатистикиПоШтрихкодам(ДанныеШтрихкодовСписок, ПараметрыСканирования, ПроверяемыйДокумент, ВидПродукции, Кэш);
```
</details>

## ОпределитьВидыУпаковокПоДаннымИнформационнойБазы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОпределитьВидыУпаковокПоДаннымИнформационнойБазы(ВидПродукции, Штрихкоды, КешДанныхРазбора, ДанныеРазбораШтрихкода) Экспорт
```

Пример вызова
```bsl
ПроверкаИПодборПродукцииМОТП.ОпределитьВидыУпаковокПоДаннымИнформационнойБазы(ВидПродукции, Штрихкоды, КешДанныхРазбора, ДанныеРазбораШтрихкода) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
