---
title: Проверка контрагентов
slug: erp-uh/проверка-контрагентов
---


## ИспользованиеПроверкиВозможно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, что проверка включена и есть необходимые права.
// Возвращаемое значение:
//  Булево - Истина, если есть нужные права на проверку и проверка включена.
//
Функция ИспользованиеПроверкиВозможно() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаКонтрагентов.ИспользованиеПроверкиВозможно() 
```
</details>

## ПроверитьКонтрагента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверка одного контрагента по ИНН, КПП и Дате.
//
// Параметры:
//  Параметры - Структура - Параметры запуска фонового задания. Ключи структуры:
//    * Контрагент - ОпределяемыйТип.КонтрагентБИП - Проверяемый контрагент.
//    * ИНН - Строка - ИНН Контрагента.
//    * КПП - Строка - КПП Контрагента.
//    * Дата - Дата - Дата, на которую выполняется проверка контрагента. Может быть не указана,
//        тогда берется текущая дата.
//  АдресХранилища - Строка - Адрес временного хранилища, в который будет помещен результат проверки контрагента.
//
Процедура ПроверитьКонтрагента(Параметры, АдресХранилища) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПроверитьКонтрагента(Параметры, АдресХранилища) 
```
</details>

## СостояниеКонтрагента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Состояние контрагента
//
// Параметры:
//		ИНН		 - Строка - ИНН Контрагента.
//		КПП		 - Строка - КПП Контрагента.
//		Дата	 - Дата - Дата, на которую выполняется проверка контрагента. Может быть не указана,
//		                  тогда берется текущая дата.
//
// Возвращаемое значение:
//  Перечисление.СостоянияСуществованияКонтрагента - Состояния контрагента согласно данным ФНС.
//
Функция СостояниеКонтрагента(ИНН, КПП, Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаКонтрагентов.СостояниеКонтрагента(ИНН, КПП, Дата);
```
</details>

## ПроверитьВебСервисомФНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверка нескольких контрагентов.
//
// Параметры:
//  ДанныеКонтрагентов		 - ТаблицаЗначений - Содержит данные проверяемых контрагентов.
//		Структуру колонок таблицы см в функции ШаблонТаблицыДанныеКонтрагента.
//	ДополнительныеПараметры  - Структура - Дополнительные параметры проверки.
// 		Структура может быть пустой или иметь следующие элементы:
//		- ЭтоПроверкаСправочника/ЭтоПроверкаДокумента/ЭтоПроверкаОтчета для указания вида
//			проверяемого объекта.
//		- СохранятьРезультатСразуПослеПроверки - флаг, позволяющий сразу после проверки
//		контрагента сохранить результат в регистр СостоянияКонтрагентов при проверке
//		в режиме ЭтоПроверкаСправочника = Истина.
//		- АдресХранилища - адрес, по которому будет сохранен результат проверки при проверке
//		в режиме ЭтоПроверкаСправочника = Истина.
//		- ВыполнятьПредварительнуюПроверкуКонтрагента - флаг, действующий при проверке
//		в режиме ЭтоПроверкаСправочника = Истина, который показывает, что предварительная проверка ИНН, КПП
//		и Даты уже была выполнена ранее и здесь проверку можно пропустить.
Процедура ПроверитьВебСервисомФНС(ДанныеКонтрагентов, ДополнительныеПараметры) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПроверитьВебСервисомФНС(ДанныеКонтрагентов, ДополнительныеПараметры) 
```
</details>

## ПроверитьКонтрагентовВДокументе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод фонового задания по проверки контрагентов в документе.
//
// Параметры:
//  Параметры	 - Структура - Параметры фонового задания. Ключи:
//		"ДанныеКонтрагентов" - ТаблицаЗначений - - Содержит данные проверяемых контрагентов.
//			Структуру колонок таблицы см в функции ШаблонТаблицыДанныеКонтрагентаДляДокумента.
//		"АдресХранилища" - Строка - Адрес, в который будет помещен результат проверки контрагента
//		"СохранятьРезультатСразуПослеПроверки" - Булево - Признак, указывающий нужно ли результат проверки контрагента
// 			сразу сохранять в регистр.
//		"ЭтоПроверкаПоКнопке" - Булево - Если Истина, то данные берутся не из кэша, а из Интернета.
Процедура ПроверитьКонтрагентовВДокументе(Параметры) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПроверитьКонтрагентовВДокументе(Параметры) 
```
</details>

## ПроверитьКонтрагентовРегламентноеЗадание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод регламентного задания по проверке контрагентов в справочнике.
// В модели сервиса обновляет неактуальные состояния контрагентов.
// В локальном режиме записывает недостающих контрагентов в регистр и обновляет неактуальные состояния.
Процедура ПроверитьКонтрагентовРегламентноеЗадание() Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПроверитьКонтрагентовРегламентноеЗадание() 
```
</details>

## ПроверитьКонтрагентовПослеВключенияПроверки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет первоначальное заполнение регистра на основе справочника контрагентов.
// 		Заполнение выполняется:
// 		1. После ручного включения проверки фоновым заданием.
// 		2. В режиме сервисов - обновлением ИБ в каждой области отдельно.
//
// Параметры:
//  Параметры	 - Структура, Неопределено - Параметры очереди заданий в модели сервиса.
//		В локальной версии - Неопределено.
Процедура ПроверитьКонтрагентовПослеВключенияПроверки(Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПроверитьКонтрагентовПослеВключенияПроверки(Параметры);
```
</details>

## ПроверитьКонтрагентовПослеВключенияПроверкиФоновоеЗадание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запуск фонового задания по проверке контрагентов после
//		включения проверки в предложении на подключение или из настроек.
Процедура ПроверитьКонтрагентовПослеВключенияПроверкиФоновоеЗадание() Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПроверитьКонтрагентовПослеВключенияПроверкиФоновоеЗадание() 
```
</details>

## ВыполнитьПроверкуКонтрагентов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вспомогательный API. Контрагенты проверяются по данным ФНС.
//  По завершению проверки в переданную таблицу добавляется колонка c состоянием контрагента.
//
// Параметры:
//  ПроверяемыеКонтрагенты - ТаблицаЗначений - Таблица, содержащая контрагентов на проверку.
//    Колонки таблицы: Контрагент, ИНН, КПП, Дата.
//  ВидПроверки - Строка - Может принимать одно следующих значений:
//    * ИзКэша - результат проверки выбирается только из кэша.
//    * АктуальныеДанные - результат проверки получается только на основе данных, возвращенных веб-сервисом проверки.
//    * Смешанный - сначала выбираются данные из кэша, затем идет обращение к веб-сервису проверки.
//  ДополнительныеПараметры - Структура - Может содержать один из следующих ключей.
//    * ЭтоПроверкаДокумента - Булево - особенность для документов: если дата документа больше текущей, то сервис ФСН
//        выдает ошибку. Чтобы такого не было, документы с будущей датой проверяем на текущую дату.
//    * ЭтоПроверкаОтчета - Булево - Для отчетов предварительная проверка не выполняется, все данные сразу уходят
//        на веб-сервис ФНС.
//    * ЭтоПроверкаСправочника - Булево - Для справочника часть состояний берется из кэша в режиме
//        проверки ИзКэша или Смешанный. После проверки данные проверки сохраняются в регистр сведений.
Процедура ВыполнитьПроверкуКонтрагентов( Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ВыполнитьПроверкуКонтрагентов();
```
</details>

## ДополнитьОписание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавление описания расположения контрагента в документе в таблицу описаний.
//
// Параметры:
//  Описание		 - ТаблицаЗначений - таблица, хранящая описание расположения контрагентов в документе.
//  Ссылка			 - ДокументСсылка - Документ, в котором выполняется проверка контрагента.
//  Элемент			 - ПолеВвода, ДекорацияФормы - Элемент, в котором находится проверяемый контрагент или счет-фактура.
//  Контрагент		 - ОпределяемыйТип.КонтрагентБИП - Проверяемый контрагент.
//  ЭлементРодитель	 - ГруппаФормы - Группа, которая содержит элемент с контрагентом или
//                     счетом-фактурой.
//		Данный элемент будет подкрашен по результату проверки контрагентов. Может не указываться.
Процедура ДополнитьОписание( Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ДополнитьОписание();
```
</details>

## ДополнитьОписаниеТабличныхЧастей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавление записи к таблице описания расположения контрагентов в табличных частях документа.
//
// Параметры:
//  Форма	 			 - ФормаКлиентскогоПриложения - Форма документа, в котором выполняется проверка контрагентов.
//  Описание 			 - ТаблицаЗначений - Таблица с описанием расположения контрагентов в табличной части документа.
//  ИмяТаблицыФормы		 - Строка - Имя таблицы формы, в которой расположен контрагент.
//  ИмяПоляСКонтрагентом - Строка - Имя колонки с контрагентом в таблице формы, в которой расположен контрагент.
//  ИмяПоляСДатой		 - Строка - Имя колонки с датой в таблице формы, на которую выполняется проверка контрагента.
//		Если в таблице формы нет такой колонки, то не заполняется.
//
Процедура ДополнитьОписаниеТабличныхЧастей(Форма, Описание, ИмяТаблицыФормы, ИмяПоляСКонтрагентом, ИмяПоляСДатой) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ДополнитьОписаниеТабличныхЧастей(Форма, Описание, ИмяТаблицыФормы, ИмяПоляСКонтрагентом, ИмяПоляСДатой) 
```
</details>

## ТестовыйРежимРаботыСервисаЗавершился
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Тестовый режим работы сервиса завершился.
//
// Возвращаемое значение:
//  Булево - Истина, если тестовый режим работы сервиса завершился.
//
Функция ТестовыйРежимРаботыСервисаЗавершился() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаКонтрагентов.ТестовыйРежимРаботыСервисаЗавершился() 
```
</details>

## УстановитьНадписиВПанелиОтчетаПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Установка надписей в панели проверки контрагентов в отчета при создании на сервере.
//
// Параметры:
//  Форма	- ФормаКлиентскогоПриложения - Форма отчета, в котором выводится результат проверки контрагентов.
Процедура УстановитьНадписиВПанелиОтчетаПриСозданииНаСервере(Форма) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.УстановитьНадписиВПанелиОтчетаПриСозданииНаСервере(Форма) 
```
</details>

## ПроверитьКонтрагентовВДокументеФоновоеЗадание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запуск фонового задания по проверке контрагента.
//
// Параметры:
//  Форма						 - ФормаКлиентскогоПриложения - Форма документа, в котором выполняется проверка контрагентов.
//  ПараметрыФоновогоЗадания	 - ТаблицаФормы - Если изменения контрагента или даты произошли в табличной части.
//								 - ПолеФормы - Элемент управления, содержащий контрагента или счет-фактуру, в случае,
//		если произошло изменение в контрагенте, находящегося в шапке или в счете-фактуре, находящегося в подвале.
//								 - Дата - Дата документа, в случае если произошло изменение даты
//								 - Неопределено - если требуется проверка всех контрагентов в документе.
//								 - Булево - если это запуск проверки контрагента при создании на сервере.
Процедура ПроверитьКонтрагентовВДокументеФоновоеЗадание(Форма, ПараметрыФоновогоЗадания) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПроверитьКонтрагентовВДокументеФоновоеЗадание(Форма, ПараметрыФоновогоЗадания) 
```
</details>

## ОтобразитьРезультатПроверкиКонтрагентаВДокументе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отображение результата проверки контрагентов в документе.
//
// Параметры:
//  Форма	- ФормаКлиентскогоПриложения - Форма документа, в котором выполняется проверка контрагентов.
Процедура ОтобразитьРезультатПроверкиКонтрагентаВДокументе(Форма) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ОтобразитьРезультатПроверкиКонтрагентаВДокументе(Форма) 
```
</details>

## ПриСозданииНаСервереСписокДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаются параметры динамического списка документов и применяется условное оформление.
//
// Параметры:
//  Список	 - ДинамическийСписок - Список документов.
Процедура ПриСозданииНаСервереСписокДокументов(Список) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПриСозданииНаСервереСписокДокументов(Список) 
```
</details>

## ПередЗаписьюНаСервереДокумент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запоминание результатов проверки контрагентов в дополнительные свойства для последующего сохранения
//	в регистр при помощи подписки на события.
//
// Параметры:
//  Форма			- ФормаКлиентскогоПриложения - Форма документа, в котором выполняется проверка контрагентов.
//  ТекущийОбъект	- ДокументОбъект - документ, запись которого выполняется.
Процедура ПередЗаписьюНаСервереДокумент(Форма, ТекущийОбъект) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПередЗаписьюНаСервереДокумент(Форма, ТекущийОбъект) 
```
</details>

## ПриСозданииНаСервереДокумент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запуск проверки контрагента, установка условного оформления.
//
// Параметры:
//  Форма	 - ФормаКлиентскогоПриложения - Форма документа, в котором выполняется проверка контрагентов.
//  Параметры		 - Структура - Если изменения произошли в табличной части.
//		В записи с ключем ИмяТаблицы указывается ИмяТаблицы, в записи с ключем Идентификатор указывается Идентификатор
//		строки,  в которой произошло изменение контрагента или даты.
//					- Строка - Имя элемента управления формы, в случае если произошло изменение в контрагенте, находящегося в шапке.
//					- Дата - Дата документа, в случае если произошло изменение даты
//					- Неопределено - если требуется проверка всех контрагентов в документе.
Процедура ПриСозданииНаСервереДокумент(Форма, Параметры) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПриСозданииНаСервереДокумент(Форма, Параметры) 
```
</details>

## ПослеЗаписиНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Восстановление результатов проверки контрагентов в табличной части после записи.
//
// Параметры:
//  Форма			- ФормаКлиентскогоПриложения - Форма документа, в котором выполняется проверка контрагентов.
//  ТекущийОбъект	- ДокументОбъект - документ, запись которого выполняется.
Процедура ПослеЗаписиНаСервере(Форма, ТекущийОбъект) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПослеЗаписиНаСервере(Форма, ТекущийОбъект) 
```
</details>

## ПриЗаписиНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохранение результатов проверки контрагентов в регистр при записи.
//
// Параметры:
//  Форма			- ФормаКлиентскогоПриложения - Форма документа, в котором выполняется проверка контрагентов.
//  ТекущийОбъект	- ДокументОбъект - документ, запись которого выполняется.
Процедура ПриЗаписиНаСервере(Форма, ТекущийОбъект) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПриЗаписиНаСервере(Форма, ТекущийОбъект) 
```
</details>

## ИнициализироватьРеквизитыФормыДокумент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вспомогательный API. Инициализировать реквизиты проверки контрагента в форме документа
//	при создании на сервере документа.
//
// Параметры:
//  Форма	 - ФормаКлиентскогоПриложения - Форма документа, в котором выполняется проверка контрагентов.
Процедура ИнициализироватьРеквизитыФормыДокумент(Форма) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ИнициализироватьРеквизитыФормыДокумент(Форма) 
```
</details>

## ОписаниеДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует описание документа, согласно которому осуществляется проверка контрагентов и вывод
//  информации о результатах проверки в форму документа.
//
// Параметры:
//  Форма	 - ФормаКлиентскогоПриложения	 - Форма документа, в котором выполняется проверка контрагентов.
//
// Возвращаемое значение:
//  ТаблицаЗначений - Таблица описания документа.
//
Функция ОписаниеДокументов(Форма) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаКонтрагентов.ОписаниеДокументов(Форма) 
```
</details>

## ДополнитьДанныеКонтрагентовВДокументе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполнение данных контрагента в документе.
//
// Параметры:
//  Ссылка				 - ДокументСсылка - Документ, в котором выполняется проверка контрагентов.
//  ДанныеКонтрагентов	 - ТаблицаЗначений - Содержит данные проверяемых контрагентов.
//		Структуру колонок таблицы см в функции ШаблонТаблицыДанныеКонтрагента.
//  Контрагент			 - ОпределяемыйТип.КонтрагентБИП - Контрагент, данными которого дополняются данные таблицы
//                                                   ДанныеКонтрагентов.
//  Дата				 - Дата - Дата, на которую выполняется проверка контрагента.
//  Состояние			 - Перечисления.СостоянияСуществованияКонтрагента - Результат проверки контрагента.
Процедура ДополнитьДанныеКонтрагентовВДокументе( Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ДополнитьДанныеКонтрагентовВДокументе();
```
</details>

## ИтоговоеСостояниеКонтрагентаВДокументе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет итоговое состояние контрагентов в документе.
//
// Параметры:
//  ДанныеКонтрагентов	 - ТаблицаЗначений	 - Содержит данные проверяемых контрагентов.
//  	Структуру колонок таблицы см в функции ШаблонТаблицыДанныеКонтрагента.
//  Отбор				 - Структура		 - отбор, накладываемый на таблицу данные контрагента.
//
// Возвращаемое значение:
//  Структура - описание состояния контрагентов - заполнен ли контрагент, его состояние, количество контрагентов.
//
Функция ИтоговоеСостояниеКонтрагентаВДокументе(ДанныеКонтрагентов, Отбор = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаКонтрагентов.ИтоговоеСостояниеКонтрагентаВДокументе(ДанныеКонтрагентов, Отбор);
```
</details>

## ПередФормированиемОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализация данных для проверки.
//
// Параметры:
//  Форма	 - ФормаКлиентскогоПриложения - Форма отчета, в котором выполняется проверка контрагентов.
Процедура ПередФормированиемОтчета(Форма) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПередФормированиемОтчета(Форма) 
```
</details>

## ДобавитьКонтрагентаНаПроверку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавление контрагента на проверку.
//
// Параметры:
//  СтруктураПараметров				 - Структура - Параметры формирования отчета.
//		Для проверки контрагентов в отчете важно наличие ключа "ДанныеДляПроверкиКонтрагентов".
//		Данный ключ формируется в процедуре ДобавитьПараметрыДляПроверкиКонтрагентов.
//  НомерСтрокиТабличногоДокумента	 - Число - Номер строки табличного документа, содержащей контрагент.
//  Контрагент						 - СправочникСсылка - Проверяемый контрагент в строке отчета.
//  ИНН								 - Строка - ИНН контрагента.
//  КПП								 - Строка - ИНН контрагента.
//  Дата							 - Дата - Дата, на которую необходимо выполнять проверку контрагента.
//	НомерРаздела					 - Число - Номер раздела отчета, в котором выводится контрагент.
Процедура ДобавитьКонтрагентаНаПроверку(СтруктураПараметров, НомерСтрокиТабличногоДокумента, Контрагент, ИНН, КПП, Дата, НомерРаздела = 0) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ДобавитьКонтрагентаНаПроверку(СтруктураПараметров, НомерСтрокиТабличногоДокумента, Контрагент, ИНН, КПП, Дата, НомерРаздела);
```
</details>

## ВыводитьСтрокуОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, нужно ли выводить данную строку в отчете по некорректным контрагентам.
//
// Параметры:
//  СтруктураПараметров	 - Структура - Параметры формирования отчета.
//		Для проверки контрагентов в отчете важно наличие ключа "ДанныеДляПроверкиКонтрагентов".
//		Данный ключ формируется в процедуре ДобавитьПараметрыДляПроверкиКонтрагентов.
//  Контрагент						 - СправочникСсылка - Проверяемый контрагент в строке отчета.
//  ИНН								 - Строка - ИНН контрагента.
//  КПП								 - Строка - ИНН контрагента.
//  Дата							 - Дата - Дата, на которую необходимо выполнять проверку контрагента.
// Возвращаемое значение:
//  Булево - Истина, если данную строку необходимо выводить в отчете по некорректным контрагентам.
Функция ВыводитьСтрокуОтчета(СтруктураПараметров, Контрагент, ИНН, КПП, Дата) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаКонтрагентов.ВыводитьСтрокуОтчета(СтруктураПараметров, Контрагент, ИНН, КПП, Дата) 
```
</details>

## ЗапомнитьДанныеОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запоминает данные отчета полученные при первоначальном формировании отчета
// и используемые в дальнейшем для проверки контрагентов в отчете.
//
// Параметры:
//  СтруктураПараметров - Структура - Параметры формирования отчета.
//      Для проверки контрагентов в отчете важно наличие ключа "ДанныеДляПроверкиКонтрагентов".
//      Данный ключ формируется в процедуре ДобавитьПараметрыДляПроверкиКонтрагентов.
//  ДанныеОтчета - РезультатЗапроса - Данные отчета полученные при первоначальном формировании отчета
//      и используемые в дальнейшем для проверки контрагентов.
Процедура ЗапомнитьДанныеОтчета(СтруктураПараметров, ДанныеОтчета) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ЗапомнитьДанныеОтчета(СтруктураПараметров, ДанныеОтчета) 
```
</details>

## ЗапомнитьРезультатФормированияОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохранение таблицы с контрагентами, участвующими в отчете.
//
// Параметры:
//  Форма				 - ФормаКлиентскогоПриложения - Форма отчета, в котором выполняется проверка контрагентов.
//  РезультатВыполнения	 - Структура - Результат формирования отчета, содержащий свойство ДанныеДляПроверкиКонтрагентов.
//  АдресХранилища	 	 - Строка - Адрес временного хранилища с результатом заполнения отчета.
//									Во временном хранилище хранится структура с обязательным ключом
//									"ДанныеДляПроверкиКонтрагентов".
Процедура ЗапомнитьРезультатФормированияОтчета(Форма, РезультатВыполнения, АдресХранилища = Неопределено) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ЗапомнитьРезультатФормированияОтчета(Форма, РезультатВыполнения, АдресХранилища);
```
</details>

## ДобавитьОбщиеПараметрыДляПроверкиКонтрагентовВОтчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавление в параметры формирования отчета обязательных данных, необходимых для проверки контрагентов в отчете.
//
// Параметры:
//	ПараметрыОтчета - Структура - Структура параметров отчета,
//								  в которую будут добавлены данные для проверки контрагентов.
//
Процедура ДобавитьОбщиеПараметрыДляПроверкиКонтрагентовВОтчете(ПараметрыОтчета) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ДобавитьОбщиеПараметрыДляПроверкиКонтрагентовВОтчете(ПараметрыОтчета) 
```
</details>

## ДобавитьПараметрыДляПроверкиКонтрагентов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавление в параметры формирования отчета данных, необходимых для проверки контрагентов в отчете.
//
// Параметры:
//  Форма						 - ФормаКлиентскогоПриложения - Форма отчета, в котором выполняется проверка контрагентов.
//  ПараметрыОтчета				 - Структура - Параметры формирования отчета.
//  ЭтоПервоеФормированиеОтчета	 - Булево - Истина, если это формирование отчета перед проверкой контрагентов.
//		Ложь, если это формирование отчета при проверке контрагентов.
//  ПолныйОтчет					 - ТабличныйДокумент - Табличный документ, содержащий в себе сформированный отчет
// 		в исходном виде (до проверки контрагентов). Если ЭтоПервоеФормированиеОтчета = Истина, то ПолныйОтчет можно не
// 		передавать.
Процедура ДобавитьПараметрыДляПроверкиКонтрагентов(Форма, ПараметрыОтчета, ЭтоПервоеФормированиеОтчета, ПолныйОтчет = Неопределено) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ДобавитьПараметрыДляПроверкиКонтрагентов(Форма, ПараметрыОтчета, ЭтоПервоеФормированиеОтчета, ПолныйОтчет);
```
</details>

## ФормироватьОтчетСтандартнымСпособом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяем, формируется ли отчет стандартным способом.
//
// Параметры:
//  СтруктураПараметров	 - Структура - Параметры формирования отчета.
//		Для проверки контрагентов в отчете важно наличие ключа "ДанныеДляПроверкиКонтрагентов".
//		Данный ключ формируется в процедуре ДобавитьПараметрыДляПроверкиКонтрагентов.
//  ДанныеОтчета		 - РезультатЗапроса - Данные отчета полученные при первоначальном формировании отчета
// 		и используемые в дальнейшем для проверки контрагентов.
// Возвращаемое значение:
//  Булево - Истина, если это формирование отчета до проверки контрагентов.
Функция ФормироватьОтчетСтандартнымСпособом(СтруктураПараметров, ДанныеОтчета) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаКонтрагентов.ФормироватьОтчетСтандартнымСпособом(СтруктураПараметров, ДанныеОтчета) 
```
</details>

## ДополнитьРезультатФормированияОтчетаДаннымиПоПроверкеКонтрагентов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополнение результата формирования отчета результатами проверки контрагентов.
//
// Параметры:
//  РезультатФормирования	 - Структура - Результат формирования отчета.
//  СтруктураПараметров		 - Структура - Результат проверки контрагентов.
//
Процедура ДополнитьРезультатФормированияОтчетаДаннымиПоПроверкеКонтрагентов(РезультатФормирования, СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ДополнитьРезультатФормированияОтчетаДаннымиПоПроверкеКонтрагентов(РезультатФормирования, СтруктураПараметров) 
```
</details>

## ОпределитьНедействующихКонтрагентовВОтчетеФоновоеЗадание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод фонового задания по проверке контрагентов в отчете.
//
// Параметры:
//  СтруктураПараметров	 - Структура - Параметры формирования отчета.
//		Для проверки контрагентов в отчете важно наличие ключа "ДанныеДляПроверкиКонтрагентов".
//		Данный ключ формируется в процедуре ДобавитьПараметрыДляПроверкиКонтрагентов.
//  АдресХранилища		 - Строка - Адрес временного хранилища, в который помещается результат
//		выполнения фонового задания по проверке контрагентов.
//
Процедура ОпределитьНедействующихКонтрагентовВОтчетеФоновоеЗадание(СтруктураПараметров, АдресХранилища) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ОпределитьНедействующихКонтрагентовВОтчетеФоновоеЗадание(СтруктураПараметров, АдресХранилища) 
```
</details>

## ПроверитьКонтрагентовВОтчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запуск фонового задания по проверке контрагентов в отчете.
//
// Параметры:
//  Форма				 - ФормаКлиентскогоПриложения - Форма отчета, в котором выполняется проверка контрагентов.
//  СтруктураПараметров	 - Структура - Параметры формирования отчета.
//		Для проверки контрагентов в отчете важно наличие ключа "ДанныеДляПроверкиКонтрагентов".
//		Данный ключ формируется в процедуре ДобавитьПараметрыДляПроверкиКонтрагентов.
Процедура ПроверитьКонтрагентовВОтчете(Форма, СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПроверитьКонтрагентовВОтчете(Форма, СтруктураПараметров) 
```
</details>

## ОтобразитьРезультатПроверкиКонтрагентаВОтчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отображение результата проверки контрагента в отчете.
//
// Параметры:
//  Форма				 		 - ФормаКлиентскогоПриложения - Форма отчета, в котором выполняется проверка контрагентов.
//  ПолеТабличногоДокумента		 - ПолеФормы - поле, в которое необходимо выводить отчет.
//  РезультатФормированияОтчета	 - ТабличныйДокумент - Документ, предназначенный для вывода в поле формы.
//	ТекущийНомерРаздела			 - Число - Номер раздела для вывода (для отчетов с разделами).
Процедура ОтобразитьРезультатПроверкиКонтрагентаВОтчете(Форма, ПолеТабличногоДокумента, РезультатФормированияОтчета, ТекущийНомерРаздела = Неопределено) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ОтобразитьРезультатПроверкиКонтрагентаВОтчете(Форма, ПолеТабличногоДокумента, РезультатФормированияОтчета, ТекущийНомерРаздела);
```
</details>

## ВывестиОтчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вывод результата проверки контрагента в поле табличного документа.
//
// Параметры:
//  Форма				 		 - ФормаКлиентскогоПриложения - Форма отчета, в котором выполняется проверка контрагентов.
//  ПолеТабличногоДокумента		 - ПолеФормы - поле, в которое необходимо выводить отчет.
//  РезультатФормированияОтчета	 - ТабличныйДокумент - Документ, предназначенный для вывода в поле формы.
Процедура ВывестиОтчет(Форма, ПолеТабличногоДокумента, РезультатФормированияОтчета) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ВывестиОтчет(Форма, ПолеТабличногоДокумента, РезультатФормированияОтчета) 
```
</details>

## ВывестиРазделОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вывод раздела отчета после проверки контрагента в поле табличного документа.
//
// Параметры:
//  Форма				 		 - ФормаКлиентскогоПриложения - Форма отчета, в котором выполняется проверка контрагентов.
//  ПолеТабличногоДокумента		 - ПолеФормы - поле, в которое необходимо выводить отчет.
//  НомерРаздела	 			 - Число - Номер раздела для вывода.
//
Процедура ВывестиРазделОтчета(Форма, ПолеТабличногоДокумента, НомерРаздела) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ВывестиРазделОтчета(Форма, ПолеТабличногоДокумента, НомерРаздела) 
```
</details>

## ПереключитьРежимОтображенияОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отображение результата проверки контрагента в отчете.
//
// Параметры:
//  Форма				 		 - ФормаКлиентскогоПриложения - Форма отчета, в котором выполняется проверка контрагентов.
//  ПолеТабличногоДокумента		 - ПолеФормы - поле, в которое необходимо выводить отчет.
//  РезультатФормированияОтчета	 - ТабличныйДокумент - Документ, предназначенный для вывода в поле формы.
Процедура ПереключитьРежимОтображенияОтчета(Форма, ПолеТабличногоДокумента, РезультатФормированияОтчета) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПереключитьРежимОтображенияОтчета(Форма, ПолеТабличногоДокумента, РезультатФормированияОтчета) 
```
</details>

## ПереключитьРежимОтображенияРазделаОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отображение результата проверки контрагента в отчете.
//
// Параметры:
//  Форма				 		 - ФормаКлиентскогоПриложения - Форма отчета, в котором выполняется проверка контрагентов.
//  ПолеТабличногоДокумента		 - ПолеФормы - поле, в которое необходимо выводить отчет.
//  НомерРаздела	 			 - Число - Номер раздела, который необходимо отобразить.
Процедура ПереключитьРежимОтображенияРазделаОтчета(Форма, ПолеТабличногоДокумента, НомерРаздела) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПереключитьРежимОтображенияРазделаОтчета(Форма, ПолеТабличногоДокумента, НомерРаздела) 
```
</details>

## ПриСозданииНаСервереОтчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливается вид панели с результатом проверки.
//
// Параметры:
//  Форма	 - ФормаКлиентскогоПриложения - Форма отчета, в котором выполняется проверка контрагентов.
//  ОтчетСРазделами	 - Булево 	- Признак того, что отчет имеет разделы.
Процедура ПриСозданииНаСервереОтчет(Форма, ОтчетСРазделами = Ложь) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПриСозданииНаСервереОтчет(Форма, ОтчетСРазделами);
```
</details>

## ИнициализироватьРеквизитыФормыОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вспомогательный API. Инициализировать реквизиты проверки контрагента в форме отчета.
//
// Параметры:
//  Форма	 - ФормаКлиентскогоПриложения - Форма отчета, в котором выполняется проверка контрагентов.
//  ОтчетСРазделами	 - Булево 	- Признак того, что отчет имеет разделы.
Процедура ИнициализироватьРеквизитыФормыОтчета(Форма, ОтчетСРазделами = Ложь) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ИнициализироватьРеквизитыФормыОтчета(Форма, ОтчетСРазделами);
```
</details>

## НоваяТаблицаРазделыОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает новую таблицу разделов отчета.
//
// Возвращаемое значение:
//		ТаблицаЗначений - таблица, содержащая колонки:
//			* НазваниеРаздела 	- Строка - Название раздела отчета.
//			* НомерРаздела 		- Число  - Номер раздела отчета.
//			* ХранилищеОтчета	- ХранилищеЗначения  	- Содержит табличный документ.
//			* ДополнительныеПараметры	- Произвольный  - Содержит дополнительную информацию по разделу.
//
Функция НоваяТаблицаРазделыОтчета() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаКонтрагентов.НоваяТаблицаРазделыОтчета() 
```
</details>

## ДобавитьРазделОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура добавляет новый раздел в отчет.
//
// Параметры:
//  СтруктураПараметров	 - Структура - Параметры формирования отчета.
//		Для проверки контрагентов в отчете важно наличие ключа "ДанныеДляПроверкиКонтрагентов".
//		Данный ключ формируется в процедуре ДобавитьПараметрыДляПроверкиКонтрагентов.
//  НазваниеРаздела		 - Строка 	- Название раздела отчета.
//  НомерРаздела		 - Число 	- Номер раздела отчета.
//  ТабличныйДокумент	 - ТабличныйДокумент - Раздел отчета.
//  ДополнительныеПараметры	 - Произвольный - Дополнительные данные, связанные с разделом отчета.
//
Процедура ДобавитьРазделОтчета(СтруктураПараметров, НазваниеРаздела, НомерРаздела, ТабличныйДокумент, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ДобавитьРазделОтчета(СтруктураПараметров, НазваниеРаздела, НомерРаздела, ТабличныйДокумент, ДополнительныеПараметры);
```
</details>

## РазделыОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает таблицу разделов отчета из результата выполнения фонового задания.
//
// Параметры:
//  РезультатВыполненияЗадания		 - Структура - Результат выполнения фонового задания.
//  ТолькоНекорректныеКонтрагенты	 - Булево	 - Признак вывода только строк с некорректными контрагентами.
//
// Возвращаемое значение:
//  ТаблицаЗначений - Описание разделов отчета.
//
Функция РазделыОтчета(РезультатВыполненияЗадания, ТолькоНекорректныеКонтрагенты = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаКонтрагентов.РазделыОтчета(РезультатВыполненияЗадания, ТолькоНекорректныеКонтрагенты);
```
</details>

## РазделыОтчетаВФорме
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает таблицу разделов отчета для формы.
//
// Параметры:
//  Форма							 - ФормаКлиентскогоПриложения	 - Форма отчета.
//  РезультатВыполненияЗадания		 - Структура, Неопределено	 - Результат выполнения фонового задания.
//  	Если не Неопределено, то результат будет прочитан из временного хранилища.
//  ТолькоНекорректныеКонтрагенты	 - Булево, Неопределено		 - Признак вывода только строк с некорректными контрагентами.
//  		Если Неопределено, то используется настройка формы "ВыведеныВсеСтроки".
//
// Возвращаемое значение:
//  ТаблицаЗначений - Описание разделов отчета.
//
Функция РазделыОтчетаВФорме(Форма, Знач РезультатВыполненияЗадания = Неопределено, Знач ТолькоНекорректныеКонтрагенты = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаКонтрагентов.РазделыОтчетаВФорме(Форма, РезультатВыполненияЗадания, ТолькоНекорректныеКонтрагенты);
```
</details>

## ПриСозданииНаСервереКонтрагент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверка наличия доступа к проверке контрагентов, запуск проверки.
//
// Параметры:
//  Форма		 - ФормаКлиентскогоПриложения	 - Карточка контрагента.
//  Параметры	 - Структура		 - Параметры из процедуры ПриСозданииНаСервере.
//
Процедура ПриСозданииНаСервереКонтрагент(Форма, Параметры) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПриСозданииНаСервереКонтрагент(Форма, Параметры) 
```
</details>

## ПриСозданииНаСервереСписокКонтрагентов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаются параметры динамического списка документов.
//
// Параметры:
//  Список	 - ДинамическийСписок - Список документов.
Процедура ПриСозданииНаСервереСписокКонтрагентов(Список) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПриСозданииНаСервереСписокКонтрагентов(Список) 
```
</details>

## ПередЗаписьюНаСервереКонтрагент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в дополнительные свойства результат проверки контрагента
//	для последующей записи его в регистр в подписке на событие.
//
// Параметры:
//  Форма	 - ФормаКлиентскогоПриложения - Форма карточки контрагента.
//  Объект	 - ДанныеФормыСтруктура - Контрагент-объект.
Процедура ПередЗаписьюНаСервереКонтрагент(Форма, Объект) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ПередЗаписьюНаСервереКонтрагент(Форма, Объект) 
```
</details>

## ИнициализироватьРеквизитыФормыКонтрагент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вспомогательный API. Инициализировать реквизиты проверки контрагента в карточке контрагента.
//
// Параметры:
//  Форма	 - ФормаКлиентскогоПриложения - Карточка контрагента, проверка которого выполняется.
Процедура ИнициализироватьРеквизитыФормыКонтрагент(Форма) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ИнициализироватьРеквизитыФормыКонтрагент(Форма) 
```
</details>

## УдалитьРезультатПроверкиКонтрагентов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вспомогательный API. Позволяет очистить состояния по контрагентам в регистре СостоянияКонтрагентов.
//
// Параметры:
//  Контрагенты - Массив из ОпределяемыйТип.КонтрагентБИП - Массив контрагентов.
//                Если нужно очистить весь регистр, то параметр не указывается.
//
Процедура УдалитьРезультатПроверкиКонтрагентов(Контрагенты = Неопределено) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.УдалитьРезультатПроверкиКонтрагентов(Контрагенты);
```
</details>

## УдалитьРезультатПроверкиКонтрагентовПоДокументам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вспомогательный API. Позволяет очистить регистр ДокументыСОшибкамиПроверкиКонтрагентов.
//
// Параметры:
//  Документы - Массив из ДокументСсылка - Документы, по которым нужно очистить результат проверки.
//		Если нужно очистить весь регистр, то параметр не указывается.
Процедура УдалитьРезультатПроверкиКонтрагентовПоДокументам(Документы = Неопределено) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.УдалитьРезультатПроверкиКонтрагентовПоДокументам(Документы);
```
</details>

## ВключитьВыключитьПроверкуКонтрагентов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Включение или отключение использования сервиса путем установки значения константе
//  ИспользоватьПроверкуКонтрагентов.
//
// Параметры:
//  ВключитьПроверку - Булево - Включить или отключить проверку контрагентов.
//
Процедура ВключитьВыключитьПроверкуКонтрагентов(ВключитьПроверку) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ВключитьВыключитьПроверкуКонтрагентов(ВключитьПроверку) 
```
</details>

## ЗапуститьФоновуюПроверкуКонтрагентовПослеИзмененияНастройкиПриНеобходимости
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запуск проверки контрагентов в фоне после включения проверки.
Процедура ЗапуститьФоновуюПроверкуКонтрагентовПослеИзмененияНастройкиПриНеобходимости() Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.ЗапуститьФоновуюПроверкуКонтрагентовПослеИзмененияНастройкиПриНеобходимости() 
```
</details>

## ПроверкаКонтрагентовВключена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Показывает, включена ли проверка контрагентов.
//
// Возвращаемое значение:
//  Булево - Значение константы ИспользоватьПроверкуКонтрагентов - включена ли проверка контрагентов в базе.
//
Функция ПроверкаКонтрагентовВключена() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаКонтрагентов.ПроверкаКонтрагентовВключена() 
```
</details>

## ЕстьПравоНаИспользованиеПроверки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяем наличие права на использование проверки контрагентов.
//
// Возвращаемое значение:
//  Булево - наличие права на использование проверки контрагентов.
//
Функция ЕстьПравоНаИспользованиеПроверки() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаКонтрагентов.ЕстьПравоНаИспользованиеПроверки() 
```
</details>

## ЕстьПравоНаРедактированиеНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяем наличие права на включение проверки контрагентов.
//
// Возвращаемое значение:
//  Булево - наличие права на включение проверки контрагентов.
//
Функция ЕстьПравоНаРедактированиеНастроек() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаКонтрагентов.ЕстьПравоНаРедактированиеНастроек() 
```
</details>

## ЕстьДоступКВебСервисуФНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет наличие доступа к веб-сервису ФНС.
//
// Возвращаемое значение:
//  Булево - наличие доступа к веб-сервису ФНС.
//
Функция ЕстьДоступКВебСервисуФНС() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаКонтрагентов.ЕстьДоступКВебСервисуФНС() 
```
</details>

## БольшеНеПоказыватьПредложениеПодключиться
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, отказался ли пользователь от использования сервиса в предложении на подключение.
//
// Возвращаемое значение:
//  Булево - пользователь отказался от использования сервиса в предложении на подключение.
//
Функция БольшеНеПоказыватьПредложениеПодключиться() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаКонтрагентов.БольшеНеПоказыватьПредложениеПодключиться() 
```
</details>

## СохранитьДатуПоследнегоОтображенияПредложенияПодключиться
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет дату последнего отображения предложения на использование сервиса.
Процедура СохранитьДатуПоследнегоОтображенияПредложенияПодключиться() Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.СохранитьДатуПоследнегоОтображенияПредложенияПодключиться() 
```
</details>

## УстановитьВидимостьИЗаголовокПредупрежденияПроТестовыйРежим
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Необходимо отказаться от использования данного метода.
// Устанавливает текст и видимость предупреждения про тестовый режим работы сервиса.
//
// Параметры:
//  Элемент - ДекорацияФормы - Элемент, в который выводится информация про тестовый режим работы сервиса.
//
Процедура УстановитьВидимостьИЗаголовокПредупрежденияПроТестовыйРежим(Элемент) Экспорт
```

Пример вызова
```bsl
ПроверкаКонтрагентов.УстановитьВидимостьИЗаголовокПредупрежденияПроТестовыйРежим(Элемент) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
