---
title: Проверка РНПТ
slug: erp-uh/проверка-рнпт
---


## ЕстьПравоНаИспользованиеПроверки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяем наличие права на использование проверки РНПТ.
//
// Возвращаемое значение:
//  Булево - наличие права на использование проверки РНПТ.
//
Функция ЕстьПравоНаИспользованиеПроверки() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаРНПТ.ЕстьПравоНаИспользованиеПроверки() 
```
</details>

## ПроверкаРНПТВключена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Показывает, включена ли проверка РНПТ.
//
// Возвращаемое значение:
//  Булево - Значение константы ИспользоватьПроверкуРНПТ - включена ли проверка РНПТ в базе.
//
Функция ПроверкаРНПТВключена() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаРНПТ.ПроверкаРНПТВключена() 
```
</details>

## ИспользованиеПроверкиВозможно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, что проверка включена и есть необходимые права.
// Возвращаемое значение:
//  Булево - Истина, если есть нужные права на проверку и проверка включена.
//
Функция ИспользованиеПроверкиВозможно() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаРНПТ.ИспользованиеПроверкиВозможно() 
```
</details>

## ЗаписатьСведенияОРНПТИзФНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает в регистр СведенияОРНПТИзФНС сведения о РНПТ.
// Параметры:
//  РНПТСсылка - СправочникСсылка - ссылка на элемент справочника РНПТ
//  СведенияОРНПТ - Структура - см. НовыйСведенияОРНПТ()
//  УдалитьЗапись - Булево - признак того, что запись по РНПТ в регистре нужно удалить
//  ПолучитьСведенияИзСервиса - Булево - признак того, что перед записью в регистр нужно получить сведения из сервиса по РНПТ
//  ТолькоАктуализация - Булево - признак того, что не не нужно добавлять запись в регистр, а нужно только актуализировать текущую, если есть
//
Процедура ЗаписатьСведенияОРНПТИзФНС(РНПТСсылка, СведенияОРНПТ, УдалитьЗапись = Ложь, ПолучитьСведенияИзСервиса = Ложь, ТолькоАктуализация = Ложь) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТ.ЗаписатьСведенияОРНПТИзФНС(РНПТСсылка, СведенияОРНПТ, УдалитьЗапись, ПолучитьСведенияИзСервиса, ТолькоАктуализация);
```
</details>

## ПроверитьРНПТРегламентноеЗадание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура регламентного задания, которая получает сведения по РНПТ из сервиса ФНС
// и проверяет документы с РНПТ к проверке.
//
Процедура ПроверитьРНПТРегламентноеЗадание() Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТ.ПроверитьРНПТРегламентноеЗадание() 
```
</details>

## ПриСозданииНаСервереДокумент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует реквивизиты проверки РНПТ.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа.
//  Параметры - Структура - параметры из процедуры ПриСозданииНаСервере.
//
Процедура ПриСозданииНаСервереДокумент(Форма, Параметры) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТ.ПриСозданииНаСервереДокумент(Форма, Параметры) 
```
</details>

## ОтобразитьРезультатПроверкиРНПТВДокументе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отображает на форме документа результат проверки РНПТ.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа.
//
Процедура ОтобразитьРезультатПроверкиРНПТВДокументе(Форма) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТ.ОтобразитьРезультатПроверкиРНПТВДокументе(Форма) 
```
</details>

## ПроверитьРНПТВДокументеФоновоеЗадание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Фоновое задание проверки РНПТ в документе на соответствие сведениям ФНС.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа.
//
Процедура ПроверитьРНПТВДокументеФоновоеЗадание(Форма) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТ.ПроверитьРНПТВДокументеФоновоеЗадание(Форма) 
```
</details>

## ПроверитьРНПТВДокументе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура, запускаемая в фоне, которая проверяет РНПТ на соответствие сведениям ФНС.
//
// Параметры:
//  Параметры - структура с полями:
//  * ДанныеРНПТ - структура - см. НовыйТаблицаДанныхРНПТ()
//  * АдресХранилища - строка - адрес хранилища, куда будет помещен результат проверки РНПТ
//  * ДокументСсылка - ДокументСсылка - ссылка на проверяемый документ, необязательный, при наличии процедура сохранит результат проверки
//
Процедура ПроверитьРНПТВДокументе(Параметры) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТ.ПроверитьРНПТВДокументе(Параметры) 
```
</details>

## ОтобразитьРезультатПолученияДокументовСОшибками
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Показывает в форме списка баннер с документами в которых есть ошибки проверки РНПТ.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма списка документа.
//
Процедура ОтобразитьРезультатПолученияДокументовСОшибками(Форма) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТ.ОтобразитьРезультатПолученияДокументовСОшибками(Форма) 
```
</details>

## ПроверитьДокументыВСпискеФоновоеЗадание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запускает фоновое задание поиска документов с ошибками для отображения в форме списка.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа.
//  ПараметрыПоиска - Структура с полями:
//    * Организация - СправочникСсылка - ссылка на организацию, по которой происходит поиск
//    * НачалоПериода - Дата - дата начала поиска
//    * КонецПериода - Дата - дата окончания поиска
//    * Контрагент - СправочникСсылка - контрагент по которому происходит поиск (может быть пустой)
//    * НастройкаОтображенияДокументов - Число (0 - все, 1 - с ошибками, 2 - без ошибок)
//    * РежимРасшифровки - Булево - признак, необходимый для получения сведений из отчета "снаружи"
//    * ЭтоВходящийДокумент - Булево - признак того, что нужно отбирать входящие документы
//
Процедура ПроверитьДокументыВСпискеФоновоеЗадание(Форма, ПараметрыПоиска) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТ.ПроверитьДокументыВСпискеФоновоеЗадание(Форма, ПараметрыПоиска) 
```
</details>

## ПослеЗаписиНаСервереДокумент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Перезаполняет результат проверки РНПТ после зписи документа
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа.
//
Процедура ПослеЗаписиНаСервереДокумент(Форма) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТ.ПослеЗаписиНаСервереДокумент(Форма) 
```
</details>

## ПолучитьСписокДокументовСОшибками
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Производит поиск документов с ошибками для отображения в форме списка.
//
// Параметры:
//  ПараметрыПоиска - Структура с полями:
//    * Организация - СправочникСсылка - ссылка на организацию, по которой происходит поиск
//    * НачалоПериода - Дата - дата начала поиска
//    * КонецПериода - Дата - дата окончания поиска
//    * Контрагент - СправочникСсылка - контрагент по которому происходит поиск (может быть пустой)
//    * НастройкаОтображенияДокументов - Число (0 - все, 1 - с ошибками, 2 - без ошибок)
//    * РежимРасшифровки - Булево - признак, необходимый для получения сведений из отчета "снаружи"
//    * ЭтоВходящийДокумент - Булево - признак того, что нужно отбирать входящие документы
//
Процедура ПолучитьСписокДокументовСОшибками(Параметры) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТ.ПолучитьСписокДокументовСОшибками(Параметры) 
```
</details>

## ПриСозданииНаСервереПодборРНПТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует реквивизиты проверки РНПТ и запускает фоновое задание проверки РНПТ.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа.
//  Параметры - Структура - параметры из процедуры ПриСозданииНаСервере.
//
Процедура ПриСозданииНаСервереПодборРНПТ(Форма, Параметры) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТ.ПриСозданииНаСервереПодборРНПТ(Форма, Параметры) 
```
</details>

## ПроверитьРНПТВФормеПодбораФоновоеЗадание
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Фоновое задание проверки РНПТ в документе на соответствие сведениям ФНС.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа.
//  Параметры - Структура с полями:
//    *Номенклатура - СправочникСсылка - ссылка на справочник с проверяемой номенклатурой.
//
Процедура ПроверитьРНПТВФормеПодбораФоновоеЗадание(Форма, Параметры) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТ.ПроверитьРНПТВФормеПодбораФоновоеЗадание(Форма, Параметры) 
```
</details>

## ОтобразитьРезультатПроверкиРНПТВФормеПодбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отображает в форме подбора РНПТ результат проверки РНПТ.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа.
//
Процедура ОтобразитьРезультатПроверкиРНПТВФормеПодбора(Форма) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТ.ОтобразитьРезультатПроверкиРНПТВФормеПодбора(Форма) 
```
</details>

## ПриСозданииНаСервереРНПТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает и выводит на форму сведения о РНПТ из ФНС.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - Карточка РНПТ.
//
Процедура ПриСозданииНаСервереРНПТ(Форма) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТ.ПриСозданииНаСервереРНПТ(Форма) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
