---
title: Проверка РНПТ переопределяемый
slug: erp-uh/проверка-рнпт-переопределяемый
---


## ДокументыСоСтатусомПроверкиРНПТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует таблицу документов со статусами проверки РНПТ в зависимости от переданных параметров поиска.
//
// Параметры:
//  ПараметрыПоиска - Структура с полями:
//    * Организация - СправочникСсылка - ссылка на организацию, по которой происходит поиск
//    * НачалоПериода - Дата - дата начала поиска
//    * КонецПериода - Дата - дата окончания поиска
//    * Контрагент - СправочникСсылка - контрагент по которому происходит поиск (может быть пустой)
//    * НастройкаОтображенияДокументов - Число (0 - все, 1 - с ошибками, 2 - без ошибок)
//    * РежимРасшифровки - Булево - признак, необходимый для получения сведений из отчета "снаружи"
//    * ЭтоВходящийДокумент - Булево - признак того, что нужно отбирать входящие документы
//
// Возвращаемое значение:
//  ТаблицаЗначений - см. текст запроса функции
//
Функция ДокументыСоСтатусомПроверкиРНПТ(ПараметрыПоискаДокументов) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаРНПТПереопределяемый.ДокументыСоСтатусомПроверкиРНПТ(ПараметрыПоискаДокументов) 
```
</details>

## ДобавитьДополнительныеКолонкиДляПроверки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет дополнительные поля для проверки РНПТ.
//
// Параметры:
//  ТаблицаДанныеРНПТ - ТаблицаЗначений - таблица, которую необходимо дополнить реквизитами для проверки
//
Процедура ДобавитьДополнительныеКолонкиДляПроверки(ТаблицаДанныеРНПТ) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТПереопределяемый.ДобавитьДополнительныеКолонкиДляПроверки(ТаблицаДанныеРНПТ) 
```
</details>

## ЗаполнитьДополнительныеКолонкиДляПроверки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет дополнительные поля для проверки нужными значениями
//
// Параметры:
//  ДанныеРНПТ - ТаблицаЗначений - см.ПроверкаРНПТ.НовыйТаблицаДанныхРНПТ()
//  Параметры - ФормаКлиентскогоПриложения или Структура с полями для заполнения дополнительных колонок для проверки.
//
Процедура ЗаполнитьДополнительныеКолонкиДляПроверки(ДанныеРНПТ, Параметры) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТПереопределяемый.ЗаполнитьДополнительныеКолонкиДляПроверки(ДанныеРНПТ, Параметры) 
```
</details>

## ПроверитьДополнительныеКолонки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет дополнительные колонки РНПТ.
//
// Параметры:
//  ПроверяемаяСтрока - Структура - строка с доп. полями по данным документа.
//  ЭталоннаяСтрока - Структура с доп. полями по данным ФНС.
//  ТолькоТекстОшибки - Булево - признак, указывающий, что процедура вызывается только для формирования текста ошибки.
//
Процедура ПроверитьДополнительныеКолонки(ПроверяемаяСтрока, ЭталоннаяСтрока, ТолькоТекстОшибки = Ложь) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТПереопределяемый.ПроверитьДополнительныеКолонки(ПроверяемаяСтрока, ЭталоннаяСтрока, ТолькоТекстОшибки);
```
</details>

## РНПТСоответствуетФормату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет соответствует ли код РНПТ формату.
//
// Параметры:
//  КодРНПТ - Строка - проверяемый код
// Возвращаемое значение:
// Булево - истина если соответствует, ложь если не соответствует.
Функция РНПТСоответствуетФормату(КодРНПТ) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаРНПТПереопределяемый.РНПТСоответствуетФормату(КодРНПТ) 
```
</details>

## ТабличныеЧастиДокументаСПрослеживаемостью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает для документа какие табличные части могут быть с прослеживаемым товаром.
//
// Параметры:
//  ДокументОбъект - проверяемы документ
// Возвращаемое значение:
// Массив - наименование табличных частей с прослеживаемостью
Функция ТабличныеЧастиДокументаСПрослеживаемостью(ДокументОбъект) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаРНПТПереопределяемый.ТабличныеЧастиДокументаСПрослеживаемостью(ДокументОбъект) 
```
</details>

## ТекстЗапросаПроверкиРНПТРегЗаданием
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текст запроса для проверки РНПТ документов регламентным заданием.
//
// Возвращаемое значение:
//  Строка - текст запроса
Функция ТекстЗапросаПроверкиРНПТРегЗаданием() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаРНПТПереопределяемый.ТекстЗапросаПроверкиРНПТРегЗаданием() 
```
</details>

## ПереопределитьТекстЗапросаДляПолученияСведенийОРНПТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Меняет текст запроса для получения сведений о РНПТ из ФНС
// Параметры:
//  Запрос - запрос, текст которого необходимо переопределить.
//
Процедура ПереопределитьТекстЗапросаДляПолученияСведенийОРНПТ(Запрос) Экспорт
```

Пример вызова
```bsl
ПроверкаРНПТПереопределяемый.ПереопределитьТекстЗапросаДляПолученияСведенийОРНПТ(Запрос) 
```
</details>

## ТипСправочникаРНПТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает тип справочника РНПТ.
//
// Возвращаемое значение:
// Тип - тип справочника РНПТ
Функция ТипСправочникаРНПТ() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаРНПТПереопределяемый.ТипСправочникаРНПТ() 
```
</details>

## РНПТПоКоду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Ищет элемент справочника РНПТ по коду.
//
// Параметры:
// КодРНПТ - строка - код РНПТ элемента справочника.
//
// Возвращаемое значение:
//  СправочникСсылка - ссылка на элемент справочника РНПТ
Функция РНПТПоКоду(КодРНПТ) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаРНПТПереопределяемый.РНПТПоКоду(КодРНПТ) 
```
</details>

## ТекстПолученияКодаРНПТВЗапросе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текст запроса для получения кода РНПТ.
//
// Возвращаемое значение:
//  Строка - текст запроса
Функция ТекстПолученияКодаРНПТВЗапросе() Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаРНПТПереопределяемый.ТекстПолученияКодаРНПТВЗапросе() 
```
</details>

## УдалитьПовторяющиесяЭлементыМассива
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет повторяющиеся элементы массива.
//
// Параметры:
//  ОбрабатываемыйМассив - Массив - элементы произвольных типов, из которых удаляются неуникальные.
//
// Возвращаемое значение:
//   Массив      - элементы ОбрабатываемыйМассив после удаления лишних.
//
Функция УдалитьПовторяющиесяЭлементыМассива(ОбрабатываемыйМассив) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаРНПТПереопределяемый.УдалитьПовторяющиесяЭлементыМассива(ОбрабатываемыйМассив) 
```
</details>

## ЕстьПрослеживаемыеТовары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет есть ли прослеживаемые товары в документе
//
// Параметры:
// ДокументОбъект - документ, который требуется проверить
//
// Возвращаемое значение:
// Булево - признак того, что в документе есть прослеживаемые товары
Функция ЕстьПрослеживаемыеТовары(ДокументОбъект) Экспорт
```

Пример вызова
```bsl
Результат = ПроверкаРНПТПереопределяемый.ЕстьПрослеживаемыеТовары(ДокументОбъект) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
