---
title: Продажи вызов сервера
slug: erp-uh/продажи-вызов-сервера
---


## ДатаОтгрузкиПустая
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, есть ли в табличной части строки с незаполненной датой отгрузки в неотмененных строках.
//
// Параметры:
//		Объект - ДанныеФормыСтруктура - проверяемый объект
//		ИмяТЧ - Строка - имя проверяемой ТЧ.
//
// Возвращаемое значение:
//		Булево - признак наличия строк с незаполненной датой отгрузки.
Функция ДатаОтгрузкиПустая(Знач Объект, ИмяТЧ) Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.ДатаОтгрузкиПустая(Объект, ИмяТЧ) 
```
</details>

## МинимальнаяДатаОтгрузкиОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает минимальную дату отгрузки Документа.
//
// Параметры:
//  Объект - ДанныеФормыСтруктура - ЗаказКлиента, ЗаявкаНаВозвратКлиента.
//  ИмяТабличнойЧасти - Строка - Имя табличной части. Значение по-умолчанию - "Товары".
//
// Возвращаемое значение:
//  Дата - Минимальная дата отгрузки документа.
//
Функция МинимальнаяДатаОтгрузкиОбъекта(Знач Объект, ИмяТабличнойЧасти = "Товары") Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.МинимальнаяДатаОтгрузкиОбъекта(Объект, ИмяТабличнойЧасти);
```
</details>

## ПолучитьСостояниеФактическойОтгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает состояние фактической отгрузки по документу
//
// Параметры:
// 		ДокументыОтгрузки - Массив - Ссылки на документы-распоряжения на отгрузку.
//
// Возвращаемое значение:
// 		Структура - Структура с полями "ЕстьОтгруженныеТовары, ЕстьНесобранныеТовары" типа "Булево".
//
Функция ПолучитьСостояниеФактическойОтгрузки(ДокументыОтгрузки) Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.ПолучитьСостояниеФактическойОтгрузки(ДокументыОтгрузки) 
```
</details>

## СформироватьДанныеЗаполненияРеализации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует структуру для создания реализации по одному или нескольким заказам клиентов.
// Если в переданных заказах отличаются реквизиты шапки, выдается сообщение об ошибке.
//
// Параметры:
//  МассивСсылок   - Массив - заказы поставщикам, по которым необходимо ввести реализацию.
//  ИмяДокумента   - Строка - имя документа создаваемого на основании заказов.
//  РеквизитыШапки - Структура - структура, в которую будут помещены реквизиты шапки из массива заказов.
//
// Возвращаемое значение:
//   Булево - Ложь, если в переданных заказах отличаются реквизиты шапки.
//
Функция СформироватьДанныеЗаполненияРеализации(МассивСсылок, ИмяДокумента, РеквизитыШапки) Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.СформироватьДанныеЗаполненияРеализации(МассивСсылок, ИмяДокумента, РеквизитыШапки) 
```
</details>

## СформироватьДанныеЗаполненияАктовВыполненныхРабот
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует структуру для создания выполнения работ по одному или нескольким заказам клиентов
// Если в переданных заказах отличаются реквизиты шапки, выдается сообщение об ошибке.
//
// Параметры:
//  МассивСсылок   - Массив - заказы поставщикам, по которым необходимо ввести реализацию.
//  РеквизитыШапки - Структура - структура, в которую будут помещены реквизиты шапки из массива заказов.
//
// Возвращаемое значение:
//   Булево - Ложь, если в переданных заказах отличаются реквизиты шапки.
//
Функция СформироватьДанныеЗаполненияАктовВыполненныхРабот(МассивСсылок, РеквизитыШапки) Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.СформироватьДанныеЗаполненияАктовВыполненныхРабот(МассивСсылок, РеквизитыШапки) 
```
</details>

## СформироватьДанныеЗаполненияОтчетаДавальцу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТКА

//++ Устарело_Переработка24

// Формирует структуру для создания реализации услуг по переработке по одному или нескольким заказам клиентов
// Если в переданных заказах отличаются реквизиты шапки, выдается сообщение об ошибке.
//
// Параметры:
//  МассивСсылок   - Массив    - заказы поставщикам, по которым необходимо ввести реализацию.
//  РеквизитыШапки - Структура - структура, в которую будут помещены реквизиты шапки из массива заказов.
//
// Возвращаемое значение:
//  Булево - Ложь, если в переданных заказах отличаются реквизиты шапки.
//
Функция СформироватьДанныеЗаполненияОтчетаДавальцу(МассивСсылок, РеквизитыШапки) Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.СформироватьДанныеЗаполненияОтчетаДавальцу(МассивСсылок, РеквизитыШапки) 
```
</details>

## СообщитьОРазличииПолейЗаказаДавальца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СообщитьОРазличииПолейЗаказаДавальца(ПредставлениеПоля, Отказ) Экспорт
```

Пример вызова
```bsl
ПродажиВызовСервера.СообщитьОРазличииПолейЗаказаДавальца(ПредставлениеПоля, Отказ));
```
</details>

## ПерезаполнитьНакладнуюПоОрдерам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
//-- Устарело_Переработка24

//-- НЕ УТКА

// Перезаполняет данные формы накладной по ордерам
//
// Параметры:
// 		ДанныеФормы - ДанныеФормыСтруктура - перезаполняемая накладная.
//
// Возвращаемое значение:
// 		Булево - "Истина", если накладная перезаполнена.
//
Функция ПерезаполнитьНакладнуюПоОрдерам(ДанныеФормы) Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.ПерезаполнитьНакладнуюПоОрдерам(ДанныеФормы) 
```
</details>

## ПолучитьОснованиеДляСчетаНаОплату
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает основание для счета на оплату
//
// Параметры:
//  ДокументОснование	 - ДокументСсылка - Документ основание счета.
//
// Возвращаемое значение:
//  ДокументСсылка, СправочникСсылка.ДоговорыКонтрагентов  - основание.
//
Функция ПолучитьОснованиеДляСчетаНаОплату(ДокументОснование) Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.ПолучитьОснованиеДляСчетаНаОплату(ДокументОснование) 
```
</details>

## СформироватьСтруктуруСпискаДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует структуру списка документов для установки статуса
//
// Параметры:
//  МассивРеализаций - Массив - массив документов.
//
// Возвращаемое значение:
//  Структура - структура возвращаемых параметров.
//
Функция СформироватьСтруктуруСпискаДокументов(МассивРеализаций) Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.СформироватьСтруктуруСпискаДокументов(МассивРеализаций) 
```
</details>

## УстановитьСтатусСоглашенийСКлиентамиДействует
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает статус "Действует" у выделенных в списке соглашений.
//
// Параметры:
//   Соглашения - Число - Количество успешно обработанных соглашений.
//
// Возвращаемое значение:
//   Число - количество соглашений, для которых установлен статус "Действует".
//
Функция УстановитьСтатусСоглашенийСКлиентамиДействует(Знач Соглашения) Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.УстановитьСтатусСоглашенийСКлиентамиДействует(Соглашения) 
```
</details>

## УстановитьСтатусСоглашенийСКлиентамиЗакрыто
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает статус "Закрыто" у выделенных в списке соглашений
//
// Параметры:
//  Соглашения - Массив - массив соглашений с клиентами.
//
// Возвращаемое значение:
//   Число - Количество успешно обработанных соглашений.
//
Функция УстановитьСтатусСоглашенийСКлиентамиЗакрыто(Знач Соглашения) Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.УстановитьСтатусСоглашенийСКлиентамиЗакрыто(Соглашения) 
```
</details>

## ЗаполнитьДанныеВыбораАналитикиРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет данные выбора во время автоподбора аналитики по введенному тексту.
//
// Параметры:
//  ДанныеВыбора - СписокЗначений - Список значений для заполнения.
//  Текст - Строка - Текст, введенный в поле.
//
Процедура ЗаполнитьДанныеВыбораАналитикиРасходов(ДанныеВыбора, Текст) Экспорт
```

Пример вызова
```bsl
ПродажиВызовСервера.ЗаполнитьДанныеВыбораАналитикиРасходов(ДанныеВыбора, Текст) 
```
</details>

## ОформитьНакладнуюНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// По переданным распоряжениям и параметрам формирует структуру таблиц документов
//
// Параметры:
// 		СоответствиеРаспоряжений - см. ПродажиКлиент.ИнициализироватьРаспоряжения
// 		ПараметрыФормирования - см. ПродажиСервер.НовыеПараметрыОформленияКомплектаДокументов
//
// Возвращаемое значение:
// 		см. ПродажиСервер.ОформитьНакладнуюНаСервере
//
Функция ОформитьНакладнуюНаСервере(СоответствиеРаспоряжений, ПараметрыФормирования) Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.ОформитьНакладнуюНаСервере(СоответствиеРаспоряжений, ПараметрыФормирования) 
```
</details>

## ОформитьРядНакладныхПоТаблицамВызов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запускает фоновое задание для формирования документов по переданной структуре
//
// Параметры:
// 	СтруктураПараметров - см. ПродажиСервер.ОформитьРядНакладныхПоТаблицамВызов.СтруктураПараметров
// 	ПараметрыФормирования - см. ПродажиСервер.НовыеПараметрыОформленияКомплектаДокументов
// 	ТекущийНомерПакета - см. ПродажиСервер.ОформитьРядНакладныхПоТаблицамВызов.ТекущийНомерПакета
//
// Возвращаемое значение:
// 	см. ПродажиСервер.ОформитьРядНакладныхПоТаблицамВызов
//
Функция ОформитьРядНакладныхПоТаблицамВызов(СтруктураПараметров, ПараметрыФормирования, ТекущийНомерПакета = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.ОформитьРядНакладныхПоТаблицамВызов(СтруктураПараметров, ПараметрыФормирования, ТекущийНомерПакета);
```
</details>

## ПолучитьПодключенноеОборудование
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу подключенного оборудования в разрезе касс и организаций
//
// Параметры:
// 	СозданныеДокументы - см. ПродажиСервер.ПолучитьПодключенноеОборудование.СозданныеДокументы
// 	ТаблицаОборудования - см. ПродажиСервер.ПолучитьПодключенноеОборудование.ТаблицаОборудования
//
Процедура ПолучитьПодключенноеОборудование(СозданныеДокументы, ТаблицаОборудования) Экспорт
```

Пример вызова
```bsl
ПродажиВызовСервера.ПолучитьПодключенноеОборудование(СозданныеДокументы, ТаблицаОборудования) 
```
</details>

## НовыеПараметрыОформленияКомплектаДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывает функцию-конструктор параметров формирования комплекта документов
//
// Возвращаемое значение:
// 	см. ПродажиСервер.НовыеПараметрыОформленияКомплектаДокументов
//
Функция НовыеПараметрыОформленияКомплектаДокументов() Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.НовыеПараметрыОформленияКомплектаДокументов() 
```
</details>

## ДополнитьСтруктуруРаспоряженийИПараметрыФормирования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет структуру данных по распоряжениям и переданные параметры формирования.
//
// Параметры:
// 		СоответствиеРаспоряжений - см. ПродажиКлиент.ИнициализироватьРаспоряжения
// 		ПараметрыФормирования - см. ПродажиСервер.НовыеПараметрыОформленияКомплектаДокументов
//
Процедура ДополнитьСтруктуруРаспоряженийИПараметрыФормирования(СоответствиеРаспоряжений, ПараметрыФормирования) Экспорт
```

Пример вызова
```bsl
ПродажиВызовСервера.ДополнитьСтруктуруРаспоряженийИПараметрыФормирования(СоответствиеРаспоряжений, ПараметрыФормирования) 
```
</details>

## ПолучитьНастройкуКомплектаДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает из хранилища настроек текущего пользователя параметры формирования комплекта документов
//
// Параметры:
// 	КлючОбъекта - Строка - ключ получаемых настроек
//
// Возвращаемое значение:
// 	см. ПродажиСервер.ПолучитьНастройкуКомплектаДокументов
//
Функция ПолучитьНастройкуКомплектаДокументов(КлючОбъекта) Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.ПолучитьНастройкуКомплектаДокументов(КлючОбъекта) 
```
</details>

## СохранитьНастройкуКомплектаДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет в хранилище настроек текущего пользователя параметры формирования комплекта документов
//
// Параметры:
// 	Настройки - см. ПродажиСервер.СохранитьНастройкуКомплектаДокументов.Настройки
// 	КлючОбъекта - Строка - ключ сохраняемых настроек
//
Процедура СохранитьНастройкуКомплектаДокументов(Настройки, КлючОбъекта) Экспорт
```

Пример вызова
```bsl
ПродажиВызовСервера.СохранитьНастройкуКомплектаДокументов(Настройки, КлючОбъекта) 
```
</details>

## ПрочитатьДанныеИзБезопасногоХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные из безопасного хранилища текущего пользователя по переданным ключам
//
// Параметры:
// 	Ключи - см. ОбщегоНазначения.ПрочитатьДанныеИзБезопасногоХранилища.Ключи
// Возвращаемое значение:
// 	см. ПродажиСервер.ПрочитатьДанныеИзБезопасногоХранилища
//
Функция ПрочитатьДанныеИзБезопасногоХранилища(Ключи) Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.ПрочитатьДанныеИзБезопасногоХранилища(Ключи) 
```
</details>

## ПроверитьДанныеПоОтборуИПартнеру
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает результат проверки партнера в созданном договоре и документе.
//
//Параметры:
//	Договор - СправочникСсылка.ДоговорыКонтрагентов - созданный договор.
//	ДанныеОтбора - Структура - параметры отбора, зависят от документа.
//	ПартнерДокумента - СправочникСсылка.Партнеры - партнер из документа.
//	СообщениеОбОшибке - Строка - формируемое сообщение об ошибке.
//
//Возвращаемое значение:
//	Булево - признак, что проверка прошла.
//
Функция ПроверитьДанныеПоОтборуИПартнеру(Договор, ДанныеОтбора, ПартнерДокумента, СообщениеОбОшибке = "") Экспорт
```

Пример вызова
```bsl
Результат = ПродажиВызовСервера.ПроверитьДанныеПоОтборуИПартнеру(Договор, ДанныеОтбора, ПартнерДокумента, СообщениеОбОшибке);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
