---
title: Производство клиент
slug: erp-uh/производство-клиент
---


## ОткрытьФормуВыбораИсполнителя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму выбора исполнителя трудозатрат в производстве. В зависимости от параметров переданного
// подразделения в форме могут быть выбраны бригады и/или физические лица.
//
// Параметры:
//  Организация			 - СправочникСсылка.Организации - значение для отбора исполнителей.
//  Подразделение		 - СправочникСсылка.СтруктураПредприятия - определяет состав исполнителей, доступных для выбора.
//  Исполнитель			 - СправочникСсылка.Бригады, СправочникСсылка.ФизическиеЛица - используется для позиционирования строки
//							на выбранном ранее значении.
//  Дата				 - Дата - используется для определения режима открытия формы: по сотрудникам или физлицам.
//  ТолькоРаботники		 - Булево - ограничивает выбор бригад.
//  ОписаниеОповещения	 - ОписаниеОповещения - содержит описание процедуры, которая будет вызвана при закрытии формы.
//
Процедура ОткрытьФормуВыбораИсполнителя(Организация, Подразделение, Исполнитель, Дата, ТолькоРаботники = Ложь, ОписаниеОповещения) Экспорт
```

Пример вызова
```bsl
ПроизводствоКлиент.ОткрытьФормуВыбораИсполнителя(Организация, Подразделение, Исполнитель, Дата, ТолькоРаботники, ОписаниеОповещения) 
```
</details>

## ОткрытьФормуВыбораПолучателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму выбора получателя в производстве. В зависимости от типа номенклатуры выбранных строк
// в форме можно выбрать подразделение (структура предприятия) или склад
//
// Параметры:
//  Форма			     - ФормаКлиентскогоПриложения   - Обрабатываемая форма
//  Объект               - ДанныеФормыСтруктура - по типу объекта
//  ПараметрыТЧ		     - Структура          - содержит имена (представление) ТЧ:
//											    ИмяТЧФорма      - имя таблицы формы
//                                              ИмяТЧОбъект     - имя табличной части объекта
//                                              ПредставлениеТЧ - представление табличной части для выводимых текстов
//  ТипыНоменклатуры     - Массив             - массив значений перечисления ТипыНоменклатуры для которых открывается форма,
//                                              если неопределено, тогда ограничения по типам не устанавливается
//  ОписаниеОповещения	 - ОписаниеОповещения - содержит описание процедуры, которая будет вызвана при закрытии формы
//
Процедура ОткрытьФормуВыбораПолучателя(Форма, Объект, ПараметрыТЧ, ТипыНоменклатуры = Неопределено, ОписаниеОповещения) Экспорт
```

Пример вызова
```bsl
ПроизводствоКлиент.ОткрытьФормуВыбораПолучателя(Форма, Объект, ПараметрыТЧ, ТипыНоменклатуры, ОписаниеОповещения) 
```
</details>

## НеобходимоРассчитатьПроцентРаспределенияЗатратНаВыходныеИзделия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция проверяет необходимость обновления процента распределения затрат на выходные изделия.
//
// Параметры:
//  ТабличнаяЧасть				 - ТаблицаФормы	 - таблица формы, отображающая ТЧ;
//  ПараметрыРаспределенияЗатрат - Структура	 - структура параметров расчета, см. ПроизводствоКлиентСервер.ПараметрыРаспределенияЗатратНаВыходныеИзделия
//  КэшированныеЗначения		 - Структура	 - структура кеша реквизитов текущей строки.
//  ДобавлениеУдаление			 - Булево		 - признак, что проверка вызывается при добавлении/удалении строки ТЧ.
//
// Возвращаемое значение:
//  Булево - истина, если нужно ли обновить служебные реквизиты.
//
Функция НеобходимоРассчитатьПроцентРаспределенияЗатратНаВыходныеИзделия(ТабличнаяЧасть, ПараметрыРаспределенияЗатрат, КэшированныеЗначения = Неопределено, ДобавлениеУдаление = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ПроизводствоКлиент.НеобходимоРассчитатьПроцентРаспределенияЗатратНаВыходныеИзделия(ТабличнаяЧасть, ПараметрыРаспределенияЗатрат, КэшированныеЗначения, ДобавлениеУдаление);
```
</details>

## ПроверитьЗаполнениеПередВводомДолиСтоимости
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для проверки заполнения полей перед выполнением команды по вводу доли стоимости.
//
// Параметры:
//  ДанныеСтроки				 - ДанныеФормыСтруктура	 - данные строки, в которой осуществляется ввод доли стоимости.
//  ПараметрыРаспределенияЗатрат - Структура			 - структура параметров расчета, см. ПроизводствоКлиентСервер.ПараметрыРаспределенияЗатратНаВыходныеИзделия
//  ИмяОбъекта					 - Строка				 - имя основного реквизита формы, связанного с редактируемым объектом.
//
// Возвращаемое значение:
//  Булево - истина, если проверка заполнения выполнена успешно, ложь - в противном случае.
//
Функция ПроверитьЗаполнениеПередВводомДолиСтоимости(ДанныеСтроки, ПараметрыРаспределенияЗатрат, ИмяОбъекта = "Объект") Экспорт
```

Пример вызова
```bsl
Результат = ПроизводствоКлиент.ПроверитьЗаполнениеПередВводомДолиСтоимости(ДанныеСтроки, ПараметрыРаспределенияЗатрат, ИмяОбъекта);
```
</details>

## ОформитьПроизводствоБезЗаказаНаОсновании
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Оформить производство без заказа на основании.
//
// Параметры:
//  МассивСсылок - Массив Из ДокументСсылка
//  ПараметрыВыполнения - см. ПодключаемыеКомандыКлиент.ПараметрыВыполненияКоманды
//
Процедура ОформитьПроизводствоБезЗаказаНаОсновании(МассивСсылок, ПараметрыВыполнения) Экспорт
```

Пример вызова
```bsl
ПроизводствоКлиент.ОформитьПроизводствоБезЗаказаНаОсновании(МассивСсылок, ПараметрыВыполнения) 
```
</details>

## ОбработатьСформированныеДокументы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработать сформированные документы производства без заказа.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения
//  Результат - Структура
//  ОповещатьОЗакрытии - Булево - оповещать о закрытии
//  ОписаниеОповещенияОЗакрытии - ОписаниеОповещения - оповещение о закрытии
//
Процедура ОбработатьСформированныеДокументы(Форма, Результат, ОповещатьОЗакрытии = Истина, ОписаниеОповещенияОЗакрытии = Неопределено) Экспорт
```

Пример вызова
```bsl
ПроизводствоКлиент.ОбработатьСформированныеДокументы(Форма, Результат, ОповещатьОЗакрытии, ОписаниеОповещенияОЗакрытии);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
