---
title: Производство клиент сервер
slug: erp-uh/производство-клиент-сервер
---


## ПараметрыРаспределенияЗатратНаВыходныеИзделия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры распределения затрат на выходные изделия.
//
// Параметры:
//  ИмяТЧ	- Строка	- имя табличной части.
//  СпособРаспределенияЗатратНаВыходныеИзделия - ПеречислениеСсылка.СпособыРаспределенияЗатратНаВыходныеИзделия -
//
// Возвращаемое значение:
//		Структура - структура со следующими ключами:
//			*ИмяТЧ - Строка - имя табличной части с выходными изделиями
//			*ЕстьПолеОтменено - Булево - Истина, если в табличной части предусмотрена отмена строк
//			*СпособРаспределенияЗатратНаВыходныеИзделия - ПеречислениеСсылка.СпособыРаспределенияЗатратНаВыходныеИзделия -
//				способ распределения затрат на выходные изделия
//			*ИмяПоляСпособРаспределенияЗатратНаВыходныеИзделия - Строка - Имя поля к способу распределения
//				в табличной части, если в документе предусмотрены разные способы распределения
//			*РассчитыватьПолеДоляСтоимостиПроцент - Булево - Истина, если в табличной части требуется рассчитывать процент
//			*РассчитыватьПризнакЕстьОшибкиЗаполнения - Булево - Истина, если в табличной части предусмотрен индикатор ошибки заполнения
//			*РассчитыватьПризнакДоляСтоимостиОбязательна - Булево - Истина, если требуется рассчитывать обязательность заполнения поля "Доля стоимости"
//			*ПолеГруппировкиЗатрат - Строка - Имя поля, идентифицирующее группировку затрат в рамках документа
//			*ПолеПредставленияГруппировкиЗатрат - Строка - Имя поля заголовка группировки затрат
//			*ДоляСтоимостиДругихДокументовВГруппировке - Число - Доля стоимости других документов,
//				если по одной группировке предусмотрено несколько документов
//			*ПоляСвязи - Строка - Поля идентифицирующие одинаковые позиции в рамках группировки затрат
//				(для одинаковых позиций доля может не указываться, в качестве доли используется количество)
//			*ТолькоПросмотр - Булево - признак того, что доли стоимости в документе можно только просматривать (значение по умолчанию ЛОЖЬ).
//			*ПараметрыЗаполненияЦены- Структура - структура, используемая для заполнения цен в табличной части документа:
//				* Дата - Дата - дата документа.
//				* Валюта - СправочникСсылка.Валюты - валюта документа.
//
//
Функция ПараметрыРаспределенияЗатратНаВыходныеИзделия(ИмяТЧ, СпособРаспределенияЗатратНаВыходныеИзделия) Экспорт
```

Пример вызова
```bsl
Результат = ПроизводствоКлиентСервер.ПараметрыРаспределенияЗатратНаВыходныеИзделия(ИмяТЧ, СпособРаспределенияЗатратНаВыходныеИзделия) 
```
</details>

## РасшифровкаВходящегоОстатка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текст сводной информации о движении материала в цеховой кладовой за отчетный период.
//
// Параметры:
//  Параметры	 - Структура	 - Структура с полями ВходящийОстаток, НачальныйОстаток, Поступило, Передано и ЕдиницаИзмерения.
//
// Возвращаемое значение:
//   - ФорматированнаяСтрока
//
Функция РасшифровкаВходящегоОстатка(Параметры) Экспорт
```

Пример вызова
```bsl
Результат = ПроизводствоКлиентСервер.РасшифровкаВходящегоОстатка(Параметры) 
```
</details>

## ЗаполнитьЗначениеРеквизита
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет значение реквизита в строке ТЧ с зависимости от значения другого реквизита.
//
// Параметры:
//  ДанныеТЧ            - ДанныеФормыКоллекция - Обрабатываемые строки, так же может быть одна строки или массив строк
//	ИмяРеквизита        - Строка               - имя заполняемого реквизитов
//  НастройкиЗаполнения - Соответствие из КлючИЗначение:
//  * Ключ     - Строка - Имя проверяемого реквизита ТЧ
//  * Значение - Соответствие из КлючИЗначение - Ключ: значение проверяемого реквизита
//                                               Значение: значение заполняемого реквизита.
//  ПроверитьЗаполнение - Булево               - Признак установки значение в случаи ее отсутствие
//	Заполнено           - Булево               - Принимает значение Истина при установки значения реквизита хотя бы у
//												 одной строки.
//
Процедура ЗаполнитьЗначениеРеквизита(ДанныеТЧ, ИмяРеквизита, НастройкиЗаполнения, ПроверитьЗаполнение = Ложь, Заполнено = Ложь) Экспорт
```

Пример вызова
```bsl
ПроизводствоКлиентСервер.ЗаполнитьЗначениеРеквизита(ДанныеТЧ, ИмяРеквизита, НастройкиЗаполнения, ПроверитьЗаполнение, Заполнено);
```
</details>

## ПараметрыФормированияДокументовПроизводстваБезЗаказов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры формирования документов производства без заказов, распределения возвратных отходов.
//
// Возвращаемое значение:
//  Структура - Параметры формирования документов производства без заказов:
//  * ИзделияПоСпецификации - Массив из Структура - перечень изделий, выпускаемых по спецификациям.
//  * ИзделияПоПравилу - Массив из Структура - перечень изделий, выпускаемых по правилам.
//  * ЗаполнятьАвтоматически - Булево - признак заполнения затратных частей.
//  * ПереченьДанных - Массив из Строка - перечень таблиц спецификаций.
//  * ОбъектыФормы - Структура - соответствие форм объектов.
//  * ПериодРегистрации - Дата - период регистрации.
//
Функция ПараметрыФормированияДокументовПроизводстваБезЗаказов() Экспорт
```

Пример вызова
```bsl
Результат = ПроизводствоКлиентСервер.ПараметрыФормированияДокументовПроизводстваБезЗаказов() 
```
</details>

## СтруктураСтрокиИзделия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Структура строки изделия.
//
// Возвращаемое значение:
//  Структура - Структура строки изделия:
// * Организация - СправочникСсылка.Организации
// * ГруппировкаЗатрат - ПеречислениеСсылка.ГруппировкиЗатратВПроизводствеБезЗаказа
// * Подразделение - СправочникСсылка.СтруктураПредприятия
// * Получатель - Неопределено
// * Номенклатура - СправочникСсылка.Номенклатура
// * Характеристика - СправочникСсылка.ХарактеристикиНоменклатуры
// * Серия - СправочникСсылка.СерииНоменклатуры
// * Назначение - СправочникСсылка.Назначения
// * НаправлениеДеятельности - СправочникСсылка.НаправленияДеятельности
// * МодельФормированияСтоимости - ПеречислениеСсылка.ТипыМоделейФормированияСтоимости
// * Спецификация - СправочникСсылка.РесурсныеСпецификации
// * ПравилоРаспределения - СправочникСсылка.ПравилаРаспределенияРасходов
// * НаправлениеВыпуска - ПеречислениеСсылка.ХозяйственныеОперации
// * Количество - Число
// * ОтражатьЗатратыДокументом - Булево
// * ОшибкаВНастройкахМодели - Булево
//
Функция СтруктураСтрокиИзделия() Экспорт
```

Пример вызова
```bsl
Результат = ПроизводствоКлиентСервер.СтруктураСтрокиИзделия() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
