---
title: Работа с контрагентами
slug: erp-uh/работа-с-контрагентами
---


## СведенияОЮридическомЛицеПоИНН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о юридическом лице из реестров ЕГРЮЛ, РАФП.
//
// Параметры:
//	ИНН - Строка - ИНН юридического лица.
//
// Возвращаемое значение:
//	- Структура - сведения о юридическом лице:
//	* ИНН - Строка - ИНН юридического лица.
//	* ЕГРЮЛ - Структура, Неопределено - сведения из ЮГРЮЛ. Поля:
//		** КПП - Строка - КПП юридического лица.
//		** Наименование - Строка - представление юридического лица в учетной программе.
//		** НаименованиеПолное - Строка - полное наименование юридического лица.
//		** НаименованиеСокращенное - Строка - сокращенное наименование юридического лица.
//		** НаименованиеПолноеЕГРЮЛ - Строка - полное наименование юридического лица в ЕГРЮЛ.
//		** НаименованиеСокращенноеЕГРЮЛ - Строка - сокращенное наименование юридического лица в ЕГРЮЛ.
//		** НаименованиеПолноеНаАнглийском - Строка - полное наименование юридического лица на английском.
//		** НаименованиеСокращенноеНаАнглийском - Строка - сокращенное наименование юридического лица на английском.
//		** РегистрационныйНомер - Строка - ОГРН юридического лица.
//		** ПравоваяФорма - Строка, Неопределено - правовая форма юридического лица.
//		** Статус - Структура - текущий статус юридического лица.
//			Поля:
//			*** Код - Строка - код статуса;
//			*** Наименование - Строка - наименование статуса;
//		** РегистрирующийОрган - Структура - орган, зарегистрировавший юридическое лицо.
//			Поля:
//			*** Код - Строка - код органа;
//			*** Наименование - Строка - наименование органа;
//		** ЮридическийАдрес - Структура, Неопределено - данные о юридическом адресе.
//			*** КонтактнаяИнформация - Строка - данные в формате JSON для заполнения реквизита
//				"Значение" контактной информации в табличной части КонтактнаяИнформация объекта
//				(см. описание подсистемы "Контактная информация" Библиотеки стандартных подсистем).
//			*** Представление - Строка - представление адреса.
//			*** Комментарий - Строка - произвольный комментарий.
//			*** Корректный - Булево - адрес является корректным по данным ФИАС;
//		** Телефон - Структура, Неопределено - устарел, данные о телефоне.
//			*** КонтактнаяИнформация - Строка - данные в формате JSON для заполнения реквизита
//				"Значение" контактной информации в табличной части КонтактнаяИнформация объекта
//				(см. описание подсистемы "Контактная информация" Библиотеки стандартных подсистем).
//			*** Представление - Строка - представление телефона.
//			*** Комментарий - Строка - произвольный комментарий.
//		** РегистрацияВНалоговомОргане - Структура, Неопределено - данные о регистрации в ИФНС.
//			*** Код - Строка - код налогового органа.
//			*** Наименование - Строка - наименование налогового органа.
//			*** ОКТМО - Строка - код ОКТМО налогового органа.
//			*** ОКАТО - Строка - код ОКАТО налогового органа.
//			*** ДатаРегистрации - Дата - дата постановки на учет в налоговом органе.
//		** ДатаРегистрации - Дата - дата регистрации юридического лица.
//		** ДатаПрекращенияДеятельности - Дата, Неопределено - дата прекращения деятельности юридического лица.
//		** НомерТиповогоУстава - Строка - Номер типового устава юридического лица.
//		** РегистрацияВПенсионномФонде - Структура, Неопределено - данные о регистрации в ПФР.
//			*** РегистрационныйНомерПФР - Строка - регистрационный номер юридического лица в ПФР.
//			*** КодОрганаПФР - Строка - код органа ПФР.
//			*** НаименованиеОрганаПФР - Строка - наименование органа ПФР.
//			*** ДатаРегистрации - Дата - дата постановки на учет в ПФР.
//		** РегистрацияВФСС - Структура, Неопределено - данные о регистрации в ФСС.
//			*** РегистрационныйНомерФСС - Строка - регистрационный номер юридического лица в ФСС.
//			*** КодПодчиненности - Строка - код подчиненности органа ФСС.
//			*** КодОрганаФСС - Строка - код органа ФСС.
//			*** НаименованиеОрганаФСС - Строка - наименование органа ФСС.
//			*** ДатаРегистрации - Дата - дата постановки на учет в ФСС.
//		** Руководители - ТаблицаЗначений - устарело, рекомендуется использовать свойство "ДанныеРуководителей".
//			Сведения о руководителях. Колонки:
//			*** Должность - Строка - должность руководителя.
//			*** Фамилия - Строка - фамилия руководителя.
//			*** Имя - Строка - имя руководителя.
//			*** Отчество - Строка - отчество руководителя.
//			*** Представление - Строка - ФИО руководителя или представление скрытых данных о руководителях.
//			*** ИНН - Строка - ИНН руководителя.
//			*** ДатаЗаписи - Дата - дата записи о руководителе.
//		** ДанныеРуководителей - Структура - сведения о руководителях:
//			*** СкрытыеДанные - Булево - признак скрытых данных о руководителях организации.
//			*** ПредставлениеСкрытыхДанных - Строка - представление скрытых данных о руководителях.
//				Заполняется если СкрытыеДанные = Истина
//			*** Руководители - ТаблицаЗначений - сведения о руководителях. Заполняется если СкрытыеДанные = Ложь. Колонки:
//				**** Должность - Строка - должность руководителя.
//				**** Фамилия - Строка - фамилия руководителя.
//				**** Имя - Строка - имя руководителя.
//				**** Отчество - Строка - отчество руководителя.
//				**** Представление - Строка - ФИО руководителя или представление скрытых данных о руководителях.
//				**** ИНН - Строка - ИНН руководителя.
//				**** ДатаЗаписи - Дата - дата записи о руководителе.
//		** ВидДеятельности - Структура - описание вида экономической деятельности. Поля:
//			*** Код - Строка - код вида деятельности;
//			*** Наименование - Строка- наименование вида деятельности;
//			*** Классификатор - Строка - тип классификатор экономической деятельности, согласно которому указаны код и наименование;
//						   Значения: "ОКВЭД", "ОКВЭД2"
//		** ОткрытыеГосударственныеДанныеФНС - ТаблицаЗначений - открытые данные. Колонки:
//			*** Год - Число - год, за который указаны данные;
//			*** КоличествоСотрудников - Число, Неопределено - количество сотрудников;
//			*** УчастиеВКГН - Строка, Неопределено - участие в консолидированной группе налогоплательщиков;
//			*** НалогообложениеЕСХН, Неопределено - Булево - Истина, если применяется тип налогообложения ЕСХН;
//			*** НалогообложениеУСН, Неопределено - Булево - Истина, если применяется тип налогообложения УСН;
//			*** НалогообложениеЕНВД, Неопределено - Булево - Истина, если применяется тип налогообложения ЕНВД;
//			*** НалогообложениеСРП, Неопределено - Булево - Истина, если применяется тип налогообложения СРП;
//		** ИсторияРеквизитов - Структура - история изменения реквизитов юридического лица.
//			*** КПП - ТаблицаЗначений - история изменения значения реквизита КПП;
//				Колонки:
//				**** Дата - Дата - дата изменения КПП;
//				**** Значение - Строка - значение реквизита КПП;
//			*** Наименование - ТаблицаЗначений - история изменения наименования;
//				Колонки:
//				**** Дата - Дата - дата изменения наименования;
//				**** НаименованиеПолное - Строка - полное наименование юридического лица;
//				**** НаименованиеСокращенное - Строка - сокращенное наименование юридического лица;
//			*** Адрес - ТаблицаЗначений - история изменения адреса;
//				Колонки:
//				**** Дата - Дата - дата изменения адреса;
//				**** КонтактнаяИнформация - Строка - данные в формате JSON для заполнения реквизита
//					"Значение" контактной информации в табличной части КонтактнаяИнформация объекта
//					(см. описание подсистемы "Контактная информация" Библиотеки стандартных подсистем).
//				**** Представление - Строка - представление адреса;
//				**** Комментарий - Строка - произвольный комментарий;
//			*** Статус - ТаблицаЗначений - история изменения статуса;
//				Колонки:
//				**** Дата - Дата - дата изменения наименования;
//				**** Код - Строка - код статуса;
//				**** Наименование - Строка - наименование статуса;
//			*** РеквизитыДиректора - ТаблицаЗначений - история изменения реквизитов директора;
//				Колонки:
//				**** Дата - Дата - дата изменения реквизитов директора;
//				**** ДатаОкончания - Дата - дата окончания действия реквизитов.
//					Пустая дата, если директор действующий;
//				**** ИНН - Строка - ИНН;
//				**** Фамилия - Строка - фамилия директора;
//				**** Имя - Строка - имя;
//				**** Отчество - Строка - отчество;
//				**** ВидДолжности - Строка - вид должности;
//				**** НаименованиеДолжности - Строка - наименование должности;
//	* РАФП - ТаблицаЗначений - сведения из РАФП. Колонки:
//			** КПП - Строка - КПП юридического лица;
//			** ВидОбособленногоПодразделения - Строка - вид обособленного подразделения;
//			** НаименованиеПолное - Строка - полное наименование представительства;
//			** РегистрацияВНалоговомОргане - Структура - информация о регистрации представительства
//														  в налоговом органе.
//				*** Код - Строка - код налогового органа.
//				*** Наименование - Строка - наименование налогового органа.
//				*** ДатаРегистрации - Дата - дата регистрации в налоговом органе;
//			** ЮридическийАдрес - Структура, Неопределено - юридический адрес:
//				*** КонтактнаяИнформация - Строка - данные в формате JSON для заполнения реквизита;
//					"Значение" контактной информации в табличной части КонтактнаяИнформация объекта
//					(см. описание подсистемы "Контактная информация" Библиотеки стандартных подсистем).
//				*** Представление - Строка - представление адреса;
//				*** Комментарий - Строка - произвольный комментарий;
//				*** Корректный - Булево - адрес является корректным по данным ФИАС;
//			** ВидДеятельности - Структура - описание основного вида экономической деятельности. Поля:
//				*** Код - Строка - код вида деятельности;
//				*** Наименование - Строка - наименование вида деятельности;
//				*** Классификатор - Строка - тип классификатор экономической деятельности, согласно которому указаны код и наименование;
//						   Значения: "ОКВЭД", "ОКВЭД2"
//			** ПрочиеВидыДеятельности - ТаблицаЗначений - описание прочих видов экономической деятельности:
//				*** Код - Строка - код вида деятельности;
//				*** Наименование - Строка - наименование вида деятельности;
//				*** Классификатор - Строка - тип классификатор экономической деятельности, согласно которому указаны код и наименование.
//						   Значения: "ОКВЭД", "ОКВЭД2";
//			** КоличествоИностранныхСотрудников - Число - количество иностранных сотрудников в представительстве;
//			** Руководитель - Структура, Неопределено - информация о руководителе:
//				*** Фамилия - Строка - фамилия руководителя;
//				*** Имя - Строка - имя руководителя;
//				*** Отчество - Строка - отчество руководителя;
//				*** Представление - Строка - ФИО руководителя;
//				*** ДатаЗаписи - Дата - дата записи о руководителе;
//			** Аккредитация - Структура - информация об аккредитации представительства. Поля:
//				*** НомерЗаписиОбАккредитации - Строка - номер записи об аккредитации;
//				*** ДатаАккредитации - Дата - дата аккредитации;
//				*** КодУполномоченногоНалоговогоОргана - Строка - код уполномоченного налогового органа,
//					выполнившего аккредитацию представительства;
//				*** НаименованиеУполномоченногоНалоговогоОргана - Строка - наименование уполномоченного налогового органа,
//					выполнившего аккредитацию представительства;
//				*** ДатаОкончанияСрокаАккредитации - Дата - дата окончания срока аккредитации;
//				*** ДатаПродленияАккредитации - Дата - дата принятия решения о продлении срока аккредитации;
//				*** ДатаОкончанияСрокаПродленияАккредитации - Дата - дата окончания срока продления аккредитации;
//			** ИностранноеЮридическоеЛицо - Структура - данные иностранной компании. Поля:
//				*** НаименованиеПолное - Строка - полное наименование иностранного юридического лица;
//				*** КодСтраны - Число - код страны регистрации по ОКСМ;
//				*** Страна - Строка - наименование страны регистрации;
//				*** Адрес - Строка - адрес иностранного юридического лица в стране регистрации;
//				*** УставныйКапитал - Структура - информация об уставном капитале. Поля:
//					**** Размер - Число - размер уставного капитала;
//					**** КодВалюты - Число - код валюты уставного капитала по ОКВ;
//					**** НаименованиеВалюты - Строка - наименование валюты уставного капитала;
//				*** КодНалогоплательщика - Строка - код или аналог кода налогоплательщика иностранного
//											юридического лица в стране регистрации;
//				*** Регистрация - Структура - информация о регистрации в стране регистрации. Поля:
//					**** РегистрационныйНомер - Строка - регистрационный номер;
//					**** НаименованиеОргана - Строка - наименование органа регистрации в стране регистрации;
//					**** ОсобенностиРежимаРегистрации - Строка - описание особенности режима регистрации;
//
//	* ОписаниеОшибки - Строка - описание возникшей ошибки.
//		Для обработки ошибки на клиентской части необходимо использовать метод
//		РаботаСКонтрагентамиКлиент.ОбработатьОшибку.
//
Функция СведенияОЮридическомЛицеПоИНН(Знач ИНН) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКонтрагентами.СведенияОЮридическомЛицеПоИНН(ИНН) 
```
</details>

## РеквизитыПредпринимателяПоИНН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает реквизиты индивидуального предпринимателя по данным ЕГРИП - ФИО, свидетельство о регистрации,
// коды и т.д.
//
// Параметры:
//	ИНН - Строка - ИНН индивидуального предпринимателя, реквизиты которого надо получить.
//
// Возвращаемое значение:
//	- Структура - реквизиты индивидуального предпринимателя.
//		* ИНН - Строка - ИНН предпринимателя.
//		* Наименование - Строка - представление предпринимателя в учетной программе.
//		* НаименованиеПолное - Строка - фамилия, имя, отчество предпринимателя.
//		* НаименованиеСокращенное - Строка - фамилия, имя, отчество предпринимателя.
//		* ВидИП - Строка - вид предпринимателя.
//		* Фамилия - Строка - фамилия предпринимателя.
//		* Имя - Строка - имя предпринимателя.
//		* Отчество - Строка - отчество предпринимателя.
//		* РегистрационныйНомер - Строка - ОГРНИП.
//		* Пол - Строка, Неопределено - "1" - Мужской, "2" - Женский.
//		* КодСтраныГражданства - Строка, Неопределено - код страны.
//		* РегистрацияВНалоговомОргане - Структура, Неопределено - данные о регистрации в ИФНС.
//			** Код - Строка - код налогового органа.
//			** Наименование - Строка - наименование налогового органа.
//			** ОКТМО - Строка - код ОКТМО налогового органа.
//			** ОКАТО - Строка - код ОКАТО налогового органа.
//			** ДатаРегистрации - Дата - дата постановки на учет в налоговом органе.
//		* ДатаРегистрации - Дата - дата регистрации предпринимателя.
//		* РегистрацияВПенсионномФонде - Структура, Неопределено - данные о регистрации в ПФР.
//			** РегистрационныйНомерПФР - Строка - регистрационный номер предпринимателя в ПФР.
//			** КодОрганаПФР - Строка - код органа ПФР.
//			** НаименованиеОрганаПФР - Строка - наименование органа ПФР.
//			** ДатаРегистрации - Дата - дата постановки на учет в ПФР.
//		* РегистрацияВФСС - Структура, Неопределено - данные о регистрации в ФСС.
//			** РегистрационныйНомерФСС - Строка - регистрационный номер предпринимателя в ФСС.
//			** КодПодчиненности - Строка - код подчиненности органа ФСС.
//			** КодОрганаФСС - Строка - код органа ФСС.
//			** НаименованиеОрганаФСС - Строка - наименование органа ФСС.
//			** ДатаРегистрации - Дата - дата постановки на учет в ФСС.
//		* СвидетельствоОРегистрации - Структура, Неопределено - данные свидетельства.
//			** Серия - Строка - серия свидетельства.
//			** Номер - Строка - номер свидетельства.
//			** Дата - Дата - дата выдачи свидетельства.
//		* ВидДеятельности - Структура - описание вида экономической деятельности. Поля:
//			** Код - Строка - код вида деятельности;
//			** Наименование - Строка - наименование вида деятельности;
//			** Классификатор - Строка - тип классификатор экономической деятельности, согласно которому указаны код и наименование;
//							   Значения: "ОКВЭД", "ОКВЭД2"
//		* ИсторияРеквизитов - Структура - история изменения реквизитов предпринимателя.
//			** ФИО - ТаблицаЗначений - история изменения ФИО;
//				Колонки:
//				*** Дата - Дата - дата изменения ФИО;
//				*** Фамилия - Строка - фамилия;
//				*** Имя - Строка - имя;
//				*** Отчество - Строка - отчество;
//			** Гражданство - ТаблицаЗначений - история изменения гражданства;
//				Колонки:
//				*** Дата - Дата - дата изменения гражданства;
//				*** КодСтраныГражданства - Строка, Неопределено - код страны;
//			** ОГРН - ТаблицаЗначений - история изменения ОГРН;
//				Колонки:
//				*** Дата - Дата - дата изменения ОГРН;
//				*** Значение - Строка - значение ОГРН;
//				*** ВидПредпринимателя - Структура - вид предпринимателя.
//					**** Дата - Дата - дата изменения вида предпринимателя;
//					**** Код - Строка - код вида предпринимателя;
//					**** Наименование - Строка - наименование вида предпринимателя;
//				*** Статус - Структура - статус предпринимателя.
//					**** Дата - Дата - дата изменения статуса;
//					**** Код - Строка - код статуса;
//					**** Наименование - Строка - наименование статуса;
//		* ОписаниеОшибки - Строка - описание возникшей ошибки.
//			Для обработки ошибки на клиентской части необходимо использовать метод
//			РаботаСКонтрагентамиКлиент.ОбработатьОшибку.
//		* КодОКВЭД (Устарело) - Строка - устарело, следует использовать ВидДеятельности.Код, код основного
//								вида деятельности по классификатору ОКВЭД.
//		* ЭтоОКВЭД2 (Устарело) - Булево - устарело, следует использовать ВидДеятельности.Классификатор, код ОКВЭД
//								приведен по классификатору редакции 2 или редакции 1.
//
Функция РеквизитыПредпринимателяПоИНН(Знач ИНН) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКонтрагентами.РеквизитыПредпринимателяПоИНН(ИНН) 
```
</details>

## ЮридическиеЛицаПоНаименованию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет поиск юридических лиц по наименованию.
// Возвращаются основные реквизиты юридических лиц по данным ЕГРЮЛ.
// Если найдено больше 20 контрагентов - возвращаются реквизиты только первых 20.
//
// Параметры:
//  Наименование - Строка - одно или несколько слов из наименования юридического лица для поиска в ЕГРЮЛ.
//  КодРегиона - Строка, 2 - код региона в юридическом адресе для поиска в ЕГРЮЛ.
//  Адрес - Строка - одно или несколько слов из юридического адреса (от региона до улицы) для поиска в ЕГРЮЛ.
//
// Возвращаемое значение:
//  Структура - реквизиты найденных юридических лиц. Содержание структуры:
//    *РеквизитыОрганизаций - Массив из Структура - реквизиты найденных контрагентов.
//      См. НовыеРеквизитыЮридическогоЛица.
//    *КоличествоНайденных - Число - общее количество найденных контрагентов (может быть больше 20).
//    *ОжиданиеОтвета - Булево - если возвращается Истина - требуется повторный вызов метода с такими же параметрами.
//    *ОписаниеОшибки - Строка - служебный реквизит.
//        Для обработки ошибки на клиентской части необходимо использовать метод
//        РаботаСКонтрагентамиКлиент.ОбработатьОшибку.
//
Функция ЮридическиеЛицаПоНаименованию(Знач Наименование, Знач КодРегиона = "", Знач Адрес = "") Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКонтрагентами.ЮридическиеЛицаПоНаименованию(Наименование, КодРегиона, Адрес);
```
</details>

## ЮридическиеЛицаПоИНН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет поиск юридических лиц по ИНН.
// Возвращаются основные реквизиты юридических лиц по данным ЕГРЮЛ.
// Если найдено больше 20 контрагентов - возвращаются реквизиты только первых 20.
//
// Параметры:
//  ИНН - Строка - ИНН юридического лица.
//  КодРегиона - Строка, 2 - код региона в юридическом адресе для поиска в ЕГРЮЛ.
//  Адрес - Строка - одно или несколько слов из юридического адреса (от региона до улицы) для поиска в ЕГРЮЛ.
//
// Возвращаемое значение:
//  Структура - реквизиты найденных юридических лиц. Содержание структуры:
//    *РеквизитыОрганизаций - Массив из Структура - реквизиты найденных контрагентов.
//      См. НовыеРеквизитыЮридическогоЛица.
//    *КоличествоНайденных - Число - общее количество найденных контрагентов.
//    *ОжиданиеОтвета - Булево - если возвращается Истина - требуется повторный вызов метода с такими же параметрами.
//    *ОписаниеОшибки - Строка - служебный реквизит.
//        Для обработки ошибки на клиентской части необходимо использовать метод
//        РаботаСКонтрагентамиКлиент.ОбработатьОшибку.
//
Функция ЮридическиеЛицаПоИНН(Знач ИНН, Знач КодРегиона = "", Знач Адрес = "") Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКонтрагентами.ЮридическиеЛицаПоИНН(ИНН, КодРегиона, Адрес);
```
</details>

## ИнформацияОСвязяхЮридическогоЛицаПоИНН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает информацию о связях юридического лица, его руководителей и учредителей
// с другими лицами по данным ЕГРЮЛ.
//
// Параметры:
//	ИНН - Строка - ИНН юридического лица, информацию о связях которого надо получить.
//
// Возвращаемое значение:
//	- Структура - информация о связях юридического лица.
//		Содержит основные данные о юридическом лице - см. РеквизитыЮридическогоЛицаПоИНН.
//		Также содержит данные:
//		* Статус - Структура - текущий статус юридического лица.
//			Поля:
//			** Код - Строка - код статуса;
//			** Наименование - Строка - наименование статуса;
//		* РегистрирующийОрган - Структура - орган, зарегистрировавший юридическое лицо. Поля:
//			** Код - Строка - код органа;
//			** Наименование - Строка - наименование органа;
//		* УставныйКапитал - Число - размер уставного капитала, рублей.
//		* ВидыДеятельности - ТаблицаЗначений - информация о видах деятельности.
//			** Код - Строка - код вида деятельности;
//			** Наименование - Строка - наименование вида деятельности;
//			** Классификатор - Строка - тип классификатор экономической деятельности, согласно которому указаны код и наименование;
//							   Значения: "ОКВЭД", "ОКВЭД2"
//			** КодОКВЭД (устарело) - Строка - код вида деятельности по классификатору ОКВЭД.
//											  Устарело, следует использовать Код.
//			** НаименованиеОКВЭД (устарело) - Строка - наименование вида деятельности по ОКВЭД,
//				сервисом не поставляется, должно заполняться из переопределяемого кода.
//											  Устарело, следует использовать Наименование.
//			** ЭтоОКВЭД2 (устарело) - Булево - код приведен по классификатору редакции 2 или редакции 1.
//											  Устарело, следует использовать Классификатор.
//		* Лицензии - ТаблицаЗначений - данные о полученных лицензиях.
//			** Лицензия - Строка - наименование лицензии.
//			** ОписаниеЛицензии - Строка - подробное описание лицензии.
//		* ЮридическийАдрес - Структура, Неопределено - данные о юридическом адресе.
//			** КонтактнаяИнформация - Строка - данные в формате JSON для заполнения реквизита
//				"Значение" контактной информации в табличной части КонтактнаяИнформация объекта
//				(см. описание подсистемы "Контактная информация" Библиотеки стандартных подсистем).
//			** Представление - Строка - представление адреса.
//			** Комментарий - Строка - произвольный комментарий.
//			** Корректный - Булево - адрес является корректным по данным ФИАС;
//		* ОрганизацииПоАдресу - ТаблицаЗначений - данные об организациях, зарегистрированных по тому же адресу.
//			** НаименованиеОрганизации - Строка - наименование организации.
//			** ИНН - Строка - ИНН организации.
//			** КодСтатуса - Строка - код текущего статуса организации.
//			** НаименованиеСтатуса - Строка - наименование текущего статуса организации.
//		* Руководители - ТаблицаЗначений - устарело, рекомендуется использовать свойство "ДанныеРуководителей".
//			Сведения о руководителях. Колонки:
//			** Должность - Строка - должность руководителя.
//			** Фамилия - Строка - фамилия руководителя.
//			** Имя - Строка - имя руководителя.
//			** Отчество - Строка - отчество руководителя.
//			** Представление - Строка - ФИО руководителя.
//			** ИНН - Строка - ИНН руководителя.
//			** ДатаЗаписи - Дата - дата записи о руководителе.
//			** ОрганизацииГдеРуководитель - ТаблицаЗначений - данные об организациях, где руководитель этой
//				организации также является руководителем. Колонки:
//				*** НаименованиеОрганизации - Строка - наименование организации.
//				*** ИНН - Строка - ИНН организации.
//				*** КодСтатуса - Строка - код текущего статуса организации.
//				*** НаименованиеСтатуса - Строка - наименование текущего статуса организации.
//			** ОрганизацииГдеРуководительПоФИО - Булево - если Истина, поиск проводился по ФИО руководителя, иначе по ИНН.
//			** ОрганизацииГдеУчредитель - ТаблицаЗначений - организации,
//				где руководитель этой организации является учредителем.
//				Колонки:
//				*** НаименованиеОрганизации - Строка - наименование организации.
//				*** ИНН - Строка - ИНН организации.
//				*** КодСтатуса - Строка - код текущего статуса организации.
//				*** НаименованиеСтатуса - Строка - наименование текущего статуса организации.
//				*** ПроцентКапитала - Число - процент в уставном капитале.
//				*** СуммаКапитала - Число - сумма взноса в уставный капитал.
//			** ОрганизацииГдеУчредительПоФИО - Булево - если Истина, поиск проводился по ФИО руководителя, иначе по ИНН.
//		* ДанныеРуководителей - Структура - сведения о руководителях:
//			** СкрытыеДанные - Булево - признак скрытых данных о руководителях организации.
//			** ПредставлениеСкрытыхДанных - Строка - представление скрытых данных о руководителях.
//				Заполняется если СкрытыеДанные = Истина
//			** Руководители - ТаблицаЗначений - сведения о руководителях. Заполняется если СкрытыеДанные = Ложь. Колонки:
//				*** Должность - Строка - должность руководителя.
//				*** Фамилия - Строка - фамилия руководителя.
//				*** Имя - Строка - имя руководителя.
//				*** Отчество - Строка - отчество руководителя.
//				*** Представление - Строка - ФИО руководителя или представление скрытых данных о руководителях.
//				*** ИНН - Строка - ИНН руководителя.
//				*** ДатаЗаписи - Дата - дата записи о руководителе.
//				*** ОрганизацииГдеРуководитель - ТаблицаЗначений - данные об организациях, где руководитель этой
//					 организации также является руководителем. Колонки:
//					**** НаименованиеОрганизации - Строка - наименование организации.
//					**** ИНН - Строка - ИНН организации.
//					**** КодСтатуса - Строка - код текущего статуса организации.
//					**** НаименованиеСтатуса - Строка - наименование текущего статуса организации.
//				*** ОрганизацииГдеРуководительПоФИО - Булево - если Истина, поиск проводился по ФИО руководителя, иначе по ИНН.
//				*** ОрганизацииГдеУчредитель - ТаблицаЗначений - организации,
//					 где руководитель этой организации является учредителем. Колонки:
//					**** НаименованиеОрганизации - Строка - наименование организации.
//					**** ИНН - Строка - ИНН организации.
//					**** КодСтатуса - Строка - код текущего статуса организации.
//					**** НаименованиеСтатуса - Строка - наименование текущего статуса организации.
//					**** ПроцентКапитала - Число - процент в уставном капитале.
//					**** СуммаКапитала - Число - сумма взноса в уставный капитал.
//				*** ОрганизацииГдеУчредительПоФИО - Булево - если Истина, поиск проводился по ФИО руководителя, иначе по ИНН.
//		* УчрежденныеФирмы - ТаблицаЗначений - организации, где эта организация является учредителем.
//			** НаименованиеОрганизации - Строка - наименование организации.
//			** ИНН - Строка - ИНН организации.
//			** КодСтатуса - Строка - код текущего статуса организации.
//			** НаименованиеСтатуса - Строка - наименование текущего статуса организации.
//			** ПроцентКапитала - Число - процент в уставном капитале.
//			** СуммаКапитала - Число - сумма взноса в уставный капитал.
//		* Учредители - ТаблицаЗначений - устарело, рекомендуется использовать свойство "ДанныеУчредителей".
//			Учредители этой организации.
//			** Учредитель - Строка - ФИО или наименование учредителя.
//			** ИНН - Строка - ИНН учредителя.
//			** ПроцентКапитала - Число - процент в уставном капитале.
//			** СуммаКапитала - Число - сумма взноса в уставный капитал.
//			** ОрганизацииГдеРуководитель - ТаблицаЗначений - данные об организациях, где этот учредитель является руководителем.
//				*** НаименованиеОрганизации - Строка - наименование организации.
//				*** ИНН - Строка - ИНН организации.
//				*** КодСтатуса - Строка - код текущего статуса организации.
//				*** НаименованиеСтатуса - Строка - наименование текущего статуса организации.
//			** ОрганизацииГдеРуководительПоФИО - Булево - если Истина, поиск проводился по ФИО учредителя, иначе по ИНН.
//			** ОрганизацииГдеУчредитель - ТаблицаЗначений - организации, где этот учредитель также является учредителем.
//				*** НаименованиеОрганизации - Строка - наименование организации.
//				*** ИНН - Строка - ИНН организации.
//				*** КодСтатуса - Строка - код текущего статуса организации.
//				*** НаименованиеСтатуса - Строка - наименование текущего статуса организации.
//				*** ПроцентКапитала - Число - процент в уставном капитале.
//				*** СуммаКапитала - Число - сумма взноса в уставный капитал.
//			** ОрганизацииГдеУчредительПоФИО - Булево - если Истина, поиск проводился по ФИО учредителя, иначе по ИНН.
//		* ДанныеУчредителей - Структура - сведения о руководителях:
//			** СкрытыеДанные - Булево - признак скрытых данных об учредителях организации.
//			** ПредставлениеСкрытыхДанных - Строка - представление скрытых данных об учредителях.
//				Заполняется если СкрытыеДанные = Истина
//			** Учредители - ТаблицаЗначений - учредители этой организации.
//				*** Учредитель - Строка - ФИО или наименование учредителя.
//				*** ИНН - Строка - ИНН учредителя.
//				*** ПроцентКапитала - Число - процент в уставном капитале.
//				*** СуммаКапитала - Число - сумма взноса в уставный капитал.
//				*** ОрганизацииГдеРуководитель - ТаблицаЗначений - данные об организациях, где этот учредитель является руководителем.
//					**** НаименованиеОрганизации - Строка - наименование организации.
//					**** ИНН - Строка - ИНН организации.
//					**** КодСтатуса - Строка - код текущего статуса организации.
//					**** НаименованиеСтатуса - Строка - наименование текущего статуса организации.
//				*** ОрганизацииГдеРуководительПоФИО - Булево - если Истина, поиск проводился по ФИО учредителя, иначе по ИНН.
//				*** ОрганизацииГдеУчредитель - ТаблицаЗначений - организации, где этот учредитель также является учредителем.
//					**** НаименованиеОрганизации - Строка - наименование организации.
//					**** ИНН - Строка - ИНН организации.
//					**** КодСтатуса - Строка - код текущего статуса организации.
//					**** НаименованиеСтатуса - Строка - наименование текущего статуса организации.
//					**** ПроцентКапитала - Число - процент в уставном капитале.
//					**** СуммаКапитала - Число - сумма взноса в уставный капитал.
//				*** ОрганизацииГдеУчредительПоФИО - Булево - если Истина, поиск проводился по ФИО учредителя, иначе по ИНН.
//		* Подразделения - ТаблицаЗначений - филиалы и представительства юридического лица, указанные в Уставе.
//			** ОписаниеПодразделения - Строка - наименование подразделения.
//		* ИзмененияВРеестре - ТаблицаЗначений - данные об изменениях в ЕГРЮЛ по этому лицу.
//			** ДатаИзменения - Дата - дата внесения изменения.
//			** ГосударственныйОрган - Строка - орган, который внес изменение.
//			** ОписаниеИзменения - Строка - описание изменения.
//		* БухгалтерскаяОтчетность - ТаблицаЗначений - данные бухгалтерской отчетности, сданной в органы Росстата.
//			** Год - Число - год, за который была сдана отчетность.
//			** КодВалютыОтчетности - Строка - в рублях, в тысячах или в миллионах рублей.
//			** ТипОтчетности - Строка - обычная отчетность, упрощенная или отчетность НКО.
//			** Показатели - ТаблицаЗначений - показатели бухгалтерской отчетности.
//				*** Код - Строка - код показателя отчетности.
//				*** Значение - Число - значение показателя отчетности.
//		* ОткрытыеГосударственныеДанныеФНС - ТаблицаЗначений - открытые данные. Колонки:
//			** Год - Число - год, за который указаны данные;
//			** КоличествоСотрудников - Число, Неопределено - количество сотрудников;
//			** СуммаДоходов - Число, Неопределено - сумма доходов;
//			** СуммаРасходов - Число, Неопределено - сумма расходов;
//			** УчастиеВКГН - Строка - участия в консолидированной группе налогоплательщиков;
//			** НалогообложениеЕСХН - Булево, Неопределено - Истина, если применяется тип налогообложения ЕСХН;
//			** НалогообложениеУСН - Булево, Неопределено - Истина, если применяется тип налогообложения УСН;
//			** НалогообложениеЕНВД - Булево, Неопределено - Истина, если применяется тип налогообложения ЕНВД;
//			** НалогообложениеСРП - Булево, Неопределено - Истина, если применяется тип налогообложения СРП;
//			** СведенияОНалогах - ТаблицаЗначений - сведения о налогах. Колонки:
//				*** Наименование - Строка - наименование налога;
//				*** Уплачено - Число, Неопределено - сумма уплаченного налога. Неопределено - нет данных;
//				*** Задолженность - Число, Неопределено - сумма задолженности по налогу. Неопределено - нет данных;
//				*** Штраф - Число, Неопределено - сумма штрафа по налогу. Неопределено - нет данных;
//				*** Пени - Число, Неопределено - сумма пеней по налогу. Неопределено - нет данных;
//		* ИсторияРеквизитов - Структура - история изменения реквизитов юридического лица.
//			** КПП - ТаблицаЗначений - история изменения значения реквизита КПП;
//				Колонки:
//				*** Дата - Дата - дата изменения КПП;
//				*** Значение - Строка - значение реквизита КПП;
//			** Наименование - ТаблицаЗначений - история изменения наименования;
//				Колонки:
//				*** Дата - Дата - дата изменения наименования;
//				*** НаименованиеПолное - Строка - полное наименование юридического лица;
//				*** НаименованиеСокращенное - Строка - сокращенное наименование юридического лица;
//			** Адрес - ТаблицаЗначений - история изменения адреса;
//				Колонки:
//				*** Дата - Дата - дата изменения адреса;
//				*** КонтактнаяИнформация - Строка - данные в формате JSON для заполнения реквизита
//					"Значение" контактной информации в табличной части КонтактнаяИнформация объекта
//					(см. описание подсистемы "Контактная информация" Библиотеки стандартных подсистем).
//				*** Представление - Строка - представление адреса;
//				*** Комментарий - Строка - произвольный комментарий;
//			** Статус - ТаблицаЗначений - история изменения статуса;
//				Колонки:
//				*** Дата - Дата - дата изменения наименования;
//				*** Код - Строка - код статуса;
//				*** Наименование - Строка - наименование статуса;
//			** РеквизитыДиректора - ТаблицаЗначений - история изменения реквизитов директора;
//				Колонки:
//				*** Дата - Дата - дата изменения реквизитов директора;
//				*** ДатаОкончания - Дата - дата окончания действия реквизитов.
//					Пустая дата, если директор действующий;
//				*** ИНН - Строка - ИНН;
//				*** Фамилия - Строка - фамилия директора;
//				*** Имя - Строка - имя;
//				*** Отчество - Строка - отчество;
//				*** ВидДолжности - Строка - вид должности;
//				*** НаименованиеДолжности - Строка - наименование должности;
//		* ОрганизацииГдеРуководитель (Устарело) - ТаблицаЗначений - данные об организациях, где руководитель этой организации также является руководителем.
//			Устарело, следует использовать Руководители[0].ОрганизацииГдеРуководитель
//			** НаименованиеОрганизации - Строка - наименование организации.
//			** ИНН - Строка - ИНН организации.
//			** КодСтатуса - Строка - код текущего статуса организации.
//			** НаименованиеСтатуса - Строка - наименование текущего статуса организации.
//		* ОрганизацииГдеРуководительПоФИО (Устарело) - Булево - если Истина, поиск проводился по ФИО руководителя, иначе по ИНН.
//			Устарело, следует использовать Руководители[0].ОрганизацииГдеРуководительПоФИО.
//		* ОрганизацииГдеУчредитель (Устарело) - ТаблицаЗначений - организации, где руководитель этой организации является учредителем.
//			Устарело, следует использовать Руководители[0].ОрганизацииГдеУчредитель.
//			** НаименованиеОрганизации - Строка - наименование организации.
//			** ИНН - Строка - ИНН организации.
//			** КодСтатуса - Строка - код текущего статуса организации.
//			** НаименованиеСтатуса - Строка - наименование текущего статуса организации.
//			** ПроцентКапитала - Число - процент в уставном капитале.
//			** СуммаКапитала - Число - сумма взноса в уставный капитал.
//		* ОрганизацииГдеУчредительПоФИО (Устарело) - Булево - если Истина, поиск проводился по ФИО руководителя, иначе по ИНН.
//			Устарело, следует использовать Руководители[0].ОрганизацииГдеУчредительПоФИО.
//		* ОжиданиеОтвета - Булево - если возвращается Истина - требуется повторный вызов метода с этими же параметрами.
//		* ОписаниеОшибки - Строка - служебный реквизит.
//			Для обработки ошибки на клиентской части необходимо использовать метод
//			РаботаСКонтрагентамиКлиент.ОбработатьОшибку;
//		* НаименованиеСтатуса - Строка - устарело, необходимо использовать Статус.Наименование - наименование текущего статуса;
//		* КодСтатуса - Строка - устарело, необходимо использовать Статус.Код - код текущего статуса.
//
Функция ИнформацияОСвязяхЮридическогоЛицаПоИНН(Знач ИНН) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКонтрагентами.ИнформацияОСвязяхЮридическогоЛицаПоИНН(ИНН) 
```
</details>

## ИнформацияОСвязяхПредпринимателяПоИНН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращается информация о связях индивидуального предпринимателя с другими лицами по данным ЕГРЮЛ и ЕГРИП.
//
// Параметры:
//	ИНН - Строка - ИНН индивидуального предпринимателя, информацию о связях которого надо получить.
//
// Возвращаемое значение:
//	- Структура - информация о связях индивидуального предпринимателя.
//		Содержит основные данные о предпринимателе - см. РеквизитыПредпринимателяПоИНН.
//		Также содержит данные:
//		* Статус - Структура - текущий статус предпринимателя.
//			Поля:
//			** Код - Строка - код статуса;
//			** Наименование - Строка - наименование статуса;
//		* УставныйКапитал - Число - размер уставного капитала, рублей.
//		* ВидыДеятельности - ТаблицаЗначений - информация о видах деятельности.
//			** Код - Строка - код вида деятельности;
//			** Наименование - Строка - наименование вида деятельности;
//			** Классификатор - Строка - тип классификатор экономической деятельности, согласно которому указаны код и наименование;
//							   Значения: "ОКВЭД", "ОКВЭД2"
//			** КодОКВЭД (устарело) - Строка - код вида деятельности по классификатору ОКВЭД.
//											  Устарело, следует использовать Код.
//			** НаименованиеОКВЭД (устарело) - Строка - наименование вида деятельности по ОКВЭД,
//				сервисом не поставляется, должно заполняться из переопределяемого кода.
//											  Устарело, следует использовать Наименование.
//			** ЭтоОКВЭД2 (устарело) - Булево - код приведен по классификатору редакции 2 или редакции 1.
//											  Устарело, следует использовать Классификатор.
//		* Лицензии - ТаблицаЗначений - данные о полученных лицензиях.
//			** Лицензия - Строка - наименование лицензии.
//			** ОписаниеЛицензии - Строка - подробное описание лицензии.
//		* ОрганизацииГдеРуководитель - ТаблицаЗначений - данные об организациях, где этот предприниматель является руководителем.
//			** НаименованиеОрганизации - Строка - наименование организации.
//			** ИНН - Строка - ИНН организации.
//			** КодСтатуса - Строка - код текущего статуса организации.
//			** НаименованиеСтатуса - Строка - наименование текущего статуса организации.
//		* ОрганизацииГдеРуководительПоФИО - Булево - если Истина, поиск проводился по ФИО предпринимателя, иначе по ИНН.
//		* ОрганизацииГдеУчредитель - ТаблицаЗначений - организации, где этот предприниматель является учредителем.
//			** НаименованиеОрганизации - Строка - наименование организации.
//			** ИНН - Строка - ИНН организации.
//			** КодСтатуса - Строка - код текущего статуса организации.
//			** НаименованиеСтатуса - Строка - наименование текущего статуса организации.
//			** ПроцентКапитала - Число - процент в уставном капитале.
//			** СуммаКапитала - Число - сумма взноса в уставный капитал.
//		* ОрганизацииГдеУчредительПоФИО - Булево - если Истина, поиск проводился по ФИО предпринимателя, иначе по ИНН.
//		* ИзмененияВРеестре - ТаблицаЗначений - данные об изменениях в ЕГРИП по этому лицу.
//			** ДатаИзменения - Дата - дата внесения изменения.
//			** ГосударственныйОрган - Строка - орган, который внес изменение.
//			** ОписаниеИзменения - Строка - описание изменения;
//		* ИсторияРеквизитов - Структура - история изменения реквизитов предпринимателя.
//			** ФИО - ТаблицаЗначений - история изменения ФИО;
//				Колонки:
//				*** Дата - Дата - дата изменения ФИО;
//				*** Фамилия - Строка - фамилия;
//				*** Имя - Строка - имя;
//				*** Отчество - Строка - отчество;
//			** Гражданство - ТаблицаЗначений - история изменения гражданства;
//				Колонки:
//				*** Дата - Дата - дата изменения гражданства;
//				*** КодСтраныГражданства - Строка, Неопределено - код страны;
//			** ОГРН - ТаблицаЗначений - история изменения ОГРН;
//				Колонки:
//				*** Дата - Дата - дата изменения ОГРН;
//				*** Значение - Строка - значение ОГРН;
//				*** ВидПредпринимателя - Структура - вид предпринимателя.
//					**** Дата - Дата - дата изменения вида предпринимателя;
//					**** Код - Строка - код вида предпринимателя;
//					**** Наименование - Строка - наименование вида предпринимателя;
//				*** Статус - Структура - статус предпринимателя.
//					**** Дата - Дата - дата изменения статуса;
//					**** Код - Строка - код статуса;
//					**** Наименование - Строка - наименование статуса;
//		* ОжиданиеОтвета - Булево - если возвращается Истина - требуется повторный вызов метода с этими же параметрами.
//		* ОписаниеОшибки - Строка - служебный реквизит.
//			Для обработки ошибки на клиентской части необходимо использовать метод
//			РаботаСКонтрагентамиКлиент.ОбработатьОшибку.
//		* КодСтатуса - Строка - устарело, необходимо использовать Статус.Код - код текущего статуса.
//
Функция ИнформацияОСвязяхПредпринимателяПоИНН(Знач ИНН) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКонтрагентами.ИнформацияОСвязяхПредпринимателяПоИНН(ИНН) 
```
</details>

## ИнформацияОПроверкахКонтролирующимиОрганамиПоСпискуИНН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает информацию о проверках юридических лиц и предпринимателей
// контролирующими органами по открытым данным единого реестра проверок.
//
// Параметры:
//	СписокИНН - Массив из Строка - ИНН юридических лиц и/или предпринимателей,
//		информацию о проверках которых необходимо получить.
//		Допустимое количество элементов - не более 1000.
//		При превышении допустимого количества вызывается исключение;
//	Плановые - Булево - требуется ли информация о плановых проверках;
//	Внеплановые - Булево - требуется ли информация о внеплановых проверках;
//	Завершенные - Булево - требуется ли информация о завершенных
//		проверках (плановых и внеплановых), по которым уже известен результат.
//	Незавершенные - Булево - требуется ли информация о незавершенных
//		проверках (плановых и внеплановых), результат по которым неизвестен;
//
// Возвращаемое значение:
//	- Структура - результат получения информации о проверках.
//	* Проверки - Соответствие - информация о проверках:
//		** Ключ - Строка - ИНН;
//		** Значение - ТаблицаЗначений - информация о проверках юридического лица
//			или предпринимателя с указанным ИНН.
//			Колонки таблицы:
//			*** Идентификатор - Строка - идентификатор проверки в едином реестре проверок;
//			*** ПлановаяПроверка - Булево - плановая проверка или внеплановая;
//			*** ПериодПроверки - Дата - месяц, в котором проводится проверка;
//			*** ДатаПроверки - Дата - дата начала проверки;
//			*** КонтролирующийОрган - Строка - орган, который проводит проверку;
//			*** АдресПроверки - Строка - адрес, по которому проводится проверка;
//			*** ЦельПроверки - Строка - с какой целью проводится проверка;
//			*** Длительность - Строка - длительность проверки;
//			*** Результат - Строка - описание результата проверки;
//			*** Нарушения - ТаблицаЗначений - найденные нарушения;
//				**** НомерНарушения - Число - номер по порядку;
//				**** Нарушение - Строка - описание нарушения;
//				**** НарушенныйАкт - Строка - нарушенный нормативный акт;
//				**** Предписание - Строка - выданное предписание о необходимости устранении нарушения;
//				**** Исполнение - Строка - информация об устранении нарушения;
//	* ОжиданиеОтвета - Булево - если возвращается Истина - требуется повторный
//		вызов метода с этими же параметрами;
//	* ОписаниеОшибки - Строка - служебный реквизит.
//		Для обработки ошибки на клиентской части необходимо использовать метод
//		РаботаСКонтрагентамиКлиент.ОбработатьОшибку.
//
Функция ИнформацияОПроверкахКонтролирующимиОрганамиПоСпискуИНН( Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКонтрагентами.ИнформацияОПроверкахКонтролирующимиОрганамиПоСпискуИНН();
```
</details>

## НаличиеПодразделенийПоИНН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о наличии подразделений у юридического лица.
//
// Параметры:
//  ИНН - Строка - ИНН юридического лица.
//
// Возвращаемое значение:
//  Структура - сведения о юридическом лице:
//    *ЕстьПодразделения - Булево - есть подразделения.
//    *ОписаниеОшибки - Строка - служебный реквизит.
//      Для обработки ошибки на клиентской части необходимо использовать метод
//      РаботаСКонтрагентамиКлиент.ОбработатьОшибку.
//
Функция НаличиеПодразделенийПоИНН(ИНН) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКонтрагентами.НаличиеПодразделенийПоИНН(ИНН) 
```
</details>

## ИнформацияОПодразделенииЮридическогоЛицаПоУникальномуНомеру
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о подразделении юридического лица по идентификатору.
//
// Параметры:
//  УникальныйНомер - Число - уникальный номер подразделения юридического лица,
//                            полученный в методах ЮридическиеЛицаПоНаименованию и ЮридическиеЛицаПоИНН
//
// Возвращаемое значение:
//  Структура - сведения о подразделении:
//    *ИНН - Строка - ИНН юридического лица.
//    *ЕГРЮЛ - Структура, Неопределено - сведения из ЮГРЮЛ. Поля:
//      **ИНН - Строка - ИНН юридического лица.
//      **КПП - Строка - КПП юридического лица.
//      **Наименование - Строка - представление юридического лица в учетной программе.
//      **РегистрационныйНомер - Строка - ОГРН юридического лица.
//      **ЮридическийАдрес - Структура, Неопределено - данные о юридическом адресе.
//        ***КонтактнаяИнформация - Строка - данные в формате JSON для заполнения реквизита
//              "Значение" контактной информации в табличной части КонтактнаяИнформация объекта
//              (см. описание подсистемы "Контактная информация" Библиотеки стандартных подсистем).
//        ***Представление - Строка - представление адреса.
//        ***Комментарий - Строка - произвольный комментарий.
//        ***Корректный - Булево - адрес является корректным по данным ФИАС;
//      **ВидДеятельности - Структура - описание вида экономической деятельности. Поля:
//        ***Код - Строка - код вида деятельности;
//        ***Наименование - Строка- наименование вида деятельности;
//    *ОписаниеОшибки - Строка - служебный реквизит.
//          Для обработки ошибки на клиентской части необходимо использовать метод
//          РаботаСКонтрагентамиКлиент.ОбработатьОшибку.
//
Функция ИнформацияОПодразделенииЮридическогоЛицаПоУникальномуНомеру(УникальныйНомер) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКонтрагентами.ИнформацияОПодразделенииЮридическогоЛицаПоУникальномуНомеру(УникальныйНомер) 
```
</details>

## ИнформацияОПодразделенииЮридическогоЛицаПоИННКПП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о подразделении юридического лица по ИНН и КПП.
//
// Параметры:
//  ИНН - Строка - ИНН юридического лица.
//  КПП - Строка - КПП юридического лица.
//
// Возвращаемое значение:
//  Структура - сведения о подразделении:
//    *ИНН - Строка - ИНН юридического лица.
//    *ЕГРЮЛ - Структура, Неопределено - сведения из ЮГРЮЛ. Поля:
//      **ИНН - Строка - ИНН юридического лица.
//      **КПП - Строка - КПП юридического лица.
//      **Наименование - Строка - представление юридического лица в учетной программе.
//      **РегистрационныйНомер - Строка - ОГРН юридического лица.
//      **ЮридическийАдрес - Структура, Неопределено - данные о юридическом адресе.
//        ***КонтактнаяИнформация - Строка - данные в формате JSON для заполнения реквизита
//              "Значение" контактной информации в табличной части КонтактнаяИнформация объекта
//              (см. описание подсистемы "Контактная информация" Библиотеки стандартных подсистем).
//        ***Представление - Строка - представление адреса.
//        ***Комментарий - Строка - произвольный комментарий.
//        ***Корректный - Булево - адрес является корректным по данным ФИАС;
//      **ВидДеятельности - Структура - описание вида экономической деятельности. Поля:
//        ***Код - Строка - код вида деятельности;
//        ***Наименование - Строка- наименование вида деятельности;
//    *ОписаниеОшибки - Строка - служебный реквизит.
//          Для обработки ошибки на клиентской части необходимо использовать метод
//          РаботаСКонтрагентамиКлиент.ОбработатьОшибку.
//
Функция ИнформацияОПодразделенииЮридическогоЛицаПоИННКПП(ИНН, КПП) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКонтрагентами.ИнформацияОПодразделенииЮридическогоЛицаПоИННКПП(ИНН, КПП) 
```
</details>

## РеквизитыНалоговогоОрганаПоКоду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращаются реквизиты налоговой инспекции по коду.
//
// Параметры:
//	КодНалоговогоОргана - Строка - код налогового органа.
//
// Возвращаемое значение:
//	- Структура - реквизиты налоговой инспекции.
//		* Код - Строка - код государственного органа;
//		* ИНН - Строка - ИНН;
//		* КПП - Строка - КПП;
//		* Наименование - Строка - наименование государственного органа;
//		* ПолноеНаименование - Строка - полное наименование государственного органа;
//		* Адрес - Строка - Юридический адрес;
//		* Телефон - Строка - Телефон;
//		* ЭлектроннаяПочта - Строка - адрес электронной почты;
//		* ИнтернетСайт - Строка - URL сайта государственного органа;
//		* ПлатежныеРеквизиты - Структура - платежные реквизиты налогового органа:
//			** ПолучательПлатежа - Строка - получатель платежа;
//			** РасчетныйСчет - Строка - расчетный счет;
//			** КоррСчет - Строка - корреспондентский счет;
//			** БИК - Строка - БИК банка;
//		* РегистрирующийОрганИП - Структура, Неопределено - реквизиты регистрирующего
//			органа индивидуальных предпринимателей:
//			** Код - Строка - код органа;
//			** Наименование - Строка - наименование органа;
//			** Адрес - Строка - юридический адрес;
//			** Телефон - Строка - Строка;
//			** Информация - Строка - информация;
//		* РегистрирующийОрганЮЛ - Структура, Неопределено - реквизиты регистрирующего органа юридических лиц.
//			Описание реквизитов см. в поле РегистрирующийОрганИП.
//		* ОписаниеОшибки - Строка - описание возникшей ошибки.
//			Для обработки ошибки на клиентской части необходимо использовать метод
//			РаботаСКонтрагентамиКлиент.ОбработатьОшибку.
//
Функция РеквизитыНалоговогоОрганаПоКоду(Знач КодНалоговогоОргана) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКонтрагентами.РеквизитыНалоговогоОрганаПоКоду(КодНалоговогоОргана) 
```
</details>

## РеквизитыОтделенияФССПоКоду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращаются реквизиты отделения ФСС по коду.
//
// Параметры:
//	КодОтделенияФСС - Строка - Код отделения ФСС.
//
// Возвращаемое значение:
//	- Структура - реквизиты отделения ФСС.
//		* Код - Строка - код государственного органа;
//		* ИНН - Строка - ИНН;
//		* КПП - Строка - КПП;
//		* Наименование - Строка - наименование государственного органа;
//		* ПолноеНаименование - Строка - полное наименование государственного органа;
//		* Адрес - Строка - Юридический адрес;
//		* Телефон - Строка - Телефон;
//		* ЭлектроннаяПочта - Строка - адрес электронной почты;
//		* ИнтернетСайт - Строка - URL сайта государственного органа;
//		* ПлатежныеРеквизиты - Структура - платежные реквизиты ФСС:
//			** ПолучательПлатежа - Строка - получатель платежа;
//			** РасчетныйСчет - Строка - расчетный счет;
//			** КоррСчет - Строка - корреспондентский счет;
//			** БИК - Строка - БИК банка;
//		* ОписаниеОшибки - Строка - описание возникшей ошибки.
//			Для обработки ошибки на клиентской части необходимо использовать метод
//			РаботаСКонтрагентамиКлиент.ОбработатьОшибку.
//
Функция РеквизитыОтделенияФССПоКоду(Знач КодОтделенияФСС) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКонтрагентами.РеквизитыОтделенияФССПоКоду(КодОтделенияФСС) 
```
</details>

## РеквизитыОтделенияПФРПоКоду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращаются реквизиты отделения ПФР по коду.
//
// Параметры:
//	КодОтделенияПФР - Строка - код отделения ПФР.
//
// Возвращаемое значение:
//	- Структура - реквизиты отделения ПРФ.
//		* Код - Строка - код государственного органа;
//		* ИНН - Строка - ИНН;
//		* КПП - Строка - КПП;
//		* Наименование - Строка - наименование государственного органа;
//		* ПолноеНаименование - Строка - полное наименование государственного органа;
//		* Адрес - Строка - Юридический адрес;
//		* Телефон - Строка - Телефон;
//		* ЭлектроннаяПочта - Строка - адрес электронной почты;
//		* ИнтернетСайт - Строка - URL сайта государственного органа;
//		* ПлатежныеРеквизиты - Структура - платежные реквизиты ПФР:
//			** ПолучательПлатежа - Строка - получатель платежа;
//			** РасчетныйСчет - Строка - расчетный счет;
//			** КоррСчет - Строка - корреспондентский счет;
//			** БИК - Строка - БИК банка;
//		* ОписаниеОшибки - Строка - описание возникшей ошибки.
//			Для обработки ошибки на клиентской части необходимо использовать метод
//			РаботаСКонтрагентамиКлиент.ОбработатьОшибку.
//
Функция РеквизитыОтделенияПФРПоКоду(Знач КодОтделенияПФР) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКонтрагентами.РеквизитыОтделенияПФРПоКоду(КодОтделенияПФР) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
