---
title: Работа с контрагентами клиент
slug: erp-uh/работа-с-контрагентами-клиент
---


## ОбработатьОшибку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обрабатывает стандартным способом ошибку, возвращенную в поле ОписаниеОшибки
// одним из методов:
// - РаботаСКонтрагентами.ЮридическиеЛицаПоНаименованию;
// - РаботаСКонтрагентами.РеквизитыПредпринимателяПоИНН;
// - РаботаСКонтрагентами.СведенияОЮридическомЛицеПоИНН;
// - РаботаСКонтрагентами.ИнформацияОСвязяхЮридическогоЛицаПоИНН;
// - РаботаСКонтрагентами.ИнформацияОСвязяхПредпринимателяПоИНН;
// - РаботаСКонтрагентами.ИнформацияОПроверкахКонтролирующимиОрганамиПоСпискуИНН;
// - РаботаСКонтрагентами.РеквизитыНалоговогоОрганаПоКоду;
// - РаботаСКонтрагентами.РеквизитыОтделенияФССПоКоду;
// - РаботаСКонтрагентами.РеквизитыОтделенияПФРПоКоду;
//
// Параметры:
//	ОписаниеОшибки - Строка - полученное описание ошибки;
//	ОбработчикЗавершения - ОписаниеОповещения - обработчик, вызываемый
//		при завершении обработки ошибки. В обработчик передается
//		значение типа Структура с полями:
//		*ПовторитьДействие - Булево - если Истина, пользователь выполнил
//			действия, необходимые для исправления ошибки и можно повторно
//			вызвать выбранный метод;
//	ДополнительныеПараметры - Структура - дополнительные параметры
//		обработки ошибки. Поля:
//		*ПредставлениеДействия - Строка - представление выполняемого действия
//			в сообщениях пользователю;
//		*ИдентификаторМестаВызова - Строка - произвольный идентификатор
//			функциональности конфигурации;
//		*Форма - ФормаКлиентскогоПриложения - форма, в которой вызывается функциональность.
//			Используется как владелец форм, открываемых в режиме
//			"Блокировать окно владельца".
//
Процедура ОбработатьОшибку( Экспорт
```

Пример вызова
```bsl
РаботаСКонтрагентамиКлиент.ОбработатьОшибку();
```
</details>

## НовыйДополнительныеПараметрыОбработкиОшибки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру дополнительных параметров для метода ОбработатьОшибку().
//
// Возвращаемое значение:
//	Структура - дополнительные параметры. Поля:
//		*ПредставлениеДействия - Строка - представление выполняемого действия
//			в сообщениях пользователю;
//		*ИдентификаторМестаВызова - Строка - произвольный идентификатор
//			функциональности конфигурации;
//		*Форма - ФормаКлиентскогоПриложения - форма, в которой вызывается функциональность.
//			Используется как владелец форм, открываемых в режиме
//			"Блокировать окно владельца".
//
Функция НовыйДополнительныеПараметрыОбработкиОшибки() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКонтрагентамиКлиент.НовыйДополнительныеПараметрыОбработкиОшибки() 
```
</details>

## НовыйПараметрыПоискаКонтрагента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров для подбора контрагентов.
//
// Возвращаемое значение:
//  Структура - параметры.
//    *Заголовок - Строка - заголовок формы;
//    *СтрокаПоиска - Строка - ИНН или наименование контрагента;
//    *Регион - Строка - регион контрагента;
//    *Адрес - Строка - адрес контрагента;
//    *РасширенныйРезультатПодбора - Булево - признак расширенного подбора.
//         Когда Ложь, в результате подбора будет возвращаться строка ИНН,
//         Когда Истина - Структура с полями ИНН, УникальныйНомер, Идентификатор.
//
Функция НовыйПараметрыПоискаКонтрагента() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКонтрагентамиКлиент.НовыйПараметрыПоискаКонтрагента() 
```
</details>

## ОткрытьПодборКонтрагента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму заполнения контрагента из данных ЕГРЮЛ.
//
// Параметры:
//  ПараметрыПоиска - Структура - параметры поиска контрагента. См НовыйПараметрыПоискаКонтрагента
//    *Заголовок - Строка - заголовок формы;
//    *СтрокаПоиска - Строка - ИНН или наименование контрагента;
//    *Регион - Строка - регион контрагента;
//    *Адрес - Строка - адрес контрагента;
//  ФормаВладелец - ФормаКлиентскогоПриложения
//                - Неопределено - форма, из которой открывается подбор.
//  ОписаниеОповещения - ОписаниеОповещения - оповещение, которое необходимо выполнить после выбора контрагента.
//   В результате подбора может быть передана строка ИНН или структура с данными контрагента:
//    *ИНН - Строка - ИНН контрагента;
//    *ЭтоПодразделение - Булево - признак обособленного подразделения;
//    *Идентификатор  - Строка - идентификатор подразделения.
//
Процедура ОткрытьПодборКонтрагента(ПараметрыПоиска, ФормаВладелец, ОписаниеОповещения) Экспорт
```

Пример вызова
```bsl
РаботаСКонтрагентамиКлиент.ОткрытьПодборКонтрагента(ПараметрыПоиска, ФормаВладелец, ОписаниеОповещения) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
