---
title: Работа с курсами валют УТ
slug: erp-uh/работа-с-курсами-валют-ут
---


## ПолучитьКоэффициентПересчетаИзВалютыВВалюту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция получает коэффициент пересчета из текущей валюты в новую валюту.
//
// Параметры:
//	ТекущаяВалюта - СправочникСсылка.Валюты - Текущая валюта документа
//	НоваяВалюта - СправочникСсылка.Валюты - Новая валюта документа
//	Дата - Дата - Дата документа.
//	БазоваяВалюта - СправочникСсылка.Валюты - Базовая валюта, относительно которой необходимо получить курс.
//											Если Неопределено, то курсы получаются относительно значения из константы БазоваяВалютаПоУмолчанию.
//	ПараметрыВариантаКурсаДоговора - См. РаботаСКурсамиВалютУТ.ПараметрыВариантаКурсаДоговора
//
// Возвращаемое значение:
//	Число - Коэффициент пересчета в новую валюту.
//
Функция ПолучитьКоэффициентПересчетаИзВалютыВВалюту(ТекущаяВалюта, НоваяВалюта, Дата, Знач БазоваяВалюта = Неопределено, ПараметрыВариантаКурсаДоговора = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКурсамиВалютУТ.ПолучитьКоэффициентПересчетаИзВалютыВВалюту(ТекущаяВалюта, НоваяВалюта, Дата, БазоваяВалюта, ПараметрыВариантаКурсаДоговора);
```
</details>

## ПолучитьКурсВалюты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает курс валюты на дату.
//
// Параметры:
//   Валюта    - СправочникСсылка.Валюты - валюта, для которой получается курс.
//   ДатаКурса - Дата - дата, на которую получается курс.
//   БазоваяВалюта - СправочникСсылка.Валюты - Валюта, относительно которой необходимо получить курс
//   ОбъектРасчетов - СправочникСсылка.ОбъектыРасчетов - Необязательный, объект расчетов, по которому определяется вариант курса договора
//
// Возвращаемое значение:
//   Структура:
//    * КурсЧислитель - Число - Числитель курса валюты на указанную дату.
//    * КурсЗнаменатель - Число - Знаменатель курса валюты на указанную дату.
//    * Валюта    - СправочникСсылка.Валюты - ссылка валюты.
//    * ДатаКурса - Дата - дата получения курса.
//    * БазоваяВалюта - СправочникСсылка.Валюты - Валюта, относительно которой получены  курс.
//
Функция ПолучитьКурсВалюты(Знач Валюта, Знач ДатаКурса, Знач БазоваяВалюта = Неопределено, ОбъектРасчетов = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКурсамиВалютУТ.ПолучитьКурсВалюты(Валюта, ДатаКурса, БазоваяВалюта, ОбъектРасчетов);
```
</details>

## ПолучитьКоэффициентыПересчетаВалюты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция получает коэффициенты пересчета сумм из валюты документа в валюту взаиморасчетов,
// в валюты управленческого и регламентированного учета.
//
// Параметры:
//	ВалютаДокумента - СправочникСсылка.Валюты - Валюта документа
//	ВалютаВзаиморасчетов - СправочникСсылка.Валюты - Валюта взаиморасчетов документа
//	Период - Дата - Дата документа
//	Организация - СправочникСсылка.Организации - Организация документа
//	КурсЧислительДокумента - Число - Необязательный, курс-числитель валюты документа
//	КурсЗнаменательДокумента - Число - Необязательный, курс-знаменатель валюты документа.
//	ОбъектРасчетов - СправочникСсылка.ОбъектыРасчетов - Необязательный,Объект расчетов для определения источника курса валюты.
//
// Возвращаемое значение:
//   Структура - Параметры курса валюты:
//	   * КоэффициентПересчетаВВалютуВзаиморасчетов 	- Число - Коэффициент пересчета в валюту взаиморасчетов.
//	   * КоэффициентПересчетаВВалютуУПР 			- Число - Коэффициент пересчета в валюту управленческого учета.
//	   * КоэффициентПересчетаВВалютуРегл 			- Число - Коэффициент пересчета в валюту регламентированного учета.
//
Функция ПолучитьКоэффициентыПересчетаВалюты(ВалютаДокумента, ВалютаВзаиморасчетов, Период, Организация, КурсЧислительДокумента = Неопределено, КурсЗнаменательДокумента = Неопределено, ОбъектРасчетов = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКурсамиВалютУТ.ПолучитьКоэффициентыПересчетаВалюты(ВалютаДокумента, ВалютаВзаиморасчетов, Период, Организация, КурсЧислительДокумента, КурсЗнаменательДокумента, ОбъектРасчетов);
```
</details>

## ПолучитьКоэффициентыПересчетаПоОбъектамРасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция получает коэффициент пересчета из текущей валюты в новую валюту.
//
// Параметры:
//	ТекущаяВалюта - СправочникСсылка.Валюты - Текущая валюта документа
//	НоваяВалюта - СправочникСсылка.Валюты - Новая валюта документа
//	Дата - Дата - Дата документа.
//	БазоваяВалюта - СправочникСсылка.Валюты - Базовая валюта, относительно которой необходимо получить курс.
//											Если Неопределено, то курсы получаются относительно значения из константы БазоваяВалютаПоУмолчанию.
//	ОбъектыРасчетов - Массив из СправочникСсылка.ОбъектыРасчетов
//
// Возвращаемое значение:
//	ТаблицаЗначений:
//- Коэффициент пересчета в новую валюту.
//
Функция ПолучитьКоэффициентыПересчетаПоОбъектамРасчетов(ТекущаяВалюта, НоваяВалюта, Дата, Знач БазоваяВалюта = Неопределено, ОбъектыРасчетов) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКурсамиВалютУТ.ПолучитьКоэффициентыПересчетаПоОбъектамРасчетов(ТекущаяВалюта, НоваяВалюта, Дата, БазоваяВалюта, ОбъектыРасчетов) 
```
</details>

## ПолучитьКурсВалютыПоОбъектамРасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает курс валюты на дату.
//
// Параметры:
//   Валюта    - Массив из СправочникСсылка.Валюты - валюты, для которых получается курс.
//   ДатаКурса - Дата - дата, на которую получается курс.
//   БазоваяВалюта - СправочникСсылка.Валюты - Валюта, относительно которой необходимо получить курс
//   ОбъектРасчетов - Массив из СправочникСсылка.ОбъектыРасчетов - Объекты расчетов, по которым определяется вариант курса договора
//
// Возвращаемое значение:
//   ТаблицаЗначений:
//    * КурсЧислитель    - Число - Числитель курса валюты на указанную дату.
//    * КурсЗнаменатель  - Число - Знаменатель курса валюты на указанную дату.
//    * Валюта           - СправочникСсылка.Валюты - ссылка валюты.
//    * ОбъектРасчетов   - СправочникСсылка.ОбъектыРасчетов - Объект расчетов, по которому определен курс
//    * ДатаКурса        - Дата - дата получения курса.
//    * БазоваяВалюта    - СправочникСсылка.Валюты - Валюта, относительно которой получены  курс.
//
Функция ПолучитьКурсВалютыПоОбъектамРасчетов(Валюты, ДатаКурса, Знач БазоваяВалюта = Неопределено, ОбъектыРасчетов) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКурсамиВалютУТ.ПолучитьКурсВалютыПоОбъектамРасчетов(Валюты, ДатаКурса, БазоваяВалюта, ОбъектыРасчетов) 
```
</details>

## ПересчитатьСуммуДокументаВВалюту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция пересчитывает сумму документа из текущей валюты в новую валюту.
//
// Параметры:
//	СуммаДокумента - Число - Текущая сумма документа
//	ТекущаяВалюта - СправочникСсылка.Валюты - Текущая валюта документа
//	НоваяВалюта - СправочникСсылка.Валюты - Новая валюта документа
//	Дата - Дата - Дата документа.
//	БазоваяВалюта - СправочникСсылка.Валюты - Валюта, относительно которой необходимо получать курсы.
//
// Возвращаемое значение:
//	Число - Новая сумма документа
//
Функция ПересчитатьСуммуДокументаВВалюту(СуммаДокумента, ТекущаяВалюта, НоваяВалюта, Дата, БазоваяВалюта) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКурсамиВалютУТ.ПересчитатьСуммуДокументаВВалюту(СуммаДокумента, ТекущаяВалюта, НоваяВалюта, Дата, БазоваяВалюта) 
```
</details>

## ПолучитьКурсВалютыУправленческогоУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает курс валюты управленческого учета относительно валюты регламентированного.
//
// Параметры:
//  Дата - Дата - Дата на которую необходимо получить курс валюты.
//  ВалютаРегламентированногоУчета - СправочникСсылка.Валюты - Валюта регламентированного учета.
//
// Возвращаемое значение:
//  Число - Курс валюты управленческого учета
//
Функция ПолучитьКурсВалютыУправленческогоУчета(Дата, ВалютаРегламентированногоУчета) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКурсамиВалютУТ.ПолучитьКурсВалютыУправленческогоУчета(Дата, ВалютаРегламентированногоУчета) 
```
</details>

## ЗаполнитьКурсДокументаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет КурсЧислитель и КурсЗнаменатель документа по умолчанию
//
// Параметры:
//	КурсЧислитель - Число - КурсЧислитель для расчета
//	КурсЗнаменатель - Число - КурсЗнаменатель для расчета
//	ВалютаДокумента - СправочникСсылка.Валюты - Валюта документа
//	ВалютаВзаиморасчетов - СправочникСсылка.Валюты - Валюта взаиморасчетов документа
//	Организация - СправочникСсылка.Организации - Организация документа
//	Дата - Дата - Необязательный, дата документа.
//	Договор - СправочникСсылка.ДоговорыКонтрагентов, СправочникСсылка.ДоговорыМеждуОрганизациями - Договор для проверки на ниличие курса
//	ОбъектРасчетов - СправочникСсылка.ОбъектыРасчетов - ОбъектРасчетов, по которому определяется курс валюты
//
Процедура ЗаполнитьКурсДокументаПоУмолчанию(КурсЧислитель, КурсЗнаменатель, ВалютаДокумента, ВалютаВзаиморасчетов, Организация, Дата = Неопределено, Договор = Неопределено, ОбъектРасчетов = Неопределено) Экспорт
```

Пример вызова
```bsl
РаботаСКурсамиВалютУТ.ЗаполнитьКурсДокументаПоУмолчанию(КурсЧислитель, КурсЗнаменатель, ВалютаДокумента, ВалютаВзаиморасчетов, Организация, Дата, Договор, ОбъектРасчетов);
```
</details>

## ПолучитьКроссКурсВалют
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает кросс-курс двух валют
//
// Параметры:
//	Валюта1 - Структура - Параметры курса валюты, относительно которой рассчитывается курс:
//       * КурсЧислитель      - Число - Курс валюты относительно валюты регламентированного учета.
//       * КурсЗнаменатель - Число - Кратность валюты относительно валюты регламентированного учета.
//	Валюта2 - Структура - Параметры курса валюты, курс которой рассчитывается:
//       * КурсЧислитель      - Число - Курс валюты относительно валюты регламентированного учета.
//       * КурсЗнаменатель - Число - Кратность относительно валюты регламентированного учета.
//
// Возвращаемое значение:
//   Структура - Параметры кросс-курса:
//       * КурсЧислитель - Число - Числитель кросс-курса
//       * КурсЗнаменатель - Число - Знаменатель кросс-курса
//
Функция ПолучитьКроссКурсВалют(Валюта1, Валюта2) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКурсамиВалютУТ.ПолучитьКроссКурсВалют(Валюта1, Валюта2) 
```
</details>

## СтруктураКурсаВалюты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает структуру параметров курса валюты
//
// Параметры:
//	КурсЧислитель - Число - Необязательный, числитель курса валюты.
//	КурсЗнаменатель - Число - Необязательный, Знаменатель курса валюты.
//
// Возвращаемое значение:
//   Структура - Параметры курса валюты:
//	   * КурсЧислитель - Число - курс валюты.
//	   * КурсЗнаменатель - Число - кратность курса.
//
Функция СтруктураКурсаВалюты(КурсЧислитель = 0, КурсЗнаменатель = 0) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКурсамиВалютУТ.СтруктураКурсаВалюты(КурсЧислитель, КурсЗнаменатель);
```
</details>

## ПересчитатьВВалюту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает сумму из одной валюты в другую.
//
// Параметры:
//  Сумма          - Число - сумма, которую необходимо пересчитать;
//  БазоваяВалюта - СправочникСсылка.Валюты - валюта, относительно которой получается курс;
//  ИсходнаяВалюта - СправочникСсылка.Валюты - пересчитываемая валюта;
//  НоваяВалюта    - СправочникСсылка.Валюты - валюта, в которую необходимо пересчитать;
//  Дата           - Дата - дата курсов валют.
//  ОбъектРасчетов - СправочникСсылка.ОбъектыРасчетов - Необязательный, объект расчетов, по которому определяется вариант курса договора
//
// Возвращаемое значение:
//  Число - пересчитанная сумма.
//
Функция ПересчитатьВВалюту(Сумма, БазоваяВалюта, ИсходнаяВалюта, НоваяВалюта, Дата, ОбъектРасчетов = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКурсамиВалютУТ.ПересчитатьВВалюту(Сумма, БазоваяВалюта, ИсходнаяВалюта, НоваяВалюта, Дата, ОбъектРасчетов);
```
</details>

## ПересчитатьПоКурсу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает сумму из текущей валюты в новую валюту по параметрам их курсов.
// Параметры курсов валют можно получить функцией РаботаСКурсамиВалют.ПолучитьКурсВалюты.
//
// Параметры:
//   Сумма - Число     - сумма, которую следует пересчитать.
//
//   ПараметрыТекущегоКурса - Структура - параметры курса валюты, из которой надо пересчитать:
//    * Валюта - СправочникСсылка.Валюты - ссылка пересчитываемой валюты.
//    * КурсЧислитель - Число - курс пересчитываемой валюты.
//    * КурсЗнаменатель - Число - кратность пересчитываемой валюты.
//
//   ПараметрыНовогоКурса   - Структура - параметры курса валюты, в  которую надо пересчитать:
//    * Валюта - СправочникСсылка.Валюты - ссылка валюты, в которую идет пересчет.
//    * КурсЧислитель - Число - курс числитель валюты, в которую идет пересчет.
//    * КурсЗнаменатель - Число - курс знаменатель валюты, в которую идет пересчет.
//
// Возвращаемое значение:
//   Число - сумма, пересчитанная по новому курсу.
//
Функция ПересчитатьПоКурсу(Сумма, ПараметрыТекущегоКурса, ПараметрыНовогоКурса) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКурсамиВалютУТ.ПересчитатьПоКурсу(Сумма, ПараметрыТекущегоКурса, ПараметрыНовогоКурса) 
```
</details>

## СформироватьСуммуПрописью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует представление суммы прописью в указанной валюте.
//
// Параметры:
//   СуммаЧислом - Число - сумма, которую надо представить прописью.
//   Валюта - СправочникСсылка.Валюты - валюта, в которой нужно представить сумму.
//   БезДробнойЧасти - Булево - указать Истина, если требуется получить сумму без дробной части (без копеек).
//   КодЯзыка - Строка - язык, на котором требуется получить сумму прописью.
//                       Состоит из кода языка по ISO 639-1 и, опционально, кода страны по ISO 3166-1, разделенных
//                       символом подчеркивания. Примеры: "en", "en_US", "en_GB", "ru", "ru_RU".
//                       Значение по умолчанию - язык конфигурации.
//
// Возвращаемое значение:
//   Строка - сумма прописью.
//
Функция СформироватьСуммуПрописью(СуммаЧислом, Валюта, БезДробнойЧасти = Ложь, Знач КодЯзыка = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСКурсамиВалютУТ.СформироватьСуммуПрописью(СуммаЧислом, Валюта, БезДробнойЧасти, КодЯзыка);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
