---
title: Работа с табличными частями
slug: erp-uh/работа-с-табличными-частями
---


## ИнициализироватьКэшСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует кэш строк на форме для для указанной таблицы.
// Для использования кэширования строк необходимо добавить на форму реквизит "КэшированныеСтроки" с типом "Произвольный".
//
// Параметры:
//  ТаблицаФормы - ТаблицаФормы - элемент формы, содержащий табличную часть.
//
Процедура ИнициализироватьКэшСтрок(ТаблицаФормы) Экспорт
```

Пример вызова
```bsl
РаботаСТабличнымиЧастями.ИнициализироватьКэшСтрок(ТаблицаФормы) 
```
</details>

## ЕстьСтрокиВБуфереОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет наличие сохраненных строк табличной части в буфере обмена.
//
// Возвращаемое значение:
//  Булево - Истина - в буфере есть строки, Ложь - в противном случае.
//
Функция ЕстьСтрокиВБуфереОбмена() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСТабличнымиЧастями.ЕстьСтрокиВБуфереОбмена() 
```
</details>

## СкопироватьСтрокиВБуферОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Копирует указанные строки табличной части в буфер обмена.
//
// Параметры:
//  ТабличнаяЧасть - ТабличнаяЧасть -
//  Строки - Массив - идентификаторы строк (свойство ВыделенныеСтроки таблицы формы).
//
Процедура СкопироватьСтрокиВБуферОбмена(ТабличнаяЧасть, Строки) Экспорт
```

Пример вызова
```bsl
РаботаСТабличнымиЧастями.СкопироватьСтрокиВБуферОбмена(ТабличнаяЧасть, Строки) 
```
</details>

## ПоместитьТаблицуЗначенийВБуферОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Копирует указанную таблицу значений в буфер обмена.
//
// Параметры:
//  Таблица - ТаблицаЗначений - таблица значений, которую необходимо поместить в буфер обмена.
//
Процедура ПоместитьТаблицуЗначенийВБуферОбмена(Таблица) Экспорт
```

Пример вызова
```bsl
РаботаСТабличнымиЧастями.ПоместитьТаблицуЗначенийВБуферОбмена(Таблица) 
```
</details>

## СтрокиИзБуфераОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает строки табличной части из буфер обмена.
//
// Параметры:
//  ПараметрыОтбора - Соответствие - задает условия поиска:
//      ключ определяет путь к данным, по которой будет осуществляться поиск, а значение - искомое значение;
//      Если путь к данным не соответствует данным исходной таблицы буфера, метод возвращает Неопределено.
//  Колонки - Строка, Массив - список колонок для возвращаемой таблицы;
//      Колонки, которых нет в исходной таблице буфера игнорируются, если же нет ни одной указанной колонки
//      в исходной таблице, метод возвращает Неопределено.
//
// Возвращаемое значение:
//  ТаблицаЗначений, Неопределено - строки из буфера, если буфер не пустой и данные в нем соответствуют заданному отбору.
//
Функция СтрокиИзБуфераОбмена(ПараметрыОтбора = Неопределено, Колонки = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСТабличнымиЧастями.СтрокиИзБуфераОбмена(ПараметрыОтбора, Колонки);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
