---
title: Работа с табличными частями клиент
slug: erp-uh/работа-с-табличными-частями-клиент
---


## ВыбранаСтрокаДляВыполненияКоманды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет наличие выделенной строки, необходимой для выполнения команды. Выводит сообщение в случае ее отсутствия.
//
// Параметры:
//  ТаблицаФормы - ТаблицаФормы - элемент формы, содержащий табличную часть.
//
// Возвращаемое значение:
//  Булево - Истина - выполнение команды возможно; Ложь - в противном случае.
//
Функция ВыбранаСтрокаДляВыполненияКоманды(ТаблицаФормы) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСТабличнымиЧастямиКлиент.ВыбранаСтрокаДляВыполненияКоманды(ТаблицаФормы) 
```
</details>

## ПараметрыПроверкиЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция-конструктор параметров проверки возможности заполнения табличной части.
//
// Возвращаемое значение:
//  Структура:
//     * ТабличнаяЧасть - ДанныеФормыКоллекция - табличная часть, которую необходимо проверить на незаполненность,
//          в случае если табличная часть заполнена, после подтверждения пользователя, происходит её очистка.
//     * ЗаголовокТабличнойЧасти - Строка - имя проверяемой табличной части, которое будет показано в сообщениях проверки
//     * ПроверятьРаспроведенность - Булево - указывает необходимость проверки непроведенности документа,
//          в случае если документ проведен, после подтверждения пользователя, происходит отмена его проведения.
//     * ПроверяемыеРеквизиты - Структура - реквизиты объекта, для которых необходимо выполнить проверку заполнения,
//          где Ключ - имя реквизита, а Значение - его заголовок.
//
Функция ПараметрыПроверкиЗаполнения() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСТабличнымиЧастямиКлиент.ПараметрыПроверкиЗаполнения() 
```
</details>

## ПроверитьВозможностьЗаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет возможность заполнения табличной части объекта.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма объекта
//  ОповещениеПослеПроверки - ОписаниеОповещения - описание процедуры, которая будет вызвана, если заполнение возможно
//      со следующими параметрами:
//          Результат - Булево - всегда Истина
//          ДополнительныеПараметры - Произвольный - параметры, заданные в ОповещениеПослеПроверки при создании.
//  ПараметрыПроверкиЗаполнения - Структура - (см. РаботаСТабличнымиЧастямиКлиент.ПараметрыПроверкиЗаполнения).
//
Процедура ПроверитьВозможностьЗаполнения(Форма, ОповещениеПослеПроверки, ПараметрыПроверкиЗаполнения) Экспорт
```

Пример вызова
```bsl
РаботаСТабличнымиЧастямиКлиент.ПроверитьВозможностьЗаполнения(Форма, ОповещениеПослеПроверки, ПараметрыПроверкиЗаполнения) 
```
</details>

## ПараметрыРазбиенияСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция-конструктор дополнительных параметров разбиения строки.
//
// Возвращаемое значение:
//  Структура:
//     * ИмяПоляКоличество - Строка - имя поля, по которому будет происходить разбиение
//     * Заголовок - Строка - заголовок формы ввода числа
//     * РазрешитьНулевоеКоличество - Булево - признак, что в исходной и конечной строке может быть 0
//     * Количество - Неопределено, Число - количество, которое будет отображено в форме редактирования числа;
//          если Неопределенно - будет показано количество, взятое из исходной строки.
//     * МаксимальноДопустимоеЗначение - Число - верхний предел указания количества.
//
Функция ПараметрыРазбиенияСтроки() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСТабличнымиЧастямиКлиент.ПараметрыРазбиенияСтроки() 
```
</details>

## РазбитьСтроку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Разбивает выделенную строку на две по введенному количеству.
//
// Параметры:
//  ТабличнаяЧасть - ДанныеФормыКоллекция - табличная часть, в которой необходимо разбить выделенную строку
//  ТаблицаФормы - ТаблицаФормы - элемент формы, содержащий табличную часть
//  ОповещениеПослеРазбиения - ОписаниеОповещения - описание процедуры, вызов которой будет произведен после разбиения,
//      с передачей значения результата разбиения: ДанныеФормыЭлементКоллекции - новая строка полученная разбиением;
//      Неопределено - разбиение не проводилось.
//  ПараметрыРазбиенияСтроки - Структура - (см. РаботаСТабличнымиЧастямиКлиент.ПараметрыРазбиенияСтроки).
//
Процедура РазбитьСтроку(ТабличнаяЧасть, ТаблицаФормы, ОповещениеПослеРазбиения = Неопределено, ПараметрыРазбиенияСтроки = Неопределено) Экспорт
```

Пример вызова
```bsl
РаботаСТабличнымиЧастямиКлиент.РазбитьСтроку(ТабличнаяЧасть, ТаблицаФормы, ОповещениеПослеРазбиения, ПараметрыРазбиенияСтроки);
```
</details>

## ОповеститьПользователяОКопированииСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Показывает окно оповещения о количестве скопированных строк.
// Оповещает другие формы о событии копирования строк в буфер обмена.
//
// Параметры:
//  КоличествоСтрок - Число - количество скопированных строк из табличной части.
//
Процедура ОповеститьПользователяОКопированииСтрок(КоличествоСтрок) Экспорт
```

Пример вызова
```bsl
РаботаСТабличнымиЧастямиКлиент.ОповеститьПользователяОКопированииСтрок(КоличествоСтрок) 
```
</details>

## ОповеститьПользователяОВставкеСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Показывает окно оповещения о количестве вставленных строк.
//
// Параметры:
//  КоличествоСтрок - Число - количество вставленных строк в табличную часть.
//
Процедура ОповеститьПользователяОВставкеСтрок(КоличествоСтрок) Экспорт
```

Пример вызова
```bsl
РаботаСТабличнымиЧастямиКлиент.ОповеститьПользователяОВставкеСтрок(КоличествоСтрок) 
```
</details>

## ПараметрыЗагрузкиНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция-конструктор параметров формы загрузки номенклатуры из внешних источников.
//
// Возвращаемое значение:
//  Структура:
//     * Заголовок - Строка - заголовок формы загрузки номенклатуры
//     * ДопПояснениеПриЗагрузке - Строка - дополнительное пояснение, выводимое на форме при загрузке номенклатуры
//     * ПараметрыОтбора - Структура - задает условия фильтрации загружаемой номенклатуры,
//          где Ключ - имя реквизита номенклатуры, а Значение - искомое значение;
//          также через ключ СегментНоменклатуры доступен отбор по сегменту номенклатуры.
//     * ПроверятьЗаполнениеХарактеристик - Булево - указывает необходимость проверки заполнения характеристик
//     * ЗаполнятьНоменклатуруПартнера - СправочникСсылка.Партнеры - при указании поставщика, определяет возможность
//          для загружаемой номенклатуры заполнить сопоставленную с ней номенклатуру поставщика.
//
//     * ЗагружатьКоличество - Булево - определяет возможность загрузки количества единиц
//     * ЗагружатьЦены - Булево - определяет возможность загрузки цен
//     * ЗагружатьСуммы - Булево - определяет возможность загрузки сумм
//     * ЗагружатьГТД - Булево - определяет возможность загрузки номеров ГТД
//
//     * ЗагружатьЗапасы - Булево - определяет возможность загрузки минимального и максимального запаса
//     * ЗагружатьСкидки - Булево - определяет возможность загрузки ручных скидок
//     * ЗагружатьУпаковочныеЛисты - Булево - определяет возможность загрузки упаковочных листов
//
//     * ПересчитыватьСуммы - Булево - указывает необходимость пересчета сумм загружаемой номенклатуры
//     * ЦенаВключаетНДС - Булево - признак включения НДС в цену и сумму загружаемой номенклатуры
//     * Организация - СправочникСсылка.Организации - определяет заполнение ставок НДС
//     * НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - определяет заполнение ставки НДС
//     * ДатаЗаполнения - Дата - указывает дату, на которую происходит заполнение ставки НДС
//     * ЭтоВозвратнаяТара - Булево - указывает, является ли загружаемая тара возвратной
//
//     * ПараметрыЦенКомплектующих - Структура - описание параметров заполнения цен для комплектующих набора:
//        ** Дата - Дата - дата получения цен
//        ** Валюта - СправочникСсылка.Валюты - валюта цен
//        ** Соглашение - СправочникСсылка.СоглашенияСКлиентами - соглашение, в рамках которого необходимо получить цены;
//              не заполняется, если необходимо заполнить цены по виду цен.
//        ** ВидЦены - СправочникСсылка.ВидыЦен - вид цены, определяющий алгоритм расчета цен;
//              не заполняется, если необходимо заполнить цены по соглашению.
//
Функция ПараметрыЗагрузкиНоменклатуры() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСТабличнымиЧастямиКлиент.ПараметрыЗагрузкиНоменклатуры() 
```
</details>

## ПоказатьФормуЗагрузкиНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму загрузки номенклатуры из внешнего источника.
//
// Параметры:
//  ПараметрыЗагрузки - см. ПараметрыЗагрузкиНоменклатуры
//  ОповещениеОЗагрузке - ОписаниеОповещения - описание процедуры, вызов которой будет произведен после загрузки,
//      с передачей значения результата загрузки: Строка - адрес во временном хранилище; Неопределено - загрузка не проводилась.
//
Процедура ПоказатьФормуЗагрузкиНоменклатуры(ПараметрыЗагрузки, ОповещениеОЗагрузке) Экспорт
```

Пример вызова
```bsl
РаботаСТабличнымиЧастямиКлиент.ПоказатьФормуЗагрузкиНоменклатуры(ПараметрыЗагрузки, ОповещениеОЗагрузке) 
```
</details>

## ПараметрыЗагрузкиНоменклатурыДляПланов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция-конструктор параметров формы загрузки номенклатуры из внешних источников для планов.
//
// Возвращаемое значение:
//  Структура:
//     * Заголовок - Строка - заголовок формы загрузки номенклатуры
//     * ПараметрыОтбора - Структура - задает условия фильтрации загружаемой номенклатуры, где Ключ - имя реквизита номенклатуры, а Значение - искомое значение:
//       ** ТипНоменклатуры - Массив из ПеречислениеСсылка.ТипыНоменклатуры -
//
//     * ВидПлана - СправочникСсылка.ВидыПланов - настройка заполнения плана
//     * ПланироватьПоСумме - Булево - признак планирования по ценам и суммам
//     * КроссТаблица - Булево - признак формирования плана в кросс-таблице
//
//     * АдресТаблицыПериодов - Строка - адрес во временном хранилище таблицы периодов
//     * АдресТаблицыТоваров - Строка - адрес во временном хранилище таблицы товаров
//
//     * Партнер - СправочникСсылка.Партнеры - партнер участвующий в хозяйственных операциях с предприятием по плану
//     * Подразделение - СправочникСсылка.СтруктураПредприятия - подразделение по которому формируется план.
//
Функция ПараметрыЗагрузкиНоменклатурыДляПланов() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСТабличнымиЧастямиКлиент.ПараметрыЗагрузкиНоменклатурыДляПланов() 
```
</details>

## ПоказатьФормуЗагрузкиНоменклатурыДляПланов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму загрузки номенклатуры из внешнего источника.
//
// Параметры:
//  ПараметрыЗагрузки - см. ПараметрыЗагрузкиНоменклатурыДляПланов
//  ОповещениеОЗагрузке - ОписаниеОповещения - описание процедуры, вызов которой будет произведен после загрузки,
//      с передачей значения результата загрузки: Строка - адрес во временном хранилище; Неопределено - загрузка не проводилась.
//
Процедура ПоказатьФормуЗагрузкиНоменклатурыДляПланов(ПараметрыЗагрузки, ОповещениеОЗагрузке) Экспорт
```

Пример вызова
```bsl
РаботаСТабличнымиЧастямиКлиент.ПоказатьФормуЗагрузкиНоменклатурыДляПланов(ПараметрыЗагрузки, ОповещениеОЗагрузке) 
```
</details>

## КэшироватьТекущуюСтроку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет в кэше на форме текущую строку указанной таблицы.
// Перед использованием необходим разовый вызов РаботаСТабличнымиЧастями.ИнициализироватьКэшСтрок().
//
// Параметры:
//  ТаблицаФормы - ТаблицаФормы - элемент формы, содержащий табличную часть.
//  Форма - ФормаКлиентскогоПриложения - форма объекта метаданных.
//
Процедура КэшироватьТекущуюСтроку(ТаблицаФормы, Форма) Экспорт
```

Пример вызова
```bsl
РаботаСТабличнымиЧастямиКлиент.КэшироватьТекущуюСтроку(ТаблицаФормы, Форма) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
