---
title: Работа с формулами повт исп
slug: erp-uh/работа-с-формулами-повт-исп
---


## СвойстваПоддерживаемыхИсточниковХарактеристик
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание поддерживаемых источников характеристик.
//
// Возвращаемое значение:
//  ТаблицаЗначений - таблица, описание поддерживаемых источников характеристик:
//    * МетаданныеИсточника - ОбъектМетаданных - Метаданные источника характеристик.
//    * ПрефиксТипаВидаХарактеристик - Строка - Идентификатор источника характеристик.
//    * ПолеИдентификатора - Строка -  Имя поля (реквизита) идентификатора (или наименования) вида характеристик.
//                           Например, "ИдентификаторДляФормул" для плана видов характеристик ДополнительныеРеквизитыИСведения.
//    * ПолеТипаЗначений   - Строка - Имя поля (реквизита), содержащее тип значения вида характеристик.
//    		Если указано выражение типа, то указание поля типа значения является не обязательным.
//    * ИспользуетсяВыражениеТипаЗначений - Булево - Флаг использования выражения типа значений, тогда вместо обращения
//    		к полю будет указано выражение.
//    		Например, для справочника ВидыКонтактнойИнформации.
//    * ВыражениеТипаЗначений - Строка - Выражение типа значений. Используется при отсутствии поля типа значений.
//    		Например, для справочника ВидыКонтактнойИнформации можно использовать
//    		выражение "ТИП(СТРОКА)".
//    * ПереопределениеВыраженияТипаЗначений - ОписаниеТипов - Содержит описание типов. Необходимо задавать всегда, когда нет реального поля,
//    		содержащего тип значения (не ПВХ, ИспользуетсяВыражениеТипаЗначений = Истина).
//    		Переопределение в методе НоваяСтрокаДереваПоПолюКомпоновки.
//    * УникальностьИмениВПределахВсейТаблицыХарактеристик - Булево - Если Истина, то идентификатор характеристики (поле имени) уникален
//    		во всей таблице характеристик. Например, значение поля "Имя" дополнительных реквизитов
//    		и сведений уникально во всей таблице ПланыВидовХарактеристик.ДополнительныеРеквизитыИСведения
//    		(т.к. один и тот же реквизит может входить в состав разных наборов).
//    		Если Ложь, то уникальность идентификатора характеристики (поле имени) не обеспечивается.
//    		Например, видов для контактной информации идентификатор "Телефон" будет использоваться
//    		в наборах "Контрагент" / "Организация" / "ФизическоеЛицо" и т.д.
//    		Если вид контактной информации указывается для одного типа, то мы можем точно определить
//    		параметры вида контактной информации (представление, тип). Если вид контактной информации
//    		указывается для составного типа, то параметры вида контактной информации (представление, тип)
//    		определяются так же как для обычных реквизитов (Представление берется с наименьшим значением,
//    		тип контактной информации указывается "прочее").
//
Функция СвойстваПоддерживаемыхИсточниковХарактеристик() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФормуламиПовтИсп.СвойстваПоддерживаемыхИсточниковХарактеристик() 
```
</details>

## СоответствияИменСтандартныхРеквизитов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает соответствие английских и русских имен стандартных реквизитов.
//
// Возвращаемое значение:
// 	Соответствие - Соответствие английских и русских имен стандартных реквизитов.
//
Функция СоответствияИменСтандартныхРеквизитов() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФормуламиПовтИсп.СоответствияИменСтандартныхРеквизитов() 
```
</details>

## ПолноеИмяТаблицыДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолноеИмяТаблицыДанных(ПолноеИмяОбъектаМетаданных) Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФормуламиПовтИсп.ПолноеИмяТаблицыДанных(ПолноеИмяОбъектаМетаданных) 
```
</details>

## ХарактеристикиПоПредставлениям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Описание
//
// Возвращаемое значение:
// 	Соответствие - соответствие представления и мест назначения характеристик:
// 	 *Ключ - Строка - Представление характеристики.
// 	 *Значение - Соответствие - соответствие типа объекта метаданных, которому принадлежит характеристика и ее параметров:
// 	        **Ключ - Тип - тип объекта метаданных, которому принадлежит характеристика. Одна характеристика может
// 	        				может быть указана нескольким типам.
// 	        **Значение - Структура - Параметры характеристики:
// 	             ***Характеристика - ПланВидовХарактеристикСсылка.ДополнительныеРеквизитыИСведения, СправочникСсылка.ВидыКонтактнойИнформации - Ссылка на характеристику.
// 	             ***Идентификатор - Строка - Идентификатор характеристики вида {Префикс.Идентификатор}
// 	             ***ТипЗначения - ОписаниеТипов - Тип значения характеристики.
//
Функция ХарактеристикиПоПредставлениям() Экспорт
```

Пример вызова
```bsl
Результат = РаботаСФормуламиПовтИсп.ХарактеристикиПоПредставлениям() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
