---
title: Раздельный учет по налогу на прибыль
slug: erp-uh/раздельный-учет-по-налогу-на-прибыль
---


## ИспользуетсяРаздельныйУчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак использования раздельного учета для организации
//
// Параметры:
// 	Организация - СправочникСсылка.Организации, Массив Из СправочникСсылка.Организации - головные организации
// 	НаДату - Дата, Неопределено - дата, на которую установлен признак
// 	МВТ    - МенеджерВременныхТаблиц, Неопределено - если передан,
// 	          данные будут помещены во временную таблицу "ОрганизацииСРаздельнымУчетом".
//
// Возвращаемое значение:
// 	Булево, Соответствие Из СправочникСсылка.Организации, Неопределено -
// 		Булево       - когда передана одна организация
// 		Соответствие - когда передан массив организаций, в соответствии будут только организации с раздельным учетом
// 		Неопределено - когда передан менеджер временных таблиц для помещения результата.
//
Функция ИспользуетсяРаздельныйУчет(Организация, Знач НаДату = Неопределено, МВТ = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ИспользуетсяРаздельныйУчет(Организация, НаДату, МВТ);
```
</details>

## ВариантыНалогообложенияПрибылиПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив вариантов н/о, означающих применение общих условий налогообложения прибыли
//
// Возвращаемое значение:
// 	Массив Из СправочникСсылка.ВариантыНалогообложенияПрибыли
//
Функция ВариантыНалогообложенияПрибылиПоУмолчанию() Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ВариантыНалогообложенияПрибылиПоУмолчанию() 
```
</details>

## ВариантНалогообложенияПрибылиПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает предопределенное значение варианта н/о для общих условий налогообложения прибыли
//
// Возвращаемое значение:
//   СправочникСсылка.ВариантыНалогообложенияПрибыли   -
//
Функция ВариантНалогообложенияПрибылиПоУмолчанию() Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ВариантНалогообложенияПрибылиПоУмолчанию() 
```
</details>

## ОсновнойВариантНалогообложенияПрибыли
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает основной вариант н/о для организации исходя из учетной политики
//
// Параметры:
//  Организация  - СправочникСсылка.Организации - организация, настройки которой требуется получить
//  НаДату       - Дата - дата, на которую читаются настройки.
//
// Возвращаемое значение:
//  СправочникСсылка.ВариантыНалогообложенияПрибыли -
//
Функция ОсновнойВариантНалогообложенияПрибыли(Организация, Знач НаДату = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ОсновнойВариантНалогообложенияПрибыли(Организация, НаДату);
```
</details>

## ТипыОбъектовУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив типов измерения "Объект учета"
//
// Возвращаемое значение:
// 	Массив - Описание
Функция ТипыОбъектовУчета() Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ТипыОбъектовУчета() 
```
</details>

## СчетаФинансовогоРезультатаСВариантамиНалогообложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив счетов по фин. резу, использующих субконто "Варианты налогообложения прибыли"
// Следует обращаться через модуль повторного использования:
// РаздельныйУчетПоНалогуНаПрибыльПовтИсп.СчетаФинансовогоРезультатаСВариантамиНалогообложения().
//
// Возвращаемое значение:
// Структура:
// 		* Счета90 - Массив Из ПланСчетовСсылка.Хозрасчетный - массив субсчетов 90-го счета с раздельным НУ
// 		* Счета91 - Массив Из ПланСчетовСсылка.Хозрасчетный - массив субсчетов 91-го счета с раздельным НУ
// 		* Счета99 - Массив Из ПланСчетовСсылка.Хозрасчетный - массив субсчетов 99-го счета с раздельным НУ
//
Функция СчетаФинансовогоРезультатаСВариантамиНалогообложения() Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.СчетаФинансовогоРезультатаСВариантамиНалогообложения() 
```
</details>

## ДобавитьВидСубконтоВариантыНалогообложенияПрибыли
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в массив субконто по вариантам н/о,
//
// Параметры:
// 	ВидыСубконто - Массив Из ПланВидовХарактеристикСсылка.ВидыСубконтоХозрасчетные
//
Процедура ДобавитьВидСубконтоВариантыНалогообложенияПрибыли(ВидыСубконто) Экспорт
```

Пример вызова
```bsl
РаздельныйУчетПоНалогуНаПрибыль.ДобавитьВидСубконтоВариантыНалогообложенияПрибыли(ВидыСубконто) 
```
</details>

## ПустаяСсылкаВариантаНалогообложенияВЗапросе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строковое значение пустой ссылки в запросе
//
// Возвращаемое значение:
// 	Строка -
Функция ПустаяСсылкаВариантаНалогообложенияВЗапросе() Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ПустаяСсылкаВариантаНалогообложенияВЗапросе() 
```
</details>

## ОбработатьПолеВариантаНалогообложенияВЗапросе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В запросе обработается поле варианта н/о, исходя из того, требуются данные в разрезе вариантов н/о или нет.
//
// Параметры:
// 	Запрос                                - Запрос -
// 	ТребуетсяУчетВариантовНалогообложения - Булево -
// 	ПутьКПолю                             - Строка - путь к полю в запросе
// 	ВидыСубконто                          - Массив Из ПланВидовХарактеристикСсылка.ВидыСубконтоХозрасчетные -
// 	                                          Если есть виды субконто, дополнится видом субконто вариантов н/о.
//                                        - Неопределено - не требуется заполнение видов субконто
// 	ЗаменяемыйТекст                       - Строка - по умолчанию "&ПолеВариантНалогообложенияПрибыли"
//
Процедура ОбработатьПолеВариантаНалогообложенияВЗапросе( Экспорт
```

Пример вызова
```bsl
РаздельныйУчетПоНалогуНаПрибыль.ОбработатьПолеВариантаНалогообложенияВЗапросе();
```
</details>

## ОбработатьПолеВариантНалогообложенияПоУмолчаниюВЗапросе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В запросе подставляется вариант н/о по умолчанию, исходя из использования раздельного учета.
//
// Параметры:
// 	Запрос                                - Запрос -
// 	ТребуетсяУчетВариантовНалогообложения - Булево -
// 	ЗаменяемыйТекст                       - Строка - по умолчанию "&ПолеВариантНалогообложенияПоУмолчанию"
//
Процедура ОбработатьПолеВариантНалогообложенияПоУмолчаниюВЗапросе( Экспорт
```

Пример вызова
```bsl
РаздельныйУчетПоНалогуНаПрибыль.ОбработатьПолеВариантНалогообложенияПоУмолчаниюВЗапросе();
```
</details>

## ПолучитьПустуюТаблицуНастройкиНалогообложенияПрибыли
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текст запроса для пустой таблицы РаздельныйУчет_НастройкиНалогообложенияПрибыли
//
// Возвращаемое значение:
//   Строка   - текст запроса
//
Функция ПолучитьПустуюТаблицуНастройкиНалогообложенияПрибыли() Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ПолучитьПустуюТаблицуНастройкиНалогообложенияПрибыли() 
```
</details>

## НовыйПараметрыПолученияНастройкиНалогообложенияПрибыли
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализируются параметры для получения настройки налогообложения прибыли
//
// Возвращаемое значение:
// 	Структура - содержит:
// 		* Период      - Дата - актуальные данные на дату.
// 		* Организация - СправочникСсылка.Организации -
//
// 		// для отбора по значениям должно быть заполнено хотя бы одно поле.
// 		* Подразделение - СправочникСсылка.СтруктураПредприятия -
// 		* ОбъектУчета   - СправочникСсылка.Номенклатура, ПланВидовХарактеристикСсылка.СтатьиДоходов -
// 		* НаправлениеДеятельности - СправочникСсылка.НаправленияДеятельности -
//
Функция НовыйПараметрыПолученияНастройкиНалогообложенияПрибыли() Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.НовыйПараметрыПолученияНастройкиНалогообложенияПрибыли() 
```
</details>

## ПолучитьНастройкуНалогообложенияПрибыли
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращается налогообложение прибыли исходя из настроек учетной политики
//
// Параметры:
// 	ПараметрыПолученияНастроек - см. НовыйПараметрыПолученияНастройкиНалогообложенияПрибыли
//
// Возвращаемое значение:
// 	СправочникСсылка.ВариантыНалогообложенияПрибыли
//
Функция ПолучитьНастройкуНалогообложенияПрибыли(ПараметрыПолученияНастроек) Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ПолучитьНастройкуНалогообложенияПрибыли(ПараметрыПолученияНастроек) 
```
</details>

## НовыйПараметрыПолученияТаблицыНастроекНалогообложенияПрибыли
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Инициализируются параметры для получения таблицы настроек налогообложения прибыли
//
// Возвращаемое значение:
// 	Структура - содержит:
// 		* Период      - Дата - актуальные данные на дату.
// 		* МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - МВТ с данными отбора и для помещения результата
// 		                          - Неопределено - когда нужен только сформированный текст запроса
// 		* ИмяТаблицы                      - Строка - имя временной таблицы (обязательно)
// 		* ИмяПоля_Организация             - Строка - имя колонки "Организация" (обязательно)
// 		* ИмяПоля_Период                  - Строка - имя колонки "Период" (обязательно, если параметр "Период" пустой)
// 		// для отбора по временной таблицы должно быть заполнено как минимум имя одного из полей ниже.
// 		* ИмяПоля_Подразделение           - Строка - имя колонки "Подразделение"
// 		* ИмяПоля_ОбъектУчета             - Строка - имя колонки "ОбъектУчета"
// 		* ИмяПоля_НаправлениеДеятельности - Строка - имя колонки "НаправлениеДеятельности"
//
Функция НовыйПараметрыПолученияТаблицыНастроекНалогообложенияПрибыли() Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.НовыйПараметрыПолученияТаблицыНастроекНалогообложенияПрибыли() 
```
</details>

## ТаблицаЗначений_НастройкиНалогообложенияПрибыли
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает настройки налогообложения прибыли исходя из организации, периода и других объектов отбора
//
// Параметры:
// 	ПараметрыПолученияНастроек - см. НовыйПараметрыПолученияТаблицыНастроекНалогообложенияПрибыли
//
// Возвращаемое значение:
// 	ТаблицаЗначений - содержит:
// 	* Организация             - СправочникСсылка.Организации
// 	* Период                  - Дата
// 	* Подразделение           - СправочникСсылка.СтруктураПредприятия
// 	* ОбъектУчета             - СправочникСсылка.Номенклатура, ПланВидовХарактеристикСсылка.СтатьиДоходов -
// 	* НаправлениеДеятельности - СправочникСсылка.НаправленияДеятельности
// 	* ВариантНалогообложенияПрибыли  - СправочникСсылка.ВариантыНалогообложенияПрибыли
//
Функция ТаблицаЗначений_НастройкиНалогообложенияПрибыли(ПараметрыПолученияНастроек) Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ТаблицаЗначений_НастройкиНалогообложенияПрибыли(ПараметрыПолученияНастроек) 
```
</details>

## ПодготовитьВТ_НастройкиНалогообложенияПрибыли
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создается временная таблица "РаздельныйУчет_НастройкиНалогообложенияПрибыли"
// Содержит колонки:
//
// 	* Организация             - СправочникСсылка.Организации,
// 	* Период                  - Дата - актуальные данные на дату
//
// 	// Значения из переданного отбора. Если отбор отсутствует, будут пустые значения
// 	* Подразделение           - СправочникСсылка.СтруктураПредприятия,
// 	* ОбъектУчета             - СправочникСсылка.Номенклатура, ПланВидовХарактеристикСсылка.СтатьиДоходов,
// 	* НаправлениеДеятельности - СправочникСсылка.НаправленияДеятельности,
//
// 	* ВариантНалогообложенияПрибыли  - СправочникСсылка.ВариантыНалогообложенияПрибыли.
//
// Параметры:
// 	ПараметрыПолученияНастроек - см. НовыйПараметрыПолученияТаблицыНастроекНалогообложенияПрибыли
//
Процедура ПодготовитьВТ_НастройкиНалогообложенияПрибыли(ПараметрыПолученияНастроек) Экспорт
```

Пример вызова
```bsl
РаздельныйУчетПоНалогуНаПрибыль.ПодготовитьВТ_НастройкиНалогообложенияПрибыли(ПараметрыПолученияНастроек) 
```
</details>

## ТекстЗапроса_НастройкиНалогообложенияПрибыли
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текст запроса для создания временной таблицы "РаздельныйУчет_НастройкиНалогообложенияПрибыли"
// Содержит колонки:
//
// 	* Организация             - СправочникСсылка.Организации,
// 	* Период                  - Дата - актуальные данные на дату
//
// 	// Значения из переданного отбора. Если отбор отсутствует, будут пустые значения
// 	* Подразделение           - СправочникСсылка.СтруктураПредприятия,
// 	* ОбъектУчета             - СправочникСсылка.Номенклатура, ПланВидовХарактеристикСсылка.СтатьиДоходов,
// 	* НаправлениеДеятельности - СправочникСсылка.НаправленияДеятельности,
//
// 	* ВариантНалогообложенияПрибыли  - СправочникСсылка.ВариантыНалогообложенияПрибыли.
//
// P.S. Необходимо перед выполнением запроса установить параметр "Период", даже если значение неизвестно и пустое.
//
// Параметры:
// 	ПараметрыПолученияНастроек - см. НовыйПараметрыПолученияТаблицыНастроекНалогообложенияПрибыли
//
// Возвращаемое значение:
// 	Строка - текст запроса
//
Функция ТекстЗапроса_НастройкиНалогообложенияПрибыли(ПараметрыПолученияНастроек) Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ТекстЗапроса_НастройкиНалогообложенияПрибыли(ПараметрыПолученияНастроек) 
```
</details>

## ЕстьНастройкиПоИзмерениям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру признаков наличия настроек по разным измерениям
//
// Параметры:
// 	Организация  - СправочникСсылка.Организации -
// 	НаДату       - Неопределено, Дата - актуальные данные на дату
//
// Возвращаемое значение:
// 	Структура - признак наличия настроек. Содержит:
// 		* ЕстьНастройкиПоПодразделениям           - Булево -
// 		* ЕстьНастройкиПоОбъектамУчета            - Булево -
// 		* ЕстьНастройкиПоНаправлениямДеятельности - Булево -
//
Функция ЕстьНастройкиПоИзмерениям(Организация, Знач НаДату = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ЕстьНастройкиПоИзмерениям(Организация, НаДату);
```
</details>

## ЕстьНастройкиПоПодразделениям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак наличия настроек по подразделениям
//
// Параметры:
// 	Организация  - СправочникСсылка.Организации -
// 	НаДату       - Неопределено, Дата - актуальные данные на дату
//
// Возвращаемое значение:
// 	Булево - признак наличия настроек
//
Функция ЕстьНастройкиПоПодразделениям(Организация, Знач НаДату = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ЕстьНастройкиПоПодразделениям(Организация, НаДату);
```
</details>

## ЕстьНастройкиПоОбъектамУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак наличия настроек по объектам учета (номенклатуре, статьям доходов)
//
// Параметры:
// 	Организация  - СправочникСсылка.Организации -
// 	НаДату       - Неопределено, Дата - актуальные данные на дату
//
// Возвращаемое значение:
// 	Булево - признак наличия настроек
//
Функция ЕстьНастройкиПоОбъектамУчета(Организация, Знач НаДату = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ЕстьНастройкиПоОбъектамУчета(Организация, НаДату);
```
</details>

## ЕстьНастройкиПоНаправлениямДеятельности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак наличия настроек по направлениям деятельности
//
// Параметры:
// 	Организация  - СправочникСсылка.Организации -
// 	НаДату       - Неопределено, Дата - актуальные данные на дату
//
// Возвращаемое значение:
// 	Булево - признак наличия настроек
//
Функция ЕстьНастройкиПоНаправлениямДеятельности(Организация, Знач НаДату = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ЕстьНастройкиПоНаправлениямДеятельности(Организация, НаДату);
```
</details>

## ПустойПодразделение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение пустого подразделения либо в объектном виде, либо строкой для запроса
//
// Параметры:
// 	СтроковоеЗначениеВЗапросе - Булево - Если "Истина", будет возвращена строка для запроса
//
// Возвращаемое значение:
// 	Строка, СправочникСсылка.СтруктураПредприятия -
//
Функция ПустойПодразделение(СтроковоеЗначениеВЗапросе = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ПустойПодразделение(СтроковоеЗначениеВЗапросе);
```
</details>

## ПустойОбъектУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение пустого подразделения либо в объектном виде, либо строкой для запроса
//
// Параметры:
// 	СтроковоеЗначениеВЗапросе - Булево - Если "Истина", будет возвращена строка для запроса
//
// Возвращаемое значение:
// 	Строка, Неопределено -
//
Функция ПустойОбъектУчета(СтроковоеЗначениеВЗапросе = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ПустойОбъектУчета(СтроковоеЗначениеВЗапросе);
```
</details>

## ПустойНаправлениеДеятельности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение пустого подразделения либо в объектном виде, либо строкой для запроса
//
// Параметры:
// 	СтроковоеЗначениеВЗапросе - Булево - Если "Истина", будет возвращена строка для запроса
//
// Возвращаемое значение:
// 	Строка, СправочникСсылка.НаправленияДеятельности -
//
Функция ПустойНаправлениеДеятельности(СтроковоеЗначениеВЗапросе = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = РаздельныйУчетПоНалогуНаПрибыль.ПустойНаправлениеДеятельности(СтроковоеЗначениеВЗапросе);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
