---
title: Распознавание документов HTTP
slug: erp-uh/распознавание-документов-http
---


## НовыеПараметры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор дополнительных параметров
//
// Возвращаемое значение:
//  Структура - позволяет задать дополнительные параметры:
//    * Заголовки - Соответствие из Строка
//    * Таймаут - Число - время ожидания осуществляемого соединения и операций, в секундах.
//                Значение по умолчанию - 30 сек.
//    * Данные - Неопределено, Строка, ДвоичныеДанные - произвольные данные, которые необходимо отправить в запросе.
//    * Json - Неопределено, Структура, Соответствие из Произвольный - Данные,
//                которые должны быть сериализованы в json и помещены в тело запроса.
//    * МаксимальноеКоличествоПовторов - Число - количество повторных попыток соединения/отправки запроса.
//        Между попытками выполняется задержка.
//        Если код состояния один из 413, 429, 503 и в ответе есть заголовок Retry-After,
//        то время задержки формируется из значения этого заголовка, иначе задержка берется равной Таймаут.
//        Значение по умолчанию: 0 - повторы не выполняются.
//
Функция НовыеПараметры() Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовHTTP.НовыеПараметры() 
```
</details>

## НовыйОтвет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пакет ответа результата вызова метода HTTP.
//
// Возвращаемое значение:
//  Структура:
//   * Метод - Строка - имя HTTP-метода запроса
//   * URL - Строка - итоговый URL, по которому был выполнен запрос.
//   * КодСостояния - Число - Код состояния ответа..
//   * Заголовки - Соответствие из Строка - Заголовки ответа.
//   * Тело - ДвоичныеДанные - Тело ответа.
//   * Кодировка - Строка - код кодировки ответа.
//   * ВремяВыполнения - Число - время выполнения запроса в миллисекундах.
//   * Ошибки - Массив Из Строка - Список ошибок возникших в ходе выполнения запроса.
//
Функция НовыйОтвет() Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовHTTP.НовыйОтвет() 
```
</details>

## ВызватьМетод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет данные на указанный адрес для обработки с использованием указанного HTTP-метода.
//
// Параметры:
//   Метод - Строка - имя HTTP-метода для запроса.
//   URL - Строка - URL ресурса, к которому будет отправлен запрос.
//   ДополнительныеПараметры - См. РаспознаваниеДокументовHTTP.НовыеПараметры
//
// Возвращаемое значение:
//   См. РаспознаваниеДокументовHTTP.НовыйОтвет
//
Функция ВызватьМетод(Метод, URL, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовHTTP.ВызватьМетод(Метод, URL, ДополнительныеПараметры);
```
</details>

## Get
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет GET запрос
//
// Параметры:
//   URL - Строка - URL ресурса, к которому будет отправлен запрос.
//   ПараметрыЗапроса - Структура, Соответствие - параметры, которые будут отправлены в URL (часть после ?).
//   ДополнительныеПараметры - См. РаспознаваниеДокументовHTTP.НовыеПараметры
//
// Возвращаемое значение:
//   См. РаспознаваниеДокументовHTTP.НовыйОтвет.
//
Функция Get(URL, ПараметрыЗапроса = Неопределено, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовHTTP.Get(URL, ПараметрыЗапроса, ДополнительныеПараметры);
```
</details>

## Post
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет POST запрос
//
// Параметры:
//   URL - Строка - URL ресурса, к которому будет отправлен запрос.
//   Данные - Структура, Соответствие, Строка, ДвоичныеДанные - см. описание ДополнительныеПараметры.Данные.
//   ДополнительныеПараметры - См. РаспознаваниеДокументовHTTP.НовыеПараметры
//
// Возвращаемое значение:
//   См. РаспознаваниеДокументовHTTP.НовыйОтвет.
//
Функция Post(URL, Данные = Неопределено, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовHTTP.Post(URL, Данные, ДополнительныеПараметры);
```
</details>

## Put
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет PUT запрос
//
// Параметры:
//   URL - Строка - URL ресурса, к которому будет отправлен запрос.
//   Данные - Структура, Соответствие из Произвольный, Строка, ДвоичныеДанные - см. описание
//                           в ДополнительныеПараметры.Данные.
//   ДополнительныеПараметры - См. РаспознаваниеДокументовHTTP.НовыеПараметры
//
// Возвращаемое значение:
//   См. РаспознаваниеДокументовHTTP.НовыйОтвет
//
Функция Put(URL, Данные = Неопределено, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовHTTP.Put(URL, Данные, ДополнительныеПараметры);
```
</details>

## Delete
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отправляет DELETE запрос
//
// Параметры:
//   URL - Строка - URL ресурса, к которому будет отправлен запрос.
//   Данные - Структура, Соответствие из Произвольный, Строка, ДвоичныеДанные - см. описание
//                           в ДополнительныеПараметры.Данные.
//   ДополнительныеПараметры - См. РаспознаваниеДокументовHTTP.НовыеПараметры
//
// Возвращаемое значение:
//   См. РаспознаваниеДокументовHTTP.НовыйОтвет
//
Функция Delete(URL, Данные = Неопределено, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовHTTP.Delete(URL, Данные, ДополнительныеПараметры);
```
</details>

## КакТекст
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ответ сервера в виде текста.
//
// Параметры:
//   Ответ - См. РаспознаваниеДокументовHTTP.НовыйОтвет
//   Кодировка - Строка, КодировкаТекста - определяет кодировку текста.
//     Если значение не задано, то кодировка извлекается из Ответ.Кодировка.
//
// Возвращаемое значение:
//   Строка - ответ сервера в виде текста.
//
Функция КакТекст(Ответ, Кодировка = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовHTTP.КакТекст(Ответ, Кодировка);
```
</details>

## КакДвоичныеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ответ сервера в виде текста.
//
// Параметры:
//   Ответ - См. РаспознаваниеДокументовHTTP.НовыйОтвет
//
// Возвращаемое значение:
//   ДвоичныеДанные - ответ сервера в виде двоичных данных.
//
Функция КакДвоичныеДанные(Ответ) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовHTTP.КакДвоичныеДанные(Ответ) 
```
</details>

## КакJson
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ответ сервера в виде десериализованного значения JSON.
//
// Параметры:
//   Ответ - См. РаспознаваниеДокументовHTTP.НовыйОтвет
//
// Возвращаемое значение:
//   Соответствие из Произвольный- ответ сервера в виде десериализованного значения JSON.
//
Функция КакJson(Ответ) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовHTTP.КакJson(Ответ) 
```
</details>

## КакИсключение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ответ сервера в виде текста предназначенного для использования в ВызватьИсключение.
//
// Параметры:
//   Ответ - См. РаспознаваниеДокументовHTTP.НовыйОтвет
//   ТекстДляПользователя - Строка - Текст пояснения причины для пользователя.
//
// Возвращаемое значение:
//   Строка - ответ сервера в виде текста исключения.
//
Функция КакИсключение(Ответ, Знач ТекстДляПользователя = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовHTTP.КакИсключение(Ответ, ТекстДляПользователя);
```
</details>

## КодыСостоянияHTTP
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Структура именованных кодов состояний HTTP.
//
// Возвращаемое значение:
//   Структура - именованные коды состояний HTTP.
//
Функция КодыСостоянияHTTP() Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовHTTP.КодыСостоянияHTTP() 
```
</details>

## ПредставлениеКодаСостоянияHTTP
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текстовое представление переданного кода состояния HTTP.
//
// Параметры:
//   КодСостояния - Число - код состояния HTTP, для которого нужно получить текстовое представление.
//
// Возвращаемое значение:
//   Строка - текстовое представление кода состояния HTTP.
//
Функция ПредставлениеКодаСостоянияHTTP(КодСостояния) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовHTTP.ПредставлениеКодаСостоянияHTTP(КодСостояния) 
```
</details>

## ОбъектВJson
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразование Объекта в JSON.
//
// Параметры:
//   Объект - Произвольный - данные, которые необходимо преобразовать в JSON.
//
// Возвращаемое значение:
//   Строка - объект в формате JSON.
//
Функция ОбъектВJson(Объект) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовHTTP.ОбъектВJson(Объект) 
```
</details>

## JsonВОбъект
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразование JSON в Объект.
//
// Параметры:
//   Json - Поток, ДвоичныеДанные, Строка - данные в формате JSON.
//   Кодировка - Строка - кодировка текста JSON. Значение по умолчанию - utf-8.
//
// Возвращаемое значение:
//   Произвольный - значение, десериализованное из JSON.
//
Функция JsonВОбъект(Json, Кодировка = "utf-8") Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовHTTP.JsonВОбъект(Json, Кодировка);
```
</details>

## Приостановить
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Приостанавливает работу программы на указанное количество секунд.
// Работает только в фоновых заданиях.
// При вызове не из фоновых заданий ничего не приостанавливает и не бросает исключений.
//
Процедура Приостановить(Секунд) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовHTTP.Приостановить(Секунд) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
