---
title: Распознавание документов служебный клиент
slug: erp-uh/распознавание-документов-служебный-клиент
---


## ЭтоПеречисление
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоПеречисление(Тип) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовСлужебныйКлиент.ЭтоПеречисление(Тип));
```
</details>

## ПоказатьВопросПользователю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Показать форму вопроса.
//
// Параметры:
//   ОписаниеОповещенияОЗавершении - ОписаниеОповещения - описание процедуры, которая будет вызвана после закрытия окна
//                                                        вопроса со следующими параметрами:
//                                                          РезультатВопроса - Структура:
//                                                            Значение - результат выбора пользователя: значение
//                                                                       системного перечисления или значение,
//                                                                       связанное с нажатой кнопкой. В случае закрытия
//                                                                       диалога по истечении времени - значение
//                                                                       Таймаут.
//                                                            БольшеНеЗадаватьЭтотВопрос - Булево - результат выбора
//                                                                                                  пользователя в
//                                                                                                  одноименном флажке.
//                                                          ДополнительныеПараметры - Структура
//   ТекстВопроса                  - Строка             - текст задаваемого вопроса.
//   Кнопки                        - РежимДиалогаВопрос
//                                 - СписокЗначений     - может быть задан список значений, в котором:
//                                       Значение - содержит значение, связанное с кнопкой и возвращаемое при
//                                                  ее нажатии. В качестве значения может использоваться значение
//                                                  перечисления КодВозвратаДиалога, а также другие значения,
//                                                  поддерживающее XDTO-сериализацию.
//                                       Представление - текст кнопки.
//
//   ДополнительныеПараметры       - см. СтандартныеПодсистемыКлиент.ПараметрыВопросаПользователю.
//
Процедура ПоказатьВопросПользователю(ОписаниеОповещенияОЗавершении, ТекстВопроса, Кнопки, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПоказатьВопросПользователю(ОписаниеОповещенияОЗавершении, ТекстВопроса, Кнопки, ДополнительныеПараметры);
```
</details>

## ПараметрыВопросаПользователю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает новую структуру дополнительных параметров для процедуры ПоказатьВопросПользователю.
//
// Возвращаемое значение:
//  Структура:
//    * КнопкаПоУмолчанию             - Произвольный - определяет кнопку по умолчанию по типу кнопки или по связанному
//                                                     с ней значению.
//    * Таймаут                       - Число        - интервал времени в секундах до автоматического закрытия окна
//                                                     вопроса.
//    * КнопкаТаймаута                - Произвольный - кнопка (по типу кнопки или по связанному с ней значению),
//                                                     на которой отображается количество секунд, оставшихся до
//                                                     истечения таймаута.
//    * Заголовок                     - Строка       - заголовок вопроса.
//    * ПредлагатьБольшеНеЗадаватьЭтотВопрос - Булево - если Истина, то в окне вопроса будет доступен одноименный флажок.
//    * БольшеНеЗадаватьЭтотВопрос    - Булево       - принимает значение, выбранное пользователем в соответствующем
//                                                     флажке.
//    * БлокироватьВесьИнтерфейс      - Булево       - если Истина, форма вопроса открывается, блокируя работу всех
//                                                     остальных открытых окон, включая главное окно.
//    * Картинка                      - Картинка     - картинка, выводимая в окне вопроса.
//
Функция ПараметрыВопросаПользователю() Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовСлужебныйКлиент.ПараметрыВопросаПользователю() 
```
</details>

## ПослеАвторизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПослеАвторизации(Результат, Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПослеАвторизации(Результат, Контекст) 
```
</details>

## ПослеВыполненияДействийПослеАвторизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПослеВыполненияДействийПослеАвторизации(Результат, Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПослеВыполненияДействийПослеАвторизации(Результат, Контекст) 
```
</details>

## ПроверитьДопустимыеДействияПослеУспешнойАвторизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПроверитьДопустимыеДействияПослеУспешнойАвторизации(ОповещениеОЗавершении, ТипАвторизации, ВладелецФормы = Неопределено) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПроверитьДопустимыеДействияПослеУспешнойАвторизации(ОповещениеОЗавершении, ТипАвторизации, ВладелецФормы);
```
</details>

## ПослеПолученияРезультатаПроверкиДопустимыхДействийПриАвторизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПослеПолученияРезультатаПроверкиДопустимыхДействийПриАвторизации(ДлительнаяОперация, Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПослеПолученияРезультатаПроверкиДопустимыхДействийПриАвторизации(ДлительнаяОперация, Контекст) 
```
</details>

## ВыполнитьДействияПослеУспешнойАвторизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВыполнитьДействияПослеУспешнойАвторизации(Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ВыполнитьДействияПослеУспешнойАвторизации(Контекст));
```
</details>

## ПослеВводаПромокодаПриАвторизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПослеВводаПромокодаПриАвторизации(ПромокодАктивирован, Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПослеВводаПромокодаПриАвторизации(ПромокодАктивирован, Контекст) 
```
</details>

## ПослеПодключенияТестовогоПериодаПриАвторизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПослеПодключенияТестовогоПериодаПриАвторизации(Результат, Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПослеПодключенияТестовогоПериодаПриАвторизации(Результат, Контекст) 
```
</details>

## ПослеВводаПромокода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПослеВводаПромокода(Результат, Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПослеВводаПромокода(Результат, Контекст) 
```
</details>

## СохранитьФайлыДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СохранитьФайлыДокумента(РаспознанныйДокумент, ИдентификаторФормы) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.СохранитьФайлыДокумента(РаспознанныйДокумент, ИдентификаторФормы) 
```
</details>

## ПослеСохраненияФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПослеСохраненияФайла(ПолученныеФайлы, Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПослеСохраненияФайла(ПолученныеФайлы, Контекст) 
```
</details>

## ПоказатьРаспознанныйДокумент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПоказатьРаспознанныйДокумент( Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПоказатьРаспознанныйДокумент();
```
</details>

## ИзменитьТипДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ИзменитьТипДокумента(Форма, ОбработкаЗавершения, ПредлагатьЗаписать = Истина) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ИзменитьТипДокумента(Форма, ОбработкаЗавершения, ПредлагатьЗаписать);
```
</details>

## ПослеПодтвержденияИзмененияТипаДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПослеПодтвержденияИзмененияТипаДокумента(РезультатВопроса, Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПослеПодтвержденияИзмененияТипаДокумента(РезультатВопроса, Контекст) 
```
</details>

## ИзменитьВариантОбработки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ИзменитьВариантОбработки(Форма, ОбработкаЗавершения, ПредлагатьЗаписать = Истина) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ИзменитьВариантОбработки(Форма, ОбработкаЗавершения, ПредлагатьЗаписать);
```
</details>

## ПослеПодтвержденияИзмененияВариантаОбработки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПослеПодтвержденияИзмененияВариантаОбработки(РезультатВопроса, Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПослеПодтвержденияИзмененияВариантаОбработки(РезультатВопроса, Контекст) 
```
</details>

## ТребуетсяИзменениеФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТребуетсяИзменениеФормы(Форма) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовСлужебныйКлиент.ТребуетсяИзменениеФормы(Форма));
```
</details>

## ОбработатьПереходФормыЕслиТребуется
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбработатьПереходФормыЕслиТребуется(Форма, Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ОбработатьПереходФормыЕслиТребуется(Форма, Контекст));
```
</details>

## ОткрытьФормуСозданияЭлемента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОткрытьФормуСозданияЭлемента( Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ОткрытьФормуСозданияЭлемента();
```
</details>

## НаборДанныхСозданияЭлемента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НаборДанныхСозданияЭлемента(НаборДанных) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовСлужебныйКлиент.НаборДанныхСозданияЭлемента(НаборДанных) 
```
</details>

## ДанныеЗаполненияДляНовогоЭлемента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДанныеЗаполненияДляНовогоЭлемента(ИсточникДанных) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовСлужебныйКлиент.ДанныеЗаполненияДляНовогоЭлемента(ИсточникДанных)
```
</details>

## ОткрытьФормуОбратнойСвязи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОткрытьФормуОбратнойСвязи(Форма) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ОткрытьФормуОбратнойСвязи(Форма) 
```
</details>

## ОбработкаВыбораОбратнойСвязи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбработкаВыбораОбратнойСвязи(Форма, ВыбранноеЗначение) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ОбработкаВыбораОбратнойСвязи(Форма, ВыбранноеЗначение) 
```
</details>

## ЗагрузитьКартинкуПоАдресу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗагрузитьКартинкуПоАдресу(ЭлементФормы, АдресКартинки) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ЗагрузитьКартинкуПоАдресу(ЭлементФормы, АдресКартинки) 
```
</details>

## ЗапросСохраненияСопоставленийТекстаСОбъектом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗапросСохраненияСопоставленийТекстаСОбъектом(ПараметрыСохранения) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ЗапросСохраненияСопоставленийТекстаСОбъектом(ПараметрыСохранения) 
```
</details>

## ПолучитьЗначенияСпискаВыбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьЗначенияСпискаВыбора(Текст, ТипЗначения, ВозможныеВарианты) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовСлужебныйКлиент.ПолучитьЗначенияСпискаВыбора(Текст, ТипЗначения, ВозможныеВарианты) 
```
</details>

## ДобавитьСоответствиеРаспознаваемыхСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьСоответствиеРаспознаваемыхСтрок( Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ДобавитьСоответствиеРаспознаваемыхСтрок();
```
</details>

## СоответствиеПереданногоРаспознанногоЗначения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СоответствиеПереданногоРаспознанногоЗначения( Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовСлужебныйКлиент.СоответствиеПереданногоРаспознанногоЗначения();
```
</details>

## ДобавитьСоответствиеРаспознаваемыхСтрокЗавершение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьСоответствиеРаспознаваемыхСтрокЗавершение(Результат, Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ДобавитьСоответствиеРаспознаваемыхСтрокЗавершение(Результат, Контекст) 
```
</details>

## ПолучитьТипЗначенияСтрокой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТипЗначенияСтрокой(Тип) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовСлужебныйКлиент.ПолучитьТипЗначенияСтрокой(Тип) 
```
</details>

## ПоказатьТребованиеВключитьИТС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПоказатьТребованиеВключитьИТС(Обработчик) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПоказатьТребованиеВключитьИТС(Обработчик) 
```
</details>

## ПоказатьПредупреждениеНулевойБаланс
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПоказатьПредупреждениеНулевойБаланс(Обработчик, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПоказатьПредупреждениеНулевойБаланс(Обработчик, ДатаОкончания) 
```
</details>

## ПоказатьПредупреждениеСервисОтключен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПоказатьПредупреждениеСервисОтключен(Обработчик) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПоказатьПредупреждениеСервисОтключен(Обработчик) 
```
</details>

## ПослеОтветаНаВопрос
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПослеОтветаНаВопрос(Результат, Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПослеОтветаНаВопрос(Результат, Контекст) 
```
</details>

## ОтображатьПредупреждение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает Ложь если не отображать
//
Функция ОтображатьПредупреждение(ИмяПараметра) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовСлужебныйКлиент.ОтображатьПредупреждение(ИмяПараметра));
```
</details>

## ВключитьСемафорПредупреждения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает Ложь если не удалось включить
//
Функция ВключитьСемафорПредупреждения() Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовСлужебныйКлиент.ВключитьСемафорПредупреждения());
```
</details>

## ВыключитьСемафорПредупреждения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВыключитьСемафорПредупреждения() Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ВыключитьСемафорПредупреждения());
```
</details>

## ДоступенНеоплаченныйРаспознанныйДокумент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДоступенНеоплаченныйРаспознанныйДокумент(РаспознанныйДокумент) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовСлужебныйКлиент.ДоступенНеоплаченныйРаспознанныйДокумент(РаспознанныйДокумент) 
```
</details>

## ПоказатьСозданиеДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПоказатьСозданиеДокумента(Форма, ПараметрыОперации, ОповещениеОЗавершении = Неопределено) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПоказатьСозданиеДокумента(Форма, ПараметрыОперации, ОповещениеОЗавершении);
```
</details>

## КонтекстСозданияРаспознанногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КонтекстСозданияРаспознанногоДокумента(Форма, ПараметрыОперации) Экспорт
```

Пример вызова
```bsl
Результат = РаспознаваниеДокументовСлужебныйКлиент.КонтекстСозданияРаспознанногоДокумента(Форма, ПараметрыОперации));
```
</details>

## ПриИзмененииСостояния
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриИзмененииСостояния(Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПриИзмененииСостояния(Контекст));
```
</details>

## СледующееСостояние
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СледующееСостояние(Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.СледующееСостояние(Контекст));
```
</details>

## ЗадатьВопросОСозданииДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьВопросОСозданииДокумента(Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ЗадатьВопросОСозданииДокумента(Контекст));
```
</details>

## ПриПолученииРезультатаОНаличииИмеющихся
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриПолученииРезультатаОНаличииИмеющихся(Результат, Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПриПолученииРезультатаОНаличииИмеющихся(Результат, Контекст) 
```
</details>

## ЗадатьВопросОЗакрытомПериоде
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьВопросОЗакрытомПериоде(Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ЗадатьВопросОЗакрытомПериоде(Контекст));
```
</details>

## ПриПолученииРезультатаОЗакрытомПериоде
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриПолученииРезультатаОЗакрытомПериоде(Результат, Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПриПолученииРезультатаОЗакрытомПериоде(Результат, Контекст) 
```
</details>

## ЗадатьВопросОПересчетеСкидок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗадатьВопросОПересчетеСкидок(Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ЗадатьВопросОПересчетеСкидок(Контекст));
```
</details>

## ПриПолученииРезультатаОПересчетеСкидок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриПолученииРезультатаОПересчетеСкидок(Результат, Контекст) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПриПолученииРезультатаОПересчетеСкидок(Результат, Контекст) 
```
</details>

## ПоказатьФормуБлокировки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПоказатьФормуБлокировки(Форма, Отказ) Экспорт
```

Пример вызова
```bsl
РаспознаваниеДокументовСлужебныйКлиент.ПоказатьФормуБлокировки(Форма, Отказ) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
