---
title: Распределение запасов движения
slug: erp-uh/распределение-запасов-движения
---


## ПараметрыДляПроведенияДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует параметры для проведения документа по регистрам учетного механизма через общий механизм проведения.
//
// Параметры:
//  Документ - ДокументОбъект - записываемый документ
//  Свойства - ФиксированнаяСтруктура - свойства документа (См. ПроведениеДокументов.СвойстваДокумента).
//
//
// Возвращаемое значение:
//  Структура - См. ПроведениеДокументов.ПараметрыУчетногоМеханизма
//
Функция ПараметрыДляПроведенияДокумента(Документ, Свойства) Экспорт
```

Пример вызова
```bsl
Результат = РаспределениеЗапасовДвижения.ПараметрыДляПроведенияДокумента(Документ, Свойства) 
```
</details>

## ТекстыЗапросовСторнирования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает тексты запросов для сторнирования движений при исправлении документов
//
// Параметры:
// 	МетаданныеДокумента - ОбъектМетаданныхДокумент - Метаданные документа, который проводится.
//
// Возвращаемое значение:
// 	Соответствие - Соответствие полного имени регистра тексту запроса сторнирования
//
Функция ТекстыЗапросовСторнирования(МетаданныеДокумента) Экспорт
```

Пример вызова
```bsl
Результат = РаспределениеЗапасовДвижения.ТекстыЗапросовСторнирования(МетаданныеДокумента) 
```
</details>

## ТекстыЗапросовКонтрольДатыЗапретаПоТаблицеИзменений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет текст запроса механизма проверки даты запрета по таблице изменений.
//
// Параметры:
// 	Запрос - Запрос - используется для установки параметров запроса.
//
// Возвращаемое значение:
//	Соответствие - соответствие имен таблиц изменения регистров и текстов запросов.
//
Функция ТекстыЗапросовКонтрольДатыЗапретаПоТаблицеИзменений(Запрос) Экспорт
```

Пример вызова
```bsl
Результат = РаспределениеЗапасовДвижения.ТекстыЗапросовКонтрольДатыЗапретаПоТаблицеИзменений(Запрос) 
```
</details>

## ОтразитьДвижения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура формирования движений по подчиненным регистрам обеспечения.
//
// Параметры:
//	ТаблицыДляДвижений - Структура - таблицы данных документа
//	Движения - КоллекцияДвижений - коллекция наборов записей движений документа
//	Отказ - Булево - признак отказа от проведения документа.
//
Процедура ОтразитьДвижения(ТаблицыДляДвижений, Движения, Отказ) Экспорт
```

Пример вызова
```bsl
РаспределениеЗапасовДвижения.ОтразитьДвижения(ТаблицыДляДвижений, Движения, Отказ) 
```
</details>

## ИнициализироватьДанныеКонтроляИзменений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует тексты запросов для контроля изменений записанных движений регистров.
//
// Параметры:
//  Запрос - Запрос - запрос, хранящий параметры используемые в списке запросов
//  ТекстыЗапроса - СписокЗначений Из Строка - список текстов запросов и их имен.
//  Документ - ДокументОбъект - записываемый документ.
//
Процедура ИнициализироватьДанныеКонтроляИзменений(Запрос, ТекстыЗапроса, Документ) Экспорт
```

Пример вызова
```bsl
РаспределениеЗапасовДвижения.ИнициализироватьДанныеКонтроляИзменений(Запрос, ТекстыЗапроса, Документ) 
```
</details>

## СообщитьОРезультатахКонтроляИзменений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит сообщения пользователю при наличии ошибок контроля изменений записанных движений регистров.
//
// Параметры:
//  РезультатыКонтроля - Структура - таблицы с результатами контроля изменений
//  Документ - ДокументОбъект - записываемый документ
//  Отказ - Булево - признак отказа от проведения документа.
//
Процедура СообщитьОРезультатахКонтроляИзменений(РезультатыКонтроля, Документ, Отказ) Экспорт
```

Пример вызова
```bsl
РаспределениеЗапасовДвижения.СообщитьОРезультатахКонтроляИзменений(РезультатыКонтроля, Документ, Отказ) 
```
</details>

## ПриИзмененииПриоритета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Перераспределяет запасы при групповом изменении приоритета заказов на отгрузку.
//
// Параметры:
// 	Заказы - Массив - ссылки на заказы.
//
Процедура ПриИзмененииПриоритета(Заказы) Экспорт
```

Пример вызова
```bsl
РаспределениеЗапасовДвижения.ПриИзмененииПриоритета(Заказы) 
```
</details>

## РасходЗапаса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// Шаблоны движений документов.

// Дополняет тексты запроса проведения документа текстами движений регистра ЗапасыИПотребности
// и регистра ЗапасыИПотребности, отражающего операцию движения товаров к отгрузке (списание из доступного остатка).
// Уменьшает фактический и свободный остаток товара на складе, работы в подразделении.
// Проведение документа может быть выполнено с контролем остатков.
// Если свободного остатка недостаточно могут быть задействованы запасы на складе,
// распределенные ранее на указанный документ планируемого расхода запаса.
//
// Параметры:
//  Запрос - Запрос - Запрос отражения документа.
//  ТекстыЗапроса - СписокЗначений - Список текстов запроса отражения документа.
//  Регистры - Неопределено, Структура, Строка - Список регистров для отражения.
//  ТекстЗапросаТабЧасть - Строка - Текст запроса получения данных документа. Выражения выборки должны содержать следующие поля:
//   * Ссылка                                     - ДокументСсылка                        - отражаемый документ.
//   * Период                                     - Дата                                  - дата отражения операции (соответствует дате документа).
//   * Номенклатура                               - СправочникСсылка.Номенклатура         - списываемая из запаса номенклатура.
//   * Характеристика                             - СправочникСсылка.ХарактеристикиНоменклатуры - списываемая из запаса характеристика номенклатуры.
//   * Склад                                      - СправочникСсылка.Склады -             - склад списания.
//   * Назначение                                 - СправочникСсылка.Назначения -         - назначение номенклатуры.
//   * Количество                                 - Число                                 - списываемое количество.
//   * ЗапланированныйРасходРаспределенногоЗапаса - ОпределяемыйТип.ОжидаемаяОтгрузка     - документ планирования расхода запасов,
//                                                                                          распределенные запасы которого будут израсходованы.
//   * КонтрольСвободногоОстатка                  - Булево                                - контроль свободного остатка при списании запасов.
//  ТекстыШаблоновВременныхТаблиц - см. ПроведениеДокументов.ДополнитьЗапросОтраженияДокумента.ТекстыШаблоновВременныхТаблиц
Процедура РасходЗапаса(Запрос, ТекстыЗапроса, Регистры, ТекстЗапросаТабЧасть, ТекстыШаблоновВременныхТаблиц = Неопределено) Экспорт
```

Пример вызова
```bsl
РаспределениеЗапасовДвижения.РасходЗапаса(Запрос, ТекстыЗапроса, Регистры, ТекстЗапросаТабЧасть, ТекстыШаблоновВременныхТаблиц);
```
</details>

## ЗапланироватьРасходЗапаса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет тексты запроса проведения документа текстами движений регистра ЗапасыИПотребности
// и регистра ЗапасыИПотребности, отражающего операцию планируемого расхода товаров.
// Резервировать: уменьшает свободный остаток с контролем остатка, формирует резерв товара на складе по заказу.
// НеОбеспечивать: не формирует потребности и резервов, фиксирует факт приема заказа
// КОбеспечению, если есть свободный остаток на складе / в ожидаемых поступлениях: уменьшает свободный остаток,
// формирует резерв товара на складе по заказуКОбеспечению, если нет свободного остатка на складе / в ожидаемых поступлениях: формирует потребность в товаре / работах
//
// Параметры:
//  Запрос - Запрос - Запрос отражения документа.
//  ТекстыЗапроса - СписокЗначений - Список текстов запроса отражения документа.
//  Регистры - Неопределено, Структура, Строка - Список регистров для отражения.
//  ТекстЗапросаТабЧасть - Строка - Текст запроса получения данных документа. Выражения выборки должны содержать следующие поля:
//   * Ссылка                                     - ДокументСсылка                         - отражаемый документ.
//   * Период                                     - Дата                                   - дата отражения операции (соответствует дате документа).
//   * Номенклатура                               - СправочникСсылка.Номенклатура          - списываемая из запаса номенклатура.
//   * Характеристика                             - СправочникСсылка.ХарактеристикиНоменклатуры - списываемая из запаса характеристика номенклатуры.
//   * Склад                                      - СправочникСсылка.Склады -              - склад списания.
//   * Назначение                                 - СправочникСсылка.Назначения -          - назначение номенклатуры.
//   * Количество                                 - Число                                  - заказываемое количество.
//   * ВариантОбеспечения                         - ПеречислениеСсылка.ВариантыОбеспечения - вариант обеспечения.
//   * Заказ                                      - ОпределяемыйТип.ОжидаемаяОтгрузка      - заказ.
//   * ЖелаемаяДатаОтгрузки                       - Дата                                   - планируемая дата списания запасов.
//   * ПоГрафику                                  - Булево - признак, что расход товара происходит по ранее запланированному в графике расходу.
//   * РаспоряжениеВГрафике                       - ОпределяемыйТип.ОжидаемаяОтгрузка      - документ планирования расхода запаса,
//                                                                                           запасы которого будут уменьшены.
//   * КоличествоВГрафике                         - Число                                  - количество запаса, на которое будет уменьшен запас
//                                                                                           ранее запланированного в графике расхода.
//
Процедура ЗапланироватьРасходЗапаса(Запрос, ТекстыЗапроса, Регистры, ТекстЗапросаТабЧасть) Экспорт
```

Пример вызова
```bsl
РаспределениеЗапасовДвижения.ЗапланироватьРасходЗапаса(Запрос, ТекстыЗапроса, Регистры, ТекстЗапросаТабЧасть) 
```
</details>

## ПриходЗапаса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет тексты запроса проведения документа текстами движений регистра ЗапасыИПотребности
// и регистра ЗапасыИПотребности, отражающего операцию фактического поступления товаров на склад
// (пополнение доступного остатка).
// Увеличивает фактический и свободный остаток товара на складе, работы в подразделении.
// Если приход товара ранее был запланирован документом планового прихода запаса (приход по графику),
// то при проведении будет уменьшен запас и свободный остаток в данном ожидаемом приходе (распоряжении).
//
// Параметры:
//  Запрос - Запрос - Запрос отражения документа.
//  ТекстыЗапроса - СписокЗначений - Список текстов запроса отражения документа.
//  Регистры - Неопределено, Структура, Строка - Список регистров для отражения.
//  ТекстЗапросаТабЧасть - Строка - Текст запроса получения данных документа. Выражения выборки должны содержать следующие поля:
//   * Ссылка               - ДокументСсылка                        - отражаемый документ.
//   * Период               - Дата                                  - дата отражения операции (соответствует дате документа).
//   * Номенклатура         - СправочникСсылка.Номенклатура         - приходуемая номенклатура.
//   * Характеристика       - СправочникСсылка.ХарактеристикиНоменклатуры - приходуемая характеристика номенклатуры.
//   * Склад                - СправочникСсылка.Склады -             - склад оприходования.
//   * Назначение           - СправочникСсылка.Назначения -         - назначение приходуемой номенклатуры.
//   * Количество           - Число                                 - приходуемое количество.
//   * ПоГрафику            - Булево                                - признак, что приход товара происходит по ранее запланированному в графике поступлению.
//   * РаспоряжениеВГрафике - ОпределяемыйТип.ОжидаемоеПоступление  - документ планирования прихода запаса,
//                                                                    запасы которого будут уменьшены на величину данного прихода запаса.
//  ТекстыШаблоновВременныхТаблиц - см. ПроведениеДокументов.ДополнитьЗапросОтраженияДокумента.ТекстыШаблоновВременныхТаблиц
Процедура ПриходЗапаса(Запрос, ТекстыЗапроса, Регистры, ТекстЗапросаТабЧасть, ТекстыШаблоновВременныхТаблиц = Неопределено) Экспорт
```

Пример вызова
```bsl
РаспределениеЗапасовДвижения.ПриходЗапаса(Запрос, ТекстыЗапроса, Регистры, ТекстЗапросаТабЧасть, ТекстыШаблоновВременныхТаблиц);
```
</details>

## ЗапланироватьПриходЗапаса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет тексты запроса проведения документа текстами движений регистра ЗапасыИПотребности
// и регистра ЗапасыИПотребности, отражающего операцию фактического поступления товаров на склад
// (пополнение доступного остатка).
// Увеличивает фактический и свободный остаток товара на складе, работы в подразделении.
// Если приход товара ранее был запланирован документом планового прихода запаса (приход по графику),
// то при проведении будет уменьшен запас и свободный остаток в данном ожидаемом приходе (распоряжении).
//
// Параметры:
//  Запрос - Запрос - Запрос отражения документа.
//  ТекстыЗапроса - СписокЗначений - Список текстов запроса отражения документа.
//  Регистры - Неопределено, Структура, Строка - Список регистров для отражения.
//  ТекстЗапросаТабЧасть - Строка - Текст запроса получения данных документа. Выражения выборки должны содержать следующие поля:
//   * Ссылка               - ДокументСсылка                        - отражаемый документ.
//   * Период               - Дата                                  - дата отражения операции (соответствует дате документа).
//   * Номенклатура         - СправочникСсылка.Номенклатура         - приходуемая номенклатура.
//   * Характеристика       - СправочникСсылка.ХарактеристикиНоменклатуры - приходуемая характеристика номенклатуры.
//   * Склад                - СправочникСсылка.Склады -             - склад оприходования.
//   * Назначение           - СправочникСсылка.Назначения -         - назначение приходуемой номенклатуры.
//   * Количество           - Число                                 - приходуемое количество.
//   * Заказ                - ОпределяемыйТип.ОжидаемоеПоступление  - заказ по которому планируется поступление.
//   * ДатаПоступления      - Булево                                - дата на которую планируется поступление.
//   * ДоступенДляРасхода   - Булево                                - признак, что данный запас можно использовать для обеспечения запланированного расхода запаса.
//   * ПоГрафику            - Булево                                - признак, что приход товара происходит по ранее запланированному в графике поступлению.
//   * РаспоряжениеВГрафике - ОпределяемыйТип.ОжидаемоеПоступление  - документ планирования прихода запаса,
//                                                                    запасы которого будут уменьшены.
//   * КоличествоВГрафике   - Число                                 - количество запаса, на которое будет уменьшен запас ранее запланированного в графике поступления.
Процедура ЗапланироватьПриходЗапаса(Запрос, ТекстыЗапроса, Регистры, ТекстЗапросаТабЧасть) Экспорт
```

Пример вызова
```bsl
РаспределениеЗапасовДвижения.ЗапланироватьПриходЗапаса(Запрос, ТекстыЗапроса, Регистры, ТекстЗапросаТабЧасть) 
```
</details>

## ОтменитьЗапланированныйПриходЗапаса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет тексты запроса проведения документа текстами движений регистра ЗапасыИПотребности
// и регистра ЗапасыИПотребности, отражающего операцию отмены запланированного прихода товаров на склад.
// Увеличивает фактический и свободный остаток товара на складе, работы в подразделении.
// Будет уменьшен запас и свободный остаток в ожидаемом приходе (распоряжении).
//
// Параметры:
//  Запрос - Запрос - Запрос отражения документа.
//  ТекстыЗапроса - СписокЗначений - Список текстов запроса отражения документа.
//  Регистры - Неопределено, Структура, Строка - Список регистров для отражения.
//  ТекстЗапросаТабЧасть - Строка - Текст запроса получения данных документа. Выражения выборки должны содержать следующие поля:
//   * Ссылка               - ДокументСсылка                        - отражаемый документ.
//   * Период               - Дата                                  - дата отражения операции (соответствует дате документа).
//   * Номенклатура         - СправочникСсылка.Номенклатура         - приходуемая номенклатура.
//   * Характеристика       - СправочникСсылка.ХарактеристикиНоменклатуры - приходуемая характеристика номенклатуры.
//   * Склад                - СправочникСсылка.Склады -             - склад оприходования.
//   * Назначение           - СправочникСсылка.Назначения -         - назначение приходуемой номенклатуры.
//   * Количество           - Число                                 - отменяемое количество.
//   * РаспоряжениеВГрафике - ОпределяемыйТип.ОжидаемоеПоступление  - документ планирования прихода запаса,
//                                                                    запасы которого будут уменьшены.
Процедура ОтменитьЗапланированныйПриходЗапаса(Запрос, ТекстыЗапроса, Регистры, ТекстЗапросаТабЧасть) Экспорт
```

Пример вызова
```bsl
РаспределениеЗапасовДвижения.ОтменитьЗапланированныйПриходЗапаса(Запрос, ТекстыЗапроса, Регистры, ТекстЗапросаТабЧасть) 
```
</details>

## ТекстЗапросаРаспоряжениеНаОбеспечениеИОтгрузку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет тексты запроса проведения документа текстами движений регистра ЗапасыИПотребности,
// отражающего операцию планирования графика отгрузки по датам, а также движения товаров к отгрузке.
//
// Параметры:
//  ТекстЗапросаТабЧасть - Строка - Текст запроса получения данных документа
//  	Выражения выборки должны содержать следующие поля:
//   * Период                                     - Дата                                   - дата отражения операции (соответствует дате документа).
//   * Номенклатура                               - СправочникСсылка.Номенклатура          - списываемая из запаса номенклатура.
//   * Характеристика                             - СправочникСсылка.ХарактеристикиНоменклатуры - списываемая из запаса характеристика номенклатуры.
//   * Склад                                      - СправочникСсылка.Склады -              - склад списания.
//   * Назначение                                 - СправочникСсылка.Назначения -          - назначение номенклатуры.
//   * Количество                                 - Число                                  - заказываемое количество.
//   * ВариантОбеспечения                         - ПеречислениеСсылка.ВариантыОбеспечения - вариант обеспечения.
//   * ЗаказНаОтгрузку                            - ОпределяемыйТип.ОжидаемаяОтгрузка      - заказ.
//   * ЖелаемаяДатаОтгрузки                       - Дата                                   - планируемая дата списания запасов.
//   * ДатаПриема - Дата -
//   * ПорядокПоПриоритету - Число -
//   * ГотовКОбеспечению - Булево -
//   * ГотовКОтгрузке - Булево -
//  ИгнорироватьГотовностьКОбеспечению - Булево -
//
//	Возвращаемое значение:
//   Строка - Текст запроса.
Функция ТекстЗапросаРаспоряжениеНаОбеспечениеИОтгрузку(ТекстЗапросаТабЧасть, ИгнорироватьГотовностьКОбеспечению) Экспорт
```

Пример вызова
```bsl
Результат = РаспределениеЗапасовДвижения.ТекстЗапросаРаспоряжениеНаОбеспечениеИОтгрузку(ТекстЗапросаТабЧасть, ИгнорироватьГотовностьКОбеспечению) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
