---
title: Расхождения сервер
slug: erp-uh/расхождения-сервер
---


## ИзменитьДокументОснованиеАктаОРасхождениях
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменяет документ основание Акта о расхождениях в соответствии с актом.
// Перед изменением выполняется проверка, что изменения требуются.
//
// Параметры:
//  АктОРасхождениях  - ДокументСсылка.АктОРасхожденияхПослеОтгрузки - акт о расхождениях.
//  Основание         - ДокументСсылка.РеализацияТоваровУслуг, ДокументСсылка.ВозвратТоваровПоставщику, ДокументСсылка.ВозвратТоваровОтКлиента -
//                      основание акта, которое подлежит изменению.
//
Процедура ИзменитьДокументОснованиеАктаОРасхождениях(АктОРасхождениях, Основание) Экспорт
```

Пример вызова
```bsl
РасхожденияСервер.ИзменитьДокументОснованиеАктаОРасхождениях(АктОРасхождениях, Основание) 
```
</details>

## ДокументОснованиеСоответствуетАкту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет доступно ли изменение основания акта
//
// Параметры:
//  АктОРасхождениях  - ДокументСсылка.АктОРасхожденияхПослеОтгрузки - акт о расхождениях.
//  Основание         - ДокументСсылка.РеализацияТоваровУслуг, ДокументСсылка.ВозвратТоваровПоставщику - основание акта,
//                      которое проверяется на возможность изменений.
//  ИзменениеДокумента - Булево -
//
// Возвращаемое значение:
//   Строка   - состояние доступности изменений. Может принимать следующие значения:
//              "ИзмененияНеТребуются", "ИзмененияВыполнены", "ТребуютсяИзменения", "ОснованиеНеСоответствуетАкту".
//
Функция ДокументОснованиеСоответствуетАкту(АктОРасхождениях, Основание, ИзменениеДокумента = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = РасхожденияСервер.ДокументОснованиеСоответствуетАкту(АктОРасхождениях, Основание, ИзменениеДокумента);
```
</details>

## ОписаниеМетаданныхПроверкиВозможностиВнесенияИзлишкаВНакладную
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Структура содержащая соответствия имен полей в акте и накладной, служебные признаки.
//
// Возвращаемое значение:
//   Структура - соответствия имен:
//   * ИмяПоляНакладнойЗаказ - Строка -
//   * ИмяПоляРегистраЗаказ - Строка -
//   * ИмяПоляАктаЗаказ - Строка -
//   * ИмяПоляАктаНакладная - Строка -
//   * ИменаПолейУникальности - Строка -
//   * ИмяПоляКОформлению - Строка -
//   * ЗаказВШапке - Булево -
//
Функция ОписаниеМетаданныхПроверкиВозможностиВнесенияИзлишкаВНакладную() Экспорт
```

Пример вызова
```bsl
Результат = РасхожденияСервер.ОписаниеМетаданныхПроверкиВозможностиВнесенияИзлишкаВНакладную() 
```
</details>

## ПроверкаВозможностиВнесенияИзлишкаВНакладную
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура - Проверка возможности внесения избытка в накладную
//
// Параметры:
//  Акт					 - ДокументОбъект	 - Текущий акт
//  ИмяРегистра			 - Строка			 - Имя регистра Заказ, соответствующий типу накладной используемой в акте
//  ОписаниеМетаданных	 - Структура		 - Описание соответствий имен полей в акте и накладной, служебные признаки
//  Отказ				 - Булево
//
Процедура ПроверкаВозможностиВнесенияИзлишкаВНакладную(Акт, ИмяРегистра, ОписаниеМетаданных, Отказ) Экспорт
```

Пример вызова
```bsl
РасхожденияСервер.ПроверкаВозможностиВнесенияИзлишкаВНакладную(Акт, ИмяРегистра, ОписаниеМетаданных, Отказ) 
```
</details>

## УстановитьВариантДействияВСтроках
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Установить вариант действия в строках.
//
// Параметры:
// 	Форма - ФормаКлиентскогоПриложения - Изменяемая форма
//  РезультатВыбораПользователя - Структура -
//  КоличествоИзмененныхСтрокСоответствие - см. РасхожденияКлиент.УстановитьВариантДействияВыделеннымСтрокам.РезультатВыбораПользователя
//
// Возвращаемое значение:
// 	Число - Количество измененных строк
Функция УстановитьВариантДействияВСтроках(Форма, РезультатВыбораПользователя, КоличествоИзмененныхСтрокСоответствие) Экспорт
```

Пример вызова
```bsl
Результат = РасхожденияСервер.УстановитьВариантДействияВСтроках(Форма, РезультатВыбораПользователя, КоличествоИзмененныхСтрокСоответствие) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
