---
title: Расчет имущественных налогов
slug: erp-uh/расчет-имущественных-налогов
---


## ПолучитьРасчетПоНалогуНаИмущество
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает результат расчета налога (или аванса по налогу) на имущество.
//
// Параметры:
//  Организация	- СправочникСсылка.Организации - Организация, для которой необходимо выполнить расчет.
//  ПериодРасчета - Дата - Дата расчета.
//  ДополнительныеПараметры - Произвольный - Дополнительные параметры расчета.
//
// Возвращаемое значение:
//  Структура - Результат расчета налога. Имена свойств соответствуют наименованиям регистров сведений, куда записывается
//  результат, а значения свойств - таблицы записей этих регистров (ТаблицаЗначений)
//
Функция ПолучитьРасчетПоНалогуНаИмущество(Организация, ПериодРасчета, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РасчетИмущественныхНалогов.ПолучитьРасчетПоНалогуНаИмущество(Организация, ПериодРасчета, ДополнительныеПараметры);
```
</details>

## СформироватьТаблицуСтавкиНалогаНаИмуществоПоОтдельнымОССрезПоследних
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует временную таблицу, содержащую срез последних на дату ставок налога на имущество по отдельным ОС.
//
// Параметры:
//  ПараметрыРасчета - 	см. ПараметрыРасчетаНалогаНаИмущество
//  Период - Дата - Дата, на которую нужно получить срез последних.
//  ДополнительныеПараметры - Произвольный - Дополнительные параметры расчета.
//  ИмяТаблицы - Строка	- Имя временной таблицы, по умолчанию "СтавкиНалогаНаИмуществоПоОтдельнымОС_СрезПоследних"
//
Процедура СформироватьТаблицуСтавкиНалогаНаИмуществоПоОтдельнымОССрезПоследних(ПараметрыРасчета, Период, ДополнительныеПараметры = Неопределено, ИмяТаблицы = "") Экспорт
```

Пример вызова
```bsl
РасчетИмущественныхНалогов.СформироватьТаблицуСтавкиНалогаНаИмуществоПоОтдельнымОССрезПоследних(ПараметрыРасчета, Период, ДополнительныеПараметры, ИмяТаблицы);
```
</details>

## СформироватьТаблицуСтавкиНалогаНаИмуществоПоОтдельнымОСЗаписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует временную таблицу, содержащую записи ставок налога на имущество по отдельным ОС до определенной даты.
//
// Параметры:
//  ПараметрыРасчета - 	см. ПараметрыРасчетаНалогаНаИмущество
//  НачалоПериода - Дата - Дата, с которой нужно получить записи.
//  КонецПериода - Дата - Дата, до которой нужно получить записи.
//  ДополнительныеПараметры - Произвольный - Дополнительные параметры расчета.
//  ИмяТаблицы - Строка	- Имя временной таблицы, по умолчанию "СтавкиНалогаНаИмуществоПоОтдельнымОС_Записи"
//
Процедура СформироватьТаблицуСтавкиНалогаНаИмуществоПоОтдельнымОСЗаписи(ПараметрыРасчета, НачалоПериода, КонецПериода, ДополнительныеПараметры = Неопределено, ИмяТаблицы = "") Экспорт
```

Пример вызова
```bsl
РасчетИмущественныхНалогов.СформироватьТаблицуСтавкиНалогаНаИмуществоПоОтдельнымОСЗаписи(ПараметрыРасчета, НачалоПериода, КонецПериода, ДополнительныеПараметры, ИмяТаблицы);
```
</details>

## СформироватьТаблицуСтавкиНалогаНаИмуществоСрезПоследних
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует временную таблицу, содержащую срез последних на дату ставок налога на имущество.
//
// Параметры:
//  ПараметрыРасчета - 	см. ПараметрыРасчетаНалогаНаИмущество
//  Период - Дата - Дата, на которую нужно получить срез последних.
//  ДополнительныеПараметры - Произвольный - Дополнительные параметры расчета.
//  ИмяТаблицы - Строка	- Имя временной таблицы, по умолчанию "СтавкиНалогаНаИмущество_СрезПоследних"
//
Процедура СформироватьТаблицуСтавкиНалогаНаИмуществоСрезПоследних(ПараметрыРасчета, Период, ДополнительныеПараметры = Неопределено, ИмяТаблицы = "") Экспорт
```

Пример вызова
```bsl
РасчетИмущественныхНалогов.СформироватьТаблицуСтавкиНалогаНаИмуществоСрезПоследних(ПараметрыРасчета, Период, ДополнительныеПараметры, ИмяТаблицы);
```
</details>

## ПараметрыРасчетаНалогаНаИмущество
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры расчета налога на имущество
//
// Параметры:
//  Организация				 - СправочникСсылка.Организации - организация, по которовый выполняется расчет налога на имущество
//  ПериодРасчета			 - Дата - окончание периода, за который рассчитывается налог
//  ДополнительныеПараметры	 - Структура, Неопределено - дополнительные параметры расчета
//
// Возвращаемое значение:
//  Структура - параметры расчета налога
//
Функция ПараметрыРасчетаНалогаНаИмущество(Организация, ПериодРасчета, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РасчетИмущественныхНалогов.ПараметрыРасчетаНалогаНаИмущество(Организация, ПериодРасчета, ДополнительныеПараметры);
```
</details>

## НачалоПримененияНовогоРасчетаНалогаНаИмущество
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НачалоПримененияНовогоРасчетаНалогаНаИмущество() Экспорт
```

Пример вызова
```bsl
Результат = РасчетИмущественныхНалогов.НачалоПримененияНовогоРасчетаНалогаНаИмущество() 
```
</details>

## ПолучитьРасчетПоТранспортномуНалогу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает результат расчета транспортного налога (или аванса по налогу).
//
// Параметры:
//  Организация	- СправочникСсылка.Организации - Организация, для которой необходимо выполнить расчет.
//  ПериодРасчета - Дата - Дата закрытия месяца.
//  ДополнительныеПараметры - Структура - произвольные параметры расчета.
//
// Возвращаемое значение:
//  Структура - Содержит:
//		* Налог - ТаблицаЗначений - Результат расчета налога.
//		* Платон - ТаблицаЗначений - Данные по платону.
//
Функция ПолучитьРасчетПоТранспортномуНалогу(Организация, ПериодРасчета, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РасчетИмущественныхНалогов.ПолучитьРасчетПоТранспортномуНалогу(Организация, ПериодРасчета, ДополнительныеПараметры);
```
</details>

## ПолучитьАвансовыйРасчетПоТранспортномуНалогу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает результат авансового расчета транспортного налога.
//
// Параметры:
//  Организация	- СправочникСсылка.Организации - Организация, для которой необходимо выполнить расчет.
//  ПериодРасчета - Дата - Дата закрытия месяца.
//  ДополнительныеПараметры - Структура - произвольные параметры расчета.
//
// Возвращаемое значение:
//  ТаблицаЗначений - Авансовый расчет налога.
//
Функция ПолучитьАвансовыйРасчетПоТранспортномуНалогу(Организация, ПериодРасчета, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РасчетИмущественныхНалогов.ПолучитьАвансовыйРасчетПоТранспортномуНалогу(Организация, ПериодРасчета, ДополнительныеПараметры);
```
</details>

## СформироватьТаблицуРегистрацияТранспортныхСредствСрезПоследних
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует временную таблицу, содержащую срез последних на дату регистрации транспортных средств.
//
// Параметры:
//  ПараметрыРасчета - см. ПараметрыРасчетаТранспортногоНалога
//  Период - Дата - Дата, на которую нужно получить срез последних.
//  ДополнительныеПараметры - Произвольный - Дополнительные параметры расчета.
//  ИмяТаблицы - Строка	- Имя временной таблицы, по умолчанию "РегистрацияТранспортныхСредств_СрезПоследних"
//
Процедура СформироватьТаблицуРегистрацияТранспортныхСредствСрезПоследних(ПараметрыРасчета, Период, ДополнительныеПараметры = Неопределено, ИмяТаблицы = "") Экспорт
```

Пример вызова
```bsl
РасчетИмущественныхНалогов.СформироватьТаблицуРегистрацияТранспортныхСредствСрезПоследних(ПараметрыРасчета, Период, ДополнительныеПараметры, ИмяТаблицы);
```
</details>

## СформироватьТаблицуРегистрацияТранспортныхСредствЗаписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует временную таблицу, содержащую записи регистрации транспортных средств.
//
// Параметры:
//  ПараметрыРасчета - см. ПараметрыРасчетаТранспортногоНалога
//  Период - Дата - Дата, до которой нужно получить записи.
//  ДополнительныеПараметры - Произвольный - Дополнительные параметры расчета.
//  ИмяТаблицы - Строка	- Имя временной таблицы, по умолчанию "РегистрацияТранспортныхСредств_Записи"
//
Процедура СформироватьТаблицуРегистрацияТранспортныхСредствЗаписи(ПараметрыРасчета, Период, ДополнительныеПараметры = Неопределено, ИмяТаблицы = "") Экспорт
```

Пример вызова
```bsl
РасчетИмущественныхНалогов.СформироватьТаблицуРегистрацияТранспортныхСредствЗаписи(ПараметрыРасчета, Период, ДополнительныеПараметры, ИмяТаблицы);
```
</details>

## ПараметрыРасчетаТранспортногоНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры расчета транспортного налога
//
// Параметры:
//  Организация	- СправочникСсылка.Организации - организация, по которовый выполняется расчет налога.
//  ПериодРасчета - Дата - окончание периода, за который рассчитывается налог.
//  ДополнительныеПараметры - Структура, Неопределено - дополнительные параметры расчета.
//
// Возвращаемое значение:
//  Структура - параметры расчета налога:
//  	* Организация - СправочникСсылка.Организации -
//  	* ПериодРасчета - Дата -
//  	* ДатаНачалаПериодаОтчета - Дата -
//  	* ДатаКонцаПериодаОтчета - Дата -
//  	* ГодовойРасчет - Булево -
//  	* МенеджерВременныхТаблиц - МенеджерВременныхТаблиц -
//
Функция ПараметрыРасчетаТранспортногоНалога(Организация, ПериодРасчета, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РасчетИмущественныхНалогов.ПараметрыРасчетаТранспортногоНалога(Организация, ПериодРасчета, ДополнительныеПараметры);
```
</details>

## КодыВидовИКатегорииТранспортныхСредств
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает коды видов и категории транспортных средств.
//
// Возвращаемое значение:
//  ТаблицаЗначений - Коды видов и категорий транспортных средств.
Функция КодыВидовИКатегорииТранспортныхСредств() Экспорт
```

Пример вызова
```bsl
Результат = РасчетИмущественныхНалогов.КодыВидовИКатегорииТранспортныхСредств() 
```
</details>

## ПолучитьРасчетПоЗемельномуНалогу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает результат расчета земельного налога (или аванса по налогу).
//
// Параметры:
//  Организация	- СправочникСсылка.Организации - Организация, для которой необходимо выполнить расчет.
//  ПериодРасчета - Дата - Дата закрытия месяца.
//  ДополнительныеПараметры - Произвольный - Дополнительные параметры расчета.
//
// Возвращаемое значение:
//  Структура - Результат расчета налога. Имена свойств соответствуют наименованиям регистров сведений, куда записывается
//  результат, а значения свойств - таблицы записей этих регистров (ТаблицаЗначений)
//
Функция ПолучитьРасчетПоЗемельномуНалогу(Организация, ПериодРасчета, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РасчетИмущественныхНалогов.ПолучитьРасчетПоЗемельномуНалогу(Организация, ПериодРасчета, ДополнительныеПараметры);
```
</details>

## СформироватьТаблицуРегистрацияЗемельныхУчастковСрезПоследних
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует временную таблицу, содержащую срез последних на дату регистрации земельных участков.
//
// Параметры:
//  ПараметрыРасчета - см. ПараметрыРасчетаЗемельногоНалога
//  Период - Дата - Дата, на которую нужно получить срез последних.
//  ДополнительныеПараметры - Произвольный - Дополнительные параметры расчета.
//  ИмяТаблицы - Строка	- Имя временной таблицы, по умолчанию "РегистрацияЗемельныхУчастков_СрезПоследних".
//  УсловияВиртуальнойТаблицы - Строка - Условия виртуальной таблицы.
//
Процедура СформироватьТаблицуРегистрацияЗемельныхУчастковСрезПоследних(ПараметрыРасчета, Период, ДополнительныеПараметры, ИмяТаблицы = "", УсловияЗапроса = "") Экспорт
```

Пример вызова
```bsl
РасчетИмущественныхНалогов.СформироватьТаблицуРегистрацияЗемельныхУчастковСрезПоследних(ПараметрыРасчета, Период, ДополнительныеПараметры, ИмяТаблицы, УсловияЗапроса);
```
</details>

## СформироватьТаблицуРегистрацияЗемельныхУчастковЗаписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует временную таблицу, содержащую записи регистрации земельных участков до определенной даты.
//
// Параметры:
//  ПараметрыРасчета - см. ПараметрыРасчетаЗемельногоНалога
//  Период - Дата - Дата, до которой нужно получить записи.
//  ДополнительныеПараметры - Произвольный - Дополнительные параметры расчета.
//  ИмяТаблицы - Строка	- Имя временной таблицы, по умолчанию "РегистрацияЗемельныхУчастков_Записи"
//
Процедура СформироватьТаблицуРегистрацияЗемельныхУчастковЗаписи(ПараметрыРасчета, Период, ДополнительныеПараметры, ИмяТаблицы = "") Экспорт
```

Пример вызова
```bsl
РасчетИмущественныхНалогов.СформироватьТаблицуРегистрацияЗемельныхУчастковЗаписи(ПараметрыРасчета, Период, ДополнительныеПараметры, ИмяТаблицы);
```
</details>

## ПараметрыРасчетаЗемельногоНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры расчета земельного налога
//
// Параметры:
//  Организация	- СправочникСсылка.Организации - организация, по которовый выполняется расчет налога.
//  ПериодРасчета - Дата - окончание периода, за который рассчитывается налог.
//  ДополнительныеПараметры - Структура, Неопределено - дополнительные параметры расчета.
//
// Возвращаемое значение:
//  Структура - параметры расчета налога:
//  	* Организация - СправочникСсылка.Организации -
//  	* ПериодРасчета - Дата -
//  	* ДатаНачалаПериодаОтчета - Дата -
//  	* ДатаКонцаПериодаОтчета - Дата -
//  	* ГодовойРасчет - Булево -
//  	* МенеджерВременныхТаблиц - МенеджерВременныхТаблиц -
//
Функция ПараметрыРасчетаЗемельногоНалога(Организация, ПериодРасчета, ДополнительныеПараметры) Экспорт
```

Пример вызова
```bsl
Результат = РасчетИмущественныхНалогов.ПараметрыРасчетаЗемельногоНалога(Организация, ПериодРасчета, ДополнительныеПараметры) 
```
</details>

## ОрганизацииУплачивающиеАвансы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОрганизацииУплачивающиеАвансы(Организация, Период, Налог, ОднаОрганизация = Истина) Экспорт
```

Пример вызова
```bsl
Результат = РасчетИмущественныхНалогов.ОрганизацииУплачивающиеАвансы(Организация, Период, Налог, ОднаОрганизация);
```
</details>

## ПодготовитьТаблицыРасчетНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицы выполнения регламентных операций расчета имущественных налогов.
//
// Параметры:
//  ТаблицаРеквизиты		 - ТаблицаЗначений	 - Таблица реквизитов документа.
//  Отказ					 - Булево			 - Флаг отказа проведения.
//  ДополнительныеПараметры	 - Структура		 - Дополнительные параметры.
//
// Возвращаемое значение:
//  Структура - Таблицы расчета налога:
//  				* ТаблицаСправкиРасчета - ТаблицаЗначений - Справка-расчет налога.
//  				* ТаблицаРасходыПоНалогу - ТаблицаЗначений - Отражение расходов по налогу.
//
Функция ПодготовитьТаблицыРасчетНалога(ТаблицаРеквизиты, Отказ, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РасчетИмущественныхНалогов.ПодготовитьТаблицыРасчетНалога(ТаблицаРеквизиты, Отказ, ДополнительныеПараметры);
```
</details>

## СформироватьДвиженияРасчетНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует движения регистров по данным расчета налога.
//
// Параметры:
//  ТаблицыНачислениеНалога	 - Структура - Содержит таблицы с результатами расчета налога.
//  ТаблицаРеквизитов		 - ТаблицаЗначений	 - Таблица реквизитов документа.
//  Движения				 - КоллекцияДвижений - Движения документа.
//  Отказ					 - Булево			 - Признак отказа от формирования движений.
//
Процедура СформироватьДвиженияРасчетНалога(ТаблицыНачислениеНалога, ТаблицаРеквизитов, Движения, Отказ, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
РасчетИмущественныхНалогов.СформироватьДвиженияРасчетНалога(ТаблицыНачислениеНалога, ТаблицаРеквизитов, Движения, Отказ, ДополнительныеПараметры);
```
</details>

## ДополнитьПараметрыДвиженийСправкиРасчеты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в состав параметров таблицу значений со структурой колонок для справки - расчета.
//
// Параметры:
//  Параметры				 - Структура	 - Содержит параметры формирования движений для справки-расчета.
//  Реквизиты				 - СтрокаТаблицыЗначений - Содержит поля:
//                                 * ВидНалога - ПеречислениеСсылка.ВидыИмущественныхНалогов - Вид налога
//  ТаблицаСправкиРасчета	 - ТаблицаЗначений		 - По структуре соответствует регистру сведений для соответствующего налога
//  		(РасчетТранспортногоНалога и др.).
//
Процедура ДополнитьПараметрыДвиженийСправкиРасчеты(Параметры, Реквизиты, ТаблицыСправокРасчетов) Экспорт
```

Пример вызова
```bsl
РасчетИмущественныхНалогов.ДополнитьПараметрыДвиженийСправкиРасчеты(Параметры, Реквизиты, ТаблицыСправокРасчетов) 
```
</details>

## ДанныеПоСреднейСтоимостиДвижимогоИмущества
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает результат расчета среднегодовой стоимости движмого имущества.
//
// Параметры:
//  Организации		- Массив, Фиксированный массив элементов типа СправочникСсылка.Организации -
//					  Организация и ее подразделения на выделенном балансе,
//					  по которым нужно рассчитать среднегодовую стоимость движимого имущества .
//  ДатаНачала		- Дата - Начало отчетного периода (года).
//  ДатаОкончания	- Дата - Окончание отчетного периода (года).
//
// Возвращаемое значение:
//  ТаблицаЗначений - Результат расчета среднегодовой стоимости имущества.
//
Функция ДанныеПоСреднейСтоимостиДвижимогоИмущества(Организации, ДатаНачала, ДатаОкончания) Экспорт
```

Пример вызова
```bsl
Результат = РасчетИмущественныхНалогов.ДанныеПоСреднейСтоимостиДвижимогоИмущества(Организации, ДатаНачала, ДатаОкончания) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
