---
title: Расчет налога на прибыль
slug: erp-uh/расчет-налога-на-прибыль
---


## НовыйКонтекстРасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описывает контекст, в котором выполняется расчет налога на прибыль - организацию, период и т.п.
//
// Параметры:
// 	Организация - СправочникСсылка.Организации - налогоплательщик
// 	КонецПериода - Дата - характеризует отчетный период; дата из последнего месяца отчетного периода
// 	РеквизитыРеглОперации - см. Документы.РегламентнаяОперация.ПодготовитьДанныеРасчетаНалогаНаПрибыль
//
// Возвращаемое значение:
// 	Структура - Описание:
// * ПрименяютсяСпециальныеРежимы - Булево -
// * ПрименяетсяПБУ18 - Булево -
// * ВариантУчетаОтложенногоНалога - ПеречислениеСсылка.ВариантыУчетаОтложенногоНалога -
// * ПоказательОпределенияДолиПрибыли - ПеречислениеСсылка.ПоказателиДляОпределенияДолиПрибыли -
// * РегистрацияПоМестуНахожденияОрганизации - СправочникСсылка.РегистрацииВНалоговомОргане, Неопределено -
// * Организация - СправочникСсылка.Организации -
// * Организации - ФиксированныйМассив Из СправочникСсылка.Организации - вся иерархия организации
// * НачалоМесяца - Дата -
// * НалоговыйПериод - Дата - начало стандартного налогового периода
// * КонецПериода - Дата -
// * НачалоНалоговогоПериода - Дата - фактическое начало налогового периода (может совпадать со стандартным началом или
//               датой регистрации организации.
// * РеквизитыРеглОперации - Структура - кэшируется копия реквизитов регл. операции или создается пустая структура
//
Функция НовыйКонтекстРасчета(Организация, КонецПериода, РеквизитыРеглОперации = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.НовыйКонтекстРасчета(Организация, КонецПериода, РеквизитыРеглОперации);
```
</details>

## ПодготовитьПараметры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// ПЕРЕДАЧА ПАРАМЕТРОВ

// Возвращает параметры для расчета
//
// Параметры:
// 	РасчетНалога - ТаблицаЗначений -
// 	ЗаписьРаспределенияБазыНалогаНаПрибыль - ТаблицаЗначений -
// 	ТаблицаРеквизиты - ТаблицаЗначений -
//
// Возвращаемое значение:
// 	Структура:
// 		*ТаблицаРасчетНалога - ТаблицаЗначений -
// 		*ЗаписьРаспределенияБазыНалогаНаПрибыль - ТаблицаЗначений -
// 		*Реквизиты - ТаблицаЗначений -
//
Функция ПодготовитьПараметры(РасчетНалога, ЗаписьРаспределенияБазыНалогаНаПрибыль, ТаблицаРеквизиты) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.ПодготовитьПараметры(РасчетНалога, ЗаписьРаспределенияБазыНалогаНаПрибыль, ТаблицаРеквизиты) 
```
</details>

## НалоговаяБаза
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// НАЧИСЛЕНИЕ НАЛОГА

// Рассчитывает налоговую базу по налогу на прибыль
//
// Параметры:
// 	НачалоПериода - Дата -
// 	КонецПериода - Дата - Описание
// 	Организация - СправочникСсылка.Организации -
// Возвращаемое значение:
// 	Число -
Функция НалоговаяБаза(НачалоПериода, КонецПериода, Организация) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.НалоговаяБаза(НачалоПериода, КонецПериода, Организация) 
```
</details>

## СуммыНалоговойБазы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает налоговую базу по налогу на прибыль
// (по неокругленным компонентам налоговой базы; в том числе, по данным бухгалтерского учета).
//
// Параметры:
//  НачалоПериода	  - Дата - начало периода расчета
//  КонецПериода	  - Дата - конец периода расчета
//  Организация		  - СправочникСсылка.Организации - налогоплательщик (головная организация)
//  ОписаниеСумм	  - Структура - см. КоллекцииСумм.НовыйОписаниеКоллекцииСумм, описание коллекции сумм,
//                      соответствующих видам учета, по данным которых должна быть рассчитана налоговая база.
//                      Заполняются суммы с именами Сумма, СуммаНУ, СуммаПР, СуммаВР.
//                      Если не передан, подразумевается СуммаНУ.
//  СчетНалоговойБазы - ПланСчетовСсылка.Хозрасчетный - субсчет счета прибылей и убытков, соответствующий части налоговой базы,
//                      облагаемой по отдельной ставке налога (в частном случае - не облагаемой).
//                      Если не передан, подразумевается счет 99.01.1
//                      ("Прибыли и убытки по деятельности с основной системой налогообложения").
//
// Возвращаемое значение:
//  Структура - см. КоллекцииСумм.НовыйКоллекцияСумм - суммы налоговой базы по выбранным видам учета.
//              Заполняются Сумма, СуммаНУ, СуммаПР, СуммаВР.
//
Функция СуммыНалоговойБазы(НачалоПериода, КонецПериода, Организация, ОписаниеСумм = Неопределено, СчетНалоговойБазы = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.СуммыНалоговойБазы(НачалоПериода, КонецПериода, Организация, ОписаниеСумм, СчетНалоговойБазы);
```
</details>

## СуммыНалоговойБазыВРазрезеВариантовНалогообложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает налоговую базу по налогу на прибыль
// (по неокругленным компонентам налоговой базы; в том числе, по данным бухгалтерского учета).
//
// Параметры:
//  НачалоПериода     - Дата - начало периода расчета
//  КонецПериода      - Дата - конец периода расчета
//  Организация       - СправочникСсылка.Организации - налогоплательщик (головная организация)
//  ИспользуетсяРаздельныйУчет - Неопределено - признак не известен, будет получен из базы данных
//                             - Булево - признак известен, обращение к базе данных не требуется
//
// Возвращаемое значение:
//  ТаблицаЗначений - содержит:
//  	* ВариантНалогообложенияПрибыли - СправочникСсылка.ВариантыНалогообложенияПрибыли - Вариант н/о
//  	* Сумма   - Число -
//  	* СуммаНУ - Число -
//  	* СуммаПР - Число -
//  	* СуммаВР - Число -
//
Функция СуммыНалоговойБазыВРазрезеВариантовНалогообложения( Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.СуммыНалоговойБазыВРазрезеВариантовНалогообложения();
```
</details>

## ПодготовитьВТ_СуммыНалоговойБазыВРазрезеВариантовНалогообложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает налоговую базу по налогу на прибыль, результат помещает во временную таблицу "СуммыНалоговойБазы"
// (по неокругленным компонентам налоговой базы; в том числе, по данным бухгалтерского учета).
//
// Колонки временной таблицы:
//  	* ВариантНалогообложенияПрибыли - СправочникСсылка.ВариантыНалогообложенияПрибыли - Вариант н/о
//  	* Сумма   - Число;
//  	* СуммаНУ - Число;
//  	* СуммаПР - Число;
//  	* СуммаВР - Число.
//
// Параметры:
//  МенеджерВременныхТаблиц  - МенеджерВременныхТаблиц -
//  НачалоПериода     - Дата - начало периода расчета
//  КонецПериода      - Дата - конец периода расчета
//  Организация       - СправочникСсылка.Организации - налогоплательщик (головная организация)
//  ИспользуетсяРаздельныйУчет - Неопределено - признак не известен, будет получен из базы данных
//                             - Булево - признак известен, обращение к базе данных не требуется
//
Процедура ПодготовитьВТ_СуммыНалоговойБазыВРазрезеВариантовНалогообложения(МенеджерВременныхТаблиц, Экспорт
```

Пример вызова
```bsl
РасчетНалогаНаПрибыль.ПодготовитьВТ_СуммыНалоговойБазыВРазрезеВариантовНалогообложения(МенеджерВременныхТаблиц, );
```
</details>

## НачислитьНалогНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Начисляет налог на прибыль - формирует проводки.
//
// Параметры:
// 	Движения - КоллекцияДвижений - коллекция движений документа "РегламентнаяОперация"
// 	КонтекстРасчета - см. НовыйКонтекстРасчета
//  РасчетРаспределенияНалоговойБазыОП - ТаблицаЗначений - см. НалоговыйУчетОбособленныхПодразделений.НовыйРасчетРаспределенияНалоговойБазы
//                                   - Неопределено - распределение по обособленным подразделениям не требуется
//	ТаблицаБазаНалогаЗаГод	- см. СуммыНалоговойБазыВРазрезеВариантовНалогообложения
//  МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - см. НалоговыйУчетОбособленныхПодразделений.ПодготовитьРасчетРаспределенияНалоговойБазы,
//                            содержит временную таблицу СоответствиеПрежнихИТекущихНалоговыхОрганов,
//                            которая используется в процедуре, если налог распределяется между налоговыми органами.
//
// Возвращаемое значение:
// 	Структура - содержит:
// 		* Проводки - Число - сумма налога за месяц
// 		* Всего    - Число - сумма налога нарастающим итогом
//
Функция НачислитьНалогНаПрибыль(Движения, КонтекстРасчета, РасчетРаспределенияНалоговойБазыОП, ТаблицаБазаНалогаЗаГод, МенеджерВременныхТаблиц) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.НачислитьНалогНаПрибыль(Движения, КонтекстРасчета, РасчетРаспределенияНалоговойБазыОП, ТаблицаБазаНалогаЗаГод, МенеджерВременныхТаблиц) 
```
</details>

## ОписаниеСуммНалоговыйУчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОписаниеСуммНалоговыйУчет() Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.ОписаниеСуммНалоговыйУчет() 
```
</details>

## ДобавитьПроводкуСписанияОтклоненийПриОкругленииНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьПроводкуСписанияОтклоненийПриОкругленииНалогаНаПрибыль( Экспорт
```

Пример вызова
```bsl
РасчетНалогаНаПрибыль.ДобавитьПроводкуСписанияОтклоненийПриОкругленииНалогаНаПрибыль();
```
</details>

## НачислениеНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Готовит данные для формирования проводок по начислению налога на прибыль на счет расчетов с бюджетом.
//
// Параметры:
//  КонтекстРасчета              - см. НовыйКонтекстРасчета
//  РаспределениеНалогаНаПрибыль - см. НовыйРаспределениеНалогаНаПрибыль
//  МенеджерВременныхТаблиц 	 - МенеджерВременныхТаблиц -см. НалоговыйУчетОбособленныхПодразделений.ПодготовитьТаблицуРаспределенияБазыНалогаНаПрибыль(),
//                                 содержит временную таблицу СоответствиеПрежнихИТекущихНалоговыхОрганов,
//                                 которая используется в процедуре, если налог распределяется между налоговыми органами.
//
// Возвращаемое значение:
//  см. НовыйНачислениеНалогаНаПрибыль
//
Функция НачислениеНалогаНаПрибыль(КонтекстРасчета, Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.НачислениеНалогаНаПрибыль(КонтекстРасчета, );
```
</details>

## ИсключитьРанееНачисленныеАвансы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ИсключитьРанееНачисленныеАвансы(НачислениеНалога, КонтекстРасчета, СоответствиеПрежнихИТекущихНалоговыхОрганов = Неопределено) Экспорт
```

Пример вызова
```bsl
РасчетНалогаНаПрибыль.ИсключитьРанееНачисленныеАвансы(НачислениеНалога, КонтекстРасчета, СоответствиеПрежнихИТекущихНалоговыхОрганов);
```
</details>

## ЗаполнитьРаспределениеНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет распределение налога на прибыль исходя из переданных факторов
//
// Параметры:
// 	РаспределениеНалогаНаПрибыль       - см. НовыйРаспределениеНалогаНаПрибыль
// 	КонтекстРасчета                    - см. НовыйКонтекстРасчета
// 	РасчетРаспределенияНалоговойБазыОП - ТаблицаЗначений - см. НалоговыйУчетОбособленныхПодразделений.ПодготовитьРасчетРаспределенияНалоговойБазы
// 	                                   - Неопределено - распределение по обособленным подразделениям не требуется
// 	ТаблицаБазаНалогаЗаГод             - см. СуммыНалоговойБазыВРазрезеВариантовНалогообложения
// 	СтавкаФедеральныйБюджет            - Число - основная ставка в федеральный бюджет
// 	СтавкаРегиональныйБюджет           - Число - основная ставка в региональный бюджет
//
Процедура ЗаполнитьРаспределениеНалогаНаПрибыль(РаспределениеНалогаНаПрибыль, Экспорт
```

Пример вызова
```bsl
РасчетНалогаНаПрибыль.ЗаполнитьРаспределениеНалогаНаПрибыль(РаспределениеНалогаНаПрибыль, );
```
</details>

## ОбщаяБазаНалогаЗаГод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает общую налоговую базу
//
// Параметры:
// 	ТаблицаБазаНалогаЗаГод - см. СуммыНалоговойБазыВРазрезеВариантовНалогообложения
//  РасчетРаспределенияНалоговойБазыОП - ТаблицаЗначений - см. НалоговыйУчетОбособленныхПодразделений.НовыйРасчетРаспределенияНалоговойБазы
//                                   - Неопределено - распределение по обособленным подразделениям не требуется
//
// Возвращаемое значение:
// 	Число -
//
Функция ОбщаяБазаНалогаЗаГод(ТаблицаБазаНалогаЗаГод, РасчетРаспределенияНалоговойБазыОП) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.ОбщаяБазаНалогаЗаГод(ТаблицаБазаНалогаЗаГод, РасчетРаспределенияНалоговойБазыОП));
```
</details>

## НалоговаяБазаРазделенаПоВариантамНалогообложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак разделения налоговой базы по вариантам н/о
//
// Параметры:
// 	ТаблицаБазаНалогаЗаГод - см. СуммыНалоговойБазыВРазрезеВариантовНалогообложения
//
// Возвращаемое значение:
// 	Булево -
//
Функция НалоговаяБазаРазделенаПоВариантамНалогообложения(ТаблицаБазаНалогаЗаГод) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.НалоговаяБазаРазделенаПоВариантамНалогообложения(ТаблицаБазаНалогаЗаГод));
```
</details>

## ТипСуммаНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТипСуммаНалога(ТочностьРасчета = 0) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.ТипСуммаНалога(ТочностьРасчета);
```
</details>

## НовыйНачислениеНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор таблицы значений "Начисление налога на прибыль"
//
// Параметры:
// 	ТочностьРасчета - Число -
//
// Возвращаемое значение:
// 	ТаблицаЗначений - Описание:
// * УровеньБюджета                - ПеречислениеСсылка.УровниБюджетов -
// * ВариантНалогообложенияПрибыли - СправочникСсылка.ВариантыНалогообложенияПрибыли -
// * РегистрацияВНалоговомОргане   - СправочникСсылка.РегистрацииВНалоговомОргане -
// * СуммаНалога                   - Число -
// * СуммаАвансовыхПлатежей        - Число -
// * СуммаПроводки                 - Число -
//
Функция НовыйНачислениеНалогаНаПрибыль(ТочностьРасчета = 0) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.НовыйНачислениеНалогаНаПрибыль(ТочностьРасчета);
```
</details>

## СвернутьНачислениеНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СвернутьНачислениеНалогаНаПрибыль(НачислениеНалога, БезУчетаВариантаНалогообложения = Ложь) Экспорт
```

Пример вызова
```bsl
РасчетНалогаНаПрибыль.СвернутьНачислениеНалогаНаПрибыль(НачислениеНалога, БезУчетаВариантаНалогообложения);
```
</details>

## ДобавитьНачислениеНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьНачислениеНалогаНаПрибыль(НачислениеНалога, Экспорт
```

Пример вызова
```bsl
РасчетНалогаНаПрибыль.ДобавитьНачислениеНалогаНаПрибыль(НачислениеНалога, );
```
</details>

## СуммаНалогаНаПрибыльВБюджет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СуммаНалогаНаПрибыльВБюджет(НалоговаяБаза, СтавкаНалога, ТочностьРасчета = 0) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.СуммаНалогаНаПрибыльВБюджет(НалоговаяБаза, СтавкаНалога, ТочностьРасчета);
```
</details>

## НовыйРаспределениеНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция-конструктор таблицы "РаспределениеНалогаНаПрибыль"
//
// Возвращаемое значение:
// 	ТаблицаЗначений - Описание:
// * ВариантНалогообложенияПрибыли - СправочникСсылка.ВариантыНалогообложенияПрибыли -
// * РегистрацияВНалоговомОргане - СправочникСсылка.РегистрацииВНалоговомОргане -
// * ДоляНалоговойБазы - Число -
// * СтавкаФедеральныйБюджет - Число -
// * СтавкаРегиональныйБюджет - Число -
// * НалоговаяБаза - Число -
Функция НовыйРаспределениеНалогаНаПрибыль() Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.НовыйРаспределениеНалогаНаПрибыль());
```
</details>

## РезультатЗапроса_СуммыНалоговойБазы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает налоговую базу по налогу на прибыль
// (по неокругленным компонентам налоговой базы; в том числе, по данным бухгалтерского учета).
//
// Параметры:
//  НачалоПериода	  - Дата - начало периода расчета
//  КонецПериода	  - Дата - конец периода расчета
//  Организация		  - СправочникСсылка.Организации - налогоплательщик (головная организация)
//  МенеджерВременныхТаблиц - МенеджерВременныхТаблиц -
//  СчетНалоговойБазы - ПланСчетовСсылка.Хозрасчетный - субсчет счета прибылей и убытков, соответствующий части налоговой базы,
//                      облагаемой по отдельной ставке налога (в частном случае - не облагаемой).
//                      Если не передан, подразумевается счет 99.01.1
//                      ("Прибыли и убытки по деятельности с основной системой налогообложения").
//  ВРазрезеВариантовНалогообложения - Булево - Если "Истина", данные будут получены в разрезе вариантов н/о
//
// Возвращаемое значение:
//  РезультатЗапроса - суммы налоговой базы по выбранным видам учета. Содержит колонки
//   * ВариантНалогообложенияПрибыли - СправочникСсылка.ВариантыНалогообложенияПрибыли - (опционально) вариант н/о.
//   * Сумма   - Число;
//   * СуммаНУ - Число;
//   * СуммаПР - Число;
//   * СуммаВР - Число.
//
Функция РезультатЗапроса_СуммыНалоговойБазы(НачалоПериода, Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.РезультатЗапроса_СуммыНалоговойБазы(НачалоПериода, );
```
</details>

## ЕстьЗадолженностьПоТорговомуСбору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В соответствии с п. 10 ст. 286 налогоплательщик вправе уменьшить сумму налога (авансового платежа),
// исчисленного по итогам налогового (отчетного) периода,
// зачисляемую в консолидированный бюджет субъекта Российской Федерации ...
// на сумму торгового сбора, фактически уплаченного с начала налогового периода до даты уплаты налога (авансового платежа).

// При этом если организация не вправе уменьшить налог на прибыль на суммы торгового сбора,
// то в соответствии с ПБУ 9 следует признать расход по обычным видам деятельности.

// В программе при расчете торгового сбора (т.е. до начисления налога на прибыль) признается расход.
// При начислении налога на прибыль этот расход может быть отсторнирован в той сумме, на которую можно уменьшить налог.

Функция ЕстьЗадолженностьПоТорговомуСбору(Организация, ДатаПодписи) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.ЕстьЗадолженностьПоТорговомуСбору(Организация, ДатаПодписи) 
```
</details>

## НалогФактическиУменьшенныйНаСуммыТорговогоСбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НалогФактическиУменьшенныйНаСуммыТорговогоСбора(Период, Организация) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.НалогФактическиУменьшенныйНаСуммыТорговогоСбора(Период, Организация) 
```
</details>

## ДобавитьПроводкиУменьшениеНаСуммуТорговогоСбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьПроводкиУменьшениеНаСуммуТорговогоСбора(Движения, НачислениеНалога, Период, Организация, ПрименяетсяПБУ18) Экспорт
```

Пример вызова
```bsl
РасчетНалогаНаПрибыль.ДобавитьПроводкиУменьшениеНаСуммуТорговогоСбора(Движения, НачислениеНалога, Период, Организация, ПрименяетсяПБУ18));
```
</details>

## УменьшениеНалогаНаСуммуТорговогоСбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет суммы уменьшения налога на прибыль на суммы торгового сбора, начисленного за налоговый период.
//
// Параметры:
//  Период		     - Дата - указание на отчетный период. Можно передавать дату окончания периода
//  Организация	     - СправочникСсылка.Организации - организация, по которой исчисляется налог и сбор
//  НачислениеНалога - см. НовыйНачислениеНалогаНаПрибыль
//
// Возвращаемое значение:
//  ТаблицаЗначений - содержит колонки РегистрацияВНалоговомОргане, СуммаНалога, СуммаУменьшения.
//
Функция УменьшениеНалогаНаСуммуТорговогоСбора(Период, Организация, НачислениеНалога) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.УменьшениеНалогаНаСуммуТорговогоСбора(Период, Организация, НачислениеНалога));
```
</details>

## РегистрацииВНалоговомОрганеПоТерриторииТорговогоСбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РегистрацииВНалоговомОрганеПоТерриторииТорговогоСбора(Организация) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.РегистрацииВНалоговомОрганеПоТерриторииТорговогоСбора(Организация));
```
</details>

## СуммаНачисленногоТорговогоСбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет сумму торгового сбора, начисленную в отчетном периоде (с начала года).
//
// См. также РасходыТорговыйСбор(), РанееОтсторнированныеРасходыТорговыйСбор()
// Возвращаемое значение:
//	Число -
//
Функция СуммаНачисленногоТорговогоСбора(Период, Организация) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.СуммаНачисленногоТорговогоСбора(Период, Организация) 
```
</details>

## РасходыТорговыйСбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет суммы расходов в виде торгового сбора за год в разрезе аналитики расходов.
// Эта сумма может быть меньше, чем общая сумма торгового сбора, так как часть сбора может уменьшить налог на прибыль
// и расходом не является.
// См. также СуммаНачисленногоТорговогоСбора(), РасходыТорговыйСбор().
//
Функция РасходыТорговыйСбор(Период, Организация) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.РасходыТорговыйСбор(Период, Организация));
```
</details>

## РанееОтсторнированныеРасходыТорговыйСбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет суммы расходов в виде торгового сбора за год в разрезе аналитики расходов,
// которые были отсторнированы при начислении налога на прибыль и уменьшении сумм налога на суммы торгового сбора.
// См. также РасходыТорговыйСбор().
//
Функция РанееОтсторнированныеРасходыТорговыйСбор(Период, Организация) // Суммы показаны с отрицательным знаком Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.РанееОтсторнированныеРасходыТорговыйСбор(Период, Организация) // Суммы показаны с отрицательным знаком);
```
</details>

## НовыйРасходыТорговыйСбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НовыйРасходыТорговыйСбор() Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.НовыйРасходыТорговыйСбор());
```
</details>

## ПодготовитьТаблицуРасчетНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// НАЧИСЛЕНИЕ УСЛОВНОГО ДОХОДА (РАСХОДА) ПО НАЛОГУ НА ПРИБЫЛЬ

Функция ПодготовитьТаблицуРасчетНалогаНаПрибыль(ТаблицаРеквизиты, СписокОрганизаций, Отказ) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.ПодготовитьТаблицуРасчетНалогаНаПрибыль(ТаблицаРеквизиты, СписокОрганизаций, Отказ) 
```
</details>

## СуммарнаяУстановленнаяСтавкаНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СуммарнаяУстановленнаяСтавкаНалога( Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.СуммарнаяУстановленнаяСтавкаНалога();
```
</details>

## ОбработатьОтрицательныеАктивыИОбязательства
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


////////////////////////////////////////////////////////////////////////////////
// РАСЧЕТ ПОСТОЯННЫХ И ОТЛОЖЕННЫХ НАЛОГОВЫХ АКТИВОВ И ОБЯЗАТЕЛЬСТВ

Процедура ОбработатьОтрицательныеАктивыИОбязательства(Строка, ОтридцательныеПНО, ОтридцательныеПНА) Экспорт
```

Пример вызова
```bsl
РасчетНалогаНаПрибыль.ОбработатьОтрицательныеАктивыИОбязательства(Строка, ОтридцательныеПНО, ОтридцательныеПНА));
```
</details>

## ПодготовитьТаблицуРазницВОценкеАктивов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПодготовитьТаблицуРазницВОценкеАктивов(Реквизиты, ТаблицаВидовАктивовИОбязательствДляРаспределения, МассивТаблицРезультатов, ВидРазницы, КоличествоОбрабатываемыхДанных, ОтридцательныеПНО = Ложь, ОтридцательныеПНА = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.ПодготовитьТаблицуРазницВОценкеАктивов(Реквизиты, ТаблицаВидовАктивовИОбязательствДляРаспределения, МассивТаблицРезультатов, ВидРазницы, КоличествоОбрабатываемыхДанных, ОтридцательныеПНО, ОтридцательныеПНА);
```
</details>

## ПодготовитьТаблицуСтоимостиНалоговыхАктивовИОбязательств
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПодготовитьТаблицуСтоимостиНалоговыхАктивовИОбязательств(Реквизиты,ТаблицаОборотовРазниц,ВидРазницы) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.ПодготовитьТаблицуСтоимостиНалоговыхАктивовИОбязательств(Реквизиты, ТаблицаОборотовРазниц, ВидРазницы));
```
</details>

## ПодготовитьТаблицыРазницИСтоимостиПНО_ПНА
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПодготовитьТаблицыРазницИСтоимостиПНО_ПНА(Реквизиты,СписокОрганизаций, КоличествоОбрабатываемыхДанных, ОтридцательныеПНО, ОтридцательныеПНА) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.ПодготовитьТаблицыРазницИСтоимостиПНО_ПНА(Реквизиты, СписокОрганизаций, КоличествоОбрабатываемыхДанных, ОтридцательныеПНО, ОтридцательныеПНА));
```
</details>

## ОборотыВременныхРазницПоВидуАктивовОбязательствРасчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные ВР по виду активов/обязательств
//
// Параметры:
// 	Реквизиты - СтрокаТаблицыЗначений -
// 	ТаблицаРезультатов - ТаблицаЗначений -
// 	ТаблицаРаспределяемыхРасходов - ДеревоЗначений, ТаблицаЗначений -
// 	КоличествоОбъектовАналитики - Число -
// Возвращаемое значение:
// 	ТаблицаЗначений -
Функция ОборотыВременныхРазницПоВидуАктивовОбязательствРасчет(Реквизиты, ТаблицаРезультатов, ТаблицаРаспределяемыхРасходов, КоличествоОбъектовАналитики) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.ОборотыВременныхРазницПоВидуАктивовОбязательствРасчет(Реквизиты, ТаблицаРезультатов, ТаблицаРаспределяемыхРасходов, КоличествоОбъектовАналитики));
```
</details>

## ОборотыВременныхРазницПоВидуАктивовОбязательствСформироватьПакет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОборотыВременныхРазницПоВидуАктивовОбязательствСформироватьПакет(СтрокаВидАктиваОбязательства, ТекИндекс = 0, СоответствиеСтрокДляСвертки = "") Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.ОборотыВременныхРазницПоВидуАктивовОбязательствСформироватьПакет(СтрокаВидАктиваОбязательства, ТекИндекс, СоответствиеСтрокДляСвертки);
```
</details>

## ОборотыПостоянныхРазницПоВидуАктивовОбязательствСформироватьПакет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОборотыПостоянныхРазницПоВидуАктивовОбязательствСформироватьПакет(СтрокаВидАктиваОбязательства, ТекИндекс = 0, СоответствиеСтрокДляСвертки = "") Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.ОборотыПостоянныхРазницПоВидуАктивовОбязательствСформироватьПакет(СтрокаВидАктиваОбязательства, ТекИндекс, СоответствиеСтрокДляСвертки);
```
</details>

## ПодготовитьТаблицуРасчетПостоянныхРазниц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитываются постоянные налоговые обязательства (активы)
//
// Параметры:
//		ТаблицаРеквизиты  - ТаблицаЗначений - значения реквизитов необходимых для расчета
//		СписокОрганизаций - СписокЗначений  - с Организациями, по которых необходимо произвести расчет
//		Отказ             - Булево          - признак, что при расчетах возникло исключение.
//		КоличествоОбрабатываемыхДанных - Число
// Возвращаемое значение:
//	Структура -
//
Функция ПодготовитьТаблицуРасчетПостоянныхРазниц(ТаблицаРеквизиты, СписокОрганизаций, Отказ, КоличествоОбрабатываемыхДанных) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.ПодготовитьТаблицуРасчетПостоянныхРазниц(ТаблицаРеквизиты, СписокОрганизаций, Отказ, КоличествоОбрабатываемыхДанных) 
```
</details>

## РассчитатьВременныеРазницы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитываются отложенные налоговые обязательства и отложенные налоговые активы
//
// Параметры:
//		ТаблицаРеквизиты  - ТаблицаЗначений - значения реквизитов необходимых для расчета
//		СписокОрганизаций - СписокЗначений  - с Организациями, по которых необходимо произвести расчет
//		Отказ             - Булево          - признак, что при расчетах возникло исключение.
//		КоличествоОбрабатываемыхДанных - Число
// Возвращаемое значение:
//	Структура -
//
Функция РассчитатьВременныеРазницы(ТаблицаРеквизиты, СписокОрганизаций, Отказ, КоличествоОбрабатываемыхДанных) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.РассчитатьВременныеРазницы(ТаблицаРеквизиты, СписокОрганизаций, Отказ, КоличествоОбрабатываемыхДанных) 
```
</details>

## ПолучитьТаблицуРаспределяемыхРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТаблицуРаспределяемыхРасходов(Реквизиты, СписокОрганизаций, ТаблицаВидовАктивовИОбязательств) Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.ПолучитьТаблицуРаспределяемыхРасходов(Реквизиты, СписокОрганизаций, ТаблицаВидовАктивовИОбязательств));
```
</details>

## РассчитатьОНО_ОНА
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитываются отложенные налоговые обязательства и
// отложенные налоговые активы по конкретному виду активов
// (обязательств).
//
// Параметры:
//		СтрокаВидАктиваОбязательства - СтрокаТаблицыЗначений - строка таблицы, в которой задано соответствие
//			вида актива (обязательства) и счетов налогового учета, на которых
//			отражаются разницы по этому виду активов.
//
Процедура РассчитатьОНО_ОНА(ТаблицаРасчетВременныхРазниц, СтрокаВидАктиваОбязательства, Реквизиты, ОборотыВременныхРазниц) Экспорт
```

Пример вызова
```bsl
РасчетНалогаНаПрибыль.РассчитатьОНО_ОНА(ТаблицаРасчетВременныхРазниц, СтрокаВидАктиваОбязательства, Реквизиты, ОборотыВременныхРазниц));
```
</details>

## РассчитатьОНАПоУбыткамТекущегоПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывается отложенные налоговый актив по убыткам текущего
// периода и отражается на счете 09.
//
Процедура РассчитатьОНАПоУбыткамТекущегоПериода(ТаблицаРасчетВременныхРазниц, СтрокаВидАктиваОбязательства, Реквизиты, СписокОрганизаций, СуммаПересчетаУбытков) Экспорт
```

Пример вызова
```bsl
РасчетНалогаНаПрибыль.РассчитатьОНАПоУбыткамТекущегоПериода(ТаблицаРасчетВременныхРазниц, СтрокаВидАктиваОбязательства, Реквизиты, СписокОрганизаций, СуммаПересчетаУбытков));
```
</details>

## ОтражениеОНАиОНО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Упорядочиваются данный для передачи их в процедуру,
// которая формирует записи по счету 68.4.
//
Процедура ОтражениеОНАиОНО(ТаблицаРасчетВременныхРазниц, ВидАктивовОбязательств, ВременныеРазницы, СчетаАктивовИОбязательств = Неопределено) Экспорт
```

Пример вызова
```bsl
РасчетНалогаНаПрибыль.ОтражениеОНАиОНО(ТаблицаРасчетВременныхРазниц, ВидАктивовОбязательств, ВременныеРазницы, СчетаАктивовИОбязательств);
```
</details>

## ПолучитьТаблицаРасчетНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТаблицаРасчетНалога() Экспорт
```

Пример вызова
```bsl
Результат = РасчетНалогаНаПрибыль.ПолучитьТаблицаРасчетНалога());
```
</details>

## СформироватьДвиженияРасчетНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// ФОРМИРОВАНИЕ ДВИЖЕНИЙ

Процедура СформироватьДвиженияРасчетНалогаНаПрибыль(ТаблицаРасчетНалога, ТаблицаРеквизиты, Движения, Отказ) Экспорт
```

Пример вызова
```bsl
РасчетНалогаНаПрибыль.СформироватьДвиженияРасчетНалогаНаПрибыль(ТаблицаРасчетНалога, ТаблицаРеквизиты, Движения, Отказ) 
```
</details>

## ОтразитьОсвобождениеОтНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОтразитьОсвобождениеОтНалога(Проводки, НачислениеНалога, КонтекстРасчета, ЕстьРаспределениеНалогаНаПрибыль) Экспорт
```

Пример вызова
```bsl
РасчетНалогаНаПрибыль.ОтразитьОсвобождениеОтНалога(Проводки, НачислениеНалога, КонтекстРасчета, ЕстьРаспределениеНалогаНаПрибыль));
```
</details>

## ИсключитьАвансовыеПлатежиДоОсвобожденияОтНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ИсключитьАвансовыеПлатежиДоОсвобожденияОтНалога(ОсвобождениеОтНалога, НачалоПериодаОсвобождения, Организация, ЕстьРаспределениеНалогаНаПрибыль) Экспорт
```

Пример вызова
```bsl
РасчетНалогаНаПрибыль.ИсключитьАвансовыеПлатежиДоОсвобожденияОтНалога(ОсвобождениеОтНалога, НачалоПериодаОсвобождения, Организация, ЕстьРаспределениеНалогаНаПрибыль));
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
