---
title: Расчет себестоимости
slug: erp-uh/расчет-себестоимости
---


## РассчитатьВсе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запуск расчета партий.
//
// Параметры:
//	ПараметрыЗапуска - Структура - Содержит ключи:
//		* Дата - Дата - период расчета
//		* МассивОрганизаций - СправочникСсылка.Организации - рассчитывать только по указанной организации; также будут пересчитаны партии по организациям, связанным по схеме Интеркампани с указанной
//					- Массив из СправочникСсылка.Организации- массив организаций, по которым надо рассчитать партии, другие организации не рассчитываются
//		* СхемаРасчета - см. РасчетСебестоимостиПрикладныеАлгоритмы.СхемаРасчетаПартий
//		* МестоВызоваРасчета - Строка - откуда вызван расчет, для протокола
//		* ВыполняетсяЗакрытиеМесяца - Булево - признак вызова расчета из механизма закрытия месяца
//		* ИдентификаторРасчета - УникальныйИдентификатор - идентификатор расчета
//	ПараметрыРасчета - Структура - параметры расчета, сформированные в вызывающем механизме.
//	ПараметрыОтладки - Структура - предназначена для переопределения одноименных свойств структуры ПараметрыРасчета.
//		Подробнее см. пояснения в коде РасчетСебестоимостиПрикладныеАлгоритмы.ИнициализироватьПараметрыРасчетаПартий к параметру ПараметрыОтладки.
//
Процедура РассчитатьВсе(ПараметрыЗапуска, ПараметрыРасчета = Неопределено, ПараметрыОтладки = Неопределено) Экспорт
```

Пример вызова
```bsl
РасчетСебестоимости.РассчитатьВсе(ПараметрыЗапуска, ПараметрыРасчета, ПараметрыОтладки);
```
</details>

## РассчитатьПредварительнуюСебестоимость
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновления стоимости товаров регламентным заданием.
//
// Параметры:
//	Период - Дата - период расчета
//	ПараметрыРасчета - Структура - параметры расчета, сформированные в вызывающем механизме.
//	ПараметрыОтладки - Структура - предназначена для переопределения одноименных свойств структуры ПараметрыРасчета.
//		Подробнее см. пояснения в коде РасчетСебестоимостиПрикладныеАлгоритмы.ИнициализироватьПараметрыРасчетаПартий к параметру ПараметрыОтладки.
//
Процедура РассчитатьПредварительнуюСебестоимость(Период = Неопределено, ПараметрыРасчета = Неопределено, ПараметрыОтладки = Неопределено) Экспорт
```

Пример вызова
```bsl
РасчетСебестоимости.РассчитатьПредварительнуюСебестоимость(Период, ПараметрыРасчета, ПараметрыОтладки);
```
</details>

## РассчитатьВсеВПопыткеИсключении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обертка для запуска расчета - выполняет расчет в Попытке - Исключении
// Параметры аналогичны процедуре РассчитатьВсе().
//
// Возвращаемое значение:
//	Булево - признак успешного выполнения расчета.
//
Функция РассчитатьВсеВПопыткеИсключении(ПараметрыЗапуска, ПараметрыРасчета = Неопределено, ПараметрыОтладки = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РасчетСебестоимости.РассчитатьВсеВПопыткеИсключении(ПараметрыЗапуска, ПараметрыРасчета, ПараметрыОтладки);
```
</details>

## РассчитатьФоновымЗаданием
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запускает расчет в фоновом задании.
//
// Возвращаемое значение:
//	Булево - признак успешного запуска фонового задания.
//
Функция РассчитатьФоновымЗаданием(Период, Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РасчетСебестоимости.РассчитатьФоновымЗаданием(Период, Организация);
```
</details>

## ИмяФоновогоЗадания
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя фонового предопределенного задания расчета партий.
//
// Возвращаемое значение:
//	Строка - наименование фонового задания
//
Функция ИмяФоновогоЗадания() Экспорт
```

Пример вызова
```bsl
Результат = РасчетСебестоимости.ИмяФоновогоЗадания() 
```
</details>

## ФоновоеЗаданиеАктивно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку на активное задание расчета партий.
//
// Возвращаемое значение:
//	Булево - признак активности фонового задания
//
Функция ФоновоеЗаданиеАктивно() Экспорт
```

Пример вызова
```bsl
Результат = РасчетСебестоимости.ФоновоеЗаданиеАктивно() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
