---
title: Расчет статусов оформления ИС
slug: erp-uh/расчет-статусов-оформления-ис
---


## ПередЗаписьюДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки на событие "Перед записью" документов ГосИС, поддерживающих статусы оформления
//
// Параметры:
//   ИмяОпцииИспользованияПодсистемы - Строка - имя функциональной опции влияющей на использование функциональности
//   Источник - ДокументОбъект - записываемый объект, поддерживающий статусы оформления,
//                               должен содержать реквизит ДокументОснование.
//   Отказ - Булево - признак (установленного ранее) отказа от записи
//
Процедура ПередЗаписьюДокумента(ИмяОпцииИспользованияПодсистемы, Источник, Отказ) Экспорт
```

Пример вызова
```bsl
РасчетСтатусовОформленияИС.ПередЗаписьюДокумента(ИмяОпцииИспользованияПодсистемы, Источник, Отказ) 
```
</details>

## ПриЗаписиДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик подписки на событие "При записи" документов ГосИС, поддерживающих статусы оформления, и их документов-оснований
//
// Параметры:
//   ИмяОпцииИспользованияПодсистемы - Строка - имя функциональной опции влияющей на использование функциональности
//   Источник - ДокументОбъект - записываемый объект.
//   Отказ    - Булево - параметр, определяющий будет ли записываться объект.
//   Модуль   - ОбщийМодуль - модуль, определяющий специфику подсистемы.
//
Процедура ПриЗаписиДокумента(ИмяОпцииИспользованияПодсистемы, Источник, Отказ, Модуль) Экспорт
```

Пример вызова
```bsl
РасчетСтатусовОформленияИС.ПриЗаписиДокумента(ИмяОпцииИспользованияПодсистемы, Источник, Отказ, Модуль) 
```
</details>

## РассчитатьДляДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик группового программного пересчета статусов оформления не привязанный к подпискам на события
// Рассчитывает статусы оформления документов и записывает их в регистр сведений СтатусыОформления*.
// ВАЖНО: все элементы массива Источники должны иметь одинаковый тип.
//
// Параметры:
//  ИмяОпцииИспользованияПодсистемы - Строка - имя функциональной опции влияющей на использование функциональности
//  Источники - ДокументСсылка
//            - СправочникСсылка
//            - Массив Из ДокументСсылка
//            - Массив Из СправочникСсылка - объекты для расчета статуса оформления
//  Модуль - ОбщийМодуль - модуль, определяющий специфику подсистемы.
//
// Возвращаемое значение:
//   Булево - общая часть расчета успешно выполнена
//
Функция РассчитатьДляДокументов(ИмяОпцииИспользованияПодсистемы, Источники, Модуль) Экспорт
```

Пример вызова
```bsl
Результат = РасчетСтатусовОформленияИС.РассчитатьДляДокументов(ИмяОпцииИспользованияПодсистемы, Источники, Модуль) 
```
</details>

## РасчетСтатусовОформленияИСДляОснований
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Расчет статусов оформления ИС (для оснований).
//
// Параметры:
//  Источники - Массив Из ОпределяемыйТип.ОснованиеСтатусыОформленияДокументовИС - объекты к расчету статусов
Процедура РасчетСтатусовОформленияИСДляОснований(Источники) Экспорт
```

Пример вызова
```bsl
РасчетСтатусовОформленияИС.РасчетСтатусовОформленияИСДляОснований(Источники) 
```
</details>

## РасчетСтатусовОформленияПослеЗаписиДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура фонового задания Расчет статусов оформления после записи документа.
//
// Параметры:
//  Параметры - Структура - Параметры фонового задания:
//   * Ссылка - ОпределяемыйТип.ОснованиеСтатусыОформленияДокументовИС - документ для расчета статусов
//  АдресРезультата - Строка - Адрес результата (не используется)
Процедура РасчетСтатусовОформленияПослеЗаписиДокумента(Параметры, АдресРезультата) Экспорт
```

Пример вызова
```bsl
РасчетСтатусовОформленияИС.РасчетСтатусовОформленияПослеЗаписиДокумента(Параметры, АдресРезультата) 
```
</details>

## РасчетСтатусовОформленияИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик регламентного задания расчета статусов
Процедура РасчетСтатусовОформленияИС() Экспорт
```

Пример вызова
```bsl
РасчетСтатусовОформленияИС.РасчетСтатусовОформленияИС() 
```
</details>

## НеВыполнятьРасчетСтатусаПриЗаписиОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает служебный признак в доп. свойствах объекта, который отключает автоматический пересчет статуса оформления.
// Следует использовать при программном формировании нескольких однотипных документов.
//
// Параметры:
//   Источник - ДокументОбъект - записываемый объект
//
Процедура НеВыполнятьРасчетСтатусаПриЗаписиОбъекта(Источник) Экспорт
```

Пример вызова
```bsl
РасчетСтатусовОформленияИС.НеВыполнятьРасчетСтатусаПриЗаписиОбъекта(Источник) 
```
</details>

## ИмяВременнойТаблицыДляВыборкиДанныхДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя временной таблицы, в которую необходимо поместить данные документа-основания.
// Необходимо использовать при определении запроса для расчета статуса оформления.
//
// Возвращаемое значение:
//   Строка - имя временной таблицы
//
Функция ИмяВременнойТаблицыДляВыборкиДанныхДокумента() Экспорт
```

Пример вызова
```bsl
Результат = РасчетСтатусовОформленияИС.ИмяВременнойТаблицыДляВыборкиДанныхДокумента() 
```
</details>

## РассчитатьДляДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает статус оформления документа и записывает его в регистр сведений СтатусыОформления*.
//
// Параметры:
//   ИмяОпцииИспользованияПодсистемы - Строка - имя функциональной опции влияющей на использование функциональности
//   Источник - ДокументОбъект - записываемый объект.
//   Модуль - ОбщийМодуль - модуль, определяющий специфику подсистемы.
//
// Возвращаемое значение:
//   Булево - общая часть расчета успешно выполнена
//
Функция РассчитатьДляДокумента(ИмяОпцииИспользованияПодсистемы, Источник, Модуль) Экспорт
```

Пример вызова
```bsl
Результат = РасчетСтатусовОформленияИС.РассчитатьДляДокумента(ИмяОпцииИспользованияПодсистемы, Источник, Модуль) 
```
</details>

## РассчитатьОбщая
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Готовит данные к расчету статусов оформления.
//
// Параметры:
//   Источники - Массив из ДокументСсылка - документы ГосИС для расчета статусов.
//   ИсточникОбъект - ДокументОбъект, Неопределено - записываемый документ-основание для документа ГосИС (если заполнен).
//   Модуль - ОбщийМодуль - модуль, определяющий специфику подсистемы.
//
Процедура РассчитатьОбщая(Источники, ИсточникОбъект, Модуль) Экспорт
```

Пример вызова
```bsl
РасчетСтатусовОформленияИС.РассчитатьОбщая(Источники, ИсточникОбъект, Модуль) 
```
</details>

## ИменаДокументовДляДокументаОснования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имена документов ГосИС, основанием для которых может являться указанный документ.
//
// Параметры:
//   ДокументОснование - ДокументСсылка - документ-основание для документа ГосИС.
//   ТипОснований      - ОписаниеТипов - коллекция типов документов ГосИС для поиска.
//
// Возвращаемое значение:
//   Массив Из Строка - имена документов ГосИС.
//
Функция ИменаДокументовДляДокументаОснования(ДокументОснование, ТипОснований) Экспорт
```

Пример вызова
```bsl
Результат = РасчетСтатусовОформленияИС.ИменаДокументовДляДокументаОснования(ДокументОснование, ТипОснований) 
```
</details>

## ЗаписатьСтатусОформленияДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает статусы оформления документов ГосИС в регистр сведений СтатусыОформленияДокументов*.
//
// Параметры:
//   ТаблицаРеквизитов - ТаблицаЗначений - собранные общим механизмом реквизиты для записи статуса
//   РегистрМенеджер - РегистрСведенийМенеджер - регистр "Статусы оформления".
//   Модуль - ОбщийМодуль - модуль, определяющий специфику подсистемы.
//   ДополнительныеПараметры - Произвольный - дополнительные параметры подсистемы.
//
Процедура ЗаписатьСтатусОформленияДокументов(ТаблицаРеквизитов, РегистрМенеджер, Модуль, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
РасчетСтатусовОформленияИС.ЗаписатьСтатусОформленияДокументов(ТаблицаРеквизитов, РегистрМенеджер, Модуль, ДополнительныеПараметры);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
