---
title: Регистрации в органе статистики вызов сервера
slug: erp-uh/регистрации-в-органе-статистики-вызов-сервера
---


## СвойстваРеспондентаРосстата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СвойстваРеспондентаРосстата(Знач Респондент) Экспорт
```

Пример вызова
```bsl
Результат = РегистрацииВОрганеСтатистикиВызовСервера.СвойстваРеспондентаРосстата(Респондент) 
```
</details>

## СвойстваРеспондентаПоРегистрации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СвойстваРеспондентаПоРегистрации(Знач Регистрация) Экспорт
```

Пример вызова
```bsl
Результат = РегистрацииВОрганеСтатистикиВызовСервера.СвойстваРеспондентаПоРегистрации(Регистрация) 
```
</details>

## СвойстваРегистрацииВОрганеСтатистики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СвойстваРегистрацииВОрганеСтатистики(Знач Регистрация, Знач Реквизиты = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РегистрацииВОрганеСтатистикиВызовСервера.СвойстваРегистрацииВОрганеСтатистики(Регистрация, Реквизиты);
```
</details>

## СведенияОРегистрацииВОрганеСтатистики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сведения о регистрации в органе статистики.
//
// Параметры:
//  СтруктурнаяЕдиница - СправочникСсылка.Организаци, СправочникСсылка.ПодразделенияОрганизаций - и т.п. объект использующий регистрацию
//                       cм. ОпределяемыйТип.ТерриторияВыполненияРабот.
//  ДатаАктуальности   - Дата   - Дата актуальности сведений (не обязательный).
//  Реквизиты          - Строка - Запрашиваемые реквизиты регистрации через запятую (не обязательный).
//
// Возвращаемое значение:
//  Структура с полями:
//    * Регистрация       - СправочникСсылка.РегистрацииВОрганеСтатистики - Ссылка на регистрацию Росстата.
//    * ДанныеРегистрации - Структура - См. СвойстваРегистрацииВОрганеСтатистики.
//    * ЭтоРеспондент     - Булево - Признак, что СтруктурнаяЕдиница является респондентом (хозяином регистрации).
//
Функция СведенияОРегистрацииВОрганеСтатистики(Знач СтруктурнаяЕдиница, Знач ДатаАктуальности = Неопределено, Знач Реквизиты = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = РегистрацииВОрганеСтатистикиВызовСервера.СведенияОРегистрацииВОрганеСтатистики(СтруктурнаяЕдиница, ДатаАктуальности, Реквизиты);
```
</details>

## ДополнитьПоРегистрацииРеспондента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДополнитьПоРегистрацииРеспондента(СведенияОрганизации, СведенияРегистрации, Знач РегистрацияРеспондента, Знач Организация, Знач ДатаЗначения) Экспорт
```

Пример вызова
```bsl
Результат = РегистрацииВОрганеСтатистикиВызовСервера.ДополнитьПоРегистрацииРеспондента(СведенияОрганизации, СведенияРегистрации, РегистрацияРеспондента, Организация, ДатаЗначения) 
```
</details>

## СтруктурныеЕдиницыПоРегистрации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структурные единицы (Подразделения и Организации) использующие указанную регистрацию Росстата с учетом иерархии.
// Принято, что регистрация наследуется вниз по иерархии подразделений, до тех пор пока не будет явно задана в нижестоящем подразделении.
//
// Параметры:
//  Регистрация	     - СправочникСсылка.РегистрацииВОрганеСтатистики - Ссылка на регистрацию Росстата.
//  ДатаАктуальности - Дата - Дата актуальности сведений.
//
// Возвращаемое значение:
//  Массив - Структурные единицы, использующие указанную регистрацию с учетом иерархии.
//
Функция СтруктурныеЕдиницыПоРегистрации(Знач Регистрация, Знач ДатаАктуальности) Экспорт
```

Пример вызова
```bsl
Результат = РегистрацииВОрганеСтатистикиВызовСервера.СтруктурныеЕдиницыПоРегистрации(Регистрация, ДатаАктуальности) 
```
</details>

## ВыбранаРегистрацияРеспондента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак, что для отчета выбрана регистрация респондента Росстата.
// Это значит, что в этом экземпляре отчета используется механизм регистраций, а не устаревший механизм обособленных подразделений.
//
// Параметры:
//  ПараметрыОтчета - Структура - Параметры отчета.
//
// Возвращаемое значение:
//  Булево - Истина если в отчете выбрана регистрация респондента Росстата.
//
Функция ВыбранаРегистрацияРеспондента(Знач ПараметрыОтчета) Экспорт
```

Пример вызова
```bsl
Результат = РегистрацииВОрганеСтатистикиВызовСервера.ВыбранаРегистрацияРеспондента(ПараметрыОтчета) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
