---
title: Регл учет сервер
slug: erp-uh/регл-учет-сервер
---


## НастройкиУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает настройки регламентированного учета.
//
// Возвращаемое значение:
// 	Структура - Описание:
//		* ДополнительноВедетсяУправленческийУчет - Булево - Истина, если совместно с регламентированным (на одном плане счетов) ведется управленческий учет.
//		* ДатаНачалаВеденияУправленческогоУчета - Дата - Дата, с которой ведется совместный управленческий и регламентированный учет. Если пустая, то с начала ведения учета.
//		* ДополнительноВедетсяУчетВВалютеФинОтчетности - Булево - Истина, если плане счетов регламентированного учета дополнительно ведется учет в валюте финансовой отчетности.
//		* ВалютаФинОтчетности - СправочникСсылка.Валюты - Валюта финансовой отчетности.
//
Функция НастройкиУчета() Экспорт
```

Пример вызова
```bsl
Результат = РеглУчетСервер.НастройкиУчета() 
```
</details>

## ВедетсяРеглУчет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет ведение регл. учета на указанную дату.
//
// Параметры:
// 	Дата - Дата - Дата, на которую нужно проверить ведение регл. учета.
//
// Возвращаемое значение:
// 	Булево - Истина, если ведется регл. учет.
Функция ВедетсяРеглУчет(Дата = '000101010000') Экспорт
```

Пример вызова
```bsl
Результат = РеглУчетСервер.ВедетсяРеглУчет(Дата);
```
</details>

## СчетУчетаПоТипуНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает счет бухгалтерского учета в зависимости от выбранного типа налога. Вызов функции происходит из
// платежных документов.
//
// Параметры:
//   ТипНалога - ПеречислениеСсылка.ТипыНалогов - Типа налогов.
//
// Возвращаемое значение:
//   ПланСчетовСсылка - Счет учета по типу налога.
//
Функция СчетУчетаПоТипуНалога(ТипНалога) Экспорт
```

Пример вызова
```bsl
Результат = РеглУчетСервер.СчетУчетаПоТипуНалога(ТипНалога) 
```
</details>

## ТипНалогаПоСчетуУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает типа налога в зависимости от выбранного счета бухгалтерского учета. Вызов функции происходит из
// обработчиков обновления.
//
// Параметры:
//   СчетУчета - ПланСчетовСсылка - Счет учета по типу налога.
//
// Возвращаемое значение:
//   ПеречислениеСсылка.ТипыНалогов - Тип налогов по счету учета.
//
Функция ТипНалогаПоСчетуУчета(СчетУчета) Экспорт
```

Пример вызова
```bsl
Результат = РеглУчетСервер.ТипНалогаПоСчетуУчета(СчетУчета) 
```
</details>

## ЕстьПравоОтраженияДокументовВРеглУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает доступность отражения документов в регл. учете текущему пользователю.
//
// Возвращаемое значение:
// 	Булево - Наличие прав на отражение документов в регл. учете
//
Функция ЕстьПравоОтраженияДокументовВРеглУчете() Экспорт
```

Пример вызова
```bsl
Результат = РеглУчетСервер.ЕстьПравоОтраженияДокументовВРеглУчете() 
```
</details>

## ВернутьДокументыКОтражению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает документы к отражению в регл. учете
//
// Параметры:
// 	ДокументыКОтражению -   ТаблицаЗначений,
// 							МенеджерВременныхТаблиц - Таблица документов, которые надо вернуть к отражению,
// 													  или менеджер временных таблиц имеющий таблицу ДокументыКОтражению
// 													  Таблица должна иметь колонки Документ, Организация, ДатаОтражения.
// 	КоличествоОбработанных - Число - В данном параметр устанавливается количество возвращенных к отражению документов.
// 									 Параметр не является обязательным.
//
Процедура ВернутьДокументыКОтражению(ДокументыКОтражению, КоличествоОбработанных = Неопределено) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ВернутьДокументыКОтражению(ДокументыКОтражению, КоличествоОбработанных);
```
</details>

## ЗарегистрироватьДокументыРасчетовСПартнерамиКОтражениюВРеглУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Регистрирует документы расчетов с партнерами к отражению в регламентированном учете.
//
// Параметры:
//	Расчеты - ТаблицаЗначений - Таблица движений по расчетам с партнерами:
//	                         * Регистратор - ДокументСсылка - Документ-регистратор движений
//	                         * Период - Дата - Период движений
//	                         * АналитикаУчетаПоПартнерам - СправочникСсылка.КлючиАналитикиУчетаПоПартнерам - Аналитика учета.
//
Процедура ЗарегистрироватьДокументыРасчетовСПартнерамиКОтражениюВРеглУчете(Расчеты) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ЗарегистрироватьДокументыРасчетовСПартнерамиКОтражениюВРеглУчете(Расчеты) 
```
</details>

## ОбновитьЗаданияКЗакрытиюМесяцаПриВыполненииРеглОперации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура вызывается из методов регламентных операций для записи в регистр сведений "ЗаданияКЗакрытиюМесяца"
//	данных о необходимости пересчета признания расходов (если изменяются организации с объектом налогообложения "Доходы минус расходы").
// Параметры:
//	Период - Дата - период пересчета;
//	СписокОрганизаций - Массив - СправочникСсылка.Организации - массив организаций, для которых запущена процедура пересчета.
//	ТолькоРасходы - Булево - Признак выборки подходящих организаций. Значение по умолчанию - Истина.
//		Если Истина - будут выбираться организации на УСН, с объектом налогообложения "Доходы минус расходы".
//		Если Ложь - будут выбираться организации на УСН вне зависимости от объекта налогообложения. значение по умолчанию - Истина.
//	КоличествоОбработанныхЭлементов - Число - Количество данных, обработанных данной процедурой (см. общий модуль "Производительность").
//
Процедура ОбновитьЗаданияКЗакрытиюМесяцаПриВыполненииРеглОперации(Период, СписокОрганизаций, ТолькоРасходы = Истина, КоличествоОбработанныхЭлементов = 0) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ОбновитьЗаданияКЗакрытиюМесяцаПриВыполненииРеглОперации(Период, СписокОрганизаций, ТолькоРасходы, КоличествоОбработанныхЭлементов);
```
</details>

## РегистрыРеглУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру регистров регл учета
//
// Возвращаемое значение:
// 	Структура - Структура регистров НДС, где
// 	     Ключ - Имя регистра
// 	     Значение - Набор записей регистра.
Функция РегистрыРеглУчета() Экспорт
```

Пример вызова
```bsl
Результат = РеглУчетСервер.РегистрыРеглУчета() 
```
</details>

## ОтразитьДвижения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура формирования движений по подчиненным регистрам регламентированного учета.
//
// Параметры:
//   ТаблицыДляДвижений - Структура - таблицы данных документа
//   Движения - КоллекцияДвижений - коллекция наборов записей движений документа
//   Отказ - Булево - признак отказа от проведения документа.
//
Процедура ОтразитьДвижения(ТаблицыДляДвижений, Движения, Отказ) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ОтразитьДвижения(ТаблицыДляДвижений, Движения, Отказ) 
```
</details>

## ПолучитьСвойстваСчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает свойства счета регламентированного учета
//
// Параметры:
// 	Счет - ПланСчетовСсылка - Счет регламентированного учета
// Возвращаемое значение:
// 	Структура - Свойства счета
Функция ПолучитьСвойстваСчета(Знач Счет) Экспорт
```

Пример вызова
```bsl
Результат = РеглУчетСервер.ПолучитьСвойстваСчета(Счет) 
```
</details>

## НастроитьВидимостьПолейНалоговогоУчетаИРазниц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Настраивает видимость полей НУ, ПР и ВР на форме
//
// Параметры:
//  ПоляНалогНаПрибыль - Соответствие - ключ = поле формы, в том числе - заголовки строк; значение = вид учета НУ/ПР/ВР
//  Период         - Дата - основной период набора записей
//  Организация    - СправочникСсылка.Организации - организация набора записей
//                 - Неопределено - организация набора записей не может быть определена
//  ВидИспользованияСумм - Строка -
//  ВыводитьСуммыРазницДляПлательщикаНалогаНаПрибыль - Булево - вывести суммы разниц, если организация ведет учет ПБУ 18/02 простым балансовым методом
//
Процедура НастроитьВидимостьПолейНалоговогоУчетаИРазниц(ПоляНалогНаПрибыль, Период, Организация = Неопределено, ВидИспользованияСумм = "", Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.НастроитьВидимостьПолейНалоговогоУчетаИРазниц(ПоляНалогНаПрибыль, Период, Организация, ВидИспользованияСумм, );
```
</details>

## ОпределитьОбъектыСКомандамиОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ Локализация

//++ НЕ УТ

// см. ВариантыОтчетовПереопределяемый.ОпределитьОбъектыСКомандамиОтчетов
Процедура ОпределитьОбъектыСКомандамиОтчетов(Объекты) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ОпределитьОбъектыСКомандамиОтчетов(Объекты) 
```
</details>

## НастроитьВариантыОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// см. ВариантыОтчетовПереопределяемый.НастроитьВариантыОтчетов
//
Процедура НастроитьВариантыОтчетов(Настройки) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.НастроитьВариантыОтчетов(Настройки) 
```
</details>

## ЗаполнитьИсточникиДанныхДляПроверкиЗапретаИзменения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// см. ДатыЗапретаИзмененияПереопределяемый.ЗаполнитьИсточникиДанныхДляПроверкиЗапретаИзменения
Процедура ЗаполнитьИсточникиДанныхДляПроверкиЗапретаИзменения(ИсточникиДанных) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ЗаполнитьИсточникиДанныхДляПроверкиЗапретаИзменения(ИсточникиДанных) 
```
</details>

## ПриОпределенииОбъектовСКомандамиСозданияНаОсновании
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// см. СозданиеНаОснованииПереопределяемый.ПриОпределенииОбъектовСКомандамиСозданияНаОсновании
Процедура ПриОпределенииОбъектовСКомандамиСозданияНаОсновании(Объекты) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ПриОпределенииОбъектовСКомандамиСозданияНаОсновании(Объекты) 
```
</details>

## ПриОпределенииОбъектовСКомандамиПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// см. УправлениеПечатьюПереопределяемый.ПриОпределенииОбъектовСКомандамиПечати
Процедура ПриОпределенииОбъектовСКомандамиПечати(СписокОбъектов) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ПриОпределенииОбъектовСКомандамиПечати(СписокОбъектов) 
```
</details>

## ДобавитьРолиДоступаКРазделу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьРолиДоступаКРазделу(ОписаниеПрофиля) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ДобавитьРолиДоступаКРазделу(ОписаниеПрофиля) 
```
</details>

## ДобавитьРолиИзмененияНСИРеглУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьРолиИзмененияНСИРеглУчета(ОписаниеПрофиля) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ДобавитьРолиИзмененияНСИРеглУчета(ОписаниеПрофиля) 
```
</details>

## ДобавитьРолиЧтенияНСИРеглУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьРолиЧтенияНСИРеглУчета(ОписаниеПрофиля) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ДобавитьРолиЧтенияНСИРеглУчета(ОписаниеПрофиля) 
```
</details>

## ДобавитьРолиЧтенияДанныхРеглУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьРолиЧтенияДанныхРеглУчета(ОписаниеПрофиля) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ДобавитьРолиЧтенияДанныхРеглУчета(ОписаниеПрофиля) 
```
</details>

## ДобавитьРолиПросмотраДанныхРеглУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьРолиПросмотраДанныхРеглУчета(ОписаниеПрофиля) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ДобавитьРолиПросмотраДанныхРеглУчета(ОписаниеПрофиля) 
```
</details>

## ДобавитьРолиРегламентированнойОтчетности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьРолиРегламентированнойОтчетности(ОписаниеПрофиля) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ДобавитьРолиРегламентированнойОтчетности(ОписаниеПрофиля) 
```
</details>

## ДобавитьРолиЧтенияНастроекОтраженияВРеглУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьРолиЧтенияНастроекОтраженияВРеглУчете(ОписаниеПрофиля) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ДобавитьРолиЧтенияНастроекОтраженияВРеглУчете(ОписаниеПрофиля) 
```
</details>

## ДобавитьРолиИзмененияНастроекОтраженияВРеглУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьРолиИзмененияНастроекОтраженияВРеглУчете(ОписаниеПрофиля) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ДобавитьРолиИзмененияНастроекОтраженияВРеглУчете(ОписаниеПрофиля) 
```
</details>

## ДобавитьЭтап_ОтражениеДокументовВРегламентированномУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет этап в таблицу этапов закрытия месяца.
// Элементы данной таблицы являются элементами второго уровня в дереве этапов в форме закрытия месяца.
//
// Параметры:
// 	ТаблицаЭтапов - (См. Обработки.ОперацииЗакрытияМесяца.ЗаполнитьОписаниеЭтаповЗакрытияМесяца)
// 	ТекущийРодитель - Строка - идентификатор группы.
Процедура ДобавитьЭтап_ОтражениеДокументовВРегламентированномУчете(ТаблицаЭтапов,ТекущийРодитель) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ДобавитьЭтап_ОтражениеДокументовВРегламентированномУчете(ТаблицаЭтапов, ТекущийРодитель) 
```
</details>

## Использование_ОтражениеДокументовВРегламентированномУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчики этапа.

Процедура Использование_ОтражениеДокументовВРегламентированномУчете(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.Использование_ОтражениеДокументовВРегламентированномУчете(ПараметрыОбработчика) 
```
</details>

## Выполнить_ОтражениеДокументовВРегламентированномУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура Выполнить_ОтражениеДокументовВРегламентированномУчете(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.Выполнить_ОтражениеДокументовВРегламентированномУчете(ПараметрыОбработчика) 
```
</details>

## ДобавитьЭтап_ФормированиеФинансовогоРезультата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет этап в таблицу этапов закрытия месяца.
// Элементы данной таблицы являются элементами второго уровня в дереве этапов в форме закрытия месяца.
//
// Параметры:
// 	ТаблицаЭтапов - (См. Обработки.ОперацииЗакрытияМесяца.ЗаполнитьОписаниеЭтаповЗакрытияМесяца)
// 	ТекущийРодитель - Строка - идентификатор группы.
Процедура ДобавитьЭтап_ФормированиеФинансовогоРезультата(ТаблицаЭтапов,ТекущийРодитель) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ДобавитьЭтап_ФормированиеФинансовогоРезультата(ТаблицаЭтапов, ТекущийРодитель) 
```
</details>

## Использование_ФормированиеФинансовогоРезультата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчики этапа.

Процедура Использование_ФормированиеФинансовогоРезультата(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.Использование_ФормированиеФинансовогоРезультата(ПараметрыОбработчика) 
```
</details>

## Выполнить_ФормированиеФинансовогоРезультата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура Выполнить_ФормированиеФинансовогоРезультата(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.Выполнить_ФормированиеФинансовогоРезультата(ПараметрыОбработчика) 
```
</details>

## ДобавитьЭтап_РасчетЕНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет этап в таблицу этапов закрытия месяца.
// Элементы данной таблицы являются элементами второго уровня в дереве этапов в форме закрытия месяца.
//
// Параметры:
// 	ТаблицаЭтапов - (См. Обработки.ОперацииЗакрытияМесяца.ЗаполнитьОписаниеЭтаповЗакрытияМесяца)
// 	ТекущийРодитель - Строка - идентификатор группы.
Процедура ДобавитьЭтап_РасчетЕНС(ТаблицаЭтапов,ТекущийРодитель) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ДобавитьЭтап_РасчетЕНС(ТаблицаЭтапов, ТекущийРодитель) 
```
</details>

## Использование_РасчетЕНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчики этапа
//
// Параметры:
// 	ПараметрыОбработчика - см. ЗакрытиеМесяцаСервер.ИнициализироватьПараметрыОбработчикаЭтапаЗакрытияМесяцаДляПроверки
//
Процедура Использование_РасчетЕНС(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.Использование_РасчетЕНС(ПараметрыОбработчика) 
```
</details>

## Выполнить_РасчетЕНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет этап закрытия месяца.
//
// Параметры:
//	ПараметрыОбработчика - см. ЗакрытиеМесяцаСервер.ИнициализироватьПараметрыОбработчикаЭтапаЗакрытияМесяцаДляПроверки.
//
Процедура Выполнить_РасчетЕНС(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.Выполнить_РасчетЕНС(ПараметрыОбработчика) 
```
</details>

## ДобавитьЭтап_ПереходНаЕНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет этап в таблицу этапов закрытия месяца.
// Элементы данной таблицы являются элементами второго уровня в дереве этапов в форме закрытия месяца.
//
// Параметры:
// 	ТаблицаЭтапов - (См. Обработки.ОперацииЗакрытияМесяца.ЗаполнитьОписаниеЭтаповЗакрытияМесяца)
// 	ТекущийРодитель - Строка - идентификатор группы.
Процедура ДобавитьЭтап_ПереходНаЕНС(ТаблицаЭтапов,ТекущийРодитель) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ДобавитьЭтап_ПереходНаЕНС(ТаблицаЭтапов, ТекущийРодитель) 
```
</details>

## Использование_ПереходНаЕНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчики этапа.

// Проверяет необходимость выполнения этапа закрытия месяца.
//
// Параметры:
//   ПараметрыОбработчика - см. ЗакрытиеМесяцаСервер.ИнициализироватьПараметрыОбработчикаЭтапаЗакрытияМесяцаДляПроверки
//
Процедура Использование_ПереходНаЕНС(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.Использование_ПереходНаЕНС(ПараметрыОбработчика) 
```
</details>

## ДобавитьЭтап_РеклассификацияДолгосрочныхАктивовОбязательств
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет этап в таблицу этапов закрытия месяца.
// Элементы данной таблицы являются элементами второго уровня в дереве этапов в форме закрытия месяца.
//
// Параметры:
// 	ТаблицаЭтапов - (См. Обработки.ОперацииЗакрытияМесяца.ЗаполнитьОписаниеЭтаповЗакрытияМесяца)
// 	ТекущийРодитель - Строка - идентификатор группы.
Процедура ДобавитьЭтап_РеклассификацияДолгосрочныхАктивовОбязательств(ТаблицаЭтапов,ТекущийРодитель) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ДобавитьЭтап_РеклассификацияДолгосрочныхАктивовОбязательств(ТаблицаЭтапов, ТекущийРодитель) 
```
</details>

## Использование_РеклассификацияДолгосрочныхАктивовОбязательств
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчики этапа.

Процедура Использование_РеклассификацияДолгосрочныхАктивовОбязательств(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.Использование_РеклассификацияДолгосрочныхАктивовОбязательств(ПараметрыОбработчика) 
```
</details>

## Выполнить_РеклассификацияДолгосрочныхАктивовОбязательств
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура Выполнить_РеклассификацияДолгосрочныхАктивовОбязательств(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.Выполнить_РеклассификацияДолгосрочныхАктивовОбязательств(ПараметрыОбработчика) 
```
</details>

## ДобавитьЭтап_ВводСведенийСреднесписочнойЧисленности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет этап в таблицу этапов закрытия месяца.
// Элементы данной таблицы являются элементами второго уровня в дереве этапов в форме закрытия месяца.
//
// Параметры:
// 	ТаблицаЭтапов - см. Обработка.ОперацииЗакрытияМесяца.ИнициализироватьТаблицуОписанияЭтапов -
// 	ТекущийРодитель - Строка - идентификатор группы.
//
Процедура ДобавитьЭтап_ВводСведенийСреднесписочнойЧисленности(ТаблицаЭтапов, ТекущийРодитель) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.ДобавитьЭтап_ВводСведенийСреднесписочнойЧисленности(ТаблицаЭтапов, ТекущийРодитель) 
```
</details>

## Использование_ВводСведенийСреднесписочнойЧисленности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура Использование_ВводСведенийСреднесписочнойЧисленности(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
РеглУчетСервер.Использование_ВводСведенийСреднесписочнойЧисленности(ПараметрыОбработчика) 
```
</details>

## ДатаНачалаОбязательногоПримененияЕНП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дату начала обязательного применения ЕНП
//
// Возвращаемое значение:
// 	Дата - дата начала обязательного применения ЕНП
//
Функция ДатаНачалаОбязательногоПримененияЕНП() Экспорт
```

Пример вызова
```bsl
Результат = РеглУчетСервер.ДатаНачалаОбязательногоПримененияЕНП() 
```
</details>

## ПроверитьИспользованиеЕНП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТ
Функция ПроверитьИспользованиеЕНП(ПараметрыОбработчикаИлиПараметрыРасчета) Экспорт
```

Пример вызова
```bsl
Результат = РеглУчетСервер.ПроверитьИспользованиеЕНП(ПараметрыОбработчикаИлиПараметрыРасчета));
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
