---
title: Регламентированный отчет прибыль
slug: erp-uh/регламентированный-отчет-прибыль
---


## ВерсияКонтейнера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет версию контейнера БРО, содержащего данные декларации.
// Ранее редакции формы использовали двухуровневую структуру,
// начиная с отчетности за 2019 год - трехуровневую, где приложения к листу 02 подчинены листу 02.
// Подробнее об устройстве контейнера см. СтраницыРазделаКонтейнера
//
// Параметры:
//  ИмяРедакции - Строка - имя редакции отчета (формы БРО)
//
// Возвращаемое значение:
//  Дата - идентификатор версии. Можно сравнивать с применением операторов < или >
//
Функция ВерсияКонтейнера(ИмяРедакции) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированныйОтчетПрибыль.ВерсияКонтейнера(ИмяРедакции) 
```
</details>

## НомерЯчейки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструирует техногенный номер ячейки, используемый в форме отчета,
// по данным, предусмотренным нормативным документом
//
// Параметры:
//  НомерЛиста		 - Строка - номер листа декларации, как указано в нормативном документе, например "02"
//  НомерПриложения	 - Строка - номер приложения к листу декларации, как указано в нормативном документе, например "1"
//  НомерСтроки		 - Строка - номер строки, как указано в нормативном документе, например "030"
//  НомерГрафы		 - Строка - условный номер графы (колонки), предусмотренный разработчиками БРО.
//                              Обычно основные суммовые показатели имеют условный номер "03".
//  ИмяРедакции      - Строка - имя редакции отчета (формы БРО)
//
// Возвращаемое значение:
//  Строка - номер ячейки отчета
//
Функция НомерЯчейки(Знач НомерЛиста, Знач НомерПриложения, Знач НомерСтроки, Знач НомерГрафы, ИмяРедакции) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированныйОтчетПрибыль.НомерЯчейки(НомерЛиста, НомерПриложения, НомерСтроки, НомерГрафы, ИмяРедакции) 
```
</details>

## ИмяРаздела
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструирует имя раздела (листа, приложения к листу, раздела декларации, подраздела и т.п.), используемое в контейнере БРО
//
// Параметры:
//  НомерЛиста		 - Строка - номер листа декларации, как указано в нормативном документе, например "02"
//  НомерПриложения	 - Строка - номер приложения к листу декларации, как указано в нормативном документе, например "1"
//
// Возвращаемое значение:
//  Строка - имя раздела
//
Функция ИмяРаздела(НомерЛиста, НомерПриложения) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированныйОтчетПрибыль.ИмяРаздела(НомерЛиста, НомерПриложения) 
```
</details>

## СтраницыРазделаКонтейнера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Находит в контейнере данных отчета коллекцию записей, соответствующую набору страниц заданного раздела (листа, приложения к листу и т.п.)
//
// Параметры:
//  Контейнер              - ДеревоЗначений, Структура - заполняемый контейнер, тип определяется редакцией отчета, см. ВерсияКонтейнера
//  НомерЛиста             - Строка - номер листа декларации, как указано в нормативном документе, например "02"
//  НомерПриложения        - Строка - номер приложения к листу декларации, как указано в нормативном документе, например "1"
//  ИндексКомплектаСтраниц - Число  - индекс заполняемой страницы (комплекта страниц) отчета.
//                                    Для добавления страницы см. ДобавитьСтраницу
//  ИмяРедакции            - Строка - имя редакции отчета (формы БРО)
//
// Возвращаемое значение:
//  КоллекцияСтрокДереваЗначений, Структура - страница контейнера БРО, с которой можно работать методами области УстановкаЗначенийКонтейнера
//
Функция СтраницыРазделаКонтейнера(Контейнер, НомерЛиста, НомерПриложения, ИндексКомплектаСтраниц, ИмяРедакции) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированныйОтчетПрибыль.СтраницыРазделаКонтейнера(Контейнер, НомерЛиста, НомерПриложения, ИндексКомплектаСтраниц, ИмяРедакции) 
```
</details>

## НомерСлужебнойЯчейкиПризнакНалогоплательщика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет номер служебной ячейки для хранения признака налогоплательщика.
// Нормативные документы предусматривают такое поле отчета, но не присваивают ему номер.
//
// Параметры:
//  НомерЛиста       - Строка - номер листа декларации, как указано в нормативном документе, например "02"
//  НомерПриложения  - Строка - номер приложения к листу декларации, как указано в нормативном документе, например "1"
//  ИмяРедакции      - Строка - имя редакции отчета (формы БРО)
//
// Возвращаемое значение:
//  Строка - см. НомерЯчейки
//
Функция НомерСлужебнойЯчейкиПризнакНалогоплательщика(НомерЛиста, НомерПриложения, ИмяРедакции) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированныйОтчетПрибыль.НомерСлужебнойЯчейкиПризнакНалогоплательщика(НомерЛиста, НомерПриложения, ИмяРедакции) 
```
</details>

## ДобавитьСтраницу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в контейнер данных отчета страницу раздела отчета (листа, приложения и т.п.)
//
// Параметры:
//  РазделБРО   - КоллекцияСтрокДереваЗначений, Структура - результат СтраницыРазделаКонтейнера
//  ИмяРедакции - Строка - имя редакции отчета (формы БРО)
//
Процедура ДобавитьСтраницу(РазделБРО, ИмяРедакции) Экспорт
```

Пример вызова
```bsl
РегламентированныйОтчетПрибыль.ДобавитьСтраницу(РазделБРО, ИмяРедакции) 
```
</details>

## ПоместитьЗначениеПоказателяНаСтраницу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает в контейнер (на страницу контейнера) значение показателя.
// Не следует использовать для показателей многострочных частей. Для них - УстановитьДанныеМногострочнойЧасти
//
// Параметры:
//  Страница     - СтрокаДереваЗначений, ТаблицаЗначений, ДанныеФормыКоллекция - элемент коллекции из СтраницыРазделаКонтейнера
//  НомерЯчейки  - Строка - номер заполняемого поля отчета, см. НомерЯчейки
//  Значение     - Число, Строка, Дата - устанавливаемое значение;
//                 тип определяется разработчиками БРО исходя из назначения ячейки. Обычно - Число
//
Процедура ПоместитьЗначениеПоказателяНаСтраницу(Страница, НомерЯчейки, Значение) Экспорт
```

Пример вызова
```bsl
РегламентированныйОтчетПрибыль.ПоместитьЗначениеПоказателяНаСтраницу(Страница, НомерЯчейки, Значение) 
```
</details>

## УстановитьДанныеМногострочнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает в контейнер (на страницу контейнера) значения показателей многострочной части
// Для установки основных данных декларации - в ПоместитьЗначениеПоказателяНаСтраницу
//
// Параметры:
//  Страница                 - СтрокаДереваЗначений, ТаблицаЗначений, ДанныеФормыКоллекция - элемент коллекции из СтраницыРазделаКонтейнера
//  КодЭлементаФНС           - Строка - код многострочной части в соответствии с форматом представления декларации в электронном виде
//  ДанныеМногострочнойЧасти - ТаблицаЗначений - помещаемые данные. Колонки должны иметь имена и типы,
//                             предусмотренные форматом представления декларации в электронном виде
//                             (см. "коды", "признак типа, формат элемента" соответственно)
//  ИмяРедакции              - Строка - имя редакции отчета (формы БРО)
//
Процедура УстановитьДанныеМногострочнойЧасти(Страница, КодЭлементаФНС, ДанныеМногострочнойЧасти, ИмяРедакции) Экспорт
```

Пример вызова
```bsl
РегламентированныйОтчетПрибыль.УстановитьДанныеМногострочнойЧасти(Страница, КодЭлементаФНС, ДанныеМногострочнойЧасти, ИмяРедакции) 
```
</details>

## ВключитьСтраницу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Включает страницу - отмечает, что страница содержит данные.
//
// Имеет два аспекта: технический и налоговый.
// 1. С технической точки зрения, показываем, используется ли конкретная страница - будет ли она представлена в составе декларации.
//    Поэтому, если есть данные для заполнения на этой странице, то нужно убедиться, что поле также заполнено.
// 2. С налоговой точки зрения, указываются особенности операций, отраженных на конкретной странице.
//    Автоматическое заполнение предполагает, что речь идет об обычных операциях - без особенностей.
//
// Параметры:
//  Страница         - СтрокаДереваЗначений, ТаблицаЗначений, ДанныеФормыКоллекция - элемент коллекции из СтраницыРазделаКонтейнера
//                     Следует передавать только фактически заполненные страницы
//  НомерЛиста       - Строка - номер листа декларации, как указано в нормативном документе, например "02"
//  НомерПриложения  - Строка - номер приложения к листу декларации, как указано в нормативном документе, например "1"
//  ИмяРедакции      - Строка - имя редакции отчета (формы БРО)
//  ПризнакНалогоплательщика - Строка - код признака налогоплательщика
//
Процедура ВключитьСтраницу(Страница, НомерЛиста, НомерПриложения, ИмяРедакции, ПризнакНалогоплательщика = "") Экспорт
```

Пример вызова
```bsl
РегламентированныйОтчетПрибыль.ВключитьСтраницу(Страница, НомерЛиста, НомерПриложения, ИмяРедакции, ПризнакНалогоплательщика);
```
</details>

## ПринятьРезультатАвтозаполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет действия, необходимые после автозаполнения.
// Это код БРО, однако необходим явный его вызов из переопределяемого кода прикладного решения,
// так как этот переопределяемый код в БРО является обработчиком фонового задания.
//
// Параметры:
//  Контейнер            - ДеревоЗначений, Структура - заполненный контейнер, тип определяется редакцией отчета, см. ВерсияКонтейнера
//  ТаблицаРасшифровки	 - ТаблицаЗначений - данные расшифровки. Конкретный формат определяется прикладным решением.
//                         Например, может использоваться ЗаполнениеРасшифровкаРегламентированнойОтчетности.НовыйРасшифровка
//  ПараметрыОтчета      - Структура - параметры, передаваемые БРО в РегламентированнаяОтчетностьПереопределяемый.ЗаполнитьОтчет
//  ИмяРедакции          - Строка - имя редакции отчета (формы БРО)
//
Процедура ПринятьРезультатАвтозаполнения(Контейнер, ТаблицаРасшифровки, ПараметрыОтчета, ИмяРедакции) Экспорт
```

Пример вызова
```bsl
РегламентированныйОтчетПрибыль.ПринятьРезультатАвтозаполнения(Контейнер, ТаблицаРасшифровки, ПараметрыОтчета, ИмяРедакции) 
```
</details>

## СлужебныйНомерКолонкиМногострочнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет служебный номер колонки многострочной части, используемый в контейнере формы отчета.
// Номер колонки включает относительный номер многострочной части и номер показателя в ней.
//
// Параметры:
//  КодТаблицыФНС	 - Строка - код таблицы (элемента типа "С") в формате представления декларации в электронном виде
//  КодЭлементаФНС	 - Строка - код элемента (колонки таблицы) в формате представления декларации в электронном виде
//  ИмяРедакции      - Строка - имя редакции отчета (формы БРО)
//
// Возвращаемое значение:
//  Строка - семизначный номер колонки
//
Функция СлужебныйНомерКолонкиМногострочнойЧасти(КодТаблицыФНС, КодЭлементаФНС, ИмяРедакции) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированныйОтчетПрибыль.СлужебныйНомерКолонкиМногострочнойЧасти(КодТаблицыФНС, КодЭлементаФНС, ИмяРедакции) 
```
</details>

## КодМножественногоЭлемента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет служебный номер показателя многострочной части, используемый для нумерации ячеек формы отчета.
//
// Параметры:
//  КодТаблицыФНС	 - Строка - код таблицы (элемента типа "С") в формате представления декларации в электронном виде
//  КодЭлементаФНС	 - Строка - код элемента (колонки таблицы) в формате представления декларации в электронном виде
//  ИмяРедакции      - Строка - имя редакции отчета (формы БРО)
//
// Возвращаемое значение:
//  Строка - пятизначный номер ячейки (включает условный номер строки и графы)
//
Функция КодМножественногоЭлемента(КодТаблицыФНС, КодЭлементаФНС, ИмяРедакции) Экспорт
```

Пример вызова
```bsl
Результат = РегламентированныйОтчетПрибыль.КодМножественногоЭлемента(КодТаблицыФНС, КодЭлементаФНС, ИмяРедакции) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
