---
title: Сверка взаиморасчетов СБП (c2b)
slug: erp-uh/сверка-взаиморасчетов-сбп-c2b
---


## ДоступнаСверкаВзаиморасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет доступность использования функциональности проведения сверки
// взаиморасчетов.
//
// Возвращаемое значение:
//  Булево - если Истина, сверка взаиморасчетов доступна.
//
Функция ДоступнаСверкаВзаиморасчетов() Экспорт
```

Пример вызова
```bsl
Результат = СверкаВзаиморасчетовСБПc2b.ДоступнаСверкаВзаиморасчетов() 
```
</details>

## НовыйДанныеОперацийОплат
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует описание данных оплат на основании переданных параметров.
//
// Параметры:
//  СуммаОперации - Число - данные суммы операции;
//  ТипОперации - Строка - тип: Оплата или Возврат;
//  Выполнена - Булево - результат завершения операции.
//
// Возвращаемое значение:
//  Структура - описание данных операции.
//
Функция НовыйДанныеОперацийОплат(СуммаОперации, ТипОперации, Выполнена) Экспорт
```

Пример вызова
```bsl
Результат = СверкаВзаиморасчетовСБПc2b.НовыйДанныеОперацийОплат(СуммаОперации, ТипОперации, Выполнена) 
```
</details>

## ЗапросОтчетПоСверкеОборотов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные отчета по сверке взаиморасчетов из сервиса участника СБП.
//
// Параметры:
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//   настройка выполнения операции;
//  НачалоПериода - Дата - дата начало выборки данных отчета;
//  КонецПериода - Дата - дата окончания выборки данных отчета;
//
// Возвращаемое значение:
//  Структура - данные сверки взаиморасчетов:
//    * ПараметрыЗапроса - Структура - данные для запроса статуса отчета:
//      ** ДатаЗапросаСтатуса - Дата - дата последнего запроса статуса отчета;
//      ** Идентификатор - Строка - идентификатор отчета;
//    * ДанныеОтчета - Структура - данные оборотов. Передается если статус операции "Выполнена".
//      ** СуммаВозвратов - Число - общая сумма возвратов за период по торговой точке;
//      ** СуммаОплат - Число - общая сумма оплат за период по торговой точке;
//      ** СуммаКомиссии - Число - рассчитанная сумма возвратов за период по торговой точке;
//    *СтатусОперации - Строка - текущее состояние операции оплаты:
//       - "Выполняется" - подтверждение формирования не получено;
//       - "Отменена" - оплата по оплата по ранее сформированному QR-коду невозможна;
//       - "Выполнена" - участник СБП подтвердил оплату;
//       - "Ошибка" - не удалось выполнить проверку оплаты из-за ошибки.
//    * КодОшибки - Строка - строковый код возникшей ошибки, который
//      может быть обработан вызывающим методом;
//    * СообщениеОбОшибке  - Строка, ФорматированнаяСтрока - сообщение об ошибке для пользователя;
//    * ИнформацияОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке для администратора.
//
Функция ЗапросОтчетПоСверкеОборотов(НастройкаПодключения, НачалоПериода, КонецПериода) Экспорт
```

Пример вызова
```bsl
Результат = СверкаВзаиморасчетовСБПc2b.ЗапросОтчетПоСверкеОборотов(НастройкаПодключения, НачалоПериода, КонецПериода) 
```
</details>

## СостояниеОтчетаПоСверкеОборотов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает статус и загружает данные отчета по сверке взаиморасчетов из сервиса участника СБП.
//
// Параметры:
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//   настройка выполнения операции;
//  ПараметрыЗапроса - Структура - данные для запроса статуса отчета:
//   * ДатаЗапросаСтатуса - Дата - дата последнего запроса статуса отчета;
//   * Идентификатор - Строка - идентификатор отчета;
//  ДлительностьОперации - Число - количество секунд ожидания формирования отчета.
//
// Возвращаемое значение:
//  Структура - данные сверки взаиморасчетов:
//    * ПараметрыЗапроса - Структура - данные для запроса статуса отчета:
//      ** ДатаЗапросаСтатуса - Дата - дата последнего запроса статуса отчета;
//      ** Идентификатор - Строка - идентификатор отчета;
//    * ДанныеОтчета - Структура - данные оборотов. Передается если статус операции "Выполнена".
//      ** СуммаВозвратов - Число - общая сумма возвратов за период по торговой точке;
//      ** СуммаОплат - Число - общая сумма оплат за период по торговой точке;
//      ** СуммаКомиссии - Число - рассчитанная сумма возвратов за период по торговой точке;
//    *СтатусОперации - Строка - текущее состояние операции оплаты:
//       - "Выполняется" - подтверждение формирования не получено;
//       - "Отменена" - оплата по оплата по ранее сформированному QR-коду невозможна;
//       - "Выполнена" - участник СБП подтвердил оплату;
//       - "Ошибка" - не удалось выполнить проверку оплаты из-за ошибки.
//    * КодОшибки - Строка - строковый код возникшей ошибки, который
//      может быть обработан вызывающим методом;
//    * СообщениеОбОшибке  - Строка, ФорматированнаяСтрока - сообщение об ошибке для пользователя;
//    * ИнформацияОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке для администратора.
//
Функция СостояниеОтчетаПоСверкеОборотов(НастройкаПодключения, ПараметрыЗапроса, ДлительностьОперации = 0) Экспорт
```

Пример вызова
```bsl
Результат = СверкаВзаиморасчетовСБПc2b.СостояниеОтчетаПоСверкеОборотов(НастройкаПодключения, ПараметрыЗапроса, ДлительностьОперации);
```
</details>

## ЗапросОтчетаПоСверкеОпераций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные операций проведенных за период.
//
// Параметры:
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//   настройка выполнения операции;
//  НачалоПериода - Дата - дата начало выборки данных отчета;
//  КонецПериода - Дата - дата окончания выборки данных отчета;
//
// Возвращаемое значение:
//  Структура - данные сверки взаиморасчетов:
//    * Идентификатор - Строка - идентификатор отчета;
//    * ДанныеОпераций - ТаблицаЗначений - данные операций участника СБП:
//     ** ТипОперации - Строка - тип операции, оплата или возврат;
//     ** ДатаОперации - Дата - дата первичного документа в 1С, который зарегистрировал операцию;
//     ** Сумма - Число - сумма операции в Системе быстрых платежей;
//     ** СуммаКомиссии - Число - рассчитанная сумма комиссии;
//     ** Идентификатор - Строка - устарел, следует использовать ИдентификаторОперации.
//        Идентификатор операции в Системе быстрых платежей;
//     ** ИдентификаторОперации - Строка - идентификатор операции в Системе быстрых платежей;
//     ** ИдентификаторОплаты - Строка - идентификатор оплаты в Системе быстрых платежей.
//    * СтатусОперации - Строка - текущее состояние операции оплаты:
//       - "Выполняется" - подтверждение формирования не получено;
//       - "Отменена" - оплата по оплата по ранее сформированному QR-коду невозможна;
//       - "Выполнена" - участник СБП подтвердил оплату;
//       - "Ошибка" - не удалось выполнить проверку оплаты из-за ошибки.
//    * КодОшибки - Строка - строковый код возникшей ошибки, который
//                 может быть обработан вызывающим методом;
//    * СообщениеОбОшибке  - Строка, ФорматированнаяСтрока - сообщение об ошибке для пользователя;
//    * ИнформацияОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке для администратора.
//
Функция ЗапросОтчетаПоСверкеОпераций(НастройкаПодключения, НачалоПериода, КонецПериода) Экспорт
```

Пример вызова
```bsl
Результат = СверкаВзаиморасчетовСБПc2b.ЗапросОтчетаПоСверкеОпераций(НастройкаПодключения, НачалоПериода, КонецПериода) 
```
</details>

## СостояниеОтчетаПоСверкеОпераций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает статус и загружает данные отчета по сверке операций из сервиса.
//
// Параметры:
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//   настройка выполнения операции;
//  ПараметрыЗапроса - Структура - данные для запроса статуса отчета:
//   * ДатаЗапросаСтатуса - Дата - дата последнего запроса статуса отчета;
//   * Идентификатор - Строка - идентификатор отчета;
//  ДлительностьОперации - Число - количество секунд ожидания формирования отчета.
//
// Возвращаемое значение:
//  Структура - данные сверки взаиморасчетов:
//    * ПараметрыЗапроса - Структура - данные для запроса статуса отчета:
//      ** ДатаЗапросаСтатуса - Дата - дата последнего запроса статуса отчета;
//      ** Идентификатор - Строка - идентификатор отчета;
//    *ДанныеОпераций - ТаблицаЗначений - результат получения отчета:
//      **ТипОперации - Строка - тип операции, оплата или возврат;
//      **ДатаОперации - Дата - дата первичного документа в 1С, который зарегистрировал операцию;
//      **Сумма - Число - сумма операции в Системе быстрых платежей;
//      **СуммаКомиссии - Число - рассчитанная сумма комиссии;
//      **Идентификатор - Строка - идентификатор операции в Системе быстрых платежей;
//      **ИдентификаторОплаты - Строка - идентификатор оплаты в Системе быстрых платежей.
//    *СтатусОперации - Строка - текущее состояние операции оплаты:
//       - "Выполняется" - подтверждение формирования не получено;
//       - "Отменена" - оплата по оплата по ранее сформированному QR-коду невозможна;
//       - "Выполнена" - участник СБП подтвердил оплату;
//       - "Ошибка" - не удалось выполнить проверку оплаты из-за ошибки.
//    * КодОшибки - Строка - строковый код возникшей ошибки, который
//      может быть обработан вызывающим методом;
//    * СообщениеОбОшибке  - Строка, ФорматированнаяСтрока - сообщение об ошибке для пользователя;
//    * ИнформацияОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке для администратора.
//
Функция СостояниеОтчетаПоСверкеОпераций( Экспорт
```

Пример вызова
```bsl
Результат = СверкаВзаиморасчетовСБПc2b.СостояниеОтчетаПоСверкеОпераций();
```
</details>

## ИдентификаторТипаОперацииОплата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает идентификатор типа операции "Оплата".
//
// Возвращаемое значение:
//  Строка - код состояния.
//
Функция ИдентификаторТипаОперацииОплата() Экспорт
```

Пример вызова
```bsl
Результат = СверкаВзаиморасчетовСБПc2b.ИдентификаторТипаОперацииОплата() 
```
</details>

## ИдентификаторТипаОперацииВозврат
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает идентификатор типа операции "Возврат".
//
// Возвращаемое значение:
//  Строка - код состояния.
//
Функция ИдентификаторТипаОперацииВозврат() Экспорт
```

Пример вызова
```bsl
Результат = СверкаВзаиморасчетовСБПc2b.ИдентификаторТипаОперацииВозврат() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
