---
title: Сверка с ФНС по имущественным налогам
slug: erp-uh/сверка-с-фнс-по-имущественным-налогам
---


## ПослеЗаписиДокументаРеализацииПолномочийНалоговыхОрганов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Срабатывает после записи объекта ДокументРеализацииПолномочийНалоговыхОрганов, когда уже записаны его файлы.
//
// Параметры:
//  Сообщение - СправочникСсылка.ДокументыРеализацииПолномочийНалоговыхОрганов - Входящее сообщение от ФНС
//  Файлы - Массив из Структура - содержит:
// 		* Адрес - Строка - Адрес во временном хранилище.
// 		* ИмяФайла - Строка - Имя файла с расширением.
Процедура ПослеЗаписиДокументаРеализацииПолномочийНалоговыхОрганов(Сообщение, Файлы) Экспорт
```

Пример вызова
```bsl
СверкаСФНСПоИмущественнымНалогам.ПослеЗаписиДокументаРеализацииПолномочийНалоговыхОрганов(Сообщение, Файлы) 
```
</details>

## СведенияОРассчитанныхНалогахИзФайлов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Собирает подробности о содержимом файлов с расчетом налогов.
// Используется как первая итерация обработки содержимого файлов.
//
// Параметры:
//  Файлы - Массив из Структура - массив описаний вложений документа - содержит:
//        * Адрес - Строка - адрес файла во временном хранилище или
//        * Данные - ДвоичныеДанные - данные файла.
//        * ИмяФайла - Строка - Имя файла с расширением.
//  Отбор - Структура - отбор данных из файлов. Возможные свойства - содержит:
//           * Организация - СправочникСсылка.Организации
//           * Налог - ПеречислениеСсылка.ВидыИмущественныхНалогов
//           * НалоговыйПериод - Дата
//  ТекстОшибки - Строка - Описание возникших при выполнении процедуры ошибок.
//
// Возвращаемое значение:
//  Структура - содержит:
//         * РассчитанныеНалоги - ТаблицаЗначений - таблица расчетов налогов, которые содержатся в файлах
//         * ИмяПервогоФайла - Строка - имя файла без расширения, которое записано внутри первого файла массива
//
Функция СведенияОРассчитанныхНалогахИзФайлов(Файлы, Отбор = Неопределено, ТекстОшибки = "") Экспорт
```

Пример вызова
```bsl
Результат = СверкаСФНСПоИмущественнымНалогам.СведенияОРассчитанныхНалогахИзФайлов(Файлы, Отбор, ТекстОшибки);
```
</details>

## СтрокиРасчетаНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выбирает строки расчета нужного налога из дерева структуры xml-файла
//
// Параметры:
//  ДеревоЗагрузки - ДеревоЗначений - результат разбора файла расчета налога
//  Налог - ПеречислениеСсылка.ВидыИмущественныхНалогов - налог, который нужно выбрать из файла
//
// Возвращаемое значение:
//  Массив - Массив из СтрокаДереваЗначений - с расчетом налога.
//
Функция СтрокиРасчетаНалога(ДеревоЗагрузки, Налог) Экспорт
```

Пример вызова
```bsl
Результат = СверкаСФНСПоИмущественнымНалогам.СтрокиРасчетаНалога(ДеревоЗагрузки, Налог) 
```
</details>

## ЗначениеПараметраРасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает значение атрибута строки сведений об объекте налогообложения.
//
// Параметры:
//  СтрокаРасчета - СтрокаДереваЗначений - строка дерева узлов, полученного из xml-файла
//                  с расчетом налога.
//  ИмяПараметра - Строка - наименование атрибута узла со сведениями об объекте налогообложения.
//
// Возвращаемое значение:
//  Строка - строковое представление значения атрибута.
//
Функция ЗначениеПараметраРасчета(СтрокаРасчета, ИмяПараметра) Экспорт
```

Пример вызова
```bsl
Результат = СверкаСФНСПоИмущественнымНалогам.ЗначениеПараметраРасчета(СтрокаРасчета, ИмяПараметра) 
```
</details>

## ИдентификаторыОбъектовНалогообложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует таблицу для поиска основного средства на основании данных его регистрации
// в качестве объекта налогообложения.
//
// Параметры:
//  Организация - СправочникСсылка.Организации - владелец объекта налогообложения
//  Налог - ПеречислениеСсылка.ВидыИмущественныхНалогов - налог, которым облагаются основные средства
//  ПоискПоVIN - Булево - нужно искать ТС по VIN (имеет смысл только для транспортного налога)
//
// Возвращаемое значение:
//  ТаблицаЗначений:
//  * ОсновноеСредство - СправочникСсылка.ОбъектыЭксплуатации - объект налогообложения.
//  * Идентификатор - Строка - регистрационный номер ТС или кадастровый номер недвижимости (участка).
//  * КодВидаТС - Строка - код вида ТС (только для транспортного налога).
Функция ИдентификаторыОбъектовНалогообложения(Организация, Налог, ПоискПоVIN = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = СверкаСФНСПоИмущественнымНалогам.ИдентификаторыОбъектовНалогообложения(Организация, Налог, ПоискПоVIN);
```
</details>

## УстановитьОсновноеСредствоПоИдентификатору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет основное средство в строке сверки на основании данных регистрации в качестве объекта налогообложения
//
// Параметры:
//  СтрокаСверки - СтрокаТаблицыЗначений - строка ТЧ Сверка документа СверкаСФНСПоИмущественнымНалогам
//  ИдентификаторыОбъектов - ТаблицаЗначений - см. ИдентификаторыОбъектовНалогообложения()
//  ЗначенияКлюча - Структура - значения полей, по которым сопоставляются объекты налогообложения при сверке расчетов
//  Налог - ПеречислениеСсылка.ВидыИмущественныхНалогов - налог, которым облагаются основные средства
//  ПоискПоVIN - Булево - нужно искать ТС по VIN (имеет смысл только для транспортного налога)
//
Процедура УстановитьОсновноеСредствоПоИдентификатору(СтрокаСверки, ИдентификаторыОбъектов, ЗначенияКлюча, Налог, ПоискПоVIN = Ложь) Экспорт
```

Пример вызова
```bsl
СверкаСФНСПоИмущественнымНалогам.УстановитьОсновноеСредствоПоИдентификатору(СтрокаСверки, ИдентификаторыОбъектов, ЗначенияКлюча, Налог, ПоискПоVIN);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
