---
title: Сводная таблица УХ
slug: erp-uh/сводная-таблица-ух
---


## ПолучитьЗначениеПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

////////////////////////////////////////////////////////////////////////////////
// ПРОЦЕДУРЫ И ФУНКЦИИ ПОЛУЧЕНИЯ ПРОИЗВОЛЬНОГО СРЕЗА ДАНЫХ ПО ПОКАЗАТЕЛЯМ ОТЧЕТОВ.
//
// Функция ПолучитьЗначениеПоказателей(СтруктураПараметровОтбора,РаскрываемыеАналитики=Неопределено,ДополнительныеПараметры = Неопределено) Экспорт
//
// 		Получает срез значений показателей по заданным отборам в разрезе заданных аналитик.
// 		Числовые показатели агрегируются по срезу, Нечисловые  - выбираются последние по периодам значения.
// Параметры:
//   - СтруктураПараметровОтбора (Обязательный).
//	 Тип:Структура.
//   Ключ структуры - имя отбора, значение структуры -  ссылка или массив ссылок. Тип значения определяется по ключу.
//   Обязательные элементы структуры: ПоказательОтчета или ВидОтчета
//   Если задан ключ "ПоказательОтчета", то фильтр по показателям устанавливается из него, иначе из значения ключа "ВидОтчета"
//   Дргими возможными ключами структуры отбора являются:
//			- Организация
//			- Валюта
//			- Сценарий
//          - ПериодОтчета
//          - Проект
//          - Аналитика[1...6], если отбор накладывается по индексу аналитики или Коды ПВХ нужных аналитик, если отбор накладывается по типу аналитики;
//   Для отсутствующих ключей отбора возвращаются все значения по данной аналитике.
//
//	- РаскрываемыеАналитики(Необязательный).
//	 Тип:Структура.
//   Ключ - Код элемента ПВХ ВидыСубконтоКорпортаивные или Индекс Аналитики (Аналитика1-6): аналитики по которым необходима дополнительная детализация(раскрытие) данных.
//   Если необходимо раскрытие по допвалютам, то передается ключ "АналитикаВалюта". Значение структуры не задается.
//   По аналитикам Сценарий,ПериодОтчета,Организация,Валюта,Проект раскрытие происходит всегда.
//
//   - ДополнительныеПараметры (Необязательный).
//	 Тип:Структура.
//   Может принимать следующие значения ключей:
//     - АнализЧувствительности:Булево. Ложь - запрос выполняется к регистрам ЗначенияПоказателей.*; Истина - запрос выполняется к регистрам ЗначенияПоказателейМоделирование.*
//     - ТолькоСинтетика:Булево. 		Ложь - запрос выполняется к регистрам ЗначенияПоказателей.*; Истина - запрос выполняется только к регистру ЗначенияПоказателейСинтетика;
//     - РежимОчистки	:Булево. 		Ложь - Извлекаются текущие значения показателей; Истина - все значения числовых показателей подменяются на 0;
//     - ВОсновнойВалюте:Булево.		Ложь - Извлекаются записи во всех(указанных в отборе) валютах. Истина - Излвлекаются записи только в основной валюте версии.
//     - СдвигПоПериоду :Число.         Если задано значение отличное от 0, то в итоговой выборке периоды записей будут смещены на указанное значение.
//     - СтруктураЗаменяемыхАналитик: Структура
//           Ключ - код поля заменяемой аналитики; значение - новое значение, на которое будет подменено поле в выборке. Заменяемое поле должно содержаться в структуре РаскрываемыеАналитики
//     - ОбщийИтог: Перечисление.ВидыИтоговПоказателя.   Добавить строку с общим итогом по срезу по ресурсу "Значение".
//
// Возвращаемое значение:
//	 ТаблицаЗначний.    Основные колонки: Показатель, Сценарий,ПериодОтчета,Организация,Проект,Валюта,Значение,ЗначениеНеЧисло.
//   Дополнительные колонки: КодПВХ1,КодПВХ2,КодПВХ..N И/ИЛИ Аналитика1,2,3,4,..N - Колонки со значением дополнительных аналитик раскрытия.
//   Неопределено -  в случае возникновения ошибок передачи параметров функции
//
//   ПРИМЕР:
//
//    тВидОтчета 		= Справочники.ВидыОтчетов.НайтиПоКоду("Выручка");
//    тВалюта           = Справочники.Валюты.НайтиПоНаименованию("RUR");
//	  тПериодыОтчета    = Новый Массив;
//	  тПериодыОтчета.Добавить(Справочники.Периоды.НайтиПоНаименованию("Январь 2021 г."));
//    тСценарий      	= Справочники.Сценарии.НайтиПоНаименованию("Факт");
//
//    СтруктураПараметровОтбора 	= Новый Структура("ВидОтчета,Валюта,ПериодОтчета,Сценарий",тВидОтчета,тВалюта,тПериодыОтчета,тСценарий);
//    РаскрываемыеАналитики 		= Новый Структура("Аналитика1,Аналитика2");
//    ДополнительныеПараметры    	= Новый Структура("ОбщийИтог",Перечисления.ВидыИтоговПоказателя.Сумма);
//
//	  тЗначения  = СводнаяТаблицаУХ.ПолучитьЗначениеПоказателей(СтруктураПараметровОтбора,РаскрываемыеАналитики,ДополнительныеПараметры);
//
//
//
Функция ПолучитьЗначениеПоказателей(СтруктураПараметровОтбора,РаскрываемыеАналитики=Неопределено,ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьЗначениеПоказателей(СтруктураПараметровОтбора, РаскрываемыеАналитики, ДополнительныеПараметры);
```
</details>

## ПолучитьСводныеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьСводныеДанные(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьСводныеДанные(СтруктураПараметров) 
```
</details>

## ПолучитьРасшифровкуГруппировок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьРасшифровкуГруппировок(ПолеИлиГруппировка,СтруктураПолей) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьРасшифровкуГруппировок(ПолеИлиГруппировка, СтруктураПолей) 
```
</details>

## ПолучитьРасшифровкуГруппировокИерархия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьРасшифровкуГруппировокИерархия(ПолеИлиГруппировка,СтруктураПолей) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьРасшифровкуГруппировокИерархия(ПолеИлиГруппировка, СтруктураПолей) 
```
</details>

## ЗаполнитьДоступныеАналитики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьДоступныеАналитики(ДоступныеАналитики,ТаблицаДоступныеПоля,ВидОтчета,Бланк,КэшАналитикПоказателей) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьДоступныеАналитики(ДоступныеАналитики, ТаблицаДоступныеПоля, ВидОтчета, Бланк, КэшАналитикПоказателей) 
```
</details>

## СоздатьТекстЗапросаНастроекСоставаАналитик
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СоздатьТекстЗапросаНастроекСоставаАналитик(ДоступныеАналитики,Бланк) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.СоздатьТекстЗапросаНастроекСоставаАналитик(ДоступныеАналитики, Бланк) 
```
</details>

## СоздатьКонтекстноеМенюСводнойТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьКонтекстноеМенюСводнойТаблицы(ЭтаФорма,Родитель,Режим=1) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СоздатьКонтекстноеМенюСводнойТаблицы(ЭтаФорма, Родитель, Режим);
```
</details>

## СоздатьКомандыСводнойТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьКомандыСводнойТаблицы(ЭтаФорма) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СоздатьКомандыСводнойТаблицы(ЭтаФорма) 
```
</details>

## УстановитьРежимМенюСводнойТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьРежимМенюСводнойТаблицы(Родитель,Режим) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.УстановитьРежимМенюСводнойТаблицы(Родитель, Режим) 
```
</details>

## ПрименитьИзмененияЭкземпляр
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПрименитьИзмененияЭкземпляр(Параметры, АдресХранилища, АдресХранилищаДополнительный) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПрименитьИзмененияЭкземпляр(Параметры, АдресХранилища, АдресХранилищаДополнительный));
```
</details>

## ЗаполнитьВалютыПоРегламенту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьВалютыПоРегламенту(РасчетПоказателейОбъект,ТаблицаИзмененныхПоказателей) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьВалютыПоРегламенту(РасчетПоказателейОбъект, ТаблицаИзмененныхПоказателей) 
```
</details>

## ПеренестиИзмерение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПеренестиИзмерение(ТаблицаИсточник,ТаблицаПриемник,Измерение) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПеренестиИзмерение(ТаблицаИсточник, ТаблицаПриемник, Измерение) 
```
</details>

## СвернутьТаблицуЗначений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СвернутьТаблицуЗначений(ИсходнаяТаблица,КолонкиГруппировок,КолонкиСуммирования) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.СвернутьТаблицуЗначений(ИсходнаяТаблица, КолонкиГруппировок, КолонкиСуммирования) 
```
</details>

## ПолучитьИзмененныеПоказатели
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьИзмененныеПоказатели(ИдентификаторСеанса,ТипЗначенияПоказателей = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьИзмененныеПоказатели(ИдентификаторСеанса, ТипЗначенияПоказателей);
```
</details>

## ПолучитьПоказателиПоСтрокамИколонкам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьПоказателиПоСтрокамИколонкам(Строки,Колонки) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьПоказателиПоСтрокамИколонкам(Строки, Колонки) 
```
</details>

## ПолучитьТаблицуДляОчистики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТаблицуДляОчистики(Параметры) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьТаблицуДляОчистики(Параметры) 
```
</details>

## ПолучитьТаблицуДляЗаписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТаблицуДляЗаписи(Параметры) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьТаблицуДляЗаписи(Параметры) 
```
</details>

## ВыполнитьКопированиеВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВыполнитьКопированиеВФоне(АдресХранилищаСтатусаКопирования,СтруктураТаблиц,КопированиеВыполнено = Ложь) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ВыполнитьКопированиеВФоне(АдресХранилищаСтатусаКопирования, СтруктураТаблиц, КопированиеВыполнено);
```
</details>

## ЗаписатьДанныеПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаписатьДанныеПоказателей(ТЗданные,АдресХранилищаСтатусаКопирования,НачальныйИндексПрогресса,Результат = Истина) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаписатьДанныеПоказателей(ТЗданные, АдресХранилищаСтатусаКопирования, НачальныйИндексПрогресса, Результат);
```
</details>

## СкопироватьЭкземплярыИсточникиПоУОП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СкопироватьЭкземплярыИсточникиПоУОП(УопИсточник,УопПриемник,ОтборыРасширеннойНастройки) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.СкопироватьЭкземплярыИсточникиПоУОП(УопИсточник, УопПриемник, ОтборыРасширеннойНастройки));
```
</details>

## ВыполнитьАктуализациюПоказателейВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВыполнитьАктуализациюПоказателейВФоне(АдресХранилищаСтатусаКопирования,СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ВыполнитьАктуализациюПоказателейВФоне(АдресХранилищаСтатусаКопирования, СтруктураПараметров) 
```
</details>

## ВыполнитьЗаполнениеФактаВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВыполнитьЗаполнениеФактаВФоне(АдресХранилищаСтатусаКопирования,СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ВыполнитьЗаполнениеФактаВФоне(АдресХранилищаСтатусаКопирования, СтруктураПараметров) 
```
</details>

## ЗаполнитьПоРегламенту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьПоРегламенту(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьПоРегламенту(СтруктураПараметров));
```
</details>

## УстановитьСтатусОбласти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьСтатусОбласти(Знач ТекущийДокумент,СостояниеОбъекта=Неопределено,ИндексБлокировки=Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.УстановитьСтатусОбласти(ТекущийДокумент, СостояниеОбъекта, ИндексБлокировки);
```
</details>

## ПолучитьНаборЗаписейОбласти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьНаборЗаписейОбласти(Область,Сценарий,Организация,Проект,Период,ПериодРодитель,СостояниеОбъекта,СостояниеБлокировки) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьНаборЗаписейОбласти(Область, Сценарий, Организация, Проект, Период, ПериодРодитель, СостояниеОбъекта, СостояниеБлокировки));
```
</details>

## ПолучитьБланкОбластиТекущегоПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьБланкОбластиТекущегоПользователя(Область) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьБланкОбластиТекущегоПользователя(Область) 
```
</details>

## ИзменитьСвойствоОбласти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ИзменитьСвойствоОбласти(ТекущийДокументСогласования,Статус=Неопределено,Блокировка=Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ИзменитьСвойствоОбласти(ТекущийДокументСогласования, Статус, Блокировка);
```
</details>

## УстановитьСтатусЭкземпляра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьСтатусЭкземпляра(Знач ТекущийДокумент,СостояниеОбъекта=Неопределено,ИндексБлокировки=Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.УстановитьСтатусЭкземпляра(ТекущийДокумент, СостояниеОбъекта, ИндексБлокировки);
```
</details>

## ПолучитьНаборЗаписейОбластиЭкзепляра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьНаборЗаписейОбластиЭкзепляра(ВидОтчета,Сценарий,Организация,Проект,Период,СостояниеОбъекта,СостояниеБлокировки) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьНаборЗаписейОбластиЭкзепляра(ВидОтчета, Сценарий, Организация, Проект, Период, СостояниеОбъекта, СостояниеБлокировки));
```
</details>

## ЗаполнитьСтрокиПоРакурсу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаполнитьСтрокиПоРакурсу(Ракурс,Бланк) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ЗаполнитьСтрокиПоРакурсу(Ракурс, Бланк) 
```
</details>

## СоздатьРакурсПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьРакурсПоУмолчанию(тСсылка) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СоздатьРакурсПоУмолчанию(тСсылка) 
```
</details>

## СохранитьДанныеОбластиВPDF
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СохранитьДанныеОбластиВPDF(ДокументСогласованияОбласти) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.СохранитьДанныеОбластиВPDF(ДокументСогласованияОбласти) 
```
</details>

## ВыполнитьАктуализациюУОПВФоне
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВыполнитьАктуализациюУОПВФоне(АдресХранилищаСтатусаКопирования,СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ВыполнитьАктуализациюУОПВФоне(АдресХранилищаСтатусаКопирования, СтруктураПараметров) 
```
</details>

## СформироватьПробнуюОтчетность_Сервер
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СформироватьПробнуюОтчетность_Сервер(ТекущийДокументУправленияПериодом,СостоянияВыполненияПроцесса,мПоследователиСтрок,ЭтапПроцесса, Организация = Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СформироватьПробнуюОтчетность_Сервер(ТекущийДокументУправленияПериодом, СостоянияВыполненияПроцесса, мПоследователиСтрок, ЭтапПроцесса, Организация);
```
</details>

## ЗаблокироватьПериоды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаблокироватьПериоды(ТекущийДокументУправленияПериодом,МассивФактическихПериодов,ОрганизацииДляАктуализации,Сценарий) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаблокироватьПериоды(ТекущийДокументУправленияПериодом, МассивФактическихПериодов, ОрганизацииДляАктуализации, Сценарий));
```
</details>

## ФорматироватьЗаголовкиИерархии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФорматироватьЗаголовкиИерархии(ИерархияГруппировокСтрок,ИерархияГруппировокКолонок,ПолеТабличногоДокументаМакет,ДокументРезультат,ВыбранныеРесурсы,ДополнительныеПараметры=Неопределено,ТЗДанные=Неопределено,ПредставлениеОтборов="") Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ФорматироватьЗаголовкиИерархии(ИерархияГруппировокСтрок, ИерархияГруппировокКолонок, ПолеТабличногоДокументаМакет, ДокументРезультат, ВыбранныеРесурсы, ДополнительныеПараметры, ТЗДанные, ПредставлениеОтборов);
```
</details>

## ФорматироватьЗаголовкиБезИерархии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФорматироватьЗаголовкиБезИерархии(ИерархияГруппировокСтрок,ИерархияГруппировокКолонок,ПолеТабличногоДокументаМакет,ДокументРезультат,ВыбранныеРесурсы,ДополнительныеПараметры=Неопределено,ТЗДанные=Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ФорматироватьЗаголовкиБезИерархии(ИерархияГруппировокСтрок, ИерархияГруппировокКолонок, ПолеТабличногоДокументаМакет, ДокументРезультат, ВыбранныеРесурсы, ДополнительныеПараметры, ТЗДанные);
```
</details>

## ФорматироватьЗаголовкиИерархииМП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФорматироватьЗаголовкиИерархииМП(ТаблицаКолонки,ТаблицаСтроки,ПолеТабличногоДокументаМакет,ДокументРезультат,ДополнитьОтклонениями,ИерархияСтрок,ИерархияКолонок) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ФорматироватьЗаголовкиИерархииМП(ТаблицаКолонки, ТаблицаСтроки, ПолеТабличногоДокументаМакет, ДокументРезультат, ДополнитьОтклонениями, ИерархияСтрок, ИерархияКолонок) 
```
</details>

## ФорматироватьЗаголовкиУправлениеПериодом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФорматироватьЗаголовкиУправлениеПериодом(ИерархияГруппировокСтрок,ИерархияГруппировокКолонок,ПолеТабличногоДокументаМакет,ДокументРезультат,ВыбранныеРесурсы,ДополнительныеПараметры=Неопределено,ТЗДанные=Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ФорматироватьЗаголовкиУправлениеПериодом(ИерархияГруппировокСтрок, ИерархияГруппировокКолонок, ПолеТабличногоДокументаМакет, ДокументРезультат, ВыбранныеРесурсы, ДополнительныеПараметры, ТЗДанные);
```
</details>

## ПолучитьТекущийПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТекущийПериод() Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьТекущийПериод() 
```
</details>

## СоздатьМакетБланкаКИК
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Функция СоздатьМакетБланкаКИК(КлючевыеПараметры)
//Параметры: КлючевыеПараметры - cтруктура, содержащая следующие свойства:
//   ВидОтчета - вид отчета, содержащий данные (обязательный)
//   НаименованиеБланка- Наименование создаваемого бланка (обязательный)
//   Периодичность - Периодичность бланка (Тип - ПеречислениеСсылка.Периодичность, Обязательный)
//   ГруппаСтрок  - Тип СправочникСсылка.СтрокиОтчетов.  Родительская строка, ограничивающая набор данных (необязательный - если не задано, то берутся все показатели вида отчета)
//   Периметр - тип СправочникСсылка.Организации. Организация группа в справочнике, содержащая периметр для КИКов.
//   (необязательный - если не задан, то используются все орг. единицы).


Функция СоздатьМакетБланкаКИК(КлючевыеПараметры) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.СоздатьМакетБланкаКИК(КлючевыеПараметры) 
```
</details>

## СоздатьБланкДляКИК
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьБланкДляКИК(СозданныйБланк,ГруппаСтрок,Периметр) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СоздатьБланкДляКИК(СозданныйБланк, ГруппаСтрок, Периметр) 
```
</details>

## РазобратьДанныеБуфера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РазобратьДанныеБуфера(ДанныеБуфера,МассивСтрок,МассивЗначений) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.РазобратьДанныеБуфера(ДанныеБуфера, МассивСтрок, МассивЗначений) 
```
</details>

## СформироватьПредставлениеОтборов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьПредставлениеОтборов(Бланк,Горизонт,ТаблицаСтраницы,СтруктураФильтров) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.СформироватьПредставлениеОтборов(Бланк, Горизонт, ТаблицаСтраницы, СтруктураФильтров) 
```
</details>

## ВернутьРисунокПустойТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ВернутьРисунокПустойТаблицы(ПолеТабличногоДокументаМакет, Заголовок) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ВернутьРисунокПустойТаблицы(ПолеТабличногоДокументаМакет, Заголовок) 
```
</details>

## ЗаполнитьНстройкиДополнительныхОтборов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьНстройкиДополнительныхОтборов(ОкончательнаяСКДАдрес,НастройкиСхемыСводнойТаблицы,СТ_ДополнительныеНастройки,СтруктураТаблицИнтерфейса,СтрокаПредставленияДополнительныхОтборов="") Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьНстройкиДополнительныхОтборов(ОкончательнаяСКДАдрес, НастройкиСхемыСводнойТаблицы, СТ_ДополнительныеНастройки, СтруктураТаблицИнтерфейса, СтрокаПредставленияДополнительныхОтборов);
```
</details>

## ОтборСуществует
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОтборСуществует(НастройкиОтбор,ИмяПоляОтбора) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ОтборСуществует(НастройкиОтбор, ИмяПоляОтбора));
```
</details>

## УпорядочитьПериоды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция УпорядочитьПериоды(СписокПериодов) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.УпорядочитьПериоды(СписокПериодов) 
```
</details>

## ПолучитьПериодПоДате
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьПериодПоДате(ДатаНачала,Периодичность) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьПериодПоДате(ДатаНачала, Периодичность));
```
</details>

## СоздатьНастройкиНовогоБланка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьНастройкиНовогоБланка(Бланк,ЗаполнитьСтроки = Ложь,ЗаполнитьПоказатели= Ложь,ГруппаСтрок = Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СоздатьНастройкиНовогоБланка(Бланк, ЗаполнитьСтроки, ЗаполнитьПоказатели, ГруппаСтрок);
```
</details>

## СкопироватьНастройкиБланка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СкопироватьНастройкиБланка(БланкИсточник,Бланк,СписокПараметровКопирования) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СкопироватьНастройкиБланка(БланкИсточник, Бланк, СписокПараметровКопирования) 
```
</details>

## СоздатьБланкПоВыделеннымСтрокамКолонкам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьБланкПоВыделеннымСтрокамКолонкам(ВыделенныеСтроки,ВыделенныеКолонки,Бланк) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СоздатьБланкПоВыделеннымСтрокамКолонкам(ВыделенныеСтроки, ВыделенныеКолонки, Бланк) 
```
</details>

## ЗаполнитьСоставПоказателейПоМассивуКолонок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСоставПоказателейПоМассивуКолонок(Бланк,ВыделенныеКолонки) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьСоставПоказателейПоМассивуКолонок(Бланк, ВыделенныеКолонки));
```
</details>

## ЗаполнитьСоставСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСоставСтрок(Бланк,Копирование=Ложь,БланкИсточник=Неопределено,ГруппаСтрок=Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьСоставСтрок(Бланк, Копирование, БланкИсточник, ГруппаСтрок);
```
</details>

## ЗаполнитьСоставСтрокПоМассивуСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСоставСтрокПоМассивуСтрок(Бланк,ВыделенныеСтроки) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьСоставСтрокПоМассивуСтрок(Бланк, ВыделенныеСтроки));
```
</details>

## ОбойтиДеревоСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбойтиДеревоСтрок(Бланк,Строки,НПП,Родитель) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОбойтиДеревоСтрок(Бланк, Строки, НПП, Родитель));
```
</details>

## ЗаполнитьСоставПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСоставПоказателей(Бланк,Копирование=Ложь,БланкИсточник=Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьСоставПоказателей(Бланк, Копирование, БланкИсточник);
```
</details>

## ЗаполнитьСтруктуруОсей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСтруктуруОсей(Бланк,Копирование=Ложь,БланкИсточник=Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьСтруктуруОсей(Бланк, Копирование, БланкИсточник);
```
</details>

## ЗаполнитьНастройкуПериодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьНастройкуПериодов(Бланк,Копирование=Ложь,БланкИсточник=Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьНастройкуПериодов(Бланк, Копирование, БланкИсточник);
```
</details>

## ЗаполнитьНастройкуАналитик
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьНастройкуАналитик(Бланк,Копирование=Ложь,БланкИсточник=Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьНастройкуАналитик(Бланк, Копирование, БланкИсточник);
```
</details>

## ЗаполнитьСоставАналитикОсей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСоставАналитикОсей(Бланк,Копирование=Ложь,БланкИсточник=Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьСоставАналитикОсей(Бланк, Копирование, БланкИсточник);
```
</details>

## СоздатьОписаниеРасчетногоПоля
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


//Дополнительные поля и отклонения

Процедура СоздатьОписаниеРасчетногоПоля(СтруктураТаблицИнтерфейса,ДопПоле,ВыбранныеРесурсы,СхемаСКД,СхемаСКДЭталон,ОтображатьСуммыВДопВалютах) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СоздатьОписаниеРасчетногоПоля(СтруктураТаблицИнтерфейса, ДопПоле, ВыбранныеРесурсы, СхемаСКД, СхемаСКДЭталон, ОтображатьСуммыВДопВалютах));
```
</details>

## СоздатьОписаниеБазовогоПоля
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьОписаниеБазовогоПоля(СтруктураТаблицИнтерфейса,СтрРесурс,ВыбранныеРесурсы_Структура,СхемаСКД,СхемаСКДЭталон) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СоздатьОписаниеБазовогоПоля(СтруктураТаблицИнтерфейса, СтрРесурс, ВыбранныеРесурсы_Структура, СхемаСКД, СхемаСКДЭталон));
```
</details>

## СоздатьОписаниеПолейРесурсов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьОписаниеПолейРесурсов(СтруктураТаблицИнтерфейса,ВыбранныеРесурсы_Структура,СхемаСКД,СхемаСКДЭталон,ОтображатьСуммыВДопВалютах) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СоздатьОписаниеПолейРесурсов(СтруктураТаблицИнтерфейса, ВыбранныеРесурсы_Структура, СхемаСКД, СхемаСКДЭталон, ОтображатьСуммыВДопВалютах) 
```
</details>

## ПолучитьТаблицуВыбранныхПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьТаблицуВыбранныхПоказателей(Бланк,АдресТаблицИнтерфейса,ТаблицыИнтерфейса=Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьТаблицуВыбранныхПоказателей(Бланк, АдресТаблицИнтерфейса, ТаблицыИнтерфейса);
```
</details>

## УстановитьУОДляЯчеекСКомментариями
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьУОДляЯчеекСКомментариями(ВыбранныеРесурсы,НастройкиСКД) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.УстановитьУОДляЯчеекСКомментариями(ВыбранныеРесурсы, НастройкиСКД) 
```
</details>

## СформироватьВыражениеИтога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СформироватьВыражениеИтога(СтруктураТаблицИнтерфейса,СхемаСКДЭталон,СтрРесурс,КодПоказателя=Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СформироватьВыражениеИтога(СтруктураТаблицИнтерфейса, СхемаСКДЭталон, СтрРесурс, КодПоказателя);
```
</details>

## СформироватьВыражениеИтогаОтносительноеОтклонение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СформироватьВыражениеИтогаОтносительноеОтклонение(СтруктураТаблицИнтерфейса,СхемаСКДЭталон,СтрРесурс,КодПоказателя=Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СформироватьВыражениеИтогаОтносительноеОтклонение(СтруктураТаблицИнтерфейса, СхемаСКДЭталон, СтрРесурс, КодПоказателя);
```
</details>

## РассчитатьДДСПоУсловиямОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РассчитатьДДСПоУсловиямОплаты(тОбъект) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.РассчитатьДДСПоУсловиямОплаты(тОбъект) 
```
</details>

## ЗаполнитьДоступныеПоля
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьДоступныеПоля(ТаблицаДоступныеПоля,ВидОтчета,Бланк,КэшАналитикПоказателей,ДоступныеАналитики,ИспользуемыеПоказатели,КэшАналитикПоказателейСТ=Неопределено,флОшибки="") Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьДоступныеПоля(ТаблицаДоступныеПоля, ВидОтчета, Бланк, КэшАналитикПоказателей, ДоступныеАналитики, ИспользуемыеПоказатели, КэшАналитикПоказателейСТ, флОшибки);
```
</details>

## ЗаполнитьНастройкиАналитик
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьНастройкиАналитик(Бланк,ТаблицаДоступныеПоля) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьНастройкиАналитик(Бланк, ТаблицаДоступныеПоля) 
```
</details>

## ЗаполнитьДоступныеПоляУправленияДоступностью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьДоступныеПоляУправленияДоступностью(ТаблицаДоступныеПоля,ДоступныеАналитики) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьДоступныеПоляУправленияДоступностью(ТаблицаДоступныеПоля, ДоступныеАналитики) 
```
</details>

## ЗаполнитьДоступныеПоляМатрицаПолномочий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьДоступныеПоляМатрицаПолномочий(ТаблицаДоступныеПоля) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьДоступныеПоляМатрицаПолномочий(ТаблицаДоступныеПоля) 
```
</details>

## ОбновитьКэшАналитикПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьКэшАналитикПоказателей(КэшАналитикПоказателей,Бланк,ВидОтчета,СписокАналитик,КэшАналитикПоказателейСТ=Неопределено,флОшибки = "") Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОбновитьКэшАналитикПоказателей(КэшАналитикПоказателей, Бланк, ВидОтчета, СписокАналитик, КэшАналитикПоказателейСТ, флОшибки);
```
</details>

## ОбновитьИспользуемыеПоказатели
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьИспользуемыеПоказатели(ИспользуемыеПоказатели,Бланк,ВидОтчета) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОбновитьИспользуемыеПоказатели(ИспользуемыеПоказатели, Бланк, ВидОтчета) 
```
</details>

## ПолучитьСоставСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьСоставСтрок(Бланк,ТаблицаСтроки,ТаблицаКолонки,ТаблицаСтраницы,ТаблицаКолонкиИСтроки,ДоступныеАналитики,КэшАналитикПоказателей) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьСоставСтрок(Бланк, ТаблицаСтроки, ТаблицаКолонки, ТаблицаСтраницы, ТаблицаКолонкиИСтроки, ДоступныеАналитики, КэшАналитикПоказателей) 
```
</details>

## ПолучитьНастройкиШкалыПериодовПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьНастройкиШкалыПериодовПоУмолчанию(Бланк) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьНастройкиШкалыПериодовПоУмолчанию(Бланк) 
```
</details>

## ПолучитьШкалуПериодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьШкалуПериодов(Бланк,ОтображатьТолькоИтогиПоПериодам,ДатаНачала,ДатаОкончания,Периодичность=Неопределено,НастройкиШкалыПериодов) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьШкалуПериодов(Бланк, ОтображатьТолькоИтогиПоПериодам, ДатаНачала, ДатаОкончания, Периодичность, НастройкиШкалыПериодов) 
```
</details>

## ОтобратьДанныеПоСтруктуреФильтров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОтобратьДанныеПоСтруктуреФильтров(ТзСтрок,СтруктураФильтровИтог) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ОтобратьДанныеПоСтруктуреФильтров(ТзСтрок, СтруктураФильтровИтог) Экспорт;);
```
</details>

## ЗаполнитьСтрокиПоОтбору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаполнитьСтрокиПоОтбору(Бланк,ТаблицаКолонкиИСтроки,КэшАналитикПоказателей,ДоступныеАналитики) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ЗаполнитьСтрокиПоОтбору(Бланк, ТаблицаКолонкиИСтроки, КэшАналитикПоказателей, ДоступныеАналитики));
```
</details>

## ПолучитьТекстЗапросаПоИндивидуальнымОтборам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТекстЗапросаПоИндивидуальнымОтборам(Запрос,РезультатИндОтборы,СтрПоказательОтбор,ТаблицаКолонкиИСтроки,ДоступныеАналитики,ЗначенияОтборов,КэшАналитикПоказателей,ИдПоказателей) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьТекстЗапросаПоИндивидуальнымОтборам(Запрос, РезультатИндОтборы, СтрПоказательОтбор, ТаблицаКолонкиИСтроки, ДоступныеАналитики, ЗначенияОтборов, КэшАналитикПоказателей, ИдПоказателей));
```
</details>

## ДобавитьСтрокуСоединенияСАналитикой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДобавитьСтрокуСоединенияСАналитикой(Запрос,Аналитика,СтрокаОтбора,ЗначениеОтбораСтрока,СписокПредставленийАналитик,ИдПоказателей) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ДобавитьСтрокуСоединенияСАналитикой(Запрос, Аналитика, СтрокаОтбора, ЗначениеОтбораСтрока, СписокПредставленийАналитик, ИдПоказателей));
```
</details>

## СформироватьТекстЗапросаПоАналитике
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьТекстЗапросаПоАналитике(Запрос,Аналитика,ЗначениеОтбораСтрока,ИдПоказателей) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.СформироватьТекстЗапросаПоАналитике(Запрос, Аналитика, ЗначениеОтбораСтрока, ИдПоказателей) 
```
</details>

## СформироватьТекстЗапросаПоУсловию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьТекстЗапросаПоУсловию(Запрос,Аналитика,ЗначениеОтбораСтрока) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.СформироватьТекстЗапросаПоУсловию(Запрос, Аналитика, ЗначениеОтбораСтрока) 
```
</details>

## СформироватьТекстЗапросаПоФункцНаправлениям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СформироватьТекстЗапросаПоФункцНаправлениям(Запрос,Аналитика,ЗначениеОтбораСтрока) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.СформироватьТекстЗапросаПоФункцНаправлениям(Запрос, Аналитика, ЗначениеОтбораСтрока) 
```
</details>

## ПолучитьОператорОтбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьОператорОтбора(ОператорСКД) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьОператорОтбора(ОператорСКД));
```
</details>

## СформироватьТекстТипизирующейСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СформироватьТекстТипизирующейСтроки(Запрос,ТаблицаКолонкиИСтроки,ДоступныеАналитики) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СформироватьТекстТипизирующейСтроки(Запрос, ТаблицаКолонкиИСтроки, ДоступныеАналитики));
```
</details>

## СоздатьНастройкуПоказателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьНастройкуПоказателя(Бланк,Показатель) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СоздатьНастройкуПоказателя(Бланк, Показатель) 
```
</details>

## ПолучитьТаблицуСтрокИКолонок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Функции формирования пустого макета добавляемой строки.
Процедура ПолучитьТаблицуСтрокИКолонок(ТаблицаСтроки,ТаблицаКолонки,ТаблицаСтраницы,ТаблицаКолонкиИСтроки) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьТаблицуСтрокИКолонок(ТаблицаСтроки, ТаблицаКолонки, ТаблицаСтраницы, ТаблицаКолонкиИСтроки));
```
</details>

## ПолучитьСоставСтрокиАналитики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьСоставСтрокиАналитики(Бланк,АналитикиТекущейОбласти,СтруктураТаблицИнтерфейса,СтруктураФильтров,ПолучатьСоставГруппы) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьСоставСтрокиАналитики(Бланк, АналитикиТекущейОбласти, СтруктураТаблицИнтерфейса, СтруктураФильтров, ПолучатьСоставГруппы) 
```
</details>

## ПолучитьТекстЗапросаПоИндивидуальнымОтборамСтрока
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТекстЗапросаПоИндивидуальнымОтборамСтрока(Запрос,РезультатИндОтборы,СтрПоказательОтбор,ТаблицаКолонкиИСтроки,ДоступныеАналитики,ЗначенияОтборов,КэшАналитикПоказателей,ИдПоказателей,ВключатьРедактируемые = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьТекстЗапросаПоИндивидуальнымОтборамСтрока(Запрос, РезультатИндОтборы, СтрПоказательОтбор, ТаблицаКолонкиИСтроки, ДоступныеАналитики, ЗначенияОтборов, КэшАналитикПоказателей, ИдПоказателей, ВключатьРедактируемые);
```
</details>

## ДобавитьВыражениеСоединенияСАналитикойСтрока
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДобавитьВыражениеСоединенияСАналитикойСтрока(Запрос,Аналитика,СтрокаОтбора,ЗначениеОтбораСтрока,СписокПредставленийАналитик,ИдПоказателей,ВключатьРедактируемые) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ДобавитьВыражениеСоединенияСАналитикойСтрока(Запрос, Аналитика, СтрокаОтбора, ЗначениеОтбораСтрока, СписокПредставленийАналитик, ИдПоказателей, ВключатьРедактируемые));
```
</details>

## ПолучитьШаблонСводнойТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьШаблонСводнойТаблицы(СтруктураФильтровИтог,СтруктураТаблицИнтерфейса,ВыбранныеРесурсы,Периодичность,ТЗСтрок,ТЗКолонок,КоличествоЯчеек) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьШаблонСводнойТаблицы(СтруктураФильтровИтог, СтруктураТаблицИнтерфейса, ВыбранныеРесурсы, Периодичность, ТЗСтрок, ТЗКолонок, КоличествоЯчеек) 
```
</details>

## ДобавитьПоляРесурсов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьПоляРесурсов(СхемаСКДЭталон,НастройкиСхемыСводнойТаблицы,ТекстОтклонения,ВариантОтображенияРесурсов) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ДобавитьПоляРесурсов(СхемаСКДЭталон, НастройкиСхемыСводнойТаблицы, ТекстОтклонения, ВариантОтображенияРесурсов) 
```
</details>

## ЗаполнитьРесурсы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьРесурсы(Источник,ТаблицаВыбранныеРесурсы) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьРесурсы(Источник, ТаблицаВыбранныеРесурсы) 
```
</details>

## ЗаполнитьВыбранныеПоказатели
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьВыбранныеПоказатели(ВыбранныеСтроки,ВыбранныеКолонки,ВыбранныеПоказатели) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьВыбранныеПоказатели(ВыбранныеСтроки, ВыбранныеКолонки, ВыбранныеПоказатели) 
```
</details>

## ЗаполнитьПоляСхемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьПоляСхемы(СхемаСКДЭталон,ТаблицаДоступныеПоля) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьПоляСхемы(СхемаСКДЭталон, ТаблицаДоступныеПоля) 
```
</details>

## ЗаполнитьПоляСхемыПоСтруктуре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьПоляСхемыПоСтруктуре(СхемаСКДЭталон,СтруктураТаблицИнтерфейса) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьПоляСхемыПоСтруктуре(СхемаСКДЭталон, СтруктураТаблицИнтерфейса) 
```
</details>

## ПолучитьОписаниеТаблицИнтерфейса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьОписаниеТаблицИнтерфейса() Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьОписаниеТаблицИнтерфейса() 
```
</details>

## ЗаполнитьЗначенияОсей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьЗначенияОсей(Бланк,ТаблицаДоступныеПоля,ТаблицаСтраницы,ТаблицаКолонки,ТаблицаСтроки,ЕстьСохраненныеЭлементы=Ложь) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьЗначенияОсей(Бланк, ТаблицаДоступныеПоля, ТаблицаСтраницы, ТаблицаКолонки, ТаблицаСтроки, ЕстьСохраненныеЭлементы);
```
</details>

## ЗаполнитьДоступныеАналитикиДляОбработкиПереноса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьДоступныеАналитикиДляОбработкиПереноса(МассивПоказателей,ТаблицаДоступныхАналитик,СтруктураФильтров = Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьДоступныеАналитикиДляОбработкиПереноса(МассивПоказателей, ТаблицаДоступныхАналитик, СтруктураФильтров);
```
</details>

## СоздатьОписаниеОтбораСКД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция СоздатьОписаниеОтбораСКД(КодПоля,ТипПоля,ЗначениеОтбора) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.СоздатьОписаниеОтбораСКД(КодПоля, ТипПоля, ЗначениеОтбора));
```
</details>

## ПолучитьИспользуемыеВидыОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьИспользуемыеВидыОтчетов(Бланк) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьИспользуемыеВидыОтчетов(Бланк) 
```
</details>

## ПреобразоватьНастройкиКонечнойСхемы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПреобразоватьНастройкиКонечнойСхемы(ТипОбъекта,ВыбранныеРесурсы,Настройки,ТаблицаСтроки,ТаблицаКолонки,ИерархияСтрок,ИерархияКолонок,НастройкиРасчетаОтклоненийВыбранные=Неопределено,ОтображатьСуммыВДопВалютах=Неопределено, Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПреобразоватьНастройкиКонечнойСхемы(ТипОбъекта, ВыбранныеРесурсы, Настройки, ТаблицаСтроки, ТаблицаКолонки, ИерархияСтрок, ИерархияКолонок, НастройкиРасчетаОтклоненийВыбранные, ОтображатьСуммыВДопВалютах, );
```
</details>

## ПолучитьФинальныеНастройкиТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьФинальныеНастройкиТаблицы(ВыбранныеРесурсы,Настройки,ТаблицаСтроки,ТаблицаКолонки,ИерархияСтрок,ИерархияКолонок,НастройкиРасчетаОтклоненийВыбранные,ОтображатьСуммыВДопВалютах,ОтображатьТолькоИтогиПоПериодам,Периодичность,СкрыватьПустые,ПоляБазы); Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьФинальныеНастройкиТаблицы(ВыбранныеРесурсы, Настройки, ТаблицаСтроки, ТаблицаКолонки, ИерархияСтрок, ИерархияКолонок, НастройкиРасчетаОтклоненийВыбранные, ОтображатьСуммыВДопВалютах, ОтображатьТолькоИтогиПоПериодам, Периодичность, СкрыватьПустые, ПоляБазы););
```
</details>

## ПолучитьФинальныеНастройкиДиаграммы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьФинальныеНастройкиДиаграммы(Настройки,ТаблицаСтроки,ТаблицаКолонки,ИерархияСтрок,ИерархияКолонок,НастройкиРасчетаОтклоненийВыбранные) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьФинальныеНастройкиДиаграммы(Настройки, ТаблицаСтроки, ТаблицаКолонки, ИерархияСтрок, ИерархияКолонок, НастройкиРасчетаОтклоненийВыбранные));
```
</details>

## СоздатьСтруктуруСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьСтруктуруСтрок(Ресурсы,Настройки,ТаблицаСтроки,ИерархияСтрок,НастройкиРасчетаОтклоненийВыбранные,ОтображатьСуммыВДопВалютах,ОтображатьТолькоИтогиПоПериодам = Ложь,Периодичность = Неопределено,СкрыватьПустые = Истина) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СоздатьСтруктуруСтрок(Ресурсы, Настройки, ТаблицаСтроки, ИерархияСтрок, НастройкиРасчетаОтклоненийВыбранные, ОтображатьСуммыВДопВалютах, ОтображатьТолькоИтогиПоПериодам, Периодичность, СкрыватьПустые);
```
</details>

## СоздатьСтруктуруКолонок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьСтруктуруКолонок(Ресурсы,Настройки,ТаблицаКолонки,ИерархияСтрок,НастройкиРасчетаОтклоненийВыбранные,ОтображатьСуммыВДопВалютах,ОтображатьТолькоИтогиПоПериодам = Ложь,Периодичность = Неопределено, ПоляБазы = Неопределено); Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СоздатьСтруктуруКолонок(Ресурсы, Настройки, ТаблицаКолонки, ИерархияСтрок, НастройкиРасчетаОтклоненийВыбранные, ОтображатьСуммыВДопВалютах, ОтображатьТолькоИтогиПоПериодам, Периодичность, ПоляБазы);
```
</details>

## ПолучитьИсключаемыеПериоды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьИсключаемыеПериоды(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьИсключаемыеПериоды(СтруктураПараметров) 
```
</details>

## ПолучитьДатуНачалаГруппировки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьДатуНачалаГруппировки(Периодичность,ГраницаОткрытогоПериода,НачалоГруппировки) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьДатуНачалаГруппировки(Периодичность, ГраницаОткрытогоПериода, НачалоГруппировки));
```
</details>

## ПолучитьЗапросДанныхСТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьЗапросДанныхСТ(СтруктураПараметров,ТестовыйМакет = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьЗапросДанныхСТ(СтруктураПараметров, ТестовыйМакет);
```
</details>

## ПолучитьПредварительныйЗапрос
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьПредварительныйЗапрос(СтруктураПараметров,КэшПоказателей,КэшАналитик) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьПредварительныйЗапрос(СтруктураПараметров, КэшПоказателей, КэшАналитик));
```
</details>

## ПолучитьПодзапросТекущейВерсии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьПодзапросТекущейВерсии(Запрос,СхемаЗапроса,СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьПодзапросТекущейВерсии(Запрос, СхемаЗапроса, СтруктураПараметров) 
```
</details>

## ПолучитьПодзапросДополнительнойВерсии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьПодзапросДополнительнойВерсии(Запрос,ДопБаза,СхемаЗапроса,СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьПодзапросДополнительнойВерсии(Запрос, ДопБаза, СхемаЗапроса, СтруктураПараметров));
```
</details>

## ПолучитьПодзапросМакетаТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьПодзапросМакетаТаблицы(Запрос) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьПодзапросМакетаТаблицы(Запрос));
```
</details>

## ИзменитьПодзапросМакетаТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ИзменитьПодзапросМакетаТаблицы(Запрос,СхемаЗапроса,СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ИзменитьПодзапросМакетаТаблицы(Запрос, СхемаЗапроса, СтруктураПараметров));
```
</details>

## ДобавитьВыражениеПолученияДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьВыражениеПолученияДанных(ТекстШаблонаЗапроса,Запрос,ГруппаПоказателей,СхемаЗапроса,СтруктураПараметров,ИдГруппы,НастройкиРасчетаОтклоненийВыбранные,Нечисловые); Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ДобавитьВыражениеПолученияДанных(ТекстШаблонаЗапроса, Запрос, ГруппаПоказателей, СхемаЗапроса, СтруктураПараметров, ИдГруппы, НастройкиРасчетаОтклоненийВыбранные, Нечисловые););
```
</details>

## ДобавитьДопВыражениеПолученияДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьДопВыражениеПолученияДанных(ТекстШаблонаЗапроса,ДопБаза,Запрос,ГруппаПоказателей,СхемаЗапроса,СтруктураПараметров,ИдГруппы,НастройкиРасчетаОтклоненийВыбранные,Нечисловые); Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ДобавитьДопВыражениеПолученияДанных(ТекстШаблонаЗапроса, ДопБаза, Запрос, ГруппаПоказателей, СхемаЗапроса, СтруктураПараметров, ИдГруппы, НастройкиРасчетаОтклоненийВыбранные, Нечисловые););
```
</details>

## ДобавитьВыражениеПолученияКомментариевДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьВыражениеПолученияКомментариевДанных(ТекстШаблонаЗапроса,Запрос,ГруппаПоказателей,СхемаЗапроса,СтруктураПараметров,ИдГруппы,НастройкиРасчетаОтклоненийВыбранные); Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ДобавитьВыражениеПолученияКомментариевДанных(ТекстШаблонаЗапроса, Запрос, ГруппаПоказателей, СхемаЗапроса, СтруктураПараметров, ИдГруппы, НастройкиРасчетаОтклоненийВыбранные););
```
</details>

## ПолучитьГруппировкуСБазой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьГруппировкуСБазой(СхемаЗапроса,СтруктураПараметров,НастройкиРасчетаОтклоненийВыбранные); Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьГруппировкуСБазой(СхемаЗапроса, СтруктураПараметров, НастройкиРасчетаОтклоненийВыбранные););
```
</details>

## ПолучитьПодзапросМакетаСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьПодзапросМакетаСтрок(СхемаЗапроса,СтруктураПараметров,НастройкиРасчетаОтклоненийВыбранные,ЕстьНечисловые); Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьПодзапросМакетаСтрок(СхемаЗапроса, СтруктураПараметров, НастройкиРасчетаОтклоненийВыбранные, ЕстьНечисловые););
```
</details>

## ПолучитьПодзапросМакетаСтрокИКолонок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьПодзапросМакетаСтрокИКолонок(СхемаЗапроса,СтруктураПараметров,НастройкиРасчетаОтклоненийВыбранные); Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьПодзапросМакетаСтрокИКолонок(СхемаЗапроса, СтруктураПараметров, НастройкиРасчетаОтклоненийВыбранные););
```
</details>

## ПолучитьФинальныйПодзапрос
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьФинальныйПодзапрос(СхемаЗапроса,СтруктураПараметров,НастройкиРасчетаОтклоненийВыбранные,ЕстьНечисловые); Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьФинальныйПодзапрос(СхемаЗапроса, СтруктураПараметров, НастройкиРасчетаОтклоненийВыбранные, ЕстьНечисловые););
```
</details>

## ПолучитьТекстСоединенияМакетаСДанными
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТекстСоединенияМакетаСДанными(ГруппаПоказателей,СтруктураТаблицИнтерфейса,ИндексБазы,ИдГруппы) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьТекстСоединенияМакетаСДанными(ГруппаПоказателей, СтруктураТаблицИнтерфейса, ИндексБазы, ИдГруппы));
```
</details>

## ПолучитьТекстСоединенияМакетаСВерсиями
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТекстСоединенияМакетаСВерсиями(ГруппаПоказателей,СтруктураТаблицИнтерфейса,ИндексБазы,ИдГруппы,ИндексБазыВерсий=Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьТекстСоединенияМакетаСВерсиями(ГруппаПоказателей, СтруктураТаблицИнтерфейса, ИндексБазы, ИдГруппы, ИндексБазыВерсий);
```
</details>

## ПолучитьТекстСоединенияМакетаСоСтатусамиПериодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТекстСоединенияМакетаСоСтатусамиПериодов(Нечисловые = Ложь,ТзСтрок) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьТекстСоединенияМакетаСоСтатусамиПериодов(Нечисловые, ТзСтрок));
```
</details>

## ПолучитьТекстСоединенияМакетаСоСтатусамиПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТекстСоединенияМакетаСоСтатусамиПоказателей(ТзСтрок, ВидыОтчетаМассив, ДоступныеПоля) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьТекстСоединенияМакетаСоСтатусамиПоказателей(ТзСтрок, ВидыОтчетаМассив, ДоступныеПоля));
```
</details>

## ПолучитьТекстСоединенияМакетаСоЗначениямиПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТекстСоединенияМакетаСоЗначениямиПоказателей(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьТекстСоединенияМакетаСоЗначениямиПоказателей(СтруктураПараметров));
```
</details>

## ПолучитьТекстСоединенияМакетаСоЗначениямиКомментариев
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТекстСоединенияМакетаСоЗначениямиКомментариев(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьТекстСоединенияМакетаСоЗначениямиКомментариев(СтруктураПараметров));
```
</details>

## ЗаполнитьТаблицуПериодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьТаблицуПериодов(ИндексБазы,ТзПериодовСоСдвигом,Сдвиг,ИсходныеПериоды,Периодичность) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьТаблицуПериодов(ИндексБазы, ТзПериодовСоСдвигом, Сдвиг, ИсходныеПериоды, Периодичность) 
```
</details>

## ДополнитьТекстФинальногоЗапроса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьТекстФинальногоЗапроса(ТекстЗапроса,СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ДополнитьТекстФинальногоЗапроса(ТекстЗапроса, СтруктураПараметров));
```
</details>

## ПолучитьВидыОтчетовПоПоказателям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьВидыОтчетовПоПоказателям(МассивПоказателей) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьВидыОтчетовПоПоказателям(МассивПоказателей) 
```
</details>

## ПолучитьКэшПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьКэшПоказателей(МассивПоказателей,ТзАналитик,КэшПоказателей,КэшАналитик) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьКэшПоказателей(МассивПоказателей, ТзАналитик, КэшПоказателей, КэшАналитик));
```
</details>

## ПолучитьКэшПоказателейТолькоСинтетика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьКэшПоказателейТолькоСинтетика(МассивПоказателей,ТзАналитик,КэшПоказателей,КэшАналитик) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьКэшПоказателейТолькоСинтетика(МассивПоказателей, ТзАналитик, КэшПоказателей, КэшАналитик));
```
</details>

## ДобавитьВыражениеПолученияДанныхПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьВыражениеПолученияДанныхПоказателей(СтруктураПараметров,ТекстШаблонаЗапроса); Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ДобавитьВыражениеПолученияДанныхПоказателей(СтруктураПараметров, ТекстШаблонаЗапроса););
```
</details>

## ПолучитьТекстСоединенияСВерсиями
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТекстСоединенияСВерсиями(ГруппаПоказателей,ИндексБазы,ИдГруппы) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьТекстСоединенияСВерсиями(ГруппаПоказателей, ИндексБазы, ИдГруппы));
```
</details>

## ПолучитьЗначениеПоказателейПоИсточнику
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьЗначениеПоказателейПоИсточнику(ТаблицаИсточник,СтруктураПараметровОтбора,РаскрываемыеАналитики=Неопределено,АнализЧувствительности=Ложь,СтруктураЗаменяемыхАналитик = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьЗначениеПоказателейПоИсточнику(ТаблицаИсточник, СтруктураПараметровОтбора, РаскрываемыеАналитики, АнализЧувствительности, СтруктураЗаменяемыхАналитик);
```
</details>

## ДобавитьВыражениеПолученияДанныхПоказателейИсточника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьВыражениеПолученияДанныхПоказателейИсточника(СтруктураПараметров,ТекстШаблонаЗапроса); Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ДобавитьВыражениеПолученияДанныхПоказателейИсточника(СтруктураПараметров, ТекстШаблонаЗапроса););
```
</details>

## ПолучитьТекстЗапроса_мПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьТекстЗапроса_мПоказателей(ТекстШаблонаЗапроса,мАналитикВТаблице) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПолучитьТекстЗапроса_мПоказателей(ТекстШаблонаЗапроса, мАналитикВТаблице));
```
</details>

## ПолучитьПоказателиВО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьПоказателиВО(ВидыОтчетов) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьПоказателиВО(ВидыОтчетов));
```
</details>

## ПолучитьТекстЗапросаПоВерсиям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТекстЗапросаПоВерсиям(Запрос,СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьТекстЗапросаПоВерсиям(Запрос, СтруктураПараметров) 
```
</details>

## ВернутьОтборДляЗапроса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ВернутьОтборДляЗапроса(Отбор) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ВернутьОтборДляЗапроса(Отбор));
```
</details>

## ПоместитьЛогИзмененныхПоказателейНечисловыеВЗапрос
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПоместитьЛогИзмененныхПоказателейНечисловыеВЗапрос(Запрос,ТекстЗапроса) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПоместитьЛогИзмененныхПоказателейНечисловыеВЗапрос(Запрос, ТекстЗапроса));
```
</details>

## ДобавитьВыражениеПолученияДанныхЛога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьВыражениеПолученияДанныхЛога(СтруктураПараметров,ТекстШаблонаЗапроса); Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ДобавитьВыражениеПолученияДанныхЛога(СтруктураПараметров, ТекстШаблонаЗапроса););
```
</details>

## ПрочитатьДанныеПоСтатусамПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПрочитатьДанныеПоСтатусамПоказателей(СтруктураФильтровИтог,ТаблицаСтраницы,ТаблицаСтроки,ТаблицаКолонки,ВыбранныеПоказатели,ВыбранныеРесурсы) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПрочитатьДанныеПоСтатусамПоказателей(СтруктураФильтровИтог, ТаблицаСтраницы, ТаблицаСтроки, ТаблицаКолонки, ВыбранныеПоказатели, ВыбранныеРесурсы) 
```
</details>

## УстановитьФорматВывода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьФорматВывода(Настройки,ЗначениеМасштаб,ЗначениеТочность,ПоляРесурсов,НастройкиРасчетаПоказателей,ОтображатьСуммыВДопВалютах=Ложь) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.УстановитьФорматВывода(Настройки, ЗначениеМасштаб, ЗначениеТочность, ПоляРесурсов, НастройкиРасчетаПоказателей, ОтображатьСуммыВДопВалютах);
```
</details>

## УстановитьОформлениеГруппировокСТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьОформлениеГруппировокСТ(НастройкиСхемыСводнойТаблицы,ТаблицаСтроки,Периодичность Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.УстановитьОформлениеГруппировокСТ(НастройкиСхемыСводнойТаблицы, ТаблицаСтроки, Периодичность);
```
</details>

## УстановитьОформлениеСтатусы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьОформлениеСтатусы(НастройкиСхемыСводнойТаблицы,ПоляРесурсов,Периодичность) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.УстановитьОформлениеСтатусы(НастройкиСхемыСводнойТаблицы, ПоляРесурсов, Периодичность) 
```
</details>

## УстановитьПредставлениеГруппировокСТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьПредставлениеГруппировокСТ(СхемаСКДЭталон,НастройкиСхемыСводнойТаблицы,ТаблицаСтроки,ТаблицаКолонки) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.УстановитьПредставлениеГруппировокСТ(СхемаСКДЭталон, НастройкиСхемыСводнойТаблицы, ТаблицаСтроки, ТаблицаКолонки) 
```
</details>

## ОформитьУровниГруппировокПоказателией
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОформитьУровниГруппировокПоказателией(КэшАналитикПоказателейСТ,ВыбранныеРесурсы,Настройки,СтруктураТаблицИнтерфейса,ПоказательОтбор = Неопределено,РежимОбратногоРаспределения,Периодичность) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОформитьУровниГруппировокПоказателией(КэшАналитикПоказателейСТ, ВыбранныеРесурсы, Настройки, СтруктураТаблицИнтерфейса, ПоказательОтбор, РежимОбратногоРаспределения, Периодичность) 
```
</details>

## ОформитьУровниРекурсивно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОформитьУровниРекурсивно(КэшАналитикПоказателейСТ,ВыбранныеРесурсы,ЭлементГруппировки,СтруктураАналитикТаблицы,ВсегоУровнейГруппирвокСтрок,ПоказательОтбор,РежимОбратногоРаспределения,СписокИспользованныхАналитик,Периодичность) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОформитьУровниРекурсивно(КэшАналитикПоказателейСТ, ВыбранныеРесурсы, ЭлементГруппировки, СтруктураАналитикТаблицы, ВсегоУровнейГруппирвокСтрок, ПоказательОтбор, РежимОбратногоРаспределения, СписокИспользованныхАналитик, Периодичность));
```
</details>

## ОформитьУровниГруппировокУправленияПС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОформитьУровниГруппировокУправленияПС(Настройки,СтруктураТаблицИнтерфейса) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОформитьУровниГруппировокУправленияПС(Настройки, СтруктураТаблицИнтерфейса) 
```
</details>

## ОформитьУровниРекурсивноПС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОформитьУровниРекурсивноПС(ЭлементГруппировки,ВсегоУровнейГруппирвокСтрок) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОформитьУровниРекурсивноПС(ЭлементГруппировки, ВсегоУровнейГруппирвокСтрок));
```
</details>

## ОформитьУровниГруппировокМП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОформитьУровниГруппировокМП(Настройки,СтруктураТаблицИнтерфейса) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОформитьУровниГруппировокМП(Настройки, СтруктураТаблицИнтерфейса) 
```
</details>

## ОформитьУровниРекурсивноМП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОформитьУровниРекурсивноМП(ЭлементГруппировки,ВсегоУровнейГруппирвокСтрок) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОформитьУровниРекурсивноМП(ЭлементГруппировки, ВсегоУровнейГруппирвокСтрок));
```
</details>

## УстановитьОформлениеДопПоля
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьОформлениеДопПоля(Настройки,НастройкиРасчетаОтклоненийВыбранные) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.УстановитьОформлениеДопПоля(Настройки, НастройкиРасчетаОтклоненийВыбранные) 
```
</details>

## ОформитьВычисляемые
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОформитьВычисляемые(ВидОтчета,Настройки,НастройкиИспользуемыхРесурсов,СтрокаОтбор = Неопределено,РежимСравненияСБазой=Ложь) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОформитьВычисляемые(ВидОтчета, Настройки, НастройкиИспользуемыхРесурсов, СтрокаОтбор, РежимСравненияСБазой);
```
</details>

## ОформитьНедоступные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОформитьНедоступные(ВидОтчета,Настройки,НастройкиИспользуемыхРесурсов,КэшАналитикПоказателей,СтрокаОтбор = Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОформитьНедоступные(ВидОтчета, Настройки, НастройкиИспользуемыхРесурсов, КэшАналитикПоказателей, СтрокаОтбор);
```
</details>

## ОформитьНеЧисловые
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОформитьНеЧисловые(ВидОтчета,Настройки,НастройкиИспользуемыхРесурсов,КэшАналитикПоказателей,СтрокаОтбор = Неопределено) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОформитьНеЧисловые(ВидОтчета, Настройки, НастройкиИспользуемыхРесурсов, КэшАналитикПоказателей, СтрокаОтбор);
```
</details>

## ОформитьНемасштабируемые
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОформитьНемасштабируемые(ВидОтчета,Настройки,НастройкиИспользуемыхРесурсов,КэшАналитикПоказателей,СтрокаОтбор = Неопределено,ЗначениеТочность) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОформитьНемасштабируемые(ВидОтчета, Настройки, НастройкиИспользуемыхРесурсов, КэшАналитикПоказателей, СтрокаОтбор, ЗначениеТочность) 
```
</details>

## ПрименитьИзменения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


Процедура ПрименитьИзменения(Параметры, АдресХранилища, АдресХранилищаДополнительный) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПрименитьИзменения(Параметры, АдресХранилища, АдресХранилищаДополнительный) 
```
</details>

## ПрименитьИзмененияСводнаяТаблица
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПрименитьИзмененияСводнаяТаблица(Параметры, АдресХранилища, АдресХранилищаДополнительный) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПрименитьИзмененияСводнаяТаблица(Параметры, АдресХранилища, АдресХранилищаДополнительный));
```
</details>

## ПолучитьЛогПоЧерновымЗаписям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьЛогПоЧерновымЗаписям(Параметры,ТипЗначенияПоказателей = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СводнаяТаблицаУХ.ПолучитьЛогПоЧерновымЗаписям(Параметры, ТипЗначенияПоказателей);
```
</details>

## ОбновитьСтруктуруБланковСТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Процедура вызывается для обновления закэшированых настроек бланков сводных таблиц при изменении версии УХ (если необходимо)
Процедура ОбновитьСтруктуруБланковСТ() Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОбновитьСтруктуруБланковСТ() 
```
</details>

## ОбновитьПорядковыеНомераСтрокБланков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьПорядковыеНомераСтрокБланков() Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОбновитьПорядковыеНомераСтрокБланков() 
```
</details>

## ЗаполнитьДеревоВыбранныхСтрок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьДеревоВыбранныхСтрок(Бланк) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьДеревоВыбранныхСтрок(Бланк));
```
</details>

## ЗаполнитьПорядковыйНомер
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьПорядковыйНомер(СтрокиДерева) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьПорядковыйНомер(СтрокиДерева));
```
</details>

## ОбновитьСвойстваПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСвойстваПоказателей(Бланк) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОбновитьСвойстваПоказателей(Бланк));
```
</details>

## ОбновитьХранилищеОтборов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьХранилищеОтборов() Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОбновитьХранилищеОтборов() 
```
</details>

## ОбновитьСоставОтборов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСоставОтборов() Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОбновитьСоставОтборов() 
```
</details>

## ОбновитьМасштабШкалыВремени
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьМасштабШкалыВремени() Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОбновитьМасштабШкалыВремени() 
```
</details>

## ОбновитьПредставлениеАналитик
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьПредставлениеАналитик() Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОбновитьПредставлениеАналитик() 
```
</details>

## ОбновитьПредставлениеКолонокСТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьПредставлениеКолонокСТ() Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОбновитьПредставлениеКолонокСТ() 
```
</details>

## ОбновитьКодыПВХВидыСубконтоКопоративные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьКодыПВХВидыСубконтоКопоративные() Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОбновитьКодыПВХВидыСубконтоКопоративные() 
```
</details>

## ОбновитьСтатусыПериодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСтатусыПериодов() Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОбновитьСтатусыПериодов() 
```
</details>

## ЗаполнитьПодменюСохраненныхВариантов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


Процедура ЗаполнитьПодменюСохраненныхВариантов(ЭтаФорма,Родитель,СоответствиеВариантовНастроекТаблицы,ИмяТекущегоВарианта="") Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьПодменюСохраненныхВариантов(ЭтаФорма, Родитель, СоответствиеВариантовНастроекТаблицы, ИмяТекущегоВарианта);
```
</details>

## СоздатьМакетСводнойТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СоздатьМакетСводнойТаблицы(БланкОбъект) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.СоздатьМакетСводнойТаблицы(БланкОбъект) 
```
</details>

## ПрочитатьСтруктуруТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПрочитатьСтруктуруТаблицы(ОбновитьДанныеОсям=Истина,СтруктураТаблицИнтерфейса,АдресСхемыКомпоновкиДанныхЭталон,КэшАналитикПоказателейСТАдрес,СтрукутраПараметров) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ПрочитатьСтруктуруТаблицы(ОбновитьДанныеОсям, СтруктураТаблицИнтерфейса, АдресСхемыКомпоновкиДанныхЭталон, КэшАналитикПоказателейСТАдрес, СтрукутраПараметров) 
```
</details>

## ЗаписатьСтруктуруТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаписатьСтруктуруТаблицы(СтрукутраПараметров) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаписатьСтруктуруТаблицы(СтрукутраПараметров) 
```
</details>

## ОбновитьПорядокСтрокБланкаСТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl



Процедура ОбновитьПорядокСтрокБланкаСТ(Бланк_) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ОбновитьПорядокСтрокБланкаСТ(Бланк_) 
```
</details>

## ВыполнитьОбновлениеПредставленийСтрокВСводнойТаблице
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВыполнитьОбновлениеПредставленийСтрокВСводнойТаблице(Строка) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ВыполнитьОбновлениеПредставленийСтрокВСводнойТаблице(Строка) 
```
</details>

## ЗаполнитьТЧПериодыГоризонта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьТЧПериодыГоризонта(ОбработкаАктуализации,ПериодФакт,ПериодПлан) Экспорт
```

Пример вызова
```bsl
СводнаяТаблицаУХ.ЗаполнитьТЧПериодыГоризонта(ОбработкаАктуализации, ПериодФакт, ПериодПлан) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
