---
title: Связанные файлы вызов сервера
slug: erp-uh/связанные-файлы-вызов-сервера
---


## СвязанныеФайлыПоВладельцу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Возвращает массив структур, описывающих файлы владельца независимо от места хранения
//
// Параметры:
//   Владелец - ЛюбаяСсылка - объект-владелец связанных файлов
//   ДокументID - идентификатор связанного объекта ДО (если не передан, будет определен автоматически)
//   ДокументТип - тип связанного объекта ДО (если не передан, будет определен автоматически)
//   ВключатьПомеченныеНаУдаление - Булево - Истина, если требуется получить и помеченные на удаление.
//
// Возвращаемое значение:
//   Массив - структуры, описывающие реквизиты связанных файлов
//
Функция СвязанныеФайлыПоВладельцу(Владелец, ДокументID = "", ДокументТип = "", Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервера.СвязанныеФайлыПоВладельцу(Владелец, ДокументID, ДокументТип, );
```
</details>

## ПолучитьФайлПоИдентификатору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, описывающую файл, найденный по идентификатору
// независимо от места хранения (1С:Документооборот или Справочник.Файлы).
//
// Параметры:
//   ДокументID - идентификатор связанного объекта ДО или УИД Справочник.Файлы
//
// Возвращаемое значение:
//  Структура, описывающая реквизиты найденного файла, если файл найден. Содержит следующие поля:
//        - ИндексКартинки - Число.
//        - Наименование - Строка, имя без расширения.
//        - Расширение - расширение без точки.
//        - СвязанныйФайл - Строка, СправочникСсылка.Фалы - идентификатор в документообороте или ссылка на справочник.
//        - Идентификатор - Строка, идентификатор в документообороте или строка уникального идентификатора элемента справочника.
//        - ДатаТекущейВерсии - Дата.
//        - Размер - Число, размер в байтах.
//        - ПометкаУдаления - Булево, помечен на удаление.
//        - Комментарий - Строка, описание файла.
//	Неопределено, если файл не найден.
//
Функция ПолучитьФайлПоИдентификатору(ИдентификаторФайла) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервера.ПолучитьФайлПоИдентификатору(ИдентификаторФайла) 
```
</details>

## ПолучитьФайлПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, описывающую файл, найденный по ссылке.
// Аналогична функции ПолучитьФайлПоИдентификатору.
//
Функция ПолучитьФайлПоСсылке(СсылкаНаФайл) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервера.ПолучитьФайлПоСсылке(СсылкаНаФайл) 
```
</details>

## ДобавитьФайлИзВременногоХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает файл, добавленный владельцу из временного хранилища и помещенный в ДО или в эту ИБ.
// Может приводить к автоматическому созданию связанного объекта.
//
// Параметры:
//   Владелец - ЛюбаяСсылка - объект-владелец связанных файлов
//   АдресВременногоХранилищаФайла - Строка - адрес временного хранилища, где размещен файл
//   Имя - Строка - имя помещаемого файла
//   Расширение - Строка - расширение помещаемого файла
//   Размер - Число - размер помещаемого файла
//   ВремяИзменения - Дата - дата и время файла на диске
//   ВремяИзмененияУниверсальное - Дата - дата и время UTC файла на диске
//   ДокументID - идентификатор связанного объекта ДО (если не передан, будет определен автоматически)
//   ДокументТип - тип связанного объекта ДО (если не передан, будет определен автоматически)
//
// Возвращаемое значение:
//   СправочникСсылка.Файлы или Строка (идентификатор файла ДО)
//
Функция ДобавитьФайлИзВременногоХранилища(Владелец, АдресВременногоХранилищаФайла, Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервера.ДобавитьФайлИзВременногоХранилища(Владелец, АдресВременногоХранилищаФайла, );
```
</details>

## ДобавитьФайлИзШаблона
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает файл, добавленный владельцу копированием шаблона и помещенный в ДО или в эту ИБ.
// Может приводить к автоматическому созданию связанного объекта.
//
// Параметры:
//   Владелец - ЛюбаяСсылка - объект-владелец связанных файлов или папка при хранении в этой ИБ
//   Шаблон - СправочникСсылка.Файлы - шаблон для копирования
//   ДокументID - идентификатор связанного объекта ДО (если не передан, будет определен автоматически)
//   ДокументТип - тип связанного объекта ДО (если не передан, будет определен автоматически)
//
// Возвращаемое значение:
//   СправочникСсылка.Файлы или Строка (идентификатор файла ДО)
//
Функция ДобавитьФайлИзШаблона(Владелец, Шаблон, ДокументID = "", ДокументТип = "") Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервера.ДобавитьФайлИзШаблона(Владелец, Шаблон, ДокументID, ДокументТип);
```
</details>

## ОбновитьФайлИзВременногоХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновить файл, добавленный владельцу из временного хранилища и помещенный в ДО или в эту ИБ.
// Может приводить к автоматическому созданию связанного объекта.
//
// Параметры:
//   Владелец - ЛюбаяСсылка - объект-владелец связанных файлов
//   АдресВременногоХранилищаФайла - Строка - адрес временного хранилища, где размещен файл
//   Имя - Строка - имя помещаемого файла
//   Расширение - Строка - расширение помещаемого файла
//   Размер - Число - размер помещаемого файла
//   ВремяИзменения - Дата - дата и время файла на диске
//   ВремяИзмененияУниверсальное - Дата - дата и время UTC файла на диске
//   ДокументID - идентификатор связанного объекта ДО (если не передан, будет определен автоматически)
//   ДокументТип - тип связанного объекта ДО (если не передан, будет определен автоматически)
//
// Возвращаемое значение:
//   Булево - Истина, если файл обновлен успешно.
//
Функция ОбновитьФайлИзВременногоХранилища(ИдентификаторФайла, Владелец, Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервера.ОбновитьФайлИзВременногоХранилища(ИдентификаторФайла, Владелец, );
```
</details>

## ВерсииФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив структур, описывающих версии файла независимо от места хранения
//
// Параметры:
//   Файл - СправочникСсылка.Файла, Строка - файл здесь или в ДО
//   ВключатьПомеченныеНаУдаление - Булево - Истина, если требуется получить и помеченные на удаление.
//
// Возвращаемое значение:
//   Массив - структуры, описывающие реквизиты версий файла
//
Функция ВерсииФайла(Файл, ВключатьПомеченныеНаУдаление = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервера.ВерсииФайла(Файл, ВключатьПомеченныеНаУдаление);
```
</details>

## ПометитьНаУдалениеСнятьПометку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помечает на удаление или снимает пометку с указанного файла.
//
// Параметры:
//   ИдентификаторФайла - СправочникСсылка.Файла, Строка - файл здесь или в ДО
//
Процедура ПометитьНаУдалениеСнятьПометку(ИдентификаторФайла) Экспорт
```

Пример вызова
```bsl
СвязанныеФайлыВызовСервера.ПометитьНаУдалениеСнятьПометку(ИдентификаторФайла) 
```
</details>

## ПометитьНаУдалениеПоВладельцу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменить пометку на удаление для файлов принадлежащих Владелец
//
// Параметры:
//	ПометкаНаУдаление - Булево, Истина - установить, Ложь - снять пометку на удаление.
//	Владелец - ЛюбаяСсылка - объект-владелец связанных файлов.
//	ДокументID - идентификатор связанного объекта ДО (если не передан, будет определен автоматически).
//	ДокументТип - тип связанного объекта ДО (если не передан, будет определен автоматически).
//
Процедура ПометитьНаУдалениеПоВладельцу(ПометкаНаУдаление, Владелец, Экспорт
```

Пример вызова
```bsl
СвязанныеФайлыВызовСервера.ПометитьНаУдалениеПоВладельцу(ПометкаНаУдаление, Владелец, );
```
</details>

## ПолучитьСсылкуНаФайл
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить ссылку на файл по его идентификатору. Для документооборота возвращает переданный идентификатор.
// Для внутреннего хранения определяет ссылку на справочник файлы.
// Необходима для унифицированной обработки идентификатора файла, с целью последующей передачи в другие функции.
//
// Параметры:
//   ИдентификаторФайла - СправочникСсылка.Файла, Строка - файл здесь или в ДО.
//
// Возвращает:
//	Строка, если используется документооборот, то возвращает переданный идентификатор файла.
//	СправочникСсылка.Файлы - если используется внутреннее хранение файлов.
Функция ПолучитьСсылкуНаФайл(ИдентификаторФайла) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервера.ПолучитьСсылкуНаФайл(ИдентификаторФайла) 
```
</details>

## ПолучитьИдентификаторФайлаПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить идентификатор файла в 1С:Документооборот, либо строку уникального идентификатора элемента справочника Файлы
// в зависимости от способа хранения файлов.
//
// Параметры:
//	СсылкаНаФайл - СпрвочникСсылка.Файлы, Строка - обобщенная ссылка на файл, помещеенный в базу.
//
// Возвращает:
//	Строка - либо идентификатор в 1С:Документооборот, либо строку уникального идентификатора элемента справочника Файлы,
//		в зависимости от способа хранения файлов.
//
Функция ПолучитьИдентификаторФайлаПоСсылке(СсылкаНаФайл) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервера.ПолучитьИдентификаторФайлаПоСсылке(СсылкаНаФайл) 
```
</details>

## ПолучитьДанныеФайлаДляОткрытия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить данные для открытия функцией СвязанныеФайлыКлиент.ОткрытьФайлДляПросмотра(ДанныеФайла)
Функция ПолучитьДанныеФайлаДляОткрытия(ИдентификаторФайла, УникальныйИдентификаторФормы) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервера.ПолучитьДанныеФайлаДляОткрытия(ИдентификаторФайла, УникальныйИдентификаторФормы) 
```
</details>

## НайтиПоследнююВерсиюФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В массиве версий ищет
Функция НайтиПоследнююВерсиюФайла(МассивВерсийФайла) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервера.НайтиПоследнююВерсиюФайла(МассивВерсийФайла) 
```
</details>

## ХранениеВДокументообороте
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет определить, используется-ли 1С Документооборот для хранения файлов.
//
Функция ХранениеВДокументообороте() Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервера.ХранениеВДокументообороте() 
```
</details>

## ПолучитьОбщийМодульСвязанныхФайловПоТипуХранения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ссылку на общий модуль для вызова функций работы с файлами.
// Читает функциональную опцию "ИспользоватьИнтеграциюС1СДокументооборот".
// Возвращаемое значение:
//	ОбщийМодуль - ссылка на общий модуль для вызова функций.
//	Если не найден, то вызывает исключение.
//
Функция ПолучитьОбщийМодульСвязанныхФайловПоТипуХранения() Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервера.ПолучитьОбщийМодульСвязанныхФайловПоТипуХранения() 
```
</details>

## ПолучитьШаблонОписанияФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру с описанием файла.
//
// Возвращает:
// 	Структура - описываюет реквизиты найденного файла.
//		Содержит следующие поля:
//        - ИндексКартинки - Число, индекс в картинке КоллекцияПиктограммФайлов.
//        - Наименование - Строка, имя без расширения.
//        - Расширение - Строка, расширение без точки.
//        - СвязанныйФайл - Строка, СправочникСсылка.Фалы - идентификатор в документообороте или ссылка на справочник.
//        - Идентификатор - Строка, идентификатор в документообороте или строка уникального идентификатора элемента справочника.
//        - ДатаТекущейВерсии - Дата.
//        - Размер - Число, размер в байтах.
//        - ПометкаУдаления - Булево, помечен на удаление.
//        - Комментарий - Строка, описание файла.
Функция ПолучитьШаблонОписанияФайла() Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервера.ПолучитьШаблонОписанияФайла() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
