---
title: Связанные файлы вызов сервера БСП
slug: erp-uh/связанные-файлы-вызов-сервера-бсп
---


## СвязанныеФайлыПоВладельцу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив структур, описывающих файлы владельца.
//
// Параметры:
//   Владелец - ЛюбаяСсылка - объект-владелец связанных файлов
//   ДокументID - не заполняется. Используется для унификации ДО и БСП.
//   ДокументТип - не заполняется.  Используется для унификации ДО и БСП.
//   ВключатьПомеченныеНаУдаление - Булево - Истина, если требуется получить и помеченные на удаление.
//
// Возвращаемое значение:
//   Массив - структуры, описывающие реквизиты связанных файлов
//
Функция СвязанныеФайлыПоВладельцу(Владелец, ДокументID = "", ДокументТип = "", Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераБСП.СвязанныеФайлыПоВладельцу(Владелец, ДокументID, ДокументТип, );
```
</details>

## ПолучитьФайлПоИдентификатору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, описывающую файл, найденный по идентификатору.
//
// Параметры:
//   ИдентификаторФайла - идентификатор связанного объекта ДО или УИД Справочник.Файлы
//
// Возвращаемое значение:
//  Структура, описывающая реквизиты найденного файла, если файл найден.
//		Описание полей см. СвязанныеФайлыВызовСервера.ПолучитьШаблонОписанияФайла().
//	Неопределено, если файл не найден.
//
Функция ПолучитьФайлПоИдентификатору(ИдентификаторФайла) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераБСП.ПолучитьФайлПоИдентификатору(ИдентификаторФайла) 
```
</details>

## ПолучитьФайлПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, описывающую файл, найденный по ссылке.
// Аналогична функции ПолучитьФайлПоИдентификатору.
//
Функция ПолучитьФайлПоСсылке(СсылкаНаФайл) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераБСП.ПолучитьФайлПоСсылке(СсылкаНаФайл) 
```
</details>

## ДобавитьФайлИзВременногоХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает файл, добавленный владельцу из временного хранилища и помещенный в ДО или в эту ИБ.
// Может приводить к автоматическому созданию связанного объекта.
//
// Параметры:
//   Владелец - ЛюбаяСсылка - объект-владелец связанных файлов
//   АдресВременногоХранилищаФайла - Строка - адрес временного хранилища, где размещен файл
//   Имя - Строка - имя помещаемого файла
//   Расширение - Строка - расширение помещаемого файла
//   Размер - Число - размер помещаемого файла
//   ВремяИзменения - Дата - дата и время файла на диске
//   ВремяИзмененияУниверсальное - Дата - дата и время UTC файла на диске
//   ДокументID - не заполняется. Используется для унификации с работой 1С: Документооборота.
//   ДокументТип - не заполняется. Используется для унификации с работой 1С: Документооборота.
//
// Возвращаемое значение:
//   СправочникСсылка.Файлы или Строка (идентификатор файла ДО)
//
Функция ДобавитьФайлИзВременногоХранилища(Владелец, АдресВременногоХранилищаФайла, Имя, Расширение, Размер, Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераБСП.ДобавитьФайлИзВременногоХранилища(Владелец, АдресВременногоХранилищаФайла, Имя, Расширение, Размер, );
```
</details>

## ДобавитьФайлИзШаблона
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает файл, добавленный владельцу копированием шаблона и помещенный в ДО или в эту ИБ.
// Может приводить к автоматическому созданию связанного объекта.
//
// Параметры:
//   Владелец - ЛюбаяСсылка - объект-владелец связанных файлов или папка при хранении в этой ИБ
//   Шаблон - СправочникСсылка.Файлы - шаблон для копирования
//   ДокументID - не заполняется. Используется для унификации с работой 1С: Документооборота.
//   ДокументТип - не заполняется. Используется для унификации с работой 1С: Документооборота.
//
// Возвращаемое значение:
//   СправочникСсылка.Файлы или Строка (идентификатор файла ДО)
//
Функция ДобавитьФайлИзШаблона(Владелец, Шаблон, ДокументID = "", ДокументТип = "") Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераБСП.ДобавитьФайлИзШаблона(Владелец, Шаблон, ДокументID, ДокументТип);
```
</details>

## ОбновитьФайлИзВременногоХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновить файл, добавленный владельцу из временного хранилища и помещенный в эту ИБ.
// Может приводить к автоматическому созданию связанного объекта.
//
// Параметры:
//   Владелец - ЛюбаяСсылка - объект-владелец связанных файлов
//   АдресВременногоХранилищаФайла - Строка - адрес временного хранилища, где размещен файл
//   Имя - Строка - имя помещаемого файла
//   Расширение - Строка - расширение помещаемого файла
//   Размер - Число - размер помещаемого файла
//   ВремяИзменения - Дата - дата и время файла на диске
//   ВремяИзмененияУниверсальное - Дата - дата и время UTC файла на диске
//   ДокументID - идентификатор связанного объекта ДО (если не передан, будет определен автоматически)
//   ДокументТип - тип связанного объекта ДО (если не передан, будет определен автоматически)
//
// Возвращаемое значение:
//   Булево - Истина, если файл обновлен успешно.
//
Функция ОбновитьФайлИзВременногоХранилища(ИдентификаторФайла, Владелец, АдресВременногоХранилищаФайла, Имя, Расширение, Размер, Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераБСП.ОбновитьФайлИзВременногоХранилища(ИдентификаторФайла, Владелец, АдресВременногоХранилищаФайла, Имя, Расширение, Размер, );
```
</details>

## ВерсииФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив структур, описывающих версии файла в БСП.
//
// Параметры:
//   Файл - СправочникСсылка.Файла - файл для получения версий.
//   ВключатьПомеченныеНаУдаление - Булево - Истина, если требуется получить и помеченные на удаление.
//
// Возвращаемое значение:
//   Массив - структуры, описывающие реквизиты версий файла
//
Функция ВерсииФайла(Файл, ВключатьПомеченныеНаУдаление = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераБСП.ВерсииФайла(Файл, ВключатьПомеченныеНаУдаление);
```
</details>

## ПометитьНаУдалениеСнятьПометку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помечает на удаление или снимает пометку с указанного файла.
//
// Параметры:
//   ИдентификаторФайла - СправочникСсылка.Файла - файл для пометки на удаление.
//
Процедура ПометитьНаУдалениеСнятьПометку(ИдентификаторФайла) Экспорт
```

Пример вызова
```bsl
СвязанныеФайлыВызовСервераБСП.ПометитьНаУдалениеСнятьПометку(ИдентификаторФайла) 
```
</details>

## ПометитьНаУдалениеПоВладельцу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменить пометку на удаление для файлов принадлежащих Владельцу.
//
// Параметры:
//	ПометкаНаУдаление - Булево, Истина - установить, Ложь - снять пометку на удаление.
//	Владелец - ЛюбаяСсылка - объект-владелец связанных файлов.
//	ДокументID - идентификатор связанного объекта ДО (если не передан, будет определен автоматически).
//	ДокументТип - тип связанного объекта ДО (если не передан, будет определен автоматически).
//
Процедура ПометитьНаУдалениеПоВладельцу(ПометкаНаУдаление, Владелец, ДокументID = "", ДокументТип = "") Экспорт
```

Пример вызова
```bsl
СвязанныеФайлыВызовСервераБСП.ПометитьНаУдалениеПоВладельцу(ПометкаНаУдаление, Владелец, ДокументID, ДокументТип);
```
</details>

## ПолучитьСсылкуНаФайл
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить ссылку на файл по его идентификатору.
// Необходима для унифицированной обработки идентификатора файла,
// с целью последующей передачи в другие функции.
//
// Параметры:
//   ИдентификаторФайла - СправочникСсылка.Файла, Строка - ссылка на файл
//		или уникальный идентификатор элемента справочника.
//
// Возвращает:
//	Строка, если используется документооборот, то возвращает переданный идентификатор файла.
//	СправочникСсылка.Файлы - если используется внутреннее хранение файлов.
Функция ПолучитьСсылкуНаФайл(ИдентификаторФайла) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераБСП.ПолучитьСсылкуНаФайл(ИдентификаторФайла) 
```
</details>

## ПолучитьИдентификаторФайлаПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить строку уникального идентификатора элемента справочника Файлы.
//
// Параметры:
//	СсылкаНаФайл - СпрвочникСсылка.Файлы - ссылка на файл, помещенный в базу.
//
// Возвращает:
//	Строка - уникальный идентификатора элемента справочника Файлы
//
Функция ПолучитьИдентификаторФайлаПоСсылке(СсылкаНаФайл) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераБСП.ПолучитьИдентификаторФайлаПоСсылке(СсылкаНаФайл) 
```
</details>

## ПолучитьДанныеФайлаДляОткрытия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить данные для открытия функцией СвязанныеФайлыКлиент.ОткрытьФайлДляПросмотра(ДанныеФайла)
Функция ПолучитьДанныеФайлаДляОткрытия(ИдентификаторФайла, УникальныйИдентификаторФормы) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераБСП.ПолучитьДанныеФайлаДляОткрытия(ИдентификаторФайла, УникальныйИдентификаторФормы) 
```
</details>

## УстановитьАктивнуюВерсиюФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Сделать версию файла текущей. Только для варианта внутреннего хранения файлов.
// Параметры:
//	Версия - СправочникСсылка.ВерсииФайлов, версия, которую устанавливаем текущей.
//
// Возвращает:
//	Булево, Истина - операция выполнена успешно. Ложь - операция не выполнена.
//
Функция УстановитьАктивнуюВерсиюФайла(Версия) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераБСП.УстановитьАктивнуюВерсиюФайла(Версия));
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
