---
title: Связанные файлы вызов сервера ДО
slug: erp-uh/связанные-файлы-вызов-сервера-до
---


## СвязанныеФайлыПоВладельцу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив структур, описывающих файлы владельца независимо от места хранения
//
// Параметры:
//   Владелец - ЛюбаяСсылка - объект-владелец связанных файлов
//   ДокументID - идентификатор связанного объекта ДО (если не передан, будет определен автоматически)
//   ДокументТип - тип связанного объекта ДО (если не передан, будет определен автоматически)
//   ВключатьПомеченныеНаУдаление - Булево - Истина, если требуется получить и помеченные на удаление.
//
// Возвращаемое значение:
//   Массив - структуры, описывающие реквизиты связанных файлов
//
Функция СвязанныеФайлыПоВладельцу(Владелец, ДокументID = "", ДокументТип = "", Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераДО.СвязанныеФайлыПоВладельцу(Владелец, ДокументID, ДокументТип, );
```
</details>

## ПолучитьФайлПоИдентификатору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, описывающую файл, найденный по идентификатору 1С:Документооборот.
//
// Параметры:
//   ИдентификаторФайла - идентификатор связанного объекта ДО.
//
// Возвращаемое значение:
//  Структура, описывающая реквизиты найденного файла, если файл найден.
//		Описание полей см. СвязанныеФайлыВызовСервера.ПолучитьШаблонОписанияФайла().
//	Неопределено, если файл не найден.
//
Функция ПолучитьФайлПоИдентификатору(ИдентификаторФайла) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераДО.ПолучитьФайлПоИдентификатору(ИдентификаторФайла) 
```
</details>

## ПолучитьФайлПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, описывающую файл, найденный по ссылке.
// Аналогична функции ПолучитьФайлПоИдентификатору.
//
Функция ПолучитьФайлПоСсылке(СсылкаНаФайл) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераДО.ПолучитьФайлПоСсылке(СсылкаНаФайл) 
```
</details>

## ДобавитьФайлИзВременногоХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает файл, добавленный владельцу из временного хранилища и помещенный в ДО.
// Может приводить к автоматическому созданию связанного объекта.
//
// Параметры:
//   Владелец - ЛюбаяСсылка - объект-владелец связанных файлов
//   АдресВременногоХранилищаФайла - Строка - адрес временного хранилища, где размещен файл
//   Имя - Строка - имя помещаемого файла
//   Расширение - Строка - расширение помещаемого файла
//   Размер - Число - размер помещаемого файла
//   ВремяИзменения - Дата - дата и время файла на диске
//   ВремяИзмененияУниверсальное - Дата - дата и время UTC файла на диске
//   ДокументID - идентификатор связанного объекта ДО (если не передан, будет определен автоматически)
//   ДокументТип - тип связанного объекта ДО (если не передан, будет определен автоматически)
//
// Возвращаемое значение:
//   Строка - идентификатор файла ДО.
//
Функция ДобавитьФайлИзВременногоХранилища(Владелец, АдресВременногоХранилищаФайла, Имя, Расширение, Размер, Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераДО.ДобавитьФайлИзВременногоХранилища(Владелец, АдресВременногоХранилищаФайла, Имя, Расширение, Размер, );
```
</details>

## ДобавитьФайлИзШаблона
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает файл, добавленный владельцу копированием шаблона и помещенный в ДО.
// Может приводить к автоматическому созданию связанного объекта.
//
// Параметры:
//   Владелец - ЛюбаяСсылка - объект-владелец связанных файлов или папка при хранении в этой ИБ
//   Шаблон - СправочникСсылка.Файлы - шаблон для копирования
//   ДокументID - идентификатор связанного объекта ДО (если не передан, будет определен автоматически)
//   ДокументТип - тип связанного объекта ДО (если не передан, будет определен автоматически)
//
// Возвращаемое значение:
//   Строка - идентификатор файла ДО.
//
Функция ДобавитьФайлИзШаблона(Владелец, Шаблон, ДокументID = "", ДокументТип = "") Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераДО.ДобавитьФайлИзШаблона(Владелец, Шаблон, ДокументID, ДокументТип);
```
</details>

## ОбновитьФайлИзВременногоХранилища
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновить файл, добавленный владельцу из временного хранилища и помещенный в ДО.
// Может приводить к автоматическому созданию связанного объекта.
//
// Параметры:
//   Владелец - ЛюбаяСсылка - объект-владелец связанных файлов
//   АдресВременногоХранилищаФайла - Строка - адрес временного хранилища, где размещен файл
//   Имя - Строка - имя помещаемого файла
//   Расширение - Строка - расширение помещаемого файла
//   Размер - Число - размер помещаемого файла
//   ВремяИзменения - Дата - дата и время файла на диске
//   ВремяИзмененияУниверсальное - Дата - дата и время UTC файла на диске
//   ДокументID - идентификатор связанного объекта ДО (если не передан, будет определен автоматически)
//   ДокументТип - тип связанного объекта ДО (если не передан, будет определен автоматически)
//
// Возвращаемое значение:
//   Булево - Истина, если файл обновлен успешно.
//
Функция ОбновитьФайлИзВременногоХранилища(ИдентификаторФайла, Владелец, Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераДО.ОбновитьФайлИзВременногоХранилища(ИдентификаторФайла, Владелец, );
```
</details>

## ВерсииФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив структур, описывающих версии файла.
//
// Параметры:
//   ИдентификаторФайла - Строка - идентификатор файла в ДО
//   ВключатьПомеченныеНаУдаление - Булево - Истина, если требуется
//		получить и помеченные на удаление.
//
// Возвращаемое значение:
//   Массив - структуры, описывающие реквизиты версий файла
//
Функция ВерсииФайла(ИдентификаторФайла, ВключатьПомеченныеНаУдаление = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераДО.ВерсииФайла(ИдентификаторФайла, ВключатьПомеченныеНаУдаление);
```
</details>

## ПометитьНаУдалениеСнятьПометку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помечает на удаление или снимает пометку с указанного файла.
//
// Параметры:
//   ИдентификаторФайла - Строка - идентификатор файла в ДО.
//
Процедура ПометитьНаУдалениеСнятьПометку(ИдентификаторФайла) Экспорт
```

Пример вызова
```bsl
СвязанныеФайлыВызовСервераДО.ПометитьНаУдалениеСнятьПометку(ИдентификаторФайла) 
```
</details>

## ПометитьНаУдалениеПоВладельцу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменить пометку на удаление для файлов принадлежащих Владелец
//
// Параметры:
//	ПометкаНаУдаление - Булево, Истина - установить, Ложь - снять пометку на удаление.
//	Владелец - ЛюбаяСсылка - объект-владелец связанных файлов.
//	ДокументID - идентификатор связанного объекта ДО (если не передан, будет определен автоматически).
//	ДокументТип - тип связанного объекта ДО (если не передан, будет определен автоматически).
//
Процедура ПометитьНаУдалениеПоВладельцу(ПометкаНаУдаление, Владелец, ДокументID = "", ДокументТип = "") Экспорт
```

Пример вызова
```bsl
СвязанныеФайлыВызовСервераДО.ПометитьНаУдалениеПоВладельцу(ПометкаНаУдаление, Владелец, ДокументID, ДокументТип);
```
</details>

## ПолучитьСсылкуНаФайл
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить ссылку на файл по его идентификатору. Возвращает переданный идентификатор.
// Необходима для унифицированной обработки идентификатора файла, с целью последующей передачи в другие функции.
// В рамках данного модуля можно не использовать.
//
// Параметры:
//   ИдентификаторФайла - Строка - идентификатор файла в ДО.
//
// Возвращает:
//	Строка, возвращает переданный идентификатор файла.
//
Функция ПолучитьСсылкуНаФайл(ИдентификаторФайла) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераДО.ПолучитьСсылкуНаФайл(ИдентификаторФайла) 
```
</details>

## ПолучитьИдентификаторФайлаПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить идентификатор файла в 1С:Документооборот.
// Вспомогательная функция для унификации идентификатора файла.
//
// Параметры:
//	СсылкаНаФайл - Строка - обобщенная ссылка на файл, помещеенный в базу.
//
// Возвращает:
//	Строка - идентификатор в 1С:Документооборот.
//
Функция ПолучитьИдентификаторФайлаПоСсылке(СсылкаНаФайл) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераДО.ПолучитьИдентификаторФайлаПоСсылке(СсылкаНаФайл) 
```
</details>

## ПолучитьДанныеФайлаДляОткрытия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить данные для открытия функцией СвязанныеФайлыКлиент.ОткрытьФайлДляПросмотра(ДанныеФайла)
//
Функция ПолучитьДанныеФайлаДляОткрытия(ИдентификаторФайла, УникальныйИдентификаторФормы) Экспорт
```

Пример вызова
```bsl
Результат = СвязанныеФайлыВызовСервераДО.ПолучитьДанныеФайлаДляОткрытия(ИдентификаторФайла, УникальныйИдентификаторФормы) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
