---
title: Сделки сервер
slug: erp-uh/сделки-сервер
---


## ПолучитьТекущийЭтап
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текущий этап процесса продажи
//
// Параметры:
// Сделка - СправочникСсылка.СделкиСКлиентами - ссылка на сделку, по которой необходимо определить текущий этап.
//
// Возвращаемое значение:
//   СправочникСсылка.СостоянияПроцессов - текущий этап сделки.
//
Функция ПолучитьТекущийЭтап(Сделка) Экспорт
```

Пример вызова
```bsl
Результат = СделкиСервер.ПолучитьТекущийЭтап(Сделка) 
```
</details>

## РассчитатьВероятность
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру с расчетной вероятностью выигрыша сделки и ее составляющими
//
// Параметры:
//  Сделка    - СправочникСсылка.СделкиСКлиентами       - сделка, вероятность успешного завершения которой рассчитывается.
//
// Возвращаемое значение:
//   Структура - содержит следующие поля:
//    *ОбщаяСЭтапа  - Число - вероятность исходя из статистики этапа.
//    *ПоМенеджеру  - Число - вероятность исходя из статистики менеджера.
//    *ПоПартнеру   - Число - вероятность исходя из статистики по партнеру.
//    *ПоВидуСделки - Число - вероятность исходя из статистики по виду сделки.
//    *Средняя      - Число - среднее значение предыдущих параметров.
//    *Расчетная    - Число - 100 если сделка закрыта и выиграна и средняя если в работе.
//
Функция РассчитатьВероятность(Сделка) Экспорт
```

Пример вызова
```bsl
Результат = СделкиСервер.РассчитатьВероятность(Сделка) 
```
</details>

## УстановитьЭтапПроцесса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает этап процесса продажи для сделки.
// Параметры:
//  Сделка - СправочникСсылка.СделкиСКлиентами   - ссылка на сделку, по которой производится переход.
//  Этап   - СправочникСсылка.СостоянияПроцессов - этап, на который нужно перевести сделку.
//
Процедура УстановитьЭтапПроцесса(Сделка, Этап) Экспорт
```

Пример вызова
```bsl
СделкиСервер.УстановитьЭтапПроцесса(Сделка, Этап) 
```
</details>

## ПолучитьЗаписьСтатистики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Найти или создать запись статистики сделок
// Параметры:
//  Сделка - СправочникСсылка.СделкиСКлиентами   - сделка, по которой создается запись.
//  Этап   - СправочникСсылка.СостоянияПроцессов - этап процесса продажи.
//
// Возвращаемое значение:
//   РегистрСведенийМенеджерЗаписи.СтатистикаСделокСКлиентами - найденная или созданная запись.
//
Функция ПолучитьЗаписьСтатистики(Сделка, Этап) Экспорт
```

Пример вызова
```bsl
Результат = СделкиСервер.ПолучитьЗаписьСтатистики(Сделка, Этап) 
```
</details>

## ЗакрытьСтатистику
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записать завершение этапа в статистику
// Параметры:
//  Сделка          - СправочникСсылка.СделкиСКлиентами - сделка, по которой создается запись.
//  Этап            - СправочникСсылка.СостоянияПроцессов - закрываемый этап процесса продажи.
//  ОтменаПроигрыша - Булево - признак, того что выполняется отмена проигрыша сделки.
//
Процедура ЗакрытьСтатистику(Сделка, Этап, ОтменаПроигрыша = Ложь) Экспорт
```

Пример вызова
```bsl
СделкиСервер.ЗакрытьСтатистику(Сделка, Этап, ОтменаПроигрыша);
```
</details>

## ЗаполнитьРеквизитыЗадачПроцесса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет реквизиты задач процесса продажи при их создании.
//
// Параметры:
//  Сделка                      - СправочникСсылка.СделкиСКлиентами - сделка, которой по которой создан процесс.
//  Процесс                     - БизнесПроцессСсылка.ТиповаяПродажа - бизнес процесс продажи.
//  ТочкаМаршрутаБизнесПроцесса - ТочкаМаршрутаБизнесПроцессаСсылка - точка маршрута, по которой создаются задачи.
//  ФормируемыеЗадачи           - Массив из ЗадачаСсылка.ЗадачаИсполнителя - массив формируемых задач.
//
Процедура ЗаполнитьРеквизитыЗадачПроцесса(Сделка, Процесс, ТочкаМаршрутаБизнесПроцесса, ФормируемыеЗадачи) Экспорт
```

Пример вызова
```bsl
СделкиСервер.ЗаполнитьРеквизитыЗадачПроцесса(Сделка, Процесс, ТочкаМаршрутаБизнесПроцесса, ФормируемыеЗадачи) 
```
</details>

## ЗапуститьПроцесс
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует и запускает экземпляр бизнес-процесса по сделке
// Параметры:
//  Сделка - СправочникСсылка.СделкиСКлиентами - сделка, которой по которой создается процесс.
//
Процедура ЗапуститьПроцесс(Знач Сделка) Экспорт
```

Пример вызова
```bsl
СделкиСервер.ЗапуститьПроцесс(Сделка) 
```
</details>

## ПерезапуститьПроцессПродажи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отменяет (проставляет пометки удаления) текущие задачи и перезапускает бизнес-процесс
// Параметры:
//  Сделка    - СправочникСсылка.СделкиСКлиентами - сделка, процесс которой нужно стартовать заново.
//  ТипСделки - ПеречислениеСсылка.ТипыСделокСКлиентами - тип сделки, определяет метаданные процесса.
//
Процедура ПерезапуститьПроцессПродажи(Сделка, ТипСделки) Экспорт
```

Пример вызова
```bsl
СделкиСервер.ПерезапуститьПроцессПродажи(Сделка, ТипСделки) 
```
</details>

## ЗавершитьПроцессПродажи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отменяет текущие задачи и завершает бизнес-процесс сделки
//
// Параметры:
//  Сделка    - СправочникСсылка.СделкиСКлиентами       - сделка, процесс которой нужно завершить.
//  ТипСделки - ПеречислениеСсылка.ТипыСделокСКлиентами - тип сделки, определяет метаданные процесса.
//
Процедура ЗавершитьПроцессПродажи(Сделка, ТипСделки) Экспорт
```

Пример вызова
```bsl
СделкиСервер.ЗавершитьПроцессПродажи(Сделка, ТипСделки) 
```
</details>

## ПолучитьОписаниеТипаСделки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// По ссылке на перечисление ТипыСделокСКлиентами получить имя и представление.
//
// Параметры:
//  ТипСделки - ПеречислениеСсылка.ТипыСделокСКлиентами - тип сделки, определяет метаданные процесса.
//
// Возвращаемое значение:
//   Структура - имеет следующие поля:
//    * Имя - Строка - имя значения перечисления.
//    * Представление - Строка - представление значения перечисления.
//
Функция ПолучитьОписаниеТипаСделки(ТипСделки) Экспорт
```

Пример вызова
```bsl
Результат = СделкиСервер.ПолучитьОписаниеТипаСделки(ТипСделки) 
```
</details>

## ПолучитьПорядокРезультата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает в отчет "воронка продаж" значение порядка результата прохождения этапа.
//
// Параметры:
//  Результат - ПеречислениеСсылка.СтатусыСделок -текущий статус сделки.
//
// Возвращаемое значение:
//   Число - значение упорядочивания статуса сделки в отчете.
//
Функция ПолучитьПорядокРезультата(Результат) Экспорт
```

Пример вызова
```bsl
Результат = СделкиСервер.ПолучитьПорядокРезультата(Результат) 
```
</details>

## ПолучитьУчастниковПоТабличнойЧастиПредметаВзаимодействия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает участников взаимодействия по табличной части предмета взаимодействия
//
// Параметры:
//  Ссылка            - ОпределяемыйТип.ПредметВзаимодействия - предмет взаимодействия
//  ОсновнойУчастник  - ОпределяемыйТип.КонтактВзаимодействия - участник взаимодействия, которого должен попасть в результирующий
//   массив, вне зависимости, содержится ли он в табличной части предмета взаимодействия или нет.
//
// Возвращаемое значение:
//   Массив             - массив участников взаимодействия.
//
Функция ПолучитьУчастниковПоТабличнойЧастиПредметаВзаимодействия(Ссылка, ОсновнойУчастник = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СделкиСервер.ПолучитьУчастниковПоТабличнойЧастиПредметаВзаимодействия(Ссылка, ОсновнойУчастник);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
