---
title: Сегменты вызов сервера
slug: erp-uh/сегменты-вызов-сервера
---


## ПрименитьИзмененияКСхемеКомпоновкиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Готовит структуру данных СКД и настроек, исходя из шаблона и данных сегмента.
//
// Параметры:
//  СегментСсылка            - СправочникСсылка.СегментыНоменклатуры, СправочникСсылка.СегментыПартнеров - сегмент, чьи
//      СКД и настройки получаются.
//  ИмяШаблонаСКД            - Строка - имя шаблона СКД
//  АдресСКД                 - Строка - адрес хранилища, в котором находится СКД.
//  АдресНастроекСКД         - Строка - адрес хранилища, в котором находятся настройки СКД.
//  УникальныйИдентификатор - УникальныйИдентификатор - идентификатор формы, из которой выполняется вызов процедуры.
//
// Возвращаемое значение:
//   Структура   -  состоит из следующих полей
//       ИмяШаблонаСКД           - Строка - имя шаблона СКД
//       ПредставлениеШаблонаСКД - Строка - пользовательское представление шаблона СКД.
//       АдресСКД                - Строка - адрес хранилища, в котором находится СКД.
//       АдресНастроекСКД        - Строка - адрес хранилища, в котором находятся настройки СКД.
//
Функция ПрименитьИзмененияКСхемеКомпоновкиДанных(СегментСсылка, ИмяШаблонаСКД, АдресСКД, АдресНастроекСКД, УникальныйИдентификатор) Экспорт
```

Пример вызова
```bsl
Результат = СегментыВызовСервера.ПрименитьИзмененияКСхемеКомпоновкиДанных(СегментСсылка, ИмяШаблонаСКД, АдресСКД, АдресНастроекСКД, УникальныйИдентификатор) 
```
</details>

## ПолучитьАдресаСхемыКомпоновкиДанныхВоВременномХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает адреса СКД и настроек согласно переданным данным.
//
// Параметры:
//  СегментСсылка            - СправочникСсылка.СегментыНоменклатуры, СправочникСсылка.СегментыПартнеров - сегмент, чьи
//      СКД и настройки получаются.
//  ИмяШаблонаСКД            - Строка - имя шаблона СКД
//  АдресСКД                 - Строка - адрес хранилища, в котором находится СКД.
//  АдресНастроекСКД         - Строка - адрес хранилища, в котором находятся настройки СКД.
//  УникальныйИдентификатор   - УникальныйИдентификатор - идентификатор формы, из которой выполняется вызов процедуры.
//
// Возвращаемое значение:
//   Структура   -  состоит из следующих полей
//       СхемаКомпоновкиДанных     - Строка - адрес шаблона СКД.
//       НастройкиКомпоновкиДанных - Строка - адрес настроек СКД.
//
Функция ПолучитьАдресаСхемыКомпоновкиДанныхВоВременномХранилище(СегментСсылка, Экспорт
```

Пример вызова
```bsl
Результат = СегментыВызовСервера.ПолучитьАдресаСхемыКомпоновкиДанныхВоВременномХранилище(СегментСсылка, );
```
</details>

## Сформировать
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет регистр сведений объектами, вошедшими в сегмент.
//
// Параметры:
//   СегментСсылка - СправочникСсылка.СегментыПартнеров, СправочникСсылка.СегментыНоменклатуры - сегмент, элементы
//       входящие в который получаются.
//
Процедура Сформировать(СегментСсылка) Экспорт
```

Пример вызова
```bsl
СегментыВызовСервера.Сформировать(СегментСсылка) 
```
</details>

## Очистить
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет из регистра сведений записи, относящиеся к сегменту
//
// Параметры:
//   СегментСсылка - СправочникСсылка.СегментыПартнеров, СправочникСсылка.СегментыНоменклатуры - сегмент, элементы
//       входящие в который получаются.
//
Процедура Очистить(СегментСсылка) Экспорт
```

Пример вызова
```bsl
СегментыВызовСервера.Очистить(СегментСсылка) 
```
</details>

## СписокЗначений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список значений, содержащий элементы, входящие в сегмент,
// с учетом способа формирования сегмента.
//
// Параметры:
//   СегментСсылка - СправочникСсылка.СегментыПартнеров, СправочникСсылка.СегментыНоменклатуры - сегмент, элементы
//       входящие в который получаются.
//
// Возвращаемое значение:
//   СписокЗначений - список элементов, входящих в сегмент.
//
Функция СписокЗначений(СегментСсылка) Экспорт
```

Пример вызова
```bsl
Результат = СегментыВызовСервера.СписокЗначений(СегментСсылка) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
