---
title: Сервис EDI переопределяемый
slug: erp-uh/сервис-edi-переопределяемый
---


## ПриОпределенииНастроекУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возможность определить настройки интеграции с EDI
//
// Параметры:
//  НастройкиУчета - Структура - см. НастройкиEDI.НастройкиУчета
//
Процедура ПриОпределенииНастроекУчета(НастройкиУчета) Экспорт
```

Пример вызова
```bsl
СервисEDIПереопределяемый.ПриОпределенииНастроекУчета(НастройкиУчета) 
```
</details>

## ПриОпределенииДоступностиРазделаВиджетаПоПравам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет определить доступность виджета EDI по правам доступа пользователя.
//
// Параметры:
//  Раздел   - ПеречислениеСсылка.РазделыВиджетовEDI - раздел текущих дел EDI для которого определяется доступность.
//  Доступен - Булево - по умолчанию Ложь.
//
Процедура ПриОпределенииДоступностиРазделаВиджетаПоПравам(Раздел, Доступен) Экспорт
```

Пример вызова
```bsl
СервисEDIПереопределяемый.ПриОпределенииДоступностиРазделаВиджетаПоПравам(Раздел, Доступен) 
```
</details>

## ЗаполнитьДанныеПрикладногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняются данными прикладного документа, для определения возможности его отправки через EDI
//
// Параметры:
//  СсылкаНаДокумент            - ДокументСсылка - раздел текущих дел EDI для которого определяется доступность.
//  ДанныеПрикладногоОбъектаEDI - Структура - требуемые данные заполнения - см. ПараметрыПрикладногоДокументаДляОпределенияВозможностиОтправки.
//  ЗаполнениеНеВыполнялось     - Булево - требуется установить в Ложь, если заполнение выполнено.
//
Процедура ЗаполнитьДанныеПрикладногоДокумента(СсылкаНаДокумент, ДанныеПрикладногоОбъектаEDI, ЗаполнениеНеВыполнялось) Экспорт
```

Пример вызова
```bsl
СервисEDIПереопределяемый.ЗаполнитьДанныеПрикладногоДокумента(СсылкаНаДокумент, ДанныеПрикладногоОбъектаEDI, ЗаполнениеНеВыполнялось) 
```
</details>

## ПриЗагрузкеДанныхИзНастроекНаСервереФормаСпискаПрикладногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возможность переопределить поведение при загрузке данных из настроек в форме списка прикладных документов
//
// Параметры:
//  Форма                 - ФормаКлиентскогоПриложения - форма, в которой выполняется событие.
//  Настройки             - Структура                  - загружаемые настройки.
//  СтандартнаяОбработка  - Булево                     - признак стандартной обработки события.
//
Процедура ПриЗагрузкеДанныхИзНастроекНаСервереФормаСпискаПрикладногоДокумента(Форма, Настройки, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
СервисEDIПереопределяемый.ПриЗагрузкеДанныхИзНастроекНаСервереФормаСпискаПрикладногоДокумента(Форма, Настройки, СтандартнаяОбработка) 
```
</details>

## ЗаполнитьПараметрыЗапретаРедактированияРеквизитовEDI
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Требуется определить какие реквизиты формы документа, будут заблокированы в зависимости от доступности реквизитов документа EDI
//
// Параметры:
//  ТаблицаПараметров      - ТаблицаЗначений - состоит из следующих колонок:
//   * ИмяРеквизита        - Строка - имя реквизита документа EDI, которое не должно быть изменено.
//   * БлокируемыеЭлементы - СписокЗначений - список имен элементов формы прикладного документа, которые должны быть заблокированы, так как они могут изменить документ EDI.
//  ТипДокумента           - ПеречислениеСсылка.ТипыДокументовEDI - тип документа, для которого выполняется настройка блокировки реквизитов.
//
Процедура ЗаполнитьПараметрыЗапретаРедактированияРеквизитовEDI(ТаблицаПараметров, ТипДокумента) Экспорт
```

Пример вызова
```bsl
СервисEDIПереопределяемый.ЗаполнитьПараметрыЗапретаРедактированияРеквизитовEDI(ТаблицаПараметров, ТипДокумента) 
```
</details>

## ПриОбновленииЗаписиСостоянияДокументовПоДаннымСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возможность выполнить действия при получении нового состояния EDI по данным сервиса.
//
// Параметры:
//  ПараметрыЗаписи      - Структура - см. РегистрСведений.СостоянияДокументовEDI.ПараметрыЗаписиВРегистр.
//
Процедура ПриОбновленииЗаписиСостоянияДокументовПоДаннымСервиса(ПараметрыЗаписи) Экспорт
```

Пример вызова
```bsl
СервисEDIПереопределяемый.ПриОбновленииЗаписиСостоянияДокументовПоДаннымСервиса(ПараметрыЗаписи) 
```
</details>

## ПриАвтоматическомОпределенииСкладаПрикладногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет значение склада прикладного объекта по набору признаков, с которыми он может коррелировать.
//
// Параметры:
//  Склад - ОпределяемыйТип.СкладEDI - значение реквизита, которое нужно заполнить.
//  ТипПрикладногоДокумента - Тип - тип прикладного объекта, для которого определяется значение реквизита.
//  КритерииПоиска - Структура - критерии отбора прикладных объектов для получения.
//    * Организация - ОпределяемыйТип.Организация - организация заказа.
//    * Контрагент - ОпределяемыйТип.КонтрагентБЭД - контрагент заказа.
//
Процедура ПриАвтоматическомОпределенииСкладаПрикладногоДокумента(Склад, Экспорт
```

Пример вызова
```bsl
СервисEDIПереопределяемый.ПриАвтоматическомОпределенииСкладаПрикладногоДокумента(Склад, );
```
</details>

## УстановитьСкладПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет склад по умолчанию
//
// Параметры:
// 	Склад - ОпределяемыйТип.СкладEDI - значение склада, которое нужно заполнить.
//
Процедура УстановитьСкладПоУмолчанию(Склад) Экспорт
```

Пример вызова
```bsl
СервисEDIПереопределяемый.УстановитьСкладПоУмолчанию(Склад) 
```
</details>

## ПриОпределенииДоступностиКомандПриОтображении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возможность определить доступность команды EDI.
//
// Параметры:
//  ПрикладнойОбъект - ДокументСсылка - документ, для которого определяется доступность команды.
//  КатегорииКоманд  - ТаблицаЗначений - см. ДокументыEDIИнтеграция.НовыйТаблицаДоступныхКатегорийКомандПриВыводеДоступныхДействий.
//
Процедура ПриОпределенииДоступностиКомандПриОтображении(ПрикладнойОбъект, КатегорииКоманд) Экспорт
```

Пример вызова
```bsl
СервисEDIПереопределяемый.ПриОпределенииДоступностиКомандПриОтображении(ПрикладнойОбъект, КатегорииКоманд) 
```
</details>

## ПередВыполнениемКомандыСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возможность проверить возможно ли выполнение команды EDI после того как пользователь уже начал ее выполнять.
//
// Параметры:
//  ПараметрыВыполнения - Структура - см. ДокументыEDIИнтеграция.НовыйВозможностьДействияСервисаПриВыполнении.
//
Процедура ПередВыполнениемКомандыСервиса(ПараметрыВыполнения) Экспорт
```

Пример вызова
```bsl
СервисEDIПереопределяемый.ПередВыполнениемКомандыСервиса(ПараметрыВыполнения) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
