---
title: Система быстрых платежей
slug: erp-uh/система-быстрых-платежей
---


## НастройкаПодключенияДоступна
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет доступность использования функциональности подключения
// к СБП на основании прав доступа пользователя.
//
// Возвращаемое значение:
//  Булево - если Истина, настройка подключения к Системе быстрых платежей доступна.
//
Функция НастройкаПодключенияДоступна() Экспорт
```

Пример вызова
```bsl
Результат = СистемаБыстрыхПлатежей.НастройкаПодключенияДоступна() 
```
</details>

## ПараметрыПодключенияПоБИК
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет возможность настройки подключения к Системе быстрых платежей.
//
// Параметры:
//  БИК - Строка - идентификатор банка;
//
// Возвращаемое значение:
//  Структура - настройки подключения:
//    * ИнтеграцияДоступнаСБПc2b - Булево - если Истина, участник СБП интегрирован;
//    * ПараметрыУчастникаСБП - Структура, Неопределено - информация об участие СБП:
//      ** Наименование - Строка - имя банка участника СБП;
//      ** НастройкаПодключения  - Массив из НастройкиПодключенияКСистемеБыстрыхПлатежей - список настроек подключения;
//      ** Идентификатор  - Строка - идентификатор участника СБП;
//
Функция ПараметрыПодключенияПоБИК(БИК) Экспорт
```

Пример вызова
```bsl
Результат = СистемаБыстрыхПлатежей.ПараметрыПодключенияПоБИК(БИК) 
```
</details>

## НастройкиПодключения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет доступность операций для настройки подключения к СБП. В сценариях оплаты
// различных участников СБП существуют отличия, поэтому ряд операций могут
// быть запрещены для выполнения. Метод следует использовать для настройки
// элементов форм оплаты и возвратов и получение общих настроек подключения.
//
// Параметры:
//  Настройка - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей -
//                  настройка выполнения операции СБП.
//
// Возвращаемое значение:
//  Структура - общие настройки и информация о доступных операциях:
//    * Идентификатор - Строка - строковый идентификатор или участника СБП;
//    * СинонимСистемы - Строка - синоним для печати;
//    * Используется - Булево - признак активности настройки;
//    * ИНН - Строка - ИНН участника СБП;
//    * БИК - Массив из Строка - список БИК участника СБП;
//    * Наименование - Строка - наименование участника СБП;
//    * НастройкиСБПc2b - Структура - настройки выполнения переводов c2b:
//       ** Переводыc2b - Булево - признак доступности переводов СБП c2b;
//       ** КассовыеСсылки - Булево - признак доступности использования кассовых ссылок;
//       ** ПлатежныйАгрегатор - Булево - настроена интеграция с платежным агрегатором;
//       ** УчастникСБПВозврата - Булево - признак доступности возврата оплаты
//          на счет отличный отчета оплаты. Для получения списка доступных участников
//          следует использовать метод ПереводыСБПc2b.УчастникиСБПДляВозврата;
//       ** ПодключениеКассовойСсылки - Булево - определяет доступность подключения кассовой ссылки.
//
Функция НастройкиПодключения(Настройка) Экспорт
```

Пример вызова
```bsl
Результат = СистемаБыстрыхПлатежей.НастройкиПодключения(Настройка) 
```
</details>

## ИзображениеQRКодаСБП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирование изображения идентификатора оплаты (QR-кода).
//
// Параметры:
//  ФункциональнаяСсылка - Строка - идентификатор оплаты;
//  Размер - Число - размер QR-кода в пикселях;
//  ТипПечати - Число - вариант печати QR-кода. В зависимости от выбранного варианта
//    печати подбирается картина с логотипом Системы быстрых платежей. Возможные варианты:
//      - 0 - печать на цветном принтере;
//      - 1 - монохромная печать;
//      - 2 - черно-белая печать;
//      - 3 - без логотипа.
//
// Возвращаемое значение:
//  ДвоичныеДанные - данные изображения QR-кода.
//
Функция ИзображениеQRКодаСБП(ФункциональнаяСсылка, Размер, ТипПечати = 0) Экспорт
```

Пример вызова
```bsl
Результат = СистемаБыстрыхПлатежей.ИзображениеQRКодаСБП(ФункциональнаяСсылка, Размер, ТипПечати);
```
</details>

## ПолучитьУчастниковСБП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список участников СБП.
//
// Возвращаемое значение:
//  Структура - результат запроса:
//   * ДанныеУчастников - Соответствие - Содержит описание данных участников СБП
//      ** Ключ - Строка - идентификатор участника СБП.
//      ** Значение - Структура - Описание параметров участника СБП.
//          *** Представление - Строка - Представление участника СБП для пользователя.
//          *** АдресСтраницыПодключения - Строка - Адрес страницы подключения к участнику СБП.
//          *** ТекстПредупреждения - Строка - Представление участника СБП для пользователя.
//          *** ИНН - Строка - ИНН участника СБП.
//          *** БИК - Массив Из Строк - Массив БИК участника СБП;
//          *** АдресСтраницыЗаявки - Строка - адресе страницы отправки заявки;
//          *** ПартнерАгентаСБП - Булево - признак подключения банка партнера Агента ТСП.
//   * Ошибка - Булево, Истина - если задание завершено с ошибкой.
//   * СообщениеОбОшибке - Строка, Форматированная строка - сообщение об ошибке для пользователя.
//   * ИнформацияОбОшибке - Строка, Форматированная строка - сообщение об ошибке для администратора.
//
Функция ПолучитьУчастниковСБП() Экспорт
```

Пример вызова
```bsl
Результат = СистемаБыстрыхПлатежей.ПолучитьУчастниковСБП() 
```
</details>

## ПараметрыПодключенияПоУчастникуСБП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры подключения, оплаты и аутентификации для участника СБП.
//
// Параметры:
//  УчастникСБП - Строка - идентификатор участника СБП для которого получается настройка.
//
// Возвращаемое значение:
//  Структура - результат выполнения:
//   * ПараметрыНастройкиПодключения - Массив из Структура - содержит описание и значения полей реквизитов справочника
//       "НастройкиПодключенияКСистемеБыстрыхПлатежей".
//   * ПараметрыОплаты - Структура - настройки приема оплат:
//      ** c2b - Массив из Структура, Неопределено - содержит описание и значения полей регистра сведений,
//         хранящего данные о настройках оплат.
//   * ПараметрыАутентификации - Массив из Структура - описание и значения параметров аутентификации.
//
Функция ПараметрыПодключенияПоУчастникуСБП(УчастникСБП) Экспорт
```

Пример вызова
```bsl
Результат = СистемаБыстрыхПлатежей.ПараметрыПодключенияПоУчастникуСБП(УчастникСБП) 
```
</details>

## ПараметрыПодключенияПоНастройке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры подключения, оплаты и аутентификации для переданного по ссылке элемента справочника
// "НастройкиПодключенияКСистемеБыстрыхПлатежей".
//
// Параметры:
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей - ссылка на элемент справочника
//    для которого нужно получить параметры подключения.
//
// Возвращаемое значение:
//  Структура - результат выполнения:
//   * ПараметрыНастройкиПодключения - Массив из Структура - содержит описание и значения полей реквизитов элемента справочника
//       "НастройкиПодключенияКСистемеБыстрыхПлатежей";
//   * ПараметрыОплаты - Структура - настройки приема оплат:
//      ** c2b - Массив из Структура, Неопределено - содержит описание и значения полей регистра сведений,
//         хранящего данные о настройках оплат.
//   * ПараметрыАутентификации - Массив из Структура - описание и значения параметров аутентификации.
//
Функция ПараметрыПодключенияПоНастройке(НастройкаПодключения) Экспорт
```

Пример вызова
```bsl
Результат = СистемаБыстрыхПлатежей.ПараметрыПодключенияПоНастройке(НастройкаПодключения) 
```
</details>

## ПроверитьПараметрыПодключения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает результат проверки подключения по переданным параметрам.
//
// Параметры:
//  ИдентификаторУчастника - Строка - идентификатор участника СБП для которого производится настройка.
//  ПараметрыАутентификации - Массив из Структура - описание и значения параметров аутентификации.
//
// Возвращаемое значение:
//  Структура - результат проверки параметров подключения:
//   * ПодключениеУстановлено - Булево, Истина - если подключение выполнено успешно;
//   * СообщениеОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке для пользователя.
//
Функция ПроверитьПараметрыПодключения( Экспорт
```

Пример вызова
```bsl
Результат = СистемаБыстрыхПлатежей.ПроверитьПараметрыПодключения();
```
</details>

## ЗаписатьПараметрыПодключения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет настройки подключения к СБП в информационную базу.
//
// Параметры:
//  НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей - ссылка на элемент справочника,
//    данные которого нужно записать. Пустая, если нужно записать новый элемент.
//  НастройкиЗаполнения - Структура - описание сохраняемых данных:
//   * ПараметрыНастройкиПодключения - Массив из Структура - содержит описание и значения полей реквизитов элемента справочника
//       "НастройкиПодключенияКСистемеБыстрыхПлатежей";
//   * ПараметрыОплаты - Структура - настройки приема оплат:
//      ** c2b - Массив из Структура, Неопределено - содержит описание и значения полей регистра сведений,
//         хранящего данные о настройках оплат.
//   * ПараметрыАутентификации - Массив из Структура - описание и значения параметров аутентификации.
//  ИдентификаторУчастника - Строка - идентификатор участника СБП для которого производится настройка.
//
// Возвращаемое значение:
//  Структура - результат создания торговой точки:
//   * НастройкаПодключения - СправочникСсылка.НастройкиПодключенияКСистемеБыстрыхПлатежей - ссылка на элемент справочника;
//   * Ошибка - Булево - признак ошибки сохранения;
//   * СообщениеОбОшибке  - Строка, ФорматированнаяСтрока - сообщение об ошибке для пользователя;
//   * ИнформацияОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке для администратора.
//
Функция ЗаписатьПараметрыПодключения( Экспорт
```

Пример вызова
```bsl
Результат = СистемаБыстрыхПлатежей.ЗаписатьПараметрыПодключения();
```
</details>

## ШаблоныСообщенийПоТипам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает перечень предопределенных шаблонов сообщений подсистемы, структурированный по типам назначения.
//
// Возвращаемое значение:
//  Структура - перечень предопределенных шаблонов сообщений подсистемы, структурированный по сценариям перевода.
//   * c2b - Структура - перечень предопределенных шаблонов сообщений c2b сценария,
//       структурированный по типам назначения.
//     ** Ключ - Строка - тип назначения шаблона, может принимать значения - Письмо, SMS.
//     ** Значение - Массив из СправочникСсылка.ШаблоныСообщений - перечень предопределенных шаблонов по типу.
//
Функция ШаблоныСообщенийПоТипам() Экспорт
```

Пример вызова
```bsl
Результат = СистемаБыстрыхПлатежей.ШаблоныСообщенийПоТипам() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
