---
title: Система быстрых платежей переопределяемый
slug: erp-uh/система-быстрых-платежей-переопределяемый
---


## ПриОпределенииНастроекПодключения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет прикладные настройки работы с Системой быстрых платежей.
//
// Параметры:
//  Настройки - Структура - настройки работы с Системой быстрых платежей:
//    * c2b - Структура, Неопределено - настройки выполнения операций c2b:
//      ** ОбъектМетаданных - Метаданные.РегистрыСведений - объект метаданных регистр сведений,
//        в котором хранятся настройки выполнения оплат. Регистр определяет связь торговой точки
//        Системы быстрых платежей и аналитики ведения учета в программах 1С. На основании данных
//        регистра должен выполняется поиск настройки подключения при выполнении
//        оплат и возвратов;
//      ** ИсключаемыеПоля - Массив Из Строка - наименования измерений, ресурсов или реквизитов, которые
//        необходимо скрыть на форме настройки подключения.
//      ** ИспользоватьЧастичныеОплаты - Булево - признак использования функциональности частичных оплат.
//      ** ИспользоватьНастройкуКассовыхСсылок - Булево - признак использования функциональности
//           добавления кассовых ссылок в мастере настройки подключения к СБП.
//      ** ШаблоныНазначений - ТаблицаЗначений - настройки заполнения шаблонов платежей:
//        *** ОбъектМетаданных - Строка - имя объекта метаданных операции.
//        *** Идентификатор - Строка - идентификатор шаблона.
//        *** Наименование - Строка - наименование шаблона для пользователя.
//        *** Параметры - Структура - параметры заполнения шаблона:
//          **** Наименование - Строка - наименование параметра для пользователя.
//          **** Идентификатор - Строка - идентификатор параметра для заполнения.
//            Идентификатор должен быть уникальный для каждого параметра и для всех шаблонов.
//
//@skip-warning
Процедура ПриОпределенииНастроекПодключения(Настройки) Экспорт
```

Пример вызова
```bsl
СистемаБыстрыхПлатежейПереопределяемый.ПриОпределенииНастроекПодключения(Настройки) 
```
</details>

## ПриЗаписиНастроекПодключения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет алгоритм записи настроек оплат в регистр сведений указанный в методе
// СистемаБыстрыхПлатежейПереопределяемый.ПриОпределенииНастроекПодключения.
//
// Параметры:
//  ПараметрыОплаты - Структура - настройки выполнения оплат:
//    * c2b - Соответствие, Неопределено - содержит данные для записи настроек в регистр сведений.
//       Структура параметра соответствует структуре регистра, которая определена
//       в метаданных за исключением полей указанных в настройках в свойстве ИсключаемыеПоля
//       процедуры СистемаБыстрыхПлатежейПереопределяемый.ПриОпределенииНастроекПодключения
//       (см. Настройки.c2b.ОбъектМетаданных).
//  Отказ - Булево - следует устанавливать значение Истина, если в процессе записи возникли ошибки;
//  СообщениеОбОшибке - Строка - сообщение для пользователя. Отображается в случае, если в параметр
//    Отказ установлено значение Истина.
//
Процедура ПриЗаписиНастроекПодключения( Экспорт
```

Пример вызова
```bsl
СистемаБыстрыхПлатежейПереопределяемый.ПриЗаписиНастроекПодключения();
```
</details>

## ПриНастройкеЭлементовФормыПодключения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет настроить элементы настройки приема оплат на формах подключения
// к Системе быстрых платежей.
//
// Параметры:
//  НастройкиФормы - Структура - содержит элементы формы и текущие значения реквизитов:
//    * ОбщиеЭлементы - Структура - общие настройки формы подключения к Системой быстрых платежей:
//      ** Наименование - Элемент - элемент формы, в котором заполняется наименование;
//      ** ДекорацияДополнительнаяИнформация - Элемент - элемент формы, в котором заполняется наименование;
//    * c2b - Структура, Неопределено - настройки элементов и значения настроек для переводов c2b:
//      ** ЭлементыНастроекОплаты - Структура - элементы формы настройки оплаты. Структура параметра
//        соответствует структуре регистра, который определяется в методе
//        СистемаБыстрыхПлатежейПереопределяемый.ПриОпределенииНастроекПодключения, за исключением
//        полей указанных в настройках в свойстве ИсключаемыеПоля.
//      ** ЗначенияНастроекОплаты - Структура - текущее значение реквизитов настроек. Структура параметра
//        соответствует структуре регистра, который определяется в методе
//        СистемаБыстрыхПлатежейПереопределяемый.ПриОпределенииНастроекПодключения, за исключением
//        полей указанных в настройках в свойстве ИсключаемыеПоля:
//  ДополнительныеПараметры - Структура, Неопределено - дополнительные параметры настройки подключения с
//    Системой быстрых платежей, которые передаются в методе СистемаБыстрыхПлатежейКлиент.ПодключитьСистемуБыстрыхПлатежей.
//
//@skip-warning
Процедура ПриНастройкеЭлементовФормыПодключения( Экспорт
```

Пример вызова
```bsl
СистемаБыстрыхПлатежейПереопределяемый.ПриНастройкеЭлементовФормыПодключения();
```
</details>

## ПриЗаполненииФормыНастройкиПодключения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Позволяет предзаполнить настройки приема платежей на формах подключения
// к Системе быстрых платежей.
//
// Параметры:
//  Настройки - Структура - содержит элементы формы и текущие значения реквизитов:
//    * ОбщиеНастройки - Структура - общие настройки формы подключения к Системой быстрых платежей:
//      ** Наименование - Строка - значение заполнения поля наименование;
//    * НастройкиОплаты - Структура - значение заполнения реквизитов настройки приема оплат.
//        ** c2b - Структура, Неопределено - значение заполнения реквизитов настройки приема оплат. Структура параметра
//           соответствует структуре регистра, который определяется в методе
//           СистемаБыстрыхПлатежейПереопределяемый.ПриОпределенииНастроекПодключения, за исключением
//           полей указанных в настройках в свойстве ИсключаемыеПоля;
//    * НастройкиУчастникаСБП - Структура - содержит настройки участника СБП:
//      ** Наименование - Строка - наименование участника СБП;
//      ** ИНН - Строка - ИНН участника СБП;
//      ** ПлатежныйАгрегатор - Булево - признак того что участник СБП является платежным агрегатором;
//      ** БИК - Массив из Строка - содержит перечень БИК участника СБП;
//  ДополнительныеПараметры - Структура, Неопределено - дополнительные параметры настройки подключения с
//    Системой быстрых платежей, которые передаются в методе СистемаБыстрыхПлатежейКлиент.ПодключитьСистемуБыстрыхПлатежей.
//
//@skip-warning
Процедура ПриЗаполненииФормыНастройкиПодключения( Экспорт
```

Пример вызова
```bsl
СистемаБыстрыхПлатежейПереопределяемый.ПриЗаполненииФормыНастройкиПодключения();
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
