---
title: Скидки наценки заполнение сервер
slug: erp-uh/скидки-наценки-заполнение-сервер
---


## НеобходимПерерасчетСкидок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция проверяет необходимость расчета скидок объекта.
//
// Параметры:
//  Объект - ДанныеФормыСтруктура - проверяемый объект
//  УправляемыеСкидки - СписокЗначений - список управляемых скидок
//  ИдентификаторФормы - УникальныйИдентификатор - уникальный идентификатор формы
//  РассчитанныеСкидкиАдресВХранилище - Строка - адрес хранилища, куда будут помещены рассчитанные скидки/наценки.
//
// Возвращаемое значение:
//  Булево -
//
Функция НеобходимПерерасчетСкидок( Экспорт
```

Пример вызова
```bsl
Результат = СкидкиНаценкиЗаполнениеСервер.НеобходимПерерасчетСкидок();
```
</details>

## ОтменитьСкидки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура отменяет рассчитанные по объекту скидки.
// Вызывается из форм документов.
//
// Параметры:
//  Объект - ДокументОбъект, ДанныеФормыСтруктура - Объект, в котором требуется рассчитать скидки (наценки).
//  ИмяТЧ - Строка - Имя табличной части.
//  РассчитыватьСуммуСНДС - Булево - Рассчитывать сумму с НДС.
//  РассчитыватьСуммуВзаиморасчетов - Булево - Рассчитывать сумму взаиморасчетов.
//  ОтменитьТолькоАвтоСкидки - Булево - Отменить только автоматические скидки (наценки).
//
Процедура ОтменитьСкидки( Экспорт
```

Пример вызова
```bsl
СкидкиНаценкиЗаполнениеСервер.ОтменитьСкидки();
```
</details>

## Рассчитать
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Выполняет расчет скидок по документу.
// Вызывается из форм документов.
//
// Параметры:
//  Объект - см. СкидкиНаценкиСервер.Рассчитать.Объект
//  ВходныеПараметры - см. НовыйПараметрыРассчитать
//
// Возвращаемое значение:
// 	см. СкидкиНаценкиСервер.Рассчитать
//
Функция Рассчитать(Объект, ВходныеПараметры) Экспорт
```

Пример вызова
```bsl
Результат = СкидкиНаценкиЗаполнениеСервер.Рассчитать(Объект, ВходныеПараметры) 
```
</details>

## ПрименитьРезультатРасчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура применяет результат расчет скидок к документу.
// Вызывается из форм документов.
//
// Параметры:
//  Объект - ДокументОбъект, ДанныеФормыСтруктура - Объект, в котором требуется рассчитать скидки (наценки).
//  ПримененныеСкидки - см. Рассчитать
//  РеализацияСверхЗаказа - Булево - Реализация сверх заказа.
//
Процедура ПрименитьРезультатРасчета(Объект, ПримененныеСкидки, РеализацияСверхЗаказа = Ложь) Экспорт
```

Пример вызова
```bsl
СкидкиНаценкиЗаполнениеСервер.ПрименитьРезультатРасчета(Объект, ПримененныеСкидки, РеализацияСверхЗаказа);
```
</details>

## НазначитьРучнуюСкидку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Процедура назначает ручные скидки в табличной части
//
// Параметры:
//  Объект - ДокументОбъект, ДанныеФормыСтруктура - Объект, в котором требуется рассчитать скидки (наценки).
//  ИмяТЧ - Строка - Имя табличной части.
//  СуммаСкидкиКРаспределению - Число - Сумма скидки (наценки) к распределению.
//  ВходныеПараметры - см. НовыйПараметрыНазначитьРучнуюСкидку
//
Процедура НазначитьРучнуюСкидку(Объект, ИмяТЧ, СуммаСкидкиКРаспределению, ВходныеПараметры) Экспорт
```

Пример вызова
```bsl
СкидкиНаценкиЗаполнениеСервер.НазначитьРучнуюСкидку(Объект, ИмяТЧ, СуммаСкидкиКРаспределению, ВходныеПараметры) 
```
</details>

## ОтменитьРучныеСкидки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl



// Процедура выполняет отмену ручных скидок в табличной части
//
// Параметры:
//  Объект - ДокументОбъект, ДанныеФормыСтруктура - Объект, в котором требуется рассчитать скидки (наценки).
//  ИмяТЧ - Строка - Имя табличной части.
//  ИспользуютсяАвтоматическиеСкидки - Булево - Признак использования автоматических скидок (наценок).
//  РассчитыватьСуммуСНДС - Булево - Рассчитывать сумму с НДС.
//  РассчитыватьСуммуВзаиморасчетов - Булево - Рассчитывать сумму взаиморасчетов.
//  РеализацияСверхЗаказа - Булево - Реализация сверх заказа.
//  ДополнительныеПараметры - Структура,Неопределено - Дополнительные параметры отмены скидок :
//  	* ИмяКолонкиКоличество - Строка - имя колонки с полем Количество.
//
Процедура ОтменитьРучныеСкидки(Объект, ИмяТЧ, ИспользуютсяАвтоматическиеСкидки, РассчитыватьСуммуСНДС, Экспорт
```

Пример вызова
```bsl
СкидкиНаценкиЗаполнениеСервер.ОтменитьРучныеСкидки(Объект, ИмяТЧ, ИспользуютсяАвтоматическиеСкидки, РассчитыватьСуммуСНДС, );
```
</details>

## АдресДанныхДляРасчетаРучныхСкидокВоВременномХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Адрес данных для расчета ручных скидок во временном хранилище
//
// Параметры:
//  Форма						 - ФормаКлиентскогоПриложения - Форма
//  УникальныйИдентификатор		 - УникальныйИдентификатор - адрес во временном хранилище
//  Параметры					 - см. НовыйПараметрыАдресДанныхДляРасчетаРучныхСкидок
//
// Возвращаемое значение:
//  Строка - Адрес во временном хранилище.
//
Функция АдресДанныхДляРасчетаРучныхСкидокВоВременномХранилище( Экспорт
```

Пример вызова
```bsl
Результат = СкидкиНаценкиЗаполнениеСервер.АдресДанныхДляРасчетаРучныхСкидокВоВременномХранилище();
```
</details>

## АдресДанныхДляРасчетаРучныхСкидокВоВременномХранилищеЗакупки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Адрес данных для расчета ручных скидок во временном хранилище закупки
//
// Параметры:
//  Форма						 - ФормаКлиентскогоПриложения - Форма
//  УникальныйИдентификатор		 - УникальныйИдентификатор - адрес во временном хранилище
//  Параметры		 			 - см. НовыйПараметрыАдресДанныхДляРасчетаРучныхСкидок
//
// Возвращаемое значение:
//  Строка - Адрес во временном хранилище.
//
Функция АдресДанныхДляРасчетаРучныхСкидокВоВременномХранилищеЗакупки( Экспорт
```

Пример вызова
```bsl
Результат = СкидкиНаценкиЗаполнениеСервер.АдресДанныхДляРасчетаРучныхСкидокВоВременномХранилищеЗакупки();
```
</details>

## СкидкиНаценкиПоЗаказу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


//
// Параметры:
//  Объект - ДокументОбъект.РеализацияТоваровУслуг - Объект.
//
// Возвращаемое значение:
//  Структура - со свойствами:
//   * ТаблицаТоваров - ТаблицаЗначений- колонки:
//  	** КодСтроки 				- Число - код строки документа ЗаказКлиента,ЗаявкаНаВозвратТоваровОтКлиента
//  	** КлючСвязи 				- Число - ключ связи строки документа ЗаказКлиента,ЗаявкаНаВозвратТоваровОтКлиента
//  	** Коэффициент 				- Число -
//  	** ПроцентАвтоматическойСкидки - Число -
//  	** ПроцентРучнойСкидки 		- Число -
//  	** ЗаказКлиента 				- ДокументСсылка.ЗаказКлиента,ДокументСсылка.ЗаявкаНаВозвратТоваровОтКлиента -
//  	** РеализацияКоличество 		- Число -
//  	** ЗаказКоличество 			- Число -
//  	** ЗаказСуммаАвтоматическойСкидки - Число -
//  	** ЗаказСуммаРучнойСкидки 	- Число -
//  	** ВалютаКоэффициентПересчета - Число -
//  	** СуммаАвтоматическойСкидки - Число -
//  	** СуммаРучнойСкидки 		- Число -
//   * СкидкиНаценкиЗаказа - ТаблицаЗначений - колонки:
//  	** КлючСвязи 	- Число -
//  	** СкидкаНаценка - СправочникСсылка.СкидкиНаценки -
//  	** Сумма 		- Число - сумма скидки/наценки с учетом коэффициента пересчета
//  	** ЗаказКлиента  - ДокументСсылка.ЗаказКлиента, ДокументСсылка.ЗаявкаНаВозвратТоваровОтКлиента -
//
Функция СкидкиНаценкиПоЗаказу(Объект) Экспорт
```

Пример вызова
```bsl
Результат = СкидкиНаценкиЗаполнениеСервер.СкидкиНаценкиПоЗаказу(Объект) 
```
</details>

## СохранитьОтработанныеСообщения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl



// Выполняет сохранение отработанных сообщений.
//
// Параметры:
//  Объект - ДанныеФормыСтруктура - Объект.
//  Сообщения - Массив - Сообщения к сохранению.
//
Процедура СохранитьОтработанныеСообщения(Объект, Сообщения) Экспорт
```

Пример вызова
```bsl
СкидкиНаценкиЗаполнениеСервер.СохранитьОтработанныеСообщения(Объект, Сообщения) 
```
</details>

## СтруктураСообщений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую сообщения для объекта.
//
// Параметры:
//  Объект - ДанныеФормыСтруктура, ДокументОбъект - Объект.
//  ДополнительныеПараметры - Структура - возможность определить имена реквизитов, НЕ обязательный:
//  	* ИмяРеквизитаПартнер -Строка - наличие не обязательно
//  	* НеВыводитьСообщенияПоСоглашению -Булево - наличие не обязательно
//
// Возвращаемое значение:
//  Структура - со свойствами:
//   * Сообщения - Массив - массив структур с ключами "СкидкаНаценка, НапомнитьПозже"
//   * АвтоматическиОткрывать - Булево - Автоматически открывать сообщение.
//   * КартаЛояльности - СправочникСсылка.КартыЛояльности - Карта лояльности.
//   * Партнер - СправочникСсылка.Партнеры - Партнер.
//   * Контрагент - СправочникСсылка.Контрагенты -
//
Функция СтруктураСообщений(Объект, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СкидкиНаценкиЗаполнениеСервер.СтруктураСообщений(Объект, ДополнительныеПараметры);
```
</details>

## НастроитьКомандуПоказатьСообщения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Настраивает отображение команды показать сообщения на форме.
//
// Параметры:
//  Объект - ДанныеФормыСтруктура - Объект.
//  ЭлементФормы - КнопкаФормы - Элемент формы.
//  Видимость - Булево - Признак видимости элемента формы.
//  ДополнительныеПараметры - см. СтруктураСообщений.ДополнительныеПараметры
//
Процедура НастроитьКомандуПоказатьСообщения(Объект, ЭлементФормы, Видимость = Истина, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
СкидкиНаценкиЗаполнениеСервер.НастроитьКомандуПоказатьСообщения(Объект, ЭлементФормы, Видимость, ДополнительныеПараметры);
```
</details>

## НовыйПараметрыРассчитать
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор параметра метода Рассчитать().
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * ТолькоПредварительныйРасчет - Булево - Только предварительный расчет.
//   * ПрименятьКОбъекту - Булево - Применять к объекту.
//   * ВосстанавливатьУправляемыеСкидки - Булево - Восстанавливать управляемые скидки (наценки).
//   * УправляемыеСкидки - СписокЗначений из СправочникСсылка.СкидкиНаценки - Управляемые скидки (наценки).
//  в зависимости от документа.
//   * РеализацияСверхЗаказа - Булево - для Документ.РеализацияТоваровУслуг.
//   * ИмяКолонкиУпаковка - Строка - для Документ.КоммерческоеПредложениеКлиенту.
//   * ИмяКолонкиКоличествоУпаковок - Строка - для Документ.КоммерческоеПредложениеКлиенту.
//   * ЗаполнитьРеализациюПоЗаказу - Булево - для Документ.РеализацияТоваровУслуг при РеализацияПоЗаказам = Истина.
//
Функция НовыйПараметрыРассчитать() Экспорт
```

Пример вызова
```bsl
Результат = СкидкиНаценкиЗаполнениеСервер.НовыйПараметрыРассчитать() 
```
</details>

## НовыйПараметрыНазначитьРучнуюСкидку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор параметра ВходныеПараметры метода НазначитьРучнуюСкидку()
//
// Возвращаемое значение:
//  Структура - Структура со свойствами, все свойства необязательные к существованию:
//   * ИспользуютсяАвтоматическиеСкидки - Булево -
//   * ТолькоДляАктивныхСтрок - Булево -
//   * РассчитыватьСуммуСНДС - Булево -
//   * РассчитыватьСуммуВзаиморасчетов - Булево -
//   * РеализацияСверхЗаказа - Булево -
//   * ВыделенныеСтроки - Массив,Неопределено -
//   * АдресВоВременномХранилище - Строка,Неопределено -
//   * ИмяКолонкиКоличество - Строка,Неопределено -
//
Функция НовыйПараметрыНазначитьРучнуюСкидку() Экспорт
```

Пример вызова
```bsl
Результат = СкидкиНаценкиЗаполнениеСервер.НовыйПараметрыНазначитьРучнуюСкидку() 
```
</details>

## НовыйПараметрыАдресДанныхДляРасчетаРучныхСкидок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор параметра ПараметрыВызова метода АдресДанныхДляРасчетаРучныхСкидокВоВременномХранилище().
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//		* ИмяТаблицы 				 - Строка - Только предварительный расчет.
//		* ИмяТаблицыВыделенныхСтрок	 - Строка,Неопределено - Имя таблицы выделенных строк.
//		* ТолькоДляВыделенныхСтрок	 - Булево - Использовать только для выделенных строк.
//		* ТолькоАктивныеСтроки		 - Булево - Только активные строки.
//		* ИспользоватьОграничения	 - Булево - Использовать ограничения.
//		* РеализацияСверхЗаказа		 - Булево - Использовать реализацию сверх заказа.
//
Функция НовыйПараметрыАдресДанныхДляРасчетаРучныхСкидок() Экспорт
```

Пример вызова
```bsl
Результат = СкидкиНаценкиЗаполнениеСервер.НовыйПараметрыАдресДанныхДляРасчетаРучныхСкидок() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
