---
title: Склады сервер
slug: erp-uh/склады-сервер
---


## РазместитьТоварВЯчейках
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура формирует таблицу размещения товара по ячейках хранения.
// В текущей версии алгоритма учитывается:
// - блокировки ячеек;
// - области хранения по приоритетам для каждой упаковки каждой номенклатуры;
// - уровни доступности ячеек;
// - контроль габаритов (в ячейку не размещается товар, который больше ее по любому габариту (если только ячейка
// 	не неограниченная по размерам);
// - контроль занятого объема в ячейке с учетом уже хранимого товара, товара к размещению и товара, обрабатываемого алгоритмом
// 	(для неограниченных по размерам ячеек не контролируется);
// - контроль занятого веса в ячейке с учетом уже хранимого товара, товара к размещению и товара, обрабатываемого алгоритмом
// 	(для неограниченных по грузоподъемности ячеек не контролируется);
// - безразмерные упаковки размещаются только в неограниченные по размерам ячейки.
//
// Параметры:
//  МенеджерВременныхТаблиц	 - МенеджерВременныхТаблиц - менеджер временных таблиц запроса, создавшего пул номенклатуры к размещению
//  	  процедура не удаляет временные таблицы, управляемые менеджером
//  Склад					 -  СправочникСсылка.Склады - склад, на котором необходимо разместить товар
//  Помещение				 - 	СправочникСсылка.СкладскиеПомещения - складское помещение, в котором располагаются ячейки, если используется деление
//  	  адресов хранения по помещениям, если не используется необходимо передавать пустую ссылку.
//
//  РабочийУчасток			 - СправочникСсылка.РабочиеУчастки - будут подобраны ячейки по правилам размещения,
//																с учетом всех приоритетов, а потом ограничены переданному участку.
//																Если передана пустая ссылка, то ограничения по участкам действовать не будет
//  ЯчейкаИсточник			 - СправочникСсылка.СкладскиеЯчейки	 - ячейка, из которой происходит размещение товаров. Передается, когда это
//																зона приемки или отгрузки. Нужна для того, чтобы рассчитать количество свободной
//																тары в ячейке и НЕ размещать тару, которая нужна для лежащих в ячейке товаров.
//  ОшибкаПроверки			 - Булево - возвращаемый признак наличия ошибки проверки правильности заполнения параметров для размещаемой номенклатуры
//  ДополнятьМногооборотнойТарой - Булево - для заданных упаковок будет добавлена указанная в них тара
//
// Возвращаемое значение:
//   Структура - структура со следующими ключами:
//	* ТаблицаРезультатов - ТаблицаЗначений - подобранные по алгоритму размещения ячейки:
//		** Номенклатура - СправочникСсылка.Номенклатура -
//		** Упаковка - СправочникСсылка.УпаковкиЕдиницыИзмерения -
//		** Ячейка - СправочникСсылка.СкладскиеЯчейки -
//		** Характеристика - СправочникСсылка.ХарактеристикиНоменклатуры -
//		** Назначение - СправочникСсылка.Назначения -
//		** Серия - СправочникСсылка.СерииНоменклатуры -
//		** КоличествоУпаковок - Число -
//		** Количество - Число -
//		** ВесУпаковки - Число -
//		** ОбъемУпаковки - Число -
//		** ПорядокОбхода - Число -
//		** Код - Число -
//		** РабочийУчасток - СправочникСсылка.РабочиеУчастки -
//	* ТаблицаОшибок - ТаблицаЗначений - товары, для которых не удалось подобрать ячейки для размещения:
//		** Номенклатура - СправочникСсылка.Номенклатура -
//		** Упаковка - СправочникСсылка.УпаковкиЕдиницыИзмерения -
//		** Характеристика - СправочникСсылка.ХарактеристикиНоменклатуры -
//		** Серия - СправочникСсылка.СерииНоменклатуры -
//		** КоличествоУпаковок - Число -
//		** Количество - Число -
//		** Назначение - СправочникСсылка.Назначения -
//  * МассивУчастков - Массив из СправочникСсылка.РабочиеУчастки - массив ссылок на рабочие участки подобранных ячеек.
//
Функция РазместитьТоварВЯчейках(МенеджерВременныхТаблиц, Склад, Помещение, РабочийУчасток, Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.РазместитьТоварВЯчейках(МенеджерВременныхТаблиц, Склад, Помещение, РабочийУчасток, );
```
</details>

## ОтобратьТоварИзЯчеек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура формирует таблицу отбора товара из ячеек хранения.
// В текущей версии алгоритма учитывается:
//	- блокировки ячеек;
//	- уровни доступности ячеек;
//	- остатки товара нужной характеристики в необходимой упаковке в ячейке.
//
// Параметры:
//	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - менеджер временных таблиц запроса, создавшего пул номенклатуры к размещению.
//		Процедура не удаляет временные таблицы, управляемые менеджером.
//	Склад - СправочникСсылка.Склады - склад, на котором необходимо разместить товар.
//	Помещение - СправочникСсылка.СкладскиеПомещения - складское помещение, в котором располагаются ячейки, если используется деление
//		адресов хранения по помещениям, если не используется необходимо передавать пустую ссылку.
//
// Возвращаемое значение:
//	Структура - см. СтруктураТаблицАлгоритмаОтборТоваров
//
Функция ОтобратьТоварИзЯчеек(МенеджерВременныхТаблиц, Склад, Помещение) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ОтобратьТоварИзЯчеек(МенеджерВременныхТаблиц, Склад, Помещение) 
```
</details>

## ПолучитьУпаковки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает таблицу упаковок, используемых для номенклатуры.
//
// Параметры:
//	Номенклатура - СправочникСсылка.Номенклатура - номенклатура, для которой необходимо получить список упаковок;
//	БазовыеВНачале - Булево - Истина - признак сортировки упаковок в таблице;
//	СкладскаяГруппа - СправочникСсылка.СкладскиеГруппыУпаковок - складская группа упаковок.
//
// Возвращаемое значение:
//	ТаблицаЗначений - таблица значений со следующими колонками:
//		* Упаковка				- СправочникСсылка.УпаковкиЕдиницыИзмерения - упаковка номенклатуры;
//		* Коэффициент			- Число - коэффициент упаковки по отношению к единице хранения номенклатуры;
//		* КоличествоУпаковок 	- Число - заполняется 0;
//		* Количество			- Число - заполняется 0.
//
Функция ПолучитьУпаковки(Номенклатура, БазовыеВНачале = Ложь, СкладскаяГруппа = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ПолучитьУпаковки(Номенклатура, БазовыеВНачале, СкладскаяГруппа);
```
</details>

## РазбитьУпаковками
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура реализует алгоритм оптимального распределения товара по упаковкам.
//  Модифицирует параметр ТаблицаУпаковок, заполняя колонки "КоличествоУпаковок", "Количество".
//
// Параметры:
//  ТаблицаУпаковок		 - ТаблицаЗначений	 - таблица упаковок:
//  	* Упаковка				- СправочникСсылка.УпаковкиЕдиницыИзмерения - упаковка номенклатуры;
//  	* Коэффициент			- Число - коэффициент упаковки по отношению к единице хранения номенклатуры;
//  	* КоличествоУпаковок 	- Число - количество упаковок номенклатуры;
//  	* Количество			- Число - количество номенклатуры в единицах хранения.
//  ТребуемоеКоличество	 - Число			 - количество номенклатуры, которое необходимо распределить.
//
Процедура РазбитьУпаковками(ТаблицаУпаковок, Знач ТребуемоеКоличество) Экспорт
```

Пример вызова
```bsl
СкладыСервер.РазбитьУпаковками(ТаблицаУпаковок, ТребуемоеКоличество) 
```
</details>

## ВыполнитьПодпиткуЗБОНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция запускает подпитку зон быстрого отбора по "Складу" и "Помещению".
//
// Параметры:
// 		Склад - СправочникСсылка.Склады - Склад на котором будет выполнятся подпитка
// 		Помещение - СправочникСсылка.СкладскиеПомещения - Помещение  на котором будет выполнятся подпитка
// 		ПараметрыФормированияЗаданий - Структура - параметры, по которым будут разбиты задания на переупаковку.
//
// Возвращаемое значение:
// 		Строка - Сообщение об ошибке.
//
Функция ВыполнитьПодпиткуЗБОНаСервере(Склад, Помещение, ПараметрыФормированияЗаданий) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ВыполнитьПодпиткуЗБОНаСервере(Склад, Помещение, ПараметрыФормированияЗаданий) 
```
</details>

## ПоказатьВременнуюТаблицу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция формирует запрос по временной таблице.
//
// Параметры:
//	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - менеджер временных таблиц запроса;
//	ИмяВременнойТаблицы - Строка - Имя временной таблицы.
//
//
// Возвращаемое значение:
//	ТаблицаЗначений - результат выборки временной таблицы из менеджера временных таблиц.
Функция ПоказатьВременнуюТаблицу(МенеджерВременныхТаблиц,ИмяВременнойТаблицы) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ПоказатьВременнуюТаблицу(МенеджерВременныхТаблиц, ИмяВременнойТаблицы) 
```
</details>

## ПрогнозРасходаУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод регламентного задания РасчетПоказателейПрогнозаРасходаУпаковок.
// Производит расчет прогноза расхода упаковок, который в дальнейшем используется для упреждающей подпитки.
//
// Параметры:
//	Склад - СправочникСсылка.Склады - склад, для которого рассчитывается прогноз расхода упаковок;
//	Помещение - СправочникСсылка.СкладскиеПомещения - складское помещение, для которого рассчитывается прогноз.
//
Процедура ПрогнозРасходаУпаковок(Склад, Помещение) Экспорт
```

Пример вызова
```bsl
СкладыСервер.ПрогнозРасходаУпаковок(Склад, Помещение) 
```
</details>

## ЗаполнитьСкладыВТабличнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет заполнение складов в табличной части документа.
//
// Параметры:
//	Склад - СправочникСсылка.Склады - Склад, выбранный в шапке документа;
//	СкладГруппа - Булево - Флаг, по которому можно определить, что в шапке документа выбран склад группа;
//	Товары - ДокументТабличнаяЧасть.ЗаказПоставщику.Товары - Таблица товаров документа;
//	ИсключитьГруппыДоступныеВЗаказах - Булево - Истина - признак исключения группы складов, доступных в заказах.
//
Процедура ЗаполнитьСкладыВТабличнойЧасти(Знач Склад, Знач СкладГруппа, Товары, ИсключитьГруппыДоступныеВЗаказах) Экспорт
```

Пример вызова
```bsl
СкладыСервер.ЗаполнитьСкладыВТабличнойЧасти(Склад, СкладГруппа, Товары, ИсключитьГруппыДоступныеВЗаказах) 
```
</details>

## ЗаполнитьСкладыВВыделенныхСтроках
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция производит заполнение реквизита "Склад" в выделенных строках табличной части
// Реквизит склад должен быть заполнен только в строках с номенклатурой типа "Перечисление.ТипыНоменклатуры.Товар".
//
// Параметры:
// 		ТабличнаяЧасть - ДанныеФормыКоллекция - Табличная часть формы для заполнения реквизита товары
// 		ВыделенныеСтроки - Массив - Массив выделенных строк табличной части
// 		СкладЗаполнения - СправочникСсылка.Склады - Склад для заполнения реквизита "Склад" табличной части
// 		ПроверятьКодСтроки - Булево - Флаг необходимость проверять код строки.
//
// Возвращаемое значение:
// 		Число - Количество заполненных строк.
//
Функция ЗаполнитьСкладыВВыделенныхСтроках(ТабличнаяЧасть, ВыделенныеСтроки, СкладЗаполнения, ПроверятьКодСтроки = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ЗаполнитьСкладыВВыделенныхСтроках(ТабличнаяЧасть, ВыделенныеСтроки, СкладЗаполнения, ПроверятьКодСтроки);
```
</details>

## ПриИзмененииСкладаВТабличнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет служебный реквизит формы данными о количестве складов используемых в табличной части документа.
//
//  Параметры:
//   ТабЧасть - ДанныеФормыКоллекция - таблица с колонками "Склад" и "Отменено" (опционально).
//   ТаблицаСклады - ДанныеФормыКоллекция - служебный реквизит формы, данные которого необходимо заполнить.
//   СкладГруппа - Булево - признак использования различных складов в документе.
//   ЕстьОтменаСтрок - Булево - Истина, если ТабЧасть содержит колонку "Отменено".
//
Процедура ПриИзмененииСкладаВТабличнойЧасти(ТабЧасть, ТаблицаСклады, СкладГруппа, ЕстьОтменаСтрок = Истина) Экспорт
```

Пример вызова
```bsl
СкладыСервер.ПриИзмененииСкладаВТабличнойЧасти(ТабЧасть, ТаблицаСклады, СкладГруппа, ЕстьОтменаСтрок);
```
</details>

## ИспользоватьСкладскиеПомещения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак использования на складе складских помещений.
//
//	Параметры:
//		Склад - СправочникСсылка.Склады - ссылка на элемент справочника "Склады"
//		Дата - Дата - на которую проверяется использование ордерной схемы при отгрузке
//		УчитыватьДату - Булево - признак необходимости учитывать дату начала использования складских помещений.
//
//	Возвращаемое значение:
//		Булево - признак использования складских помещений.
//
Функция ИспользоватьСкладскиеПомещения(Склад, Дата = Неопределено, УчитыватьДату = Истина) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ИспользоватьСкладскиеПомещения(Склад, Дата, УчитыватьДату);
```
</details>

## ИспользоватьАдресноеХранениеСправочно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак использования на складе(помещении) справочного размещения товаров в ячейки.
//
// Параметры:
//  Склад			 - СправочникСсылка.Склады - ссылка на элемент справочника "Склады
//  Помещение		 - СправочникСсылка.СкладскиеПомещения - ссылка на элемент справочника "Складские помещения"
//  Дата			 - Дата - дата, на которую проверяется использование справочного размещения товаров в ячейки
//  УчитыватьДату	 - Булево - признак необходимости учитывать дату.
//
// Возвращаемое значение:
//  Булево - признак использования адресного хранения справочно.
//
Функция ИспользоватьАдресноеХранениеСправочно(Склад, Помещение, Дата = Неопределено, УчитыватьДату = Истина) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ИспользоватьАдресноеХранениеСправочно(Склад, Помещение, Дата, УчитыватьДату);
```
</details>

## ИспользоватьПрогнозРасходаУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак использования на складе(помещении) подпитки зон быстрого отбора.
//
// Параметры:
//  Склад		 - СправочникСсылка.Склады - ссылка на элемент справочника "Склады
//  Помещение	 - СправочникСсылка.СкладскиеПомещения - ссылка на элемент справочника "Складские помещения".
//
// Возвращаемое значение:
//  Булево - признак использования подпитки на складе.
//
Функция ИспользоватьПрогнозРасходаУпаковок(Склад, Помещение) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ИспользоватьПрогнозРасходаУпаковок(Склад, Помещение) 
```
</details>

## ПолучитьПредставлениеСклада
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает строковое представление склада
//
// Параметры:
//  СкладПредставление		 - Строка - строковое представление склада
//  ПомещениеПредставление	 - Строка - строковое представление складского помещения.
//
// Возвращаемое значение:
//  Строка - строковое представление склада.
//
Функция ПолучитьПредставлениеСклада(СкладПредставление, ПомещениеПредставление = "") Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ПолучитьПредставлениеСклада(СкладПредставление, ПомещениеПредставление);
```
</details>

## НачинатьОтгрузкуПослеФормированияЗаданияНаПеревозку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак зависимости начала отгрузки от наличия задания на перевозку.
//
// Параметры:
//  Склад	 - СправочникСсылка.Склады - ссылка на элемент справочника "Склады.
//
// Возвращаемое значение:
//  Булево - признак зависимости начала отгрузки от наличия задания на перевозку.
//
Функция НачинатьОтгрузкуПослеФормированияЗаданияНаПеревозку(Склад) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.НачинатьОтгрузкуПослеФормированияЗаданияНаПеревозку(Склад) 
```
</details>

## ИспользоватьСтатусыОрдеров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак использования на складе статусов приходных или расходных ордеров.
//
// Параметры:
//	Склад - СправочникСсылка.Склады - ссылка на элемент справочника "Склады";
//	ПроверятьПриходные - Булево - проверять статусы приходных ордеров;
//	ПроверятьРасходные - Булево - проверять статусы расходных ордеров.
//
// Возвращаемое значение:
//	Булево - Истина - признак использования статусов ордеров.
//
Функция ИспользоватьСтатусыОрдеров(Склад, ПроверятьПриходные = Истина, ПроверятьРасходные = Истина) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ИспользоватьСтатусыОрдеров(Склад, ПроверятьПриходные, ПроверятьРасходные);
```
</details>

## ИспользоватьСтатусыПересчетовТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак использования на складе статусов приходных или расходных ордеров.
//
// Параметры:
//  Склад	 - СправочникСсылка.Склады	 - ссылка на элемент справочника "Склады".
//
// Возвращаемое значение:
//  Булево - Истина - признак использования статусов ордеров.
//
Функция ИспользоватьСтатусыПересчетовТоваров(Склад) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ИспользоватьСтатусыПересчетовТоваров(Склад) 
```
</details>

## ИспользоватьРабочиеУчастки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак использования на складе(помещении) рабочих участков.
//
// Параметры:
//  Склад		 - СправочникСсылка.Склады			 - ссылка на элемент справочника "Склады;
//  Помещение	 - СправочникСсылка.СкладскиеПомещения	 - ссылка на элемент справочника "Складские помещения".
//
// Возвращаемое значение:
//  Булево - признак использования на складе(помещении) рабочих участков.
//
Функция ИспользоватьРабочиеУчастки(Склад, Помещение) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ИспользоватьРабочиеУчастки(Склад, Помещение) 
```
</details>

## ИспользоватьАдресноеХранение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак использования на складе(помещении) хранения остатков в разрезе ячеек.
//
// Параметры:
//  Склад			 - СправочникСсылка.Склады - ссылка на элемент справочника "Склады
//  Помещение		 - СправочникСсылка.СкладскиеПомещения - ссылка на элемент справочника "Складские помещения"
//  Дата			 - Дата - дата, на которую проверяется использование хранения остатков в разрезе ячеек
//  УчитыватьДату	 - Булево - признак необходимости учитывать дату начала использования адресного хранения.
//
// Возвращаемое значение:
//  Булево - признак использования адресного хранения на складе.
//
Функция ИспользоватьАдресноеХранение(Склад, Помещение = Неопределено, Дата = Неопределено, УчитыватьДату = Истина) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ИспользоватьАдресноеХранение(Склад, Помещение, Дата, УчитыватьДату);
```
</details>

## ИспользоватьОрдернуюСхемуПриОтгрузке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак использования на складе ордерной схемы при отгрузке.
//
// Параметры:
//	Склад	 - СправочникСсылка.Склады - ссылка на элемент справочника "Склады".
//	Дата	 - Дата - дата, на которую проверяется использование ордерной схемы при отгрузке.
//
// Возвращаемое значение:
//	Булево - признак использования ордерной схемы при отгрузке.
//
Функция ИспользоватьОрдернуюСхемуПриОтгрузке(Склад, Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ИспользоватьОрдернуюСхемуПриОтгрузке(Склад, Дата);
```
</details>

## ИспользоватьОрдернуюСхемуПриПоступлении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак использования на складе ордерной схемы при поступлении.
//
// Параметры:
//	Склад			 - СправочникСсылка.Склады - ссылка на элемент справочника "Склады".
//	Дата			 - Дата - дата, на которую проверяется использование ордерной схемы при поступлении.
//	МожетБытьГруппа	 - Булево - признак группы.
//
// Возвращаемое значение:
//	Булево - признак использования ордерной схемы при поступлении.
//
Функция ИспользоватьОрдернуюСхемуПриПоступлении(Склад, Дата = Неопределено, МожетБытьГруппа = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ИспользоватьОрдернуюСхемуПриПоступлении(Склад, Дата, МожетБытьГруппа);
```
</details>

## ИспользоватьОрдернуюСхемуПриОтраженииИзлишковНедостач
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак использования на складе ордерной схемы при отражении излишков, недостач.
//
// Параметры:
//	Склад	 - СправочникСсылка.Склады - ссылка на элемент справочника "Склады".
//	Дата	 - Дата - дата, на которую проверяется использование ордерной схемы при отражении излишков, недостач.
//
// Возвращаемое значение:
//	Булево - признак использования ордерной схемы при отражении излишков, недостач.
//
Функция ИспользоватьОрдернуюСхемуПриОтраженииИзлишковНедостач(Склад, Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ИспользоватьОрдернуюСхемуПриОтраженииИзлишковНедостач(Склад, Дата);
```
</details>

## ЕстьРазрешенныеСкладыОрдерныеПриОтраженииИзлишковНедостач
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак использования на одном из разрешенных складов
//	ордерной схемы при отражении излишков, недостач.
//
//	Возвращаемое значение:
//		Булево - признак использования ордерной схемы при отражении излишков и недостач.
//
Функция ЕстьРазрешенныеСкладыОрдерныеПриОтраженииИзлишковНедостач() Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ЕстьРазрешенныеСкладыОрдерныеПриОтраженииИзлишковНедостач() 
```
</details>

## ЕстьСкладыБезОрдернойСхемыПриОтраженииИзлишковНедостач
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, есть ли в базе склады без ордерной схемы на отражение излишков и недостач
// Возвращаемое значение:
//  Булево -
//
Функция ЕстьСкладыБезОрдернойСхемыПриОтраженииИзлишковНедостач() Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ЕстьСкладыБезОрдернойСхемыПриОтраженииИзлишковНедостач() 
```
</details>

## ЕстьОрдерныйНаОтгрузкуСклад
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак использования на складе ордерной схемы при отгрузке
//	Параметры:
//		Склады - Массив из СправочникСсылка.Склад, Неопределено - в параметре передаются ссылки на элементы справочника Склады
//						 Если переданно неопределено - проверяется наличие хотя бы одного ордерного склада, другие параметры
//						  не учитываются
//		Дата - Дата - дата, на которую проверяется использование ордерной схемы при отгрузке
//		Склад - СправочникСсылка.Склады - в параметре передается ссылка на склад из шапки.
//
// Возвращаемое значение:
// Булево - Истина -признак использования на складе ордерной схемы при отгрузке.
//
Функция ЕстьОрдерныйНаОтгрузкуСклад(Склады = Неопределено, Дата = Неопределено, Склад = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ЕстьОрдерныйНаОтгрузкуСклад(Склады, Дата, Склад);
```
</details>

## ЕстьОрдерныйНаПоступлениеСклад
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак использования на складе ордерной схемы при поступлении
//	Параметры:
//		Склады - Массив из СправочникСсылка.Склад - в параметре передаются ссылки на элементы справочника Склады
//		Дата - Дата - дата, на которую проверяется использование ордерной схемы при отгрузке
//		Склады - Массив, СправочникСсылка.Склад, Неопределено - в параметре передаются ссылки на элементы справочника Склады
//						 Если переданно неопределено - проверяется наличие хотя бы одного ордерного склада, другие параметры
//						  не учитываются
//
// Возвращаемое значение:
// Булево - Истина -признак использования на складе ордерной схемы при поступлении.
//
Функция ЕстьОрдерныйНаПоступлениеСклад(Склады = Неопределено, Дата = Неопределено, Склад = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ЕстьОрдерныйНаПоступлениеСклад(Склады, Дата, Склад);
```
</details>

## ЕстьНеОрдерныйНаПоступлениеСклад
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак использования на складе неордерной схемы при поступлении
//	Параметры:
//		Склады - Массив из СправочникСсылка.Склад - в параметре передаются ссылки на элементы справочника Склады.
//
// Возвращаемое значение:
// Булево - Истина - признак использования на складе ордерной схемы при поступлении.
//
Функция ЕстьНеОрдерныйНаПоступлениеСклад(Склады) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ЕстьНеОрдерныйНаПоступлениеСклад(Склады) 
```
</details>

## ЕстьНеОрдерныйНаОтгрузкуСклад
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак использования на складе неордерной схемы при отгрузке
//	Параметры:
//		Склады - Массив из СправочникСсылка.Склады - в параметре передаются ссылки на элементы справочника Склады.
//
// Возвращаемое значение:
// Булево - Истина -признак использования на складе неордерной схемы при отгрузке.
//
Функция ЕстьНеОрдерныйНаОтгрузкуСклад(Склады) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ЕстьНеОрдерныйНаОтгрузкуСклад(Склады) 
```
</details>

## ИспользованиеСерийНаСкладе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, используются ли на складе серии. Для группы складов определяет используются ли серии в подчиненных складах.
//
// Параметры:
//  Склад					 - СправочникСсылка.Склады	 - склад или группа складов, для которого нужно определить использование серий
//  СкладМожетБытьГруппой	 - Булево					 - признак, что в первом параметре может быть передана группа.
//
// Возвращаемое значение:
//  Структура - структура со следующими ключами:
//  *ИспользоватьСерииНоменклатуры - Булево
//  *УчитыватьСебестоимостьПоСериям - Булево.
//
Функция ИспользованиеСерийНаСкладе(Склад, СкладМожетБытьГруппой) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ИспользованиеСерийНаСкладе(Склад, СкладМожетБытьГруппой) 
```
</details>

## ИспользованиеСерийНаСкладеПоПолитикамУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет установлены хотя бы в одном виде номенклатуры значения политики учета серии для склада.
//
// Параметры:
//  Склад	 - СправочникСсылка.Склады	 - склад для которого определяются политики.
//
// Возвращаемое значение:
//  Структура - структура со следующими ключами:
//  	* УказыватьПриПланированииОтгрузки - Булево
//  	* УчитыватьСебестоимостьПоСериям - Булево.
//
Функция ИспользованиеСерийНаСкладеПоПолитикамУчета(Склад) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ИспользованиеСерийНаСкладеПоПолитикамУчета(Склад) 
```
</details>

## ИспользованиеСерийВПодразделении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, используются ли в подразделении серии
//
// Параметры:
//  Подразделение	 - СправочникСсылка.СтруктураПредприятия - подразделение, для которого нужно определить использование серий.
//
// Возвращаемое значение:
//  Структура - структура со следующими ключами:
//  	* ИспользоватьСерииНоменклатуры - Булево
//  	* УчитыватьСебестоимостьПоСериям - Булево.
//
Функция ИспользованиеСерийВПодразделении(Подразделение) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ИспользованиеСерийВПодразделении(Подразделение) 
```
</details>

## ЕстьПоддержкаДоставкиСвоимиКурьерами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак использования на складе доставки своими курьерами.
//
//	Параметры:
//		Склад - СправочникСсылка.Склады - ссылка на элемент справочника "Склады"
//		Дата - Дата - на которую проверяется поддержка доставки своими курьерами
//
//	Возвращаемое значение:
//		Булево - признак поддержки доставки своими курьерами.
//
Функция ЕстьПоддержкаДоставкиСвоимиКурьерами(Склад, Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ЕстьПоддержкаДоставкиСвоимиКурьерами(Склад, Дата);
```
</details>

## ЕстьПоддержкаСборкиЗаказов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак использования на складе сборки.
//
//	Параметры:
//		Склад - СправочникСсылка.Склады - ссылка на элемент справочника "Склады"
//		Дата - Дата - на которую проверяется поддержка сборки заказов
//
//	Возвращаемое значение:
//		Булево - признак поддержки сборки заказов.
//
Функция ЕстьПоддержкаСборкиЗаказов(Склад, Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ЕстьПоддержкаСборкиЗаказов(Склад, Дата);
```
</details>

## ДоступныеСкладыСотрудникаПоТипуСотрудника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает доступные сотруднику для работы склады.
//
// Параметры:
//  Сотрудник	 - 	СправочникСсылка.ФизическиеЛица - сотрудник для которого необходимо получить склады.
//  ТипСотрудника	 - 	Строка - наименование типа сотрудника из списка (курьер, сборщик, диспетчер).
//
// Возвращаемое значение:
//  Массив - массив ссылок на склады.
//
Функция ДоступныеСкладыСотрудникаПоТипуСотрудника(Сотрудник, ТипСотрудника) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ДоступныеСкладыСотрудникаПоТипуСотрудника(Сотрудник, ТипСотрудника) 
```
</details>

## СтатусыРаспоряженийДляНачалаДоставкиКурьером
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает статусы сборки и доставки заказов необходимых для назначения заказов курьеру.
//
// Возвращаемое значение:
//  Массив - массив значений статусов.
//
Функция СтатусыРаспоряженийДляНачалаДоставкиКурьером() Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.СтатусыРаспоряженийДляНачалаДоставкиКурьером() 
```
</details>

## СтатусыРаспоряженийПриДоставкеКурьером
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает статусы сборки и доставки заказов доставляемых курьером.
//
// Возвращаемое значение:
//  Массив - массив значений статусов.
//
Функция СтатусыРаспоряженийПриДоставкеКурьером() Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.СтатусыРаспоряженийПриДоставкеКурьером() 
```
</details>

## СтатусыРаспоряженийЗавершенных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает статусы сборки и доставки завершенных заказов.
//
// Возвращаемое значение:
//  Массив - массив значений статусов.
//
Функция СтатусыРаспоряженийЗавершенных() Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.СтатусыРаспоряженийЗавершенных() 
```
</details>

## СтатусыРаспоряженийКонтрольСборки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает статусы сборки и доставки заказов необходимых для контроля сборки.
//
// Возвращаемое значение:
//  Массив - массив значений статусов.
//
Функция СтатусыРаспоряженийКонтрольСборки() Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.СтатусыРаспоряженийКонтрольСборки() 
```
</details>

## СтатусыРаспоряженийКонтрольДоставки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает статусы сборки и доставки заказов необходимых для контроля доставки.
//
// Возвращаемое значение:
//  Массив - массив значений статусов.
//
Функция СтатусыРаспоряженийКонтрольДоставки() Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.СтатусыРаспоряженийКонтрольДоставки() 
```
</details>

## НастройкиСкладаДляСборкиИДоставки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает настройки сборки и доставки для склада.
//
//	Параметры:
//		Склад - СправочникСсылка.Склады - ссылка на элемент справочника "Склады"
//		Дата - Дата - на которую проверяется поддержка доставки своими курьерами
//
//	Возвращаемое значение:
//		Структура, Неопределено - структура значений настроек, если настройки не заданы, то возвращает.
//
Функция НастройкиСкладаДляСборкиИДоставки(Склад, Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.НастройкиСкладаДляСборкиИДоставки(Склад, Дата);
```
</details>

## СтатусЗаказаКСборке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает статусы сборки и доставки заказов необходимых для назначения заказов курьеру.
//
// Возвращаемое значение:
//  Массив - массив значений статусов.
//
Функция СтатусЗаказаКСборке() Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.СтатусЗаказаКСборке() 
```
</details>

## СтатусЗаказаСобирается
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает статусы сборки и доставки заказов необходимых для назначения заказов курьеру.
//
// Возвращаемое значение:
//  Массив - массив значений статусов.
//
Функция СтатусЗаказаСобирается() Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.СтатусЗаказаСобирается() 
```
</details>

## РазрешенаФискализацияПоСкладу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает разрешение фискализации по складу
//
// Параметры:
// 	Склад - СправочникСсылка.Склады
// 	ПерсональнаяНастройка - Булево - персональная настройка фискализации
// 	Дата - Дата
//
// Возвращаемое значение:
// 	Булево
Функция РазрешенаФискализацияПоСкладу(Склад, ПерсональнаяНастройка, Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.РазрешенаФискализацияПоСкладу(Склад, ПерсональнаяНастройка, Дата);
```
</details>

## СтатусыРаспоряженийОтмененных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает статусы сборки и доставки заказов необходимых для назначения заказов курьеру.
//
// Возвращаемое значение:
//  Массив - массив значений статусов.
//
Функция СтатусыРаспоряженийОтмененных() Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.СтатусыРаспоряженийОтмененных() 
```
</details>

## ПараметрыЗаполненияОрдеровОтобраннымиТоварами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры вызова функции ЗаполнитьОрдераОтобраннымиТоварами.
//
// Возвращаемое значение:
//	Структура:
//		* РежимЗаполнения - Строка - одна из строк Множественное или Единичное;
//		* МассивДокументов - Массив - (передается, если режим Множественное) массив ссылок документов, которые
//			нужно перезаполнить;
//		* ДокументОбъект - ДокументОбъект.РасходныйОрдерНаТовары, ДокументОбъект.ОрдерНаПеремещениеТоваров - (передается,
//			если режим Единичное);
//		* ИзменениеСтатуса - Булево - признак, что при после заполнения нужно изменить статус документа (если это возможно);
//		* СтатусДокумента - ПеречислениеСсылка.СтатусыРасходныхОрдеров, ПеречислениеСсылка.СтатусыОрдеровНаПеремещение -
//				передается, если ИзменениеСтатуса = Истина - статус документа, который нужно установить.
//
Функция ПараметрыЗаполненияОрдеровОтобраннымиТоварами() Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ПараметрыЗаполненияОрдеровОтобраннымиТоварами() 
```
</details>

## ЗаполнитьОрдераОтобраннымиТоварами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет ордера отобранными из ячеек товарами
//
// Параметры:
//  ПараметрыЗаполнения	 - см. ПараметрыЗаполненияОрдеровОтобраннымиТоварами
//  Модифицированность	 - Булево	 - требуется, если вызывается из формы документа. Истина, если ТЧ документа была перезаполнена.
//
// Возвращаемое значение:
//  Массив - (ДокументСсылка) - измененные процедурой документы.
//
Функция ЗаполнитьОрдераОтобраннымиТоварами(ПараметрыЗаполнения, Модифицированность = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ЗаполнитьОрдераОтобраннымиТоварами(ПараметрыЗаполнения, Модифицированность);
```
</details>

## ПомещениеДляНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает помещение на котором имеется самый большой остаток
//
//	Параметры:
//		Параметры - Структура - структура, по которой осуществляется поиск помещений:
//			* Номенклатура - СправочникСсылка.Номенклатура
//			* Характеристика - СправочникСсылка.ХарактеристикиНоменклатуры
//			* Склад - СправочникСсылка.Склады
//	Возвращаемое значение:
//		СправочникСсылка.СкладскиеПомещения - помещение на котором имеется самый большой остаток.
//
Функция ПомещениеДляНоменклатуры(Параметры) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ПомещениеДляНоменклатуры(Параметры) 
```
</details>

## ДополнитьТекстЗапросаПризнакОрдерногоСклада
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения признака использования
// ордерного склада при обработке строк табличной части.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаПризнакОрдерногоСклада(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
СкладыСервер.ДополнитьТекстЗапросаПризнакОрдерногоСклада(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаПризнакДвиженияПоСкладскимРегистрам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения признака наличия
// движений по складским регистрам при обработке строк табличной части.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаПризнакДвиженияПоСкладскимРегистрам(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
СкладыСервер.ДополнитьТекстЗапросаПризнакДвиженияПоСкладскимРегистрам(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаПроверитьЗаполнитьСклад
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения поля склад при обработке строк
// табличной части.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаПроверитьЗаполнитьСклад(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
СкладыСервер.ДополнитьТекстЗапросаПроверитьЗаполнитьСклад(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаИспользоватьАдресноеХранение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения признака использования
// адресного склада при пакетной обработке строк табличных частей.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаИспользоватьАдресноеХранение(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
СкладыСервер.ДополнитьТекстЗапросаИспользоватьАдресноеХранение(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаИспользоватьСкладскиеПомещения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения признака использования
// складских помещений при пакетной обработке строк табличных частей.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаИспользоватьСкладскиеПомещения(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
СкладыСервер.ДополнитьТекстЗапросаИспользоватьСкладскиеПомещения(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаЗаполнитьПомещение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения помещения
// с наибольшим остатком по номенклатуре, характеристике и складу в строке табличной части документа.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаЗаполнитьПомещение(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
СкладыСервер.ДополнитьТекстЗапросаЗаполнитьПомещение(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## РассчитатьСостоянийРаспоряженийНаОтбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура рассчитывает состояния распоряжений на отбор.
//
// Параметры:
//	Склад - СправочникСсылка.Склады - склад;
//	Помещение - СправочникСсылка.СкладскиеПомещения - складское помещение;
//	РаспоряженияНаОтбор - ТаблицаЗначений - таблица значений, в которую помещаются результаты расчета состояний. Колонки:
//			* Распоряжение - ДокументСсылка - документ-распоряжение;
//			* ДатаОтгрузки - Дата - дата отгрузки;
//			* Приоритет - СправочникСсылка.Приоритеты - приоритет на производство;
//			* ТипДокумента - Тип - тип документа;
//			* Номер - Строка - номер документа;
//			* ЗонаОтгрузки - СправочникСсылка.СкладскиеЯчейки - зона отгрузки;
//			* Комментарий - Строка - комментарий;
//			* Состояние - ПеречислениеСсылка.СостоянияРаспоряженийНаОтборТоваров - состояние распоряжения на отбор;
//			* ИндексКартинки - Число - индекс картинки строк из коллекции картинок ПодчиненныйЭлементГруппа.
//	ОтображениеДеталей - Булево - признак, что сейчас отображается список расходных ордеров по заданию на перевозку
//	ЗаданиеНаПеревозку - ДокументСсылка.ЗаданиеНаПеревозку - задание на перевозку, по которому сейчас отображаются расходные ордера.
//		Этот документ добавляется в самое начало таблицы РаспоряженияНаОтбор.
//	СостояниеОтбора - Строка - состояние распоряжения на отбор товаров.
//
Процедура РассчитатьСостоянийРаспоряженийНаОтбор(Склад, Помещение, РаспоряженияНаОтбор, ОтображениеДеталей, ЗаданиеНаПеревозку, СостояниеОтбора) Экспорт
```

Пример вызова
```bsl
СкладыСервер.РассчитатьСостоянийРаспоряженийНаОтбор(Склад, Помещение, РаспоряженияНаОтбор, ОтображениеДеталей, ЗаданиеНаПеревозку, СостояниеОтбора) 
```
</details>

## ПереоформитьРасходныеОрдера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция создает и редактирует расходные ордера для Склада и Получателя, если для них сумма
// по ресурсам регистра движения к отгрузке не равна 0.
//
// Параметры:
//	Параметры - Структура - структура, набор параметров для создания расходных ордеров:
//		*Склад - СправочникСсылка.Склады - ссылка на склад, который указан в распоряжениях на отгрузку;
//		*Помещение - СправочникСсылка.СкладскиеПомещения - ссылка на помещение, которое указано в распоряжения на отгрузку,
//		либо пустая ссылка справочника "Складские помещения";
//		*Получатель - ОпределяемыйТип.ОтправительПолучательТоваров - адресат, кому предназначен ордер;
//		*ЗонаОтгрузки - СправочникСсылка.СкладскиеЯчейки - ссылка на ячейку склада, которая является зоной отгрузки
//			либо пустая ссылка справочника "Складские ячейки";
//		*СозданныеРасходныеОрдера - ТаблицаЗначений - необязательный, таблица ордеров, которые можно перезаполнить:
//			**ДокументОбъект - ДокументОбъект.РасходныйОрдерНаТовары - ранее созданный расходный ордер.
//			**Использован - Булево - Ложь если можно перезаполнить.
//
// Возвращаемое значение:
//	Структура - структура со следующими ключами:
//	*ОформленныеОрдера - ТаблицаЗначений - таблица ссылок ордеров и действий, совершенных над ними.
//	*ЕстьОшибка - Булево - признак ошибки.
//
Функция ПереоформитьРасходныеОрдера(Параметры) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ПереоформитьРасходныеОрдера(Параметры) 
```
</details>

## СоздатьЗаданияНаПереупаковку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура создает задания на переупаковку, у которых есть движения в отборе
//
// Параметры:
//  СтруктураПараметров	 - Структура	 - структура, имеющая следующие ключи:
//  	*Склад - СправочникСсылка.Склады - ссылка на склад, который указан в расходных ордерах;
//  	*Помещение - СправочникСсылка.СкладскиеПомещения - ссылка на помещение, которое указано в расходных ордерах,
//  		либо пустая ссылка справочника "Складские помещения";
//  	*ПоВсемРаспоряжениям - Булево - Истина, если выполнить создание ордеров по всем распоряжениям
//  		Ложь, если выполнить по тем распоряжениям, которые указаны в параметре МассивРаспоряжений;
//  	*МассивРаспоряжений - Массив - массив ссылок на расходные ордера, по которым нужно создать задания на отбор,
//  		необязательный параметр в случае, если параметр ПоВсемРаспоряжениям = Истина;
//  	*РабочийУчасток - СправочникСсылка.РабочиеУчастки - ссылка на рабочий участок, по которому будут сформированы задания на отбор;
//  	*НастройкаФормированияПоРабочимУчасткам - Строка - возможные значения:
//  		"СРазбиениемПоРабочимУчасткам", "ПоОдномуРабочемуУчастку", "БезРазбиенияПоРабочимУчасткам";
//  	*ОграничиватьПоОбъему - Булево - параметр рабочего участка;
//  	*ОграничиватьПоВесу - Булево - параметр рабочего участка;
//  	*ОграничениеПоОбъему - Число - параметр рабочего участка;
//  	*ОграничениеПоВесу - Число - параметр рабочего участка;
//  	*Исполнитель - СправочникСсылка.Пользователи - ссылка на пользователя системы, который будет указан в созданных заданиях на отбор,
//  		необязательный параметр;
Процедура СоздатьЗаданияНаПереупаковку(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
СкладыСервер.СоздатьЗаданияНаПереупаковку(СтруктураПараметров) 
```
</details>

## СоздатьЗаданияНаОтбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура создает задания на отбор, у которых есть движения в отборе
//
// Параметры:
//  СтруктураПараметров	 - Структура	 - структура, имеющая следующие ключи:
//  	*Склад - СправочникСсылка.Склады - ссылка на склад, который указан в расходных ордерах;
//  	*Помещение - СправочникСсылка.СкладскиеПомещения - ссылка на помещение, которое указано в расходных ордерах,
//  		либо пустая ссылка справочника "Складские помещения";
//  	*ПоВсемРаспоряжениям - Булево - Истина, если выполнить создание ордеров по всем распоряжениям
//  		Ложь, если выполнить по тем распоряжениям, которые указаны в параметре МассивРаспоряжений;
//  	*МассивРаспоряжений - Массив - массив ссылок на расходные ордера, по которым нужно создать задания на отбор,
//  		необязательный параметр в случае, если параметр ПоВсемРаспоряжениям = Истина;
//  	*РабочийУчасток - СправочникСсылка.РабочиеУчастки - ссылка на рабочий участок, по которому будут сформированы задания на отбор;
//  	*НастройкаФормированияПоРабочимУчасткам - Строка - возможные значения:
//  		"СРазбиениемПоРабочимУчасткам", "ПоОдномуРабочемуУчастку", "БезРазбиенияПоРабочимУчасткам";
//  	*ОграничиватьПоОбъему - Булево - параметр рабочего участка;
//  	*ОграничиватьПоВесу - Булево - параметр рабочего участка;
//  	*ОграничениеПоОбъему - Число - параметр рабочего участка;
//  	*ОграничениеПоВесу - Число - параметр рабочего участка;
//  	*Исполнитель - СправочникСсылка.Пользователи - ссылка на пользователя системы, который будет указан в созданных заданиях на отбор,
//  		необязательный параметр;
//  	*ДействиеПриНехваткеУпаковок - Число - может принимать следующие значения:
//	  		0 - создать только задания на отбор
// 		 	1 - создать задания на отбор и переупаковку
//  		2 - создать только задания на переупаковку.
//
Процедура СоздатьЗаданияНаОтбор(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
СкладыСервер.СоздатьЗаданияНаОтбор(СтруктураПараметров) 
```
</details>

## ОстаткиТоваровКОтбору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура в переданный через параметры менеджер временных таблиц помещает туда таблицы "ТаблицаТоварныеМестаКОтбору"
// и "ТаблицаНоменклатуры". "ТаблицаТоварныеМестаКОтбору" хранит товарные места, которые осталось отобрать.
// "ТаблицаНоменклатуры" хранит цельную номенклатуру, которую осталось отобрать.
//
// Параметры:
//  Менеджер	 - МенеджерВременныхТаблиц - Менеджер, в который будут помещены временные таблицы "ТаблицаТоварныеМестаКОтбору" и "ТаблицаНоменклатуры"
//  Распоряжения - Массив, ДокументСсылка.РасходныйОрдерНаТовары, ДокументСсылка.ОрдерНаПеремещениеТоваров -
//                 распоряжения, на основании которых будет создаваться отбор товаров
//  Склад		 - СправочникСсылка.Склады - склад из распоряжения или рабочего места
//  Помещение	 - СправочникСсылка.СкладскиеПомещения - помещение из распоряжения или рабочего места.
//
Процедура ОстаткиТоваровКОтбору(Менеджер, Распоряжения, Склад, Помещение) Экспорт
```

Пример вызова
```bsl
СкладыСервер.ОстаткиТоваровКОтбору(Менеджер, Распоряжения, Склад, Помещение) 
```
</details>

## СоздатьЗаданияНаПодпитку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать СкладыСервер.СоздатьЗаданияНаПеремещение
// Параметры:
//	СтруктураПараметров - Структура - имеющая следующие ключи:
//		*Склад - СправочникСсылка.Склады - ссылка на склад, который указан в расходных ордерах;
//		*Помещение - СправочникСсылка.СкладскиеПомещения - ссылка на помещение, которое указано в расходных ордерах,
//			либо пустая ссылка справочника "Складские помещения";
//		*ПоВсемРаспоряжениям - Булево - не используется
//		*МассивРаспоряжений - Массив - не используется;
//		*РабочийУчасток - СправочникСсылка.РабочиеУчастки - ссылка на рабочий участок, по которому будут сформированы задания на подпитку (переупаковку);
//		*НастройкаФормированияПоРабочимУчасткам - Строка - возможные значения:
//			"СРазбиениемПоРабочимУчасткам", "ПоОдномуРабочемуУчастку", "БезРазбиенияПоРабочимУчасткам";
//		*ОграничиватьПоОбъему - Булево - параметр рабочего участка;
//		*ОграничиватьПоВесу - Булево - параметр рабочего участка;
//		*ОграничениеПоОбъему - Число - параметр рабочего участка;
//		*ОграничениеПоВесу - Число - параметр рабочего участка;
//		*Исполнитель - СправочникСсылка.Пользователи - ссылка на пользователя системы,
//			который будет указан в созданных заданиях на подпитку (переупаковку), необязательный параметр.
Процедура СоздатьЗаданияНаПодпитку(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
СкладыСервер.СоздатьЗаданияНаПодпитку(СтруктураПараметров) 
```
</details>

## СоздатьЗаданияНаПеремещение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает задания на перемещение. Используется для запуска регламентного задания
// Параметры:
//	СтруктураПараметров - Структура - имеющая следующие ключи:
//		*Склад - СправочникСсылка.Склады - ссылка на склад, который указан в расходных ордерах;
//		*Помещение - СправочникСсылка.СкладскиеПомещения - ссылка на помещение, которое указано в расходных ордерах,
//			либо пустая ссылка справочника "Складские помещения";
//		*ПравилоСоздания - ПеречислениеСсылка.ПравилаСозданияЗаданийНаОтборРазмещение - ссылка на правило, по которому
//			будет происходить создание заданий;
//		*РазбиватьПоКоличествуЯчеек - Булево - разбивать задания по количеству ячеек;
//		*КоличествоЯчеекВЗадании - Число - максимально возможное количество ячеек в одном задании;
//		*НастройкаРазбиенияПоРабочимУчасткам - Строка - возможные значения:
//			"СРазбиениемПоРабочимУчасткам", "ПоОдномуРабочемуУчастку", "БезРазбиенияПоРабочимУчасткам";
//		*РабочийУчасток - СправочникСсылка.РабочиеУчастки - ссылка на рабочий участок, по которому будут сформированы
//			задания;
//		*НастройкиОтбора - КомпоновщикНастроекКомпоновкиДанных - настройки отбора товаров;
//		*ОграничиватьПоОбъему - Булево - параметр рабочего участка;
//		*ОграничиватьПоВесу - Булево - параметр рабочего участка;
//		*ОграничениеПоОбъему - Число - параметр рабочего участка;
//		*ОграничениеПоВесу - Число - параметр рабочего участка;
//		*Исполнитель - СправочникСсылка.Пользователи - ссылка на пользователя системы,
//			который будет указан в созданных заданиях, необязательный параметр;
Процедура СоздатьЗаданияНаПеремещение(СтруктураПараметров) Экспорт
```

Пример вызова
```bsl
СкладыСервер.СоздатьЗаданияНаПеремещение(СтруктураПараметров) 
```
</details>

## СоздатьЗаданияНаПеремещениеПоПравилу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает задания на перемещения
// Параметры:
//	ПараметрыСоздания - Структура - структура с ключами:
//		*Склад - СправочникСсылка.Склады - ссылка на склад, который указан в расходных ордерах;
//		*Помещение - СправочникСсылка.СкладскиеПомещения - ссылка на помещение, которое указано в расходных ордерах,
//			либо пустая ссылка справочника "Складские помещения";
//		*ПравилоСоздания - ПеречислениеСсылка.ПравилаСозданияЗаданийНаОтборРазмещение - ссылка на правило, по которому
//			будет происходить создание заданий;
//		*РазбиватьПоКоличествуЯчеек - Булево - разбивать задания по количеству ячеек;
//		*КоличествоЯчеекВЗадании - Число - максимально возможное количество ячеек в одном задании;
//		*НастройкаФормированияПоРабочимУчасткам - Строка - возможные значения:
//			"СРазбиениемПоРабочимУчасткам", "ПоОдномуРабочемуУчастку", "БезРазбиенияПоРабочимУчасткам";
//		*РабочийУчасток - СправочникСсылка.РабочиеУчастки - ссылка на рабочий участок, по которому будут сформированы
//			задания;
//		*НастройкиОтбора - КомпоновщикНастроекКомпоновкиДанных - настройки отбора товаров;
//		*ОграничиватьПоОбъему - Булево - параметр рабочего участка;
//		*ОграничиватьПоВесу - Булево - параметр рабочего участка;
//		*ОграничениеПоОбъему - Число - параметр рабочего участка;
//		*ОграничениеПоВесу - Число - параметр рабочего участка;
//		*Исполнитель - СправочникСсылка.Пользователи - ссылка на пользователя системы,
//			который будет указан в созданных заданиях, необязательный параметр;
//
Процедура СоздатьЗаданияНаПеремещениеПоПравилу(Знач ПараметрыСоздания) Экспорт
```

Пример вызова
```bsl
СкладыСервер.СоздатьЗаданияНаПеремещениеПоПравилу(ПараметрыСоздания) 
```
</details>

## СоздатьЗаданияНаПересчетТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура создает задания на пересчет
//	Параметры:
//		ПараметрыГенерации - Структура - структура, имеющая следующие ключи:
//			*ПересчетПоНаполненности - Булево - только ячейки с остатками,
//			*ПересчетПоОсобымУсловиям - Булево - выбор ячеек по особым условиям (см. ПересчетСомнительныхЯчеек, ПересчетПоНастройкамПериодичности, ПересчетПоЯчейкамСОтрицательнымиОстатками)
//			*ПересчетСомнительныхЯчеек - Булево - выбирать ячейки, которые были помечены как сомнительные или в которых была ошибка отбора
//			*ПересчетПоНастройкамПериодичности - Булево - выбирать ячейки, для которых настало время выполнить пересчет,
//			*ПересчетПоЯчейкамСОтрицательнымиОстатками - Булево - выбирать ячейки, в которых есть отрицательные остатки,
//			*НастройкиОтбора - КомпоновщикНастроекКомпоновкиДанных - хранит настройки отбора товаров,
//			*РазбиватьПоРабочимУчасткам - Булево - Истина, если нужно, чтобы созданные пересчеты были разбиты по рабочим участкам,
//			*РазбиватьПоКоличествуЯчеек - Булево - Истина, если нужно, к каждом пересчете было определенное число ячеек,
//			*КоличествоЯчеекВЗадании - Число - актуален, если РазбиватьПоКоличествуЯчеек = Истина
Процедура СоздатьЗаданияНаПересчетТоваров(ПараметрыГенерации) Экспорт
```

Пример вызова
```bsl
СкладыСервер.СоздатьЗаданияНаПересчетТоваров(ПараметрыГенерации) 
```
</details>

## ПараметрыФормированияЗаданийНаПодпитку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров формирования заданий на подпитку.
//
// Параметры:
//	ПоРаспоряжениямНаОтбор - Булево - Истина - задание на подпитку формируется на основании распоряжений.
//
// Возвращаемое значение:
//	Структура - параметры формирования заданий на подпитку.
//
Функция ПараметрыФормированияЗаданийНаПодпитку(ПоРаспоряжениямНаОтбор) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ПараметрыФормированияЗаданийНаПодпитку(ПоРаспоряжениямНаОтбор) 
```
</details>

## СтруктураПараметровСозданияЗаданийНаОтборПодпитку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров создания заданий на отбор или подпитку.
//
// Возвращаемое значение:
//	Структура - параметры создания заданий на отбор или подпитку.
//
Функция СтруктураПараметровСозданияЗаданийНаОтборПодпитку() Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.СтруктураПараметровСозданияЗаданийНаОтборПодпитку() 
```
</details>

## ПараметрыПереоформленияРасходныхОрдеров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров, используемых для переоформления расходных ордеров.
//
// Возвращаемое значение:
//	Структура - параметры, используемые для переоформления расходных ордеров.
//
Функция ПараметрыПереоформленияРасходныхОрдеров() Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ПараметрыПереоформленияРасходныхОрдеров() 
```
</details>

## ПустойПолучательОтправитель
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив всех возможных пустых ссылок определяемого типа ОтправительПолучательТоваров.
//
// Возвращаемое значение:
//  Массив - Массив пустых ссылок.
//
Функция ПустойПолучательОтправитель() Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ПустойПолучательОтправитель() 
```
</details>

## УстановитьУсловноеОформлениеСкладаВТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление для поля Склад в ТЧ объекта
//
// Параметры:
// 		Форма - ФормаКлиентскогоПриложения - Содержит данную форму
// 		ИмяПоляВводаСклада - Строка - Наименование элемента формы, содержащего склад,
//										 если оно отличается от "ТоварыСклад".
//
Процедура УстановитьУсловноеОформлениеСкладаВТЧ(Форма, Экспорт
```

Пример вызова
```bsl
СкладыСервер.УстановитьУсловноеОформлениеСкладаВТЧ(Форма, );
```
</details>

## УстановитьУсловноеОформлениеСкладаВШапке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление для поля Склад в шапке объекта
//    в зависимости от флага "СкладОбязателен".
//
// Параметры:
// 		Форма - ФормаКлиентскогоПриложения - Содержит данную форму.
//
Процедура УстановитьУсловноеОформлениеСкладаВШапке(Форма) Экспорт
```

Пример вызова
```bsl
СкладыСервер.УстановитьУсловноеОформлениеСкладаВШапке(Форма) 
```
</details>

## УстановитьУсловноеОформлениеПоДействиюВСтроке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает условное оформление по действию со строкой в ордерах на отгрузку.
//
// Параметры:
//  Форма	 - ФормаКлиентскогоПриложения - Форма для условного оформления.
//
Процедура УстановитьУсловноеОформлениеПоДействиюВСтроке(Форма) Экспорт
```

Пример вызова
```bsl
СкладыСервер.УстановитьУсловноеОформлениеПоДействиюВСтроке(Форма) 
```
</details>

## УстановитьУсловноеОформлениеПодразделенияВТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает условное оформление для поля Подразделение в ТЧ объекта.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - Форма для условного оформления
//  ИмяТабличнойЧасти - Строка
//  ЕстьСкладВТабличнойЧасти - Булево
//
Процедура УстановитьУсловноеОформлениеПодразделенияВТЧ(Форма, ИмяТабличнойЧасти = "Товары", ЕстьСкладВТабличнойЧасти = Истина, ПрефиксОбъект = "Объект.") Экспорт
```

Пример вызова
```bsl
СкладыСервер.УстановитьУсловноеОформлениеПодразделенияВТЧ(Форма, ИмяТабличнойЧасти, ЕстьСкладВТабличнойЧасти, ПрефиксОбъект);
```
</details>

## ПроверитьОрдерностьСклада
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура проверяет ордерность по заданному виду, в случае неордерности склада пользователю выводится сообщение.
//
// Параметры:
//  Склад			 - СправочникСсылка.Склады	 - ссылка на склад, который проверяется на ордерность;
//  Дата			 - Дата						 - дата, на которую проверяется ордерность;
//  ВидОрдернойСхемы - Строка					 - возможные значения: "ПриОтраженииИзлишковНедостач", "ПриОтгрузке", "ПриПоступлении".
//  Отказ			 - Булево					 - в параметр возвращается Ложь, если проверка не пройдена.
//
Процедура ПроверитьОрдерностьСклада(Склад, Дата, ВидОрдернойСхемы, Отказ) Экспорт
```

Пример вызова
```bsl
СкладыСервер.ПроверитьОрдерностьСклада(Склад, Дата, ВидОрдернойСхемы, Отказ) 
```
</details>

## ПроверитьЗаполнениеЯчеек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура - Проверить заполнение ячеек в ТЧ при обработке проверки заполнения
//
// Параметры:
//  Объект	- ДокументОбъект  - документ, в ТЧ которого нужно проверить заполнение ячеек
//  		- ФормаКлиентскогоПриложения - объект, в ТЧ которого нужно проверить заполнение ячеек, должны содержать:
//				* Ссылка - ДокументСсылка
//  			* Склад - СправочникСсылка.Склады
//  			* Помещение - СправочникСсылка.СкладскиеПомещения
//  МассивНепроверяемыхРеквизитов - Массив - массив реквизитов, которые не нужно проверять платформенной проверкой
//	Отказ - Булево - отказ продолжения операции
//	ПараметрыПроверки - см. СкладыСервер.ПараметрыПроверкиЗаполненияЯчеек
//
Процедура ПроверитьЗаполнениеЯчеек(Объект, МассивНепроверяемыхРеквизитов, Отказ, ПараметрыПроверки = Неопределено) Экспорт
```

Пример вызова
```bsl
СкладыСервер.ПроверитьЗаполнениеЯчеек(Объект, МассивНепроверяемыхРеквизитов, Отказ, ПараметрыПроверки);
```
</details>

## ПараметрыПроверкиЗаполненияЯчеек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает параметры проверки заполнения ячеек
//
// Возвращаемое значение:
//  Структура - структура со следующими ключами и значениями:
//  *ИмяТЧ - Строка - значение по умолчанию "Товары"
//  *ВыводитьНомераСтрок - Булево - значение по умолчанию Истина.
//
Функция ПараметрыПроверкиЗаполненияЯчеек() Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ПараметрыПроверкиЗаполненияЯчеек() 
```
</details>

## ПроверитьЗаполнениеПомещений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура - Проверить заполнение помещений в ТЧ при обработке проверки заполнения.
//
// Параметры:
//  Объект	- ДокументОбъект  - документ, в ТЧ которого нужно проверить заполнение ячеек
//  		- ФормаКлиентскогоПриложения - объект, в ТЧ которого нужно проверить заполнение ячеек, должны содержать:
//				* Ссылка - ДокументСсылка
//  			* Склад - СправочникСсылка.Склады
//  МассивНепроверяемыхРеквизитов - Массив - массив реквизитов, которые не нужно проверять платформенной проверкой
//	Отказ - Булево - отказ продолжения операции
//	ПараметрыПроверки - Структура - описание см. СкладыСервер.ПараметрыПроверкиЗаполненияПомещений.
//
Процедура ПроверитьЗаполнениеПомещений(Объект, МассивНепроверяемыхРеквизитов, Отказ, ПараметрыПроверки = Неопределено) Экспорт
```

Пример вызова
```bsl
СкладыСервер.ПроверитьЗаполнениеПомещений(Объект, МассивНепроверяемыхРеквизитов, Отказ, ПараметрыПроверки);
```
</details>

## ПараметрыПроверкиЗаполненияПомещений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает параметры проверки заполнения ячеек
//
// Возвращаемое значение:
//  Структура - структура со следующими ключами и значениями:
//  * ИмяТЧ - Строка - значение по умолчанию "Товары"
//  * ВыводитьНомераСтрок - Булево - значение по умолчанию Истина.
//
Функция ПараметрыПроверкиЗаполненияПомещений() Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ПараметрыПроверкиЗаполненияПомещений() 
```
</details>

## ПроверитьИспользованиеЯчеекПоПравиламОбособления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет использование ячеек в ТЧ по правилам размещения обособленных товаров
//
// Параметры:
//  Объект	- ДокументОбъект - документ, в ТЧ которого нужно проверить заполнение помещений.
//  		- ФормаКлиентскогоПриложения - объект, в ТЧ которого нужно проверить заполнение помещений, должны содержать:
//				* Ссылка - ДокументСсылка
//  			* Ячейка - СправочникСсылка.СкладскиеЯчейки
//  			* Номенклатура - СправочникСсылка.Номенклатура
//  			* Назначение - СправочникСсылка.Назначения
//	Отказ - Булево - отказ продолжения операции
//	ИмяТЧ - Строка - имя табличной части, которую нужно проверить.
Процедура ПроверитьИспользованиеЯчеекПоПравиламОбособления(Объект, Отказ, ИмяТЧ) Экспорт
```

Пример вызова
```bsl
СкладыСервер.ПроверитьИспользованиеЯчеекПоПравиламОбособления(Объект, Отказ, ИмяТЧ) 
```
</details>

## ПроверитьОрдераНаВозможностьИзмененияСтатуса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет возможность изменения статуса ордера на отгрузку на статус "К проверке".
// Если все товары по ордеру отобраны, то ордер попадет в массив-результат.
//
// Параметры:
//  Ордера	 - 	Массив, ДокументСсылка.РасходныйОрдерНаТовары, ДокументСсылка.ОрдерНаПеремещениеТоваров -  ссылка на ордер или массив ссылок на ордера.
//
// Возвращаемое значение:
//  Массив - массив ссылок на ордера, которые можно перевести в статус "К проверке".
//
Функция ПроверитьОрдераНаВозможностьИзмененияСтатуса(Ордера) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ПроверитьОрдераНаВозможностьИзмененияСтатуса(Ордера) 
```
</details>

## ИмяПоляСкладПоИмениДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция имя поля склада в документе.
//
// Параметры:
//  ИмяДокумента - Строка	 - наименование документа.
//
// Возвращаемое значение:
//  Строка - имя поля склада в документе.
//
Функция ИмяПоляСкладПоИмениДокумента(ИмяДокумента) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ИмяПоляСкладПоИмениДокумента(ИмяДокумента) 
```
</details>

## СписокПодчиненныхСкладов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует список с подчиненными складами, включая переданный
//
// Параметры:
//  Склад	 - СправочникСсылка.Склады - склад, по которому формируется список.
//
// Возвращаемое значение:
//  СписокЗначений - список с подчиненными складами.
//
Функция СписокПодчиненныхСкладов(Склад) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.СписокПодчиненныхСкладов(Склад) 
```
</details>

## ГруппировкаТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя реквизита для группировки товаров
//
// Параметры:
//  Склад - СправочникСсылка.Склады - Склад по которому требуется узнать группировку товаров.
//
// Возвращаемое значение:
//  Строка - наименование реквизита справочника Номенклатура.
Функция ГруппировкаТоваров(Склад) Экспорт
```

Пример вызова
```bsl
Результат = СкладыСервер.ГруппировкаТоваров(Склад) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
