---
title: Сообщения в службу технической поддержки БПО клиент
slug: erp-uh/сообщения-в-службу-технической-поддержки-бпо-клиент
---


## ПараметрыОтправкиСообщенияОбОшибке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров для отправки сообщения об ошибке в техническую поддержку
//
// Возвращаемое значение:
//  Структура:
//   * ИдентификаторОборудования - СправочникСсылка.ПодключаемоеОборудование, Неопределено - ссылка на элемент
//       подключаемого оборудования.
//   * ТекстОшибки - Строка - Текст ошибки который будет добавлен в письмо.
//   * ДополнительныеДанные - Структура, Массив из Структура, Неопределено - Дополнительные данные которые будут
//       преобразованы в текст и добавлены в файл "Сведения о драйвере.txt".
//   * ЗадатьВопрос - Булево - Если установлена Истина, тогда будет задан вопрос об отправке сообщения
//   * ТекстВопроса - Строка - Текст вопроса который будет выведен пользователю
//
Функция ПараметрыОтправкиСообщенияОбОшибке() Экспорт
```

Пример вызова
```bsl
Результат = СообщенияВСлужбуТехническойПоддержкиБПОКлиент.ПараметрыОтправкиСообщенияОбОшибке() 
```
</details>

## НачатьОтправкуСообщенияОбОшибке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Начинает отправку сообщения об ошибке, на сайт фирмы 1С.
// Добавив в сообщение информацию о драйвере, а так же лог файлы если они существуют.
// Лог файлы отправляются в формате BASE64.
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения, Неопределено - Метод, в который должен быть
//                          передан результат отправки сообщения. В метод передается значение типа
//                          Структура - результат отправки сообщения:
//                            КодОшибки - Строка - идентификатор ошибки при отправки
//                                                  <Пустая строка> - отправка выполнена успешно;
//                                                  "НеверныйФорматЗапроса" - переданы некорректные параметры
//                                                    сообщения сообщения в техническую поддержку;
//                                                  "ПревышенМаксимальныйРазмер" - превышен максимальный
//                                                     размер вложения;
//                                                  "НеизвестнаяОшибка" - при отправке сообщения возникли ошибки.
//                            СообщениеОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке
//                                                 для пользователя.
//  Параметры - См. ПараметрыОтправкиСообщенияОбОшибке
//
Процедура НачатьОтправкуСообщенияОбОшибке(ОповещениеОЗавершении, Параметры) Экспорт
```

Пример вызова
```bsl
СообщенияВСлужбуТехническойПоддержкиБПОКлиент.НачатьОтправкуСообщенияОбОшибке(ОповещениеОЗавершении, Параметры) 
```
</details>

## ПоказатьВопросОправкиСообщенияОбОшибке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Показывает вопрос отправки сообщения об ошибке, и отправляет сообщение на сайт фирмы 1С
// если получено подтверждение.
// Добавив в сообщение информацию о драйвере, а так же лог файлы если они существуют.
// Лог файлы отправляются в формате BASE64.
//
// Параметры:
//  ОповещениеОЗавершении - ОписаниеОповещения, Неопределено - Метод, в который должен быть
//                          передан результат отправки сообщения. В метод передается значение типа
//                          Структура - результат отправки сообщения:
//                            *КодОшибки - Строка - идентификатор ошибки при отправки:
//                                                   <Пустая строка> - отправка выполнена успешно;
//                                                   "НеверныйФорматЗапроса" - переданы некорректные параметры
//                                                     сообщения сообщения в техническую поддержку;
//                                                   "ПревышенМаксимальныйРазмер" - превышен максимальный
//                                                     размер вложения;
//                                                   "НеизвестнаяОшибка" - при отправке сообщения возникли ошибки.
//                            *СообщениеОбОшибке - Строка, ФорматированнаяСтрока - сообщение об ошибке
//                                                 для пользователя.
//  Параметры - Структура - см. ПараметрыОтправкиСообщенияОбОшибке()
//  @skip-check doc-comment-description-ends-on-dot
//
Процедура ПоказатьВопросОправкиСообщенияОбОшибке(ОповещениеОЗавершении, Параметры) Экспорт
```

Пример вызова
```bsl
СообщенияВСлужбуТехническойПоддержкиБПОКлиент.ПоказатьВопросОправкиСообщенияОбОшибке(ОповещениеОЗавершении, Параметры) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
