---
title: Структура заказа вызов сервера
slug: erp-uh/структура-заказа-вызов-сервера
---


## ТабличнаяЧастьПеремещениеИзделийПоНоменклатурномуПлану
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные для формирование документов "Заказ на перемещение товаров" Или "Перемещение товаров", табличная часть заполняются изделиями готовыми к отгрузке со склада.
//
// Параметры:
//  ИдентификаторыСтрок - Массив - список ключей указывающих изделия в партии перемещения товаров.
//  ТолькоВНаличии - Булево - признак, если истина, то список номенклатуры запланированной к перемещению будет отфильтрован по наличию на складе отгрузки.
// Возвращаемое значение:
//  ТаблицаЗначений - содержит структуру параметров замены:
//  	* Номенклатура			 - СправочникСсылка.Номенклатура				 - номенклатура.
//  	* Характеристика		 - СправочникСсылка.ХарактеристикиНоменклатуры	 - характеристика номенклатуры.
//  	* СкладОтгрузки			 - СправочникСсылка.Склады						 - склад отгрузки.
//  	* СкладПоступления		 - СправочникСсылка.Склады						 - склад поступления.
//  	* Назначение			 - СправочникСсылка.Назначения					 - назначение.
//  	* Обособленно			 - Булево										 - признак, "обособленное обеспечение".
//  	* КоличествоУпаковок	 - Число										 - количество в упаковках.
//  	* Количество			 - Число										 - количество в ед.хранения товара.
//
Функция ТабличнаяЧастьПеремещениеИзделийПоНоменклатурномуПлану(ИдентификаторыСтрок, ТолькоВНаличии = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = СтруктураЗаказаВызовСервера.ТабличнаяЧастьПеремещениеИзделийПоНоменклатурномуПлану(ИдентификаторыСтрок, ТолькоВНаличии);
```
</details>

## ТабличнаяЧастьПеремещениеКомплектующихПоНоменклатурномуПлану
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные для формирование документов "Заказ на перемещение товаров" Или "Перемещение товаров", табличная часть заполняются комплектующими готовыми к отгрузке со склада.
//
// Параметры:
//  Изделие          - Структура - данные изделия для получения списка комплектующих к перемещению.
//  ЭтапПроизводства - СправочникСсылка.ЭтапыПроизводства - дополнительный отбор комплектующих по этапу производства.
//  ТолькоВНаличии - Булево - признак, если истина, то список номенклатуры запланированной к перемещению будет отфильтрован по наличию на складе отгрузки.
//
// Возвращаемое значение:
//  ТаблицаЗначений - см.СтруктураЗаказаВызовСервера.ТабличнаяЧастьПеремещениеИзделийПоНоменклатурномуПлану
//
Функция ТабличнаяЧастьПеремещениеКомплектующихПоНоменклатурномуПлану(Изделие, ЭтапПроизводства = Неопределено, ТолькоВНаличии = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = СтруктураЗаказаВызовСервера.ТабличнаяЧастьПеремещениеКомплектующихПоНоменклатурномуПлану(Изделие, ЭтапПроизводства, ТолькоВНаличии);
```
</details>

## ЗапуститьПересчетСтруктурыЗаказа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет задания к пересчету структуры заказа на производство и запускает расчет
//
// Параметры:
// 	ЗаказыНаПроизводство - Массив, ДокументСсылка.ЗаказНаПроизводство2_2	- заказ на производство или список заказов на производство.
//
Процедура ЗапуститьПересчетСтруктурыЗаказа(ЗаказыНаПроизводство) Экспорт
```

Пример вызова
```bsl
СтруктураЗаказаВызовСервера.ЗапуститьПересчетСтруктурыЗаказа(ЗаказыНаПроизводство) 
```
</details>

## ЗапуститьПересчетСтруктурыЗаказаПоСпецификации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет задания к расчету структуры заказа на производство по спецификации и запускает расчет
//
// Параметры:
// 	Спецификация			 - СправочникСсылка.РесурсныеСпецификации			- спецификация.
// 	ЗаказыНаПроизводство	 - Массив, ДокументСсылка.ЗаказНаПроизводство2_2	- заказ на производство или список заказов на производство.
//
Процедура ЗапуститьПересчетСтруктурыЗаказаПоСпецификации(Спецификация, ЗаказыНаПроизводство) Экспорт
```

Пример вызова
```bsl
СтруктураЗаказаВызовСервера.ЗапуститьПересчетСтруктурыЗаказаПоСпецификации(Спецификация, ЗаказыНаПроизводство) 
```
</details>

## ПолноеПредставлениеЗаказа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует полное представление заказа на производство.
// Формат: "Заказ № %1 от %2, дата потребности %3".
//
// Параметры:
//  НомерДокумента		 - Строка	 - номер документа.
//  ДатаДокумента		 - Дата 	 - дата документа.
//  ЖелаемаяДатаВыпуска	 - Дата 	 - желаемая дата.
//
// Возвращаемое значение:
//  Строка - полное представление заказа на производство.
//
Функция ПолноеПредставлениеЗаказа(НомерДокумента, ДатаДокумента, ЖелаемаяДатаВыпуска) Экспорт
```

Пример вызова
```bsl
Результат = СтруктураЗаказаВызовСервера.ПолноеПредставлениеЗаказа(НомерДокумента, ДатаДокумента, ЖелаемаяДатаВыпуска) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
