---
title: Тестирование
slug: erp-uh/тестирование
---


## СохранитьЭталонныеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод выполняет помещение во временные таблицы данных по указанным регистрам и указанный месяц
// Создается временная таблица ЭталонИмяОбъектаМетаданных,
// где ИмяОбъектаМетаданных - это имя регистра.
// Пример: ЭталонСебестоимостьТоваров.
// Параметры:
//		КонтрольныеРегистры - Массив - Список регистров по которым сохраняются данные.
//		ПараметрыЗапроса - см. Тестирование.ПараметрыЗапроса
//		Месяц - Дата - Начало месяца, за который необходимо считать данные.
//		МассивРегистраторов - Массив - Список документов по которым сохраняются движения.
//										Если используется данный параметр, то Месяц не используется.
//		ЭталонныеДанные - ТаблицаЗначений - Эталонные данные, с которыми происходит сравнение.
// Возвращаемое значение:
//	МенеджерВременныхТаблиц - Содержит временные таблицы с выборками по указанным регистрам.
Функция СохранитьЭталонныеДанные(КонтрольныеРегистры, ПараметрыЗапроса = Неопределено, МассивРегистраторов = Неопределено, ЭталонныеДанные = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = Тестирование.СохранитьЭталонныеДанные(КонтрольныеРегистры, ПараметрыЗапроса, МассивРегистраторов, ЭталонныеДанные);
```
</details>

## СравнитьСЭталоннымиДанными
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод выполняет сравнение данных из временных таблиц с данными из контрольных регистров,
//  возвращает поля по которым расходятся данные с детализацией до исходных и результирующих
//  данных.
//
// Параметры:
//  ВременныеТаблицы		 - МенеджерВременныхТаблиц	 - Содержит эталонные данные.
//  КонтрольныеРегистры		 - Массив					 - Список регистров по которым сравниваются данные.
//  ПараметрыЗапроса 		 - см. Тестирование.ПараметрыЗапроса
//  Месяц					 - Дата						 - Начало месяца, за который сравниваются данные.
//  МассивРегистраторов		 - Массив					 - Список документов по которым сохраняются движения.
//  					Если используется данный параметр, то Месяц не используется.
//  ЭталонныеДанные 		 - ТаблицаЗначений			 - Эталонные данные, с которыми происходит сравнение.
//  ДополнительныеПараметры	 - см. ДополнительныеПараметрыФормированияЗапросаСравнения
//
// Возвращаемое значение:
//  Структура - Содержит в себе таблицы с расхождениями по контрольным регистрам.
//
Функция СравнитьСЭталоннымиДанными(ВременныеТаблицы, КонтрольныеРегистры, ПараметрыЗапроса = Неопределено, МассивРегистраторов = Неопределено, ЭталонныеДанные = Неопределено, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = Тестирование.СравнитьСЭталоннымиДанными(ВременныеТаблицы, КонтрольныеРегистры, ПараметрыЗапроса, МассивРегистраторов, ЭталонныеДанные, ДополнительныеПараметры);
```
</details>

## СформироватьЗапрос
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Метод формирует текст запроса по всем полям для указанного объекта метаданных.
//
// Параметры:
//  ПутьКМетаданным				 - Строка	 - Путь к объекту, по которому сохраняются данные.
//  	Пример "РегистрНакопления.СебестоимостьТоваров".
//  СохранитьВоВременнуюТаблицу	 - Булево	 - Результат запроса будет сохранен во временную таблицу вида
//  	"ЭталонИмяОбъектаМетаданных"
//  ОтборПоРегистраторам		 - Булево	 - Необязательный параметр, при установке в истина в запросе будет накладываться
//  	условие на выборку данных, где регистратор в массиве регистраторов. Отбора
//  	по периоду не будет.
//	ЭталоннаяТаблица			 - ТаблицаЗначений - Эталонные данные, с которыми происходит сравнение.
//  ДополнительныеПараметры		 - см. ДополнительныеПараметрыФормированияЗапросаСравнения.
//
// Возвращаемое значение:
//  Строка - Текст запроса.
//
Функция СформироватьЗапрос(ПутьКМетаданным,	СохранитьВоВременнуюТаблицу = Ложь, ОтборПоРегистраторам = Ложь, ЭталоннаяТаблица = Неопределено, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = Тестирование.СформироватьЗапрос(ПутьКМетаданным, СохранитьВоВременнуюТаблицу, ОтборПоРегистраторам, ЭталоннаяТаблица, ДополнительныеПараметры);
```
</details>

## ДополнительныеПараметрыФормированияЗапросаСравнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция-конструктор структуры параметров для формирования запроса сравнения
//
// Возвращаемое значение:
// 	Структура - Описание:
// * ОпределятьОбщееРасхождение - Булево -
// * ПроверятьКонтрольнуюСумму - Булево -
// * ДопустимоеОтклонение - Строка -
// * УсловияОтбораПосле - Строка -
// * УсловияОтбораДо - Строка -
// * ПоляКлючиКоторыеНужноРазвернуть - Массив -
// * СгруппироватьПоИзмерениям - Булево -
// * ЗаменыПолейПосле - Структура -
// * ЗаменыПолейДо - Структура -
// * ИсключаемыеПоля - Структура -
// * ПриРасхожденияхВыбиратьПервые - Число - при установке флага ОпределятьОбщееРасхождение управляет сколько первых
// 		максимальных расхождений будет выводиться при выборке расхождений
//
Функция ДополнительныеПараметрыФормированияЗапросаСравнения() Экспорт
```

Пример вызова
```bsl
Результат = Тестирование.ДополнительныеПараметрыФормированияЗапросаСравнения() 
```
</details>

## ПараметрыЗапроса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция - конструктор создания структуры параметров запроса.
//
// Возвращаемое значение:
//	Структура - структура параметров:
// * НачалоПериода - Дата -
// * КонецПериода - Дата -
// * МассивРегистраторов - Массив -
// * ОтборПоРегистраторам - Булево -
//
Функция ПараметрыЗапроса(Месяц, МассивРегистраторов = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = Тестирование.ПараметрыЗапроса(Месяц, МассивРегистраторов);
```
</details>

## РегистрыСоСлужебнымРегистратором
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РегистрыСоСлужебнымРегистратором() Экспорт
```

Пример вызова
```bsl
Результат = Тестирование.РегистрыСоСлужебнымРегистратором() 
```
</details>

## ИмяПоляРегистратораРегистра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя поля регистратора для регистра. Для регистров со служебным регистратором будет возвращен "ДокументРегистратор",
//	если регистр является независимым регистром сведений, то будет возвращен "Партия".
//
//	Параметры:
//		КоллекцияМетаданных - ОбъектМетаданныхКонфигурация, Строка - анализируемый объект метаданных или его полное имя
//			(как правило регистр накопления или регистр сведений).
//
//	Возвращаемое значение:
//		Строка - имя поля регистратора, которое должно использоваться для данного регистра.
//
Функция ИмяПоляРегистратораРегистра(КоллекцияМетаданных) Экспорт
```

Пример вызова
```bsl
Результат = Тестирование.ИмяПоляРегистратораРегистра(КоллекцияМетаданных) 
```
</details>

## ПолучитьЭталонныеДанные
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьЭталонныеДанные() Экспорт
```

Пример вызова
```bsl
Результат = Тестирование.ПолучитьЭталонныеДанные() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
