---
title: Торговые предложения переопределяемый
slug: erp-uh/торговые-предложения-переопределяемый
---


## ПриОпределенииНастроек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет настройки подсистемы.
//
// Параметры:
//  Настройки - Структура - настройки подсистемы.
//    Ключи:
//    * ДоступнаФункциональностьЗапросаЦен - Булево - флаг наличия функционала запроса цен в прикладном решении.
//    * ИспользоватьХарактеристики - Булево - флаг использования характеристик.
//    * ВариантыПубликацииОстатков - Массив - из ПеречислениеСсылка.ВариантыПубликацииОстатковТорговыеПредложения
//                                   список из доступных вариантов публикации остатков. Если массив заполнен
//                                   не будет, функциональность публикации остатков будет отключена.
//    * ВариантыПубликацииСкидок   - Массив- из ПеречислениеСсылка.ВариантыПубликацииСкидок
//                                   список из доступных вариантов публикации скидок. Если список заполнен
//                                   не будет, функциональность публикации скидок будет отключена.
//
Процедура ПриОпределенииНастроек(Настройки) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПриОпределенииНастроек(Настройки) 
```
</details>

## ФункциональнаяОпцияИспользуется
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет доступность функциональных опций перед открытием формы публикации торговых предложений.
//    В случае, если в процедуре параметр Результат не будет установлен в Истина, будет вызвана процедура
//    ТорговыеПредложенияПереопределяемый.СообщитьОНеобходимостиИспользованияФункциональнойОпции.
//
// Параметры:
//   ИмяФормы - Строка - имя формы, для которой получаются данные.
//   Результат - Булево - признак того, что функциональные опции включены.
//
Процедура ФункциональнаяОпцияИспользуется(Знач ИмяФормы, Результат) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ФункциональнаяОпцияИспользуется(ИмяФормы, Результат) 
```
</details>

## СообщитьОНеобходимостиИспользованияФункциональнойОпции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выдает сообщение пользователю о том, что функциональная опция использования видов номенклатуры отключена.
//
// Параметры:
//  ИмяФормы - Строка - имя формы из которой вызывается сообщение.
//  Используется - Булево - признак того, что функциональная опция включена или нет.
//  Отказ - Булево - признак того, что форму сопоставления номенклатуры открывать не нужно.
//
Процедура СообщитьОНеобходимостиИспользованияФункциональнойОпции(Знач ИмяФормы, Знач Используется, Отказ) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.СообщитьОНеобходимостиИспользованияФункциональнойОпции(ИмяФормы, Используется, Отказ) 
```
</details>

## ЗаполнитьАдресаАбонента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполнение адресов абонента по зарегистрированным организациям и складам.
//
// Параметры:
//  АдресаАбонента - ТаблицаЗначения - таблица для заполнения:
//   * Представление - Строка - представление адреса.
//   * ЗначенияПолей - Строка - адрес в формате XML.
//   * Описание - Строка - комментарий адреса.
//   * Ссылка - Ссылка - объект хранения контактной информации.
//   * Вид - СправочникСсылка.ВидыКонтактнойИнформации - вид контактной информации.
//
Процедура ЗаполнитьАдресаАбонента(АдресаАбонента) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ЗаполнитьАдресаАбонента(АдресаАбонента) 
```
</details>

## ПолучитьСпособыДоставки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получение способов доставки для заполнения по умолчанию значений при формировании заказов.
//
// Параметры:
//  СпособыДоставки - СписокЗначений - возможные значения способа доставки.
//                                     Первое значение является значением по умолчанию.
//  ВидДоставки	- Строка - значение вида доставки, варианты "Самовывоз", "Доставка".
//
Процедура ПолучитьСпособыДоставки(СпособыДоставки, ВидДоставки = Неопределено) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПолучитьСпособыДоставки(СпособыДоставки, ВидДоставки);
```
</details>

## ПолучитьВалютуРегламентированногоУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получение валюты регламентированного учета.
//
// Параметры:
//  Валюта - СправочникСсылка - валюта регламентированного учета.
//
Процедура ПолучитьВалютуРегламентированногоУчета(Валюта) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПолучитьВалютуРегламентированногоУчета(Валюта) 
```
</details>

## ПолучитьИмяСтавкиНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получение имени ставки НДС.
//
// Параметры:
//  Ссылка		 - СправочникСсылка, ПеречислениеСсылка - ссылка на значение ставки НДС прикладного решения.
//  ИмяСтавкиНДС - Строка - идентификатор ставки НДС, вида: "НДС0", "НДС10", НДС10_110, "НДС18", НДС18_118,
//        "НДС20", НДС20_120, "БезНДС".
//
Процедура ПолучитьИмяСтавкиНДС(Знач Ссылка, ИмяСтавкиНДС) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПолучитьИмяСтавкиНДС(Ссылка, ИмяСтавкиНДС) 
```
</details>

## ПолучитьЗначениеСтавкиНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получение значения ставки НДС по идентификатору.
//
// Параметры:
//  ИмяСтавкиНДС - Строка - идентификатор ставки НДС, например "НДС0", "НДС10", "НДС18", "НДС20", "БезНДС".
//  Ссылка		 - СправочникСсылка, ПеречислениеСсылка - ссылка на значение ставки НДС прикладного решения.
//
Процедура ПолучитьЗначениеСтавкиНДС(Знач ИмяСтавкиНДС, Ссылка) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПолучитьЗначениеСтавкиНДС(ИмяСтавкиНДС, Ссылка) 
```
</details>

## ПолучитьПараметрыЕдиницыИзмерения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить единицы измерения.
//
// Параметры:
//  Код	   - Строка - код единицы измерения.
//  Ссылка - Ссылка - ссылку на единицу измерения
//  Представление - Строка - представление единицы измерения в базе.
//
Процедура ПолучитьПараметрыЕдиницыИзмерения(Знач Код, Ссылка, Представление) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПолучитьПараметрыЕдиницыИзмерения(Код, Ссылка, Представление) 
```
</details>

## ЗаполнитьСведенияОНоменклатуре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет основные сведения о номенклатуре. В обработчике следует по колонке "Номенклатура"
//  заполнить колонки "ЕдиницаИзмерения", "Упаковка", "ИспользованиеХарактеристик". При заполнении
//  следует учитывать, что все заполняемые колонки не являются обязательными. Устанавливать значения
//  следует конструкцией ЗаполнитьЗначенияСвойств(Строка, ИсточникДанных, , "Номенклатура").
//
// Параметры:
//  ДанныеНоменклатуры - ТаблицаЗначений, ДанныеФормыКоллекция - заполняемая таблица номенклатуры:
//    * Номенклатура - ОпределяемыйТип.НоменклатураБЭД - ссылка на номенклатуру
//    * ЕдиницаИзмерения - СправочникСсылка - единица измерения номенклатуры
//    * Упаковка - ОпределяемыйТип.УпаковкаНоменклатурыБЭД - упаковка номенклатуры
//    * ИспользованиеХарактеристик - Булево - признак использования характеристик номенклатуры
//
Процедура ЗаполнитьСведенияОНоменклатуре(ДанныеНоменклатуры) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ЗаполнитьСведенияОНоменклатуре(ДанныеНоменклатуры) 
```
</details>

## ПолучитьСвойстваТорговогоПредложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получение свойств торгового предложения.
//
// Параметры:
//  Источник        - СправочникСсылка - источник торгового соглашения, например СправочникСсылка.Соглашения.
//  ЗначенияСвойств - Структура - возвращаемое значение заполнения:
//      * Организация     - ОпределяемыйТип.Организация - организация торгового предложения.
//      * Валюта          - СправочникСсылка            - валюта торгового предложения.
//      * ЦенаВключаетНДС - Булево                      - признак указания цен с учетом НДС.
//
Процедура ПолучитьСвойстваТорговогоПредложения(Знач Источник, ЗначенияСвойств) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПолучитьСвойстваТорговогоПредложения(Источник, ЗначенияСвойств) 
```
</details>

## ДобавитьСлужебныеКолонкиТовары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавление служебных колонок в таблицу товары.
//
// Параметры:
//  Товары - ТаблицаЗначений - исходная таблица с товарами, колонки:
//    Обязательные поля:
//    * Номенклатура   - ОпределяемыйТип.НоменклатураБЭД - номенклатурная позиция.
//    * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатурыБЭД - характеристика номенклатуры.
//    * Упаковка       - ОпределяемыйТип.УпаковкаНоменклатурыБЭД - упаковка номенклатуры.
//    * Количество     - Число - количество.
//    Заполняемые поля:
//    * УпаковкаКод         - Строка - код упаковки.
//    * ЕдиницаИзмеренияКод - Строка - код единицы измерения.
//    * УпаковкаЧислитель   - Число - числитель упаковки номенклатуры.
//    * УпаковкаЗнаменатель - Число - знаменатель упаковки номенклатуры.
//    * Артикул             - Строка - артикул номенклатуры.
//    * Наименование        - Строка - наименование номенклатуры.
//    * Штрихкоды           - Массив из Строка - штрихкоды номенклатуры.
//  ПолучатьШтрихКоды - Булево - признак необходимости заполнения штрихкодов номенклатуры.
//                               Для значения Ложь, штрихкоды не заполняются.
//
Процедура ДобавитьСлужебныеКолонкиТовары(Товары, Знач ПолучатьШтрихКоды = Ложь) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ДобавитьСлужебныеКолонкиТовары(Товары, ПолучатьШтрихКоды);
```
</details>

## СвойстваКонтекстаДокументовДляПоискаПредложений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает значения контекста на основании которого будет производиться поиск предложений
// и которые будут переданы в шапку создаваемых заказов.
//
// Параметры:
//  ПараметрКоманды   - Массив из ДокументСсылка - ссылки на документы для заполнения таблицы поиска товаров в 1С:Бизнес-сеть.
//  КонтекстИсточника - Структура - свойства источника, используемые для формирования заказов.
//  ТаблицаТовары     - ТаблицаЗначений - товары для поиска с реквизитами, состав:
//    * Номенклатура     - СправочникСсылка - номенклатура.
//    * Характеристика   - СправочникСсылка - характеристика номенклатуры.
//    * Упаковка         - СправочникСсылка - упаковка номенклатуры.
//    * Количество       - Число - количество.
//    * ЕдиницаИзмерения - СправочникСсылка - единица измерения номенклатуры.
//    * Числитель        - Число - числитель упаковки.
//    * Знаменатель      - Число - знаменатель номенклатуры.
//    * Склад            - СправочникСсылка - склад для заказа.
//    * КонтекстСтроки   - Произвольный - дополнительные свойства по источнику.
//
Процедура СвойстваКонтекстаДокументовДляПоискаПредложений(Знач ПараметрКоманды, КонтекстИсточника, ТаблицаТовары) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.СвойстваКонтекстаДокументовДляПоискаПредложений(ПараметрКоманды, КонтекстИсточника, ТаблицаТовары) 
```
</details>

## ОпределитьКодЕдиницыИзмерения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается для определения кода единицы измерения по единице измерения.
//  В случае если не определять код единицы измерения внутри данной процедуры,
//  код будет определен как значение реквизита код элемента, в случае, если
//  справочник имеет длину кода не равную нулю.
//
// Параметры:
//  ЕдиницаИзмерения    - СправочникСсылка - единица измерения
//  КодЕдиницыИзмерения - Строка - Код единицы измерения
//
Процедура ОпределитьКодЕдиницыИзмерения(ЕдиницаИзмерения, КодЕдиницыИзмерения) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ОпределитьКодЕдиницыИзмерения(ЕдиницаИзмерения, КодЕдиницыИзмерения) 
```
</details>

## ПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура, вызываемая из обработчика события формы ПриСозданииНаСервере.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма, из обработчика события которой происходит вызов процедуры.
//
Процедура ПриСозданииНаСервере(Форма) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПриСозданииНаСервере(Форма) 
```
</details>

## ОбработатьВыбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработка выбора формы (переопределяемое событие).
// См. описание метода ОбработкаВыбора.
//
// Параметры:
//  Форма             - ФормаКлиентскогоПриложения - форма источника события.
//  ВыбранноеЗначение - Произвольный - выбранное событие.
//  ИсточникВыбора    - Произвольный - форма, где осуществлен выбор.
//
Процедура ОбработатьВыбор(Форма, Знач ВыбранноеЗначение, Знач ИсточникВыбора) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ОбработатьВыбор(Форма, ВыбранноеЗначение, ИсточникВыбора) 
```
</details>

## ОбработатьОповещение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработка оповещения формы (переопределяемое событие).
// См. описание метода ОбработкаОповещения.
//
// Параметры:
//  ИмяСобытия - Строка - имя оповещения.
//  Параметр   - Произвольный - параметр сообщения.
//  Источник   - ФормаКлиентскогоПриложения - форма источника события.
//
Процедура ОбработатьОповещение(Знач ИмяСобытия, Параметр, Источник) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ОбработатьОповещение(ИмяСобытия, Параметр, Источник) 
```
</details>

## УстановитьУсловноеОформлениеЕдиницИзмерения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление для единиц измерения номенклатуры.
//
// Параметры:
// 	 Форма - Форма - управляемая форму.
// 	 ИмяПоляВводаЕдиницИзмерения - Строка - наименование элемента формы, содержащего ед. измерения номенклатуры.
// 	 ПутьКПолюОтбора - Строка - полный путь к реквизиту.
//
Процедура УстановитьУсловноеОформлениеЕдиницИзмерения(Форма, Знач ИмяПоляВводаЕдиницИзмерения, Знач ПутьКПолюОтбора) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.УстановитьУсловноеОформлениеЕдиницИзмерения(Форма, ИмяПоляВводаЕдиницИзмерения, ПутьКПолюОтбора) 
```
</details>

## ПолучитьТоварыДляПодсказокПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавление служебных колонок в таблицу товары.
//
// Параметры:
//  Ссылка            - ДокументСсылка - ссылка на документ с товарами.
//  ПолучатьШтрихКоды - Булево - признак необходимости заполнения штрихкодов номенклатуры.
//  Товары            - ТаблицаЗначений - таблица с товарами:
//   * Номенклатура        - Ссылка - номенклатура.
//   * Характеристика      - Ссылка - характеристика.
//   * Упаковка            - Ссылка - упаковка.
//   * Количество          - Число - количество товара.
//   * УпаковкаКод         - Строка - код упаковки по классификатору ОКЕИ.
//   * ЕдиницаИзмеренияКод - Строка - код единицы измерений по классификатору ОКЕИ.
//   * УпаковкаЧислитель   - Число - числитель упаковки по отношению к единице измерения.
//   * УпаковкаЗнаменатель - Знаменатель - знаменатель упаковки по отношению к единице измерения.
//   * Артикул             - Строка - артикул товара.
//   * Наименование        - Строка - наименование товара.
//   * Штрихкоды           - Массив из Строка - штрихкоды товара.
//
Процедура ПолучитьТоварыДляПодсказокПоСсылке(Знач Ссылка, Знач ПолучатьШтрихКоды, Товары) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПолучитьТоварыДляПодсказокПоСсылке(Ссылка, ПолучатьШтрихКоды, Товары) 
```
</details>

## ЗаполнитьШтрихкодыДляВыгрузки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет данных номенклатуры для выгрузки в сервис 1С:Бизнес-сеть. Выгрузка необходима для формирования
// уведомлений пользователю о наличии в сервисе предложений по товарам, которые он закупает,
// а также уведомлений о наличии спроса на товар, который он продает.
// Данные должны формироваться на основании оборотов организации за день, предшествующий дню даты вызова метода.
//
// Параметры:
//  Организации	    - Массив из ОпределяемыйТип.Организация - список организаций, для которых производится выгрузка.
//  РежимПоставщика - Булево - выгружать только данные по продажам.
//  РежимПокупателя - Булево - выгружать только данные по покупкам.
//  Штрихкоды       - ТаблицаЗначений - данные по штрихкодам:
//    * Организация     - ОпределяемыйТип.Организация - ссылка на организацию.
//    * Штрихкод        - Строка - штрихкод товара.
//    * Артикул         - Строка - артикул товара.
//    * Наименование    - Строка - наименование товара.
//    * ВидНоменклатуры - Строка, Массив - наименование вида номенклатуры (категории, группы номенклатуры)
//                                         или массив из наименований видов номенклатуры по иерархии.
//    * РежимПоставщика - Булево - признак использования штрихкода в продажах.
//    * РежимПокупателя - Булево - признак использования штрихкода в закупках.
//
Процедура ЗаполнитьШтрихкодыДляВыгрузки(Знач Организации, Знач РежимПоставщика, Знач РежимПокупателя, Штрихкоды) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ЗаполнитьШтрихкодыДляВыгрузки(Организации, РежимПоставщика, РежимПокупателя, Штрихкоды) 
```
</details>

## СоздатьДокументЗаказПоставщикуНаОснованииТорговогоПредложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает документ заказ поставщику на основании данных торгового предложения.
//
// Параметры:
//  ДанныеЗаполнения - Структура - данные торгового предложения:
//   * Организация       - ОпределяемыйТип.Организация   - организация торгового предложения.
//   * Контрагент        - ОпределяемыйТип.КонтрагентБЭД - поставщик торгового предложения.
//   * Валюта            - СправочникСсылка - валюта торгового предложения.
//   * СтрокиЗаказа      - ТаблицаЗначений - содержит данные табличной части.
//      ** Номенклатура     - СправочникСсылка.
//      ** Характеристика   - СправочникСсылка.
//      ** ЕдиницаИзмерения - СправочникСсылка.
//      ** Количество       - Число.
//      ** Цена             - Число.
//      ** ЦенаВключаетНДС  - Булево.
//      ** СтавкаНДС        - ПеречислениеСсылка.
//      ** СуммаНДС         - Число.
//      ** СуммаСНДС        - Число.
//      ** Сумма            - Число.
//      ** ИдентификаторНоменклатуры - Строка - идентификатор номенклатуры поставщика.
//   * КонтекстИсточника - Структура - набор данных из основания содержащий данные для заполнения шапки документа.
//   * СпособДоставки    - Ссылка - способ доставки прикладного решения.
//   * АдресДоставки     - Строка - представление адреса доставки.
//   * АдресДоставкиЗначенияПолей - Строка - значение адреса доставки в формате XML.
//  ДокументОбъект - ДокументОбъект - созданный документ для заказа товаров, может быть не записан.
//  Отказ - Булево - признак ошибки при работе метода.
//
Процедура СоздатьДокументЗаказПоставщикуНаОснованииТорговогоПредложения(Знач ДанныеЗаполнения, ДокументОбъект, Отказ) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.СоздатьДокументЗаказПоставщикуНаОснованииТорговогоПредложения(ДанныеЗаполнения, ДокументОбъект, Отказ) 
```
</details>

## УдалитьДокументыЗаказПоставщику
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет созданные заказы поставщику при переходе на шаг назад.
//
// Параметры:
//  ТаблицаДокументы - ТаблицаЗначений - таблица документов для удаления, состав:
//    * Ссылка - ДокументСсылка - ссылка на удаляемый документ.
//  Отказ - Булево - признак результата удаления документов.
//
Процедура УдалитьДокументыЗаказПоставщику(ТаблицаДокументы, Отказ) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.УдалитьДокументыЗаказПоставщику(ТаблицаДокументы, Отказ) 
```
</details>

## ПересчитатьСуммуПоСтроке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Производит пересчет суммы для заказа товаров.
//
// Параметры:
//  СтрокаТоваров - Структура - реквизиты строки товаров для пересчета суммы при формировании заказов:
//    * ПроцентНДС      - Строка - значение НДС, полученное из сервиса.
//    * СтавкаНДС       - Ссылка - значение ставки НДС.
//    * Цена            - Число - цена товара для заказа.
//    * ЦенаВключаетНДС - Булево - признак включения НДС в цену.
//    * Количество      - Число - количество товара для заказа.
//    * Сумма           - Число - сумма заказа по строке.
//    * СуммаНДС        - Число - сумма НДС строки.
//    * СуммаСНДС       - Число - значение суммы с НДС.
//    * ПроцентСкидки   - Число - процент скидки по строке.
//    * СуммаСкидки     - Число - сумма скидки по строке.
//
Процедура ПересчитатьСуммуПоСтроке(СтрокаТоваров) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПересчитатьСуммуПоСтроке(СтрокаТоваров) 
```
</details>

## ЗаполнитьРеквизитыЗаказов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполнение реквизитов заказов.
//
// Параметры:
//  ТаблицаЗаказов	 - ТаблицаЗначений - таблица с ссылками и реквизитами для заполнения:
//                       *Ссылка - ДокументСсылка - ссылка на документ заказа
//                       *Контрагент - ОпределяемыйТип.КонтрагентБЭД - контрагент документа
//                       *Организация - ОпределяемыйТип.Организация - организация документа
//                       *СуммаДокумента - Число - сумма документа
//                       *Валюта - СправочникСсылка -валюта документа
//                       *ЗначениеКартинки - Число - индекс картинки документа коллекции
//                          БиблиотекаКартинок.СтатусыДокумента для отображения статуса документа
//
Процедура ЗаполнитьРеквизитыЗаказов(ТаблицаЗаказов) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ЗаполнитьРеквизитыЗаказов(ТаблицаЗаказов) 
```
</details>

## ПриОпределенииПраваСозданияЗаказовПоставщику
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В обработчике требуется определить право текущего пользователя на создание
//   документов заказа поставщику.
//
// Параметры:
//  ЕстьПраво      - Булево - признак наличия прав у текущего пользователя на
//                         создание документов заказа поставщику
//                         Истина - пользователь имеет права создавать документы
//                         Ложь - права на создание документов отсутствуют
//  ТекстСообщения - Строка - текст сообщения пользователю, выводимое при отсутствии
//                         права на создание документов.
//
Процедура ПриОпределенииПраваСозданияЗаказовПоставщику(ЕстьПраво, ТекстСообщения) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПриОпределенииПраваСозданияЗаказовПоставщику(ЕстьПраво, ТекстСообщения) 
```
</details>

## ИнициализацияЗапросаПубликуемыхТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализация запроса публикуемых прайс листов.
// В запросе необходимо описать получение временных таблицы с предопределенными полями.
// Возможно добавление дополнительных полей для использования в других временных таблицах.
//
// Параметры запроса:
//  * ПрайсЛист - ОпределяемыйТип.ТорговоеПредложение - ссылка на прайс-лист.
//  * Период    - дата - получения периодических данных, например дата установки цены.
//
// Временные таблицы и предопределенные поля:
// ПрайсЛисты - данные прайс листов:
//  * Ссылка                - ОпределяемыйТип.ТорговоеПредложение - ссылка на прайс-лист.
//  * Организация           - ОпределяемыйТип.Организация - ссылка на организацию.
//  * Наименование          - Строка - наименование.
//  * ДатаНачалаДействия    - Дата - дата начала действия.
//  * ДатаОкончанияДействия - Дата - дата окончания действия.
//  * Валюта                - СправочникСсылка.Валюты - валюта публикации.
//  * ЦенаВключаетНДС        - Булево - признак включения НДС в минимальную сумму заказа.
//  * СрокПоставки           - Число - срок поставки товара.
//  * ПоВсемТоварам          - Булево - признак того, что предложение формируется по всем товарам прайс листа.
//  * ВидЦены                - СправочникСсылка.ВидыЦен - вид цены.
//  * МинимальнаяСуммаЗаказа - Число - минимальная сумма для оформления заказа (0 - сумма заказа может быть любой).
//  * ПубликоватьЦены        - Булево - признак публикации цен на товары.
//
// Контрагенты - для которых доступны торговые предложения:
//  * ПрайсЛист - ОпределяемыйТип.ТорговоеПредложение - ссылка прайс-листа.
//  * Контрагент - ОпределяемыйТип.КонтрагентБЭД - ссылка на контрагента.
//
// Контакты - контактная информация:
//  * ПрайсЛист             - ОпределяемыйТип.ТорговоеПредложение - ссылка на прайс-лист.
//  * ПредставлениеКонтакта - Строка - представление контакта, например ФИО.
//  * Телефон               - Строка - телефон.
//  * ЭлектроннаяПочта      - Строка - адрес электронной почты.
//  * ВебСайт               - Строка - адрес сайта.
//
// Товары - данные товаров:
//  * ПрайсЛист        - ОпределяемыйТип.ТорговоеПредложение - ссылка на прайс-лист.
//  * Номенклатура     - ОпределяемыйТип.НоменклатураБЭД - номенклатура.
//  * Характеристика   - ОпределяемыйТип.ХарактеристикаНоменклатурыБЭД - характеристика.
//  * ЕдиницаИзмерения - СправочникСсылка - базовая единица измерения товара.
//  * НаименованиеНоменклатуры   - Строка - публикуемое представление номенклатуры.
//  * НаименованиеХарактеристики - Строка - публикуемое представление характеристики.
//  * ОписаниеНоменклатуры       - Строка - описание номенклатуры.
//  * Артикул              - Строка - артикул товара.
//  * Упаковка             - ОпределяемыйТип.УпаковкаНоменклатурыБЭД - упаковка товара.
//  * НаименованиеУпаковки - Строка - наименование упаковки товара.
//  * ЧислительУпаковки    - Число  - числитель отношения упаковки к единице измерения.
//  * ЗнаменательУпаковки  - Число  - знаменатель отношения упаковки к единице измерения.
//  * КратностьУпаковки    - Число  - кратность количества логистических упаковок в торговом предложении.
//  * СтавкаНДС            - Ссылка - значение ставки НДС.
//  * ЦенаВключаетНДС      - Булево - признак включения НДС в цену
//  * Цена                 - Число  - стоимость товара в валюте публикации.
//  * СрокПоставки         - Число  - срок поставки на склад поставщика.
//  * Наличие              - Число - наличие товара на складах (0 - нет на складе, 1 - мало, 2 - достаточно, 3 - много).
//  * Количество           - Число - количество товара на складах.
//  * ВидНоменклатуры      - СправочникСсылка - группировка номенклатуры в прикладном решении.
//  * Родитель             - СправочникСсылка - родитель номенклатуры в иерархии.
//  * ПричинаИсключенияИзПубликации - ОпределяемыйТип.ПричинаИсключенияИзПубликацииТорговыеПредложения - причина по которой
//         данная позиция не должна быть опубликована в сервисе. В случае, если данная позиция должна быть опубликована
//         содержит в себе пустое значение типа ОпределяемыйТип.ПричинаИсключенияИзПубликацииТорговыеПредложения.
//
// Свойства - характеристики номенклатуры:
//  * Номенклатура   - ОпределяемыйТип.НоменклатураБЭД - номенклатура.
//  * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатурыБЭД - характеристика.
//  * Свойство       - Ссылка - свойство товара.
//  * Значение       - Ссылка - значение свойства товара.
//
// Штрихкоды - штрихкоды номенклатуры:
//  * Номенклатура   - ОпределяемыйТип.НоменклатураБЭД - номенклатура.
//  * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатурыБЭД - характеристика.
//  * Упаковка       - СправочникСсылка - единица измерения упаковки товара.
//  * Значение       - Строка - штрихкод.
//
// Изображения - отбираются актуальные изображения товаров поставщика для публикации:
//  * Номенклатура    - ОпределяемыйТип.НоменклатураБЭД                                   - номенклатура.
//  * Характеристика  - ОпределяемыйТип.ХарактеристикаНоменклатурыБЭД                     - характеристика.
//  * ФайлИзображения - ОпределяемыйТип.ПрисоединенныеФайлыИзображенийТорговоеПредложение - ссылка на
//                        справочник "ПрисоединенныеФайлы", реализованный по технологии библиотеки стандартных подсистем,
//                        обрабатываются с расширением: jpeg, jpg, jpe, png, gif, bmp.
//
// СкидкиЗаОбъемПродаж - описывает цену одной логистической упаковки ТП при приобретении указанного объема товара
// при варианте публикации "Виды скидок". Из выборки необходимо исключить записи где количество = 1:
//  * Номенклатура   - ОпределяемыйТип.НоменклатураБЭД - номенклатура.
//  * Количество     - Число  - при покупке заданного количества логистических упаковок, от.
//  * ВидыЦен        - ОпределяемыйТип.ВидыСкидок
//  * Цена           - Число  - стоимость товара в валюте публикации.
//  * ЦенаДоСкидки   - Число  - в случае, если товар имеет дополнительную скидку, по мимо скидки за объем продаж,
//  								указывается стоимость товара до скидки в валюте публикации.
//  * Комментарий    - Строка - текстовое описание ценового условия.
//
// СкидкиЗаОбъемПродажВидыЦен - описывает цену одной логистической упаковки ТП при приобретении указанного объема товара
// при варианте публикации "Виды цен". Из выборки необходимо исключить записи где количество = 1:
//  * Номенклатура   - ОпределяемыйТип.НоменклатураБЭД - номенклатура.
//  * Количество     - Число  - при покупке заданного количества логистических упаковок, от.
//  * ВидыЦен        - ОпределяемыйТип.ВидыЦен
//  * Цена           - Число  - стоимость товара в валюте публикации.
//  * ЦенаДоСкидки   - Число  - в случае, если товар имеет дополнительную скидку, по мимо скидки за объем продаж,
//  								указывается стоимость товара до скидки в валюте публикации.
//  * Комментарий    - Строка - текстовое описание ценового условия.
//
// СкидкиПроцентСумма - описывает цену одной логистической упаковки ТП для выбранной скидки,
// при варианте публикации "Виды скидок". Из выборки необходимо исключить записи где количество > 1:
//  * Номенклатура   - ОпределяемыйТип.НоменклатураБЭД - номенклатура.
//  * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатурыБЭД - характеристика.
//  * ВидыЦен      - ОпределяемыйТип.ВидыСкидок
//  * Цена           - Число  - стоимость товара в валюте публикации.
//  * Комментарий    - Строка - текстовое описание ценового условия.
//
// СкидкиПроцентСуммаВидыЦен - описывает цену одной логистической упаковки ТП для выбранной скидки,
// при варианте публикации "Виды цен". Из выборки необходимо исключить записи где количество > 1:
//  * Номенклатура   - ОпределяемыйТип.НоменклатураБЭД - номенклатура.
//  * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатурыБЭД - характеристика.
//  * ВидыЦен        - ОпределяемыйТип.ВидыЦен
//  * Цена           - Число  - стоимость товара в валюте публикации.
//  * Комментарий    - Строка - текстовое описание ценового условия.
//
// Параметры:
//  Запрос - Запрос - запрос для получения публикуемых прайс-листов и товаров.
//
Процедура ИнициализацияЗапросаПубликуемыхТоваров(Запрос) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ИнициализацияЗапросаПубликуемыхТоваров(Запрос) 
```
</details>

## ОпределитьОбрабатываемыеРеквизитыКарточкиТорговогоПредложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет возможность изменения реквизитов карточки торгового предложения, которые доступны
//    к интерактивному редактированию из печатной формы.
//
// Реквизиты, для которых доступность редактирования будет установлена в Истина будут выделены
//    цветом и пиктограммой в карточке торгового предложения. При нажатии на значение данного
//    реквизита будет вызван метод ОбработатьНажатиеПоГиперссылкеРеквизитаКарточкиТорговогоПредложения
//    общего модуля ТорговыеПредложенияКлиентПереопределяемый.
//
// Параметры:
//  Реквизиты - Соответствие     - соответствие, определяющее доступность интерактивного изменения
//        реквизитов торгового предложения в карточке торгового предложения:
//            * Ключ - Строка - имя реквизита с учетом имени таблицы. Например:
//                    "Товары.НаименованиеНоменклатуры", "Контакты.Телефон"
//            * Значение - Булево - определяет, будет ли доступно интерактивное изменение реквизита
//
// Пример:
//    Реквизиты["Товары.НаименованиеНоменклатуры"] = Истина;
//    Реквизиты["Контакты.Телефон"] = Ложь;
//
Процедура ОпределитьОбрабатываемыеРеквизитыКарточкиТорговогоПредложения(Реквизиты) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ОпределитьОбрабатываемыеРеквизитыКарточкиТорговогоПредложения(Реквизиты) 
```
</details>

## ОпределитьВладельцевНезаполненныхРеквизитов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается для получения информации об объектах-источниках незаполненных данных при
//    проверке заполнения обязательных реквизитов.
//
// В последствии выводит ссылки для диагностики на форму и при нажатии пользователем на
//    ошибку открывает объект и выводит сообщение, позиционируясь на реквизите для заполнения.
//    В случае открытии формы сообщение выводится стандартно, без позиционирования.
// Проверяемые реквизиты:
//  "Товары.Артикул"
//  "Товары.НаименованиеНоменклатуры"
//  "Товары.НаименованиеХарактеристики"
//  "Товары.НаименованиеУпаковки"
//  "Товары.НаименованиеУпаковки"
//  "Товары.УпаковкаКод"
//  "Товары.УпаковкаКод"
//  "Товары.СтавкаНДС"
//  "Товары.Изображения"
//  "СкидкиЗаОпт.Цена"
//  "Скидки.Цена"
//  "Свойства.Свойство"
//  "Контакты.Телефон"
//  "ПрайсЛисты.АдресЭлектроннойПочты"
//  "ПрайсЛисты.Наименование"
//  "ПрайсЛисты.ДатаНачалаДействия"
//  "ПрайсЛисты.ДатаОкончанияДействия"
//  "КонтрагентыСлужебный.КонтрагентИНН"
//  "КонтрагентыСлужебный.КонтрагентКПП"
//  "ПричинаИсключенияИзПубликации"
//
// Параметры:
//  ПроверяемыйРеквизит        -     Строка - имя колонки и таблицы для публикации товаров
//            см. ТорговыеПредложенияПереопределяемый.ИнициализацияЗапросаПубликуемыхТоваров
//  СтрокаТорговогоПредложения -     СтрокаТаблицыЗначений - строка таблицы для публикации товаров
//            см. ТорговыеПредложенияПереопределяемый.ИнициализацияЗапросаПубликуемыхТоваров
//  ДополнительныйРеквизит     -     ОпределяемыйТип.ДополнительныеРеквизитыРаботаСНоменклатурой, Строка - ссылка на
//  		  дополнительный реквизит. Используется в случае, если ПроверяемыйРеквизит равен "Свойства.Свойство"
//  		  или "Свойства.Значение".
//            уникальный идентификатор строкой. Используется в случае, если необходимо передать уникальный идентификатор
//            объекта, используемого для целей получения информации об объектах-источниках незаполненных данных.
//            см. ТорговыеПредложенияПереопределяемый.ИнициализацияЗапросаПубликуемыхТоваров
//  СсылкаНаОбъект             -     ЛюбаяСсылка - ссылка на объект-владелец данных.
//  ПутьКДанным                -     Строка - путь к данным объекта на открываемой форме
//                                            для заполнения. Если нужно открыть иную форму то указывается полный путь
//                                            до формы и через "|" путь до реквизита указываемой формы.
//  ТекстСообщения             -     Строка - текст сообщения, выводимый пользователю при активации реквизита.
//
// Пример:
//    Если ПроверяемыйРеквизит = "Товары.Артикул" Тогда
//        СсылкаНаОбъект = СтрокаТорговогоПредложения.Номенклатура;
//        ПутьКДанным = "Объект.Артикул";
//        ТекстСообщения = "Не заполнен артикул номенклатуры";
//    ИначеЕсли ПроверяемыйРеквизит = "ПрайсЛисты.АдресЭлектроннойПочты" Тогда
//		СсылкаНаОбъект  = СтрокаТорговогоПредложения.ПрайсЛист;
//		ПутьКДанным = "РегистрСведений.СостоянияСинхронизацииТорговыеПредложения.Форма.НастройкиПубликации|Запись.АдресЭлектроннойПочты";
//		ТекстСообщения = НСтр("ru = 'Необходимо заполнить поле ""Уведомление о заказах по эл.почте"".'");
//    ИначеЕсли ПроверяемыйРеквизит = "СкидкиЗаОпт.Цена"
//		Или ПроверяемыйРеквизит = "Скидки.Цена" Тогда
//
//		СсылкаНаОбъект = СтрокаТорговогоПредложения.ПрайсЛист;
//		ПутьКДанным    = "РегистрСведений.ПрайсЛист.Форма.ФормаПрайсЛиста|";
//
//		ИдентификаторСсылки = Новый УникальныйИдентификатор(ДополнительныйРеквизит);
//		ВидЦеныСсылка = Справочники.ВидыЦен.ПолучитьСсылку(ИдентификаторСсылки);
//		ПредставлениеВидЦены = ВидЦеныСсылка.ПолноеНаименование();
//		ПредставлениеНоменклатуры = СтрокаТорговогоПредложения.Номенклатура.ПолноеНаименование();
//
//		ШаблонСообщения = НСтр("ru = 'Для товара ""%1"" не заполнен вид цены: ""%2""'");
//		ТекстСообщения = СтрШаблон(ШаблонСообщения, ПредставлениеНоменклатуры, ПредставлениеВидЦены);
//    КонецЕсли;
//
Процедура ОпределитьВладельцевНезаполненныхРеквизитов(ПроверяемыйРеквизит, СтрокаТорговогоПредложения, Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ОпределитьВладельцевНезаполненныхРеквизитов(ПроверяемыйРеквизит, СтрокаТорговогоПредложения, );
```
</details>

## ОпределитьОбрабатываемыеПричиныИсключенияИзПубликации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается для определения причин отсутствия позиции торгового предложения в публикации,
//    доступных для исправления интерактивно.
//
// Для указанных в обработчике значений при расшифровке причины будет вызван обработчик
//    ТорговыеПредложенияКлиентПереопределяемый.ОбработатьНажатиеПоГиперссылкеПричиныИсключенияИзПубликации.
//
// Параметры:
//  Причины - Массив из ОпределяемыйТип.ПричинаИсключенияИзПубликацииТорговыеПредложения - значения,
//             для которых доступна расшифровка причины, по которой данная позиция не публикуется в
//             сервисе.
//
// Пример:
//    Причины.Добавить(Перечисления._ДемоПричиныИсключенияИзПубликации.ОтсутствуетНаСкладе);
//    Причины.Добавить(Перечисления._ДемоПричиныИсключенияИзПубликации.НеУказанаЦена);
//
Процедура ОпределитьОбрабатываемыеПричиныИсключенияИзПубликации(Причины) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ОпределитьОбрабатываемыеПричиныИсключенияИзПубликации(Причины) 
```
</details>

## ЗаполнитьПакетПредложений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Не используется
// Заполнение пакета торговых предложений.
//
// Параметры:
//  ТорговоеПредложение	 - СправочникСсылка - ссылка на элемент справочника определяющего торговые предложения,
//                                            например СправочникСсылка.Соглашения.
//  ПакетПредложений	 - Структура - свойства публикуемого торгового предложения.
//
Процедура ЗаполнитьПакетПредложений(Знач ТорговоеПредложение, ПакетПредложений) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ЗаполнитьПакетПредложений(ТорговоеПредложение, ПакетПредложений) 
```
</details>

## ПолучитьРеквизитыНоменклатурыДоступныеДляПубликации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Используется метод РаботаСНоменклатуройПереопределяемый.ПолучитьРеквизитыНоменклатурыДоступныеДляПубликации.
// Получение публикуемых реквизитов номенклатуры.
//
// Параметры:
//  ПубликуемыеРеквизиты - Соответствие - реквизиты справочника Номенклатура, публикуемые для торговых предложений.
//    * Ключ     - Произвольный - значение реквизита сопоставления, см. определяемый тип ДополнительныеРеквизитыРаботаСНоменклатурой.
//    * Значение - Структура - свойства реквизита:
//      ** Представление    - Строка - наименование для отображения.
//      ** ПутьКДанным      - Строка - текст запроса для получения данных.
//      ** ТипЗначения      - ОписаниеТипов - описание типа данных.
//      ** ПустоеЗначение   - Произвольный - Значение реквизита, при котором, он считается не заполненным.
//
Процедура ПолучитьРеквизитыНоменклатурыДоступныеДляПубликации(ПубликуемыеРеквизиты) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПолучитьРеквизитыНоменклатурыДоступныеДляПубликации(ПубликуемыеРеквизиты) 
```
</details>

## ПолучитьДоступныеТипыЗначенийСвойствДляСопоставления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Используется метод РаботаСНоменклатуройПереопределяемый.ПолучитьДоступныеТипыЗначенийСвойствДляСопоставления.
// Получение доступных типов значений свойств для сопоставления.
//
// Параметры:
//  ТипыЗначенийСвойств - СписокЗначений - доступные типы значений, например Тип("СправочникСсылка.Производители").
//
Процедура ПолучитьДоступныеТипыЗначенийСвойствДляСопоставления(ТипыЗначенийСвойств) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПолучитьДоступныеТипыЗначенийСвойствДляСопоставления(ТипыЗначенийСвойств) 
```
</details>

## ПустаяСсылкаРеквизитаОбъектаДляСопоставления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Используется метод РаботаСНоменклатуройПереопределяемый.ПустаяСсылкаРеквизитаОбъектаДляСопоставления.
// Возвращает пустую ссылку реквизита объекта для сопоставления.
//
// Параметры:
//  Ссылка - ЛюбаяСсылка - пустая ссылка для заполнения сопоставления,
//                         например ПланыВидовХарактеристик.ДополнительныеРеквизитыИСведения.
//
Процедура ПустаяСсылкаРеквизитаОбъектаДляСопоставления(Ссылка) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПустаяСсылкаРеквизитаОбъектаДляСопоставления(Ссылка) 
```
</details>

## ИнициализацияСпискаСопоставленияНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Используется метод РаботаСНоменклатуройПереопределяемый.ИнициализацияСпискаСопоставленияНоменклатуры.
// Инициализация динамического списка сопоставления номенклатуры в форме сопоставления номенклатуры.
// Заполняется переопределяемый текст запроса и свойства списка.
//
// Параметры:
//  Список - ЭлементФормы - элемент динамического списка в форме.
//
Процедура ИнициализацияСпискаСопоставленияНоменклатуры(Список) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ИнициализацияСпискаСопоставленияНоменклатуры(Список) 
```
</details>

## ПолучитьДанныеСопоставленияРеквизитов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Используется метод РаботаСНоменклатуройПереопределяемый.ПолучитьДанныеСопоставленияРеквизитов
// Получение данных для сопоставления реквизитов и значений реквизитов информационной базы и сервиса.
//
// Параметры:
//  ОбъектСопоставления      - СправочникСсылка - ссылка на справочник виды номенклатуры.
//  СопоставленныеРеквизиты	 - ТаблицаЗначений - сопоставленные реквизиты в ИБ.
//    * РеквизитОбъекта                 - Произвольный - реквизит.
//    * ИдентификаторРеквизитаКатегории - Строка - идентификатор реквизита категории в сервисе.
//    * Представление                   - Строка - представление реквизита.
//  ДополнительныеРеквизиты  - ТаблицаЗначений - дополнительные реквизиты номенклатуры.
//    * РеквизитОбъекта - Произвольный - реквизит.
//    * ТипЗначения     - ОписаниеТипов - тип реквизита.
//  РасчетСоответствий       - ТаблицаЗначений - таблица количества соответствий значений реквизитов.
//    * РеквизитОбъекта                    - Произвольный - реквизит.
//    * КоличествоЗначенийРеквизита        - Число - количество значений реквизита в ИБ.
//    * КоличествоСопоставленныхРеквизитов - Число - количество сопоставленных значений реквизитов.
//
Процедура ПолучитьДанныеСопоставленияРеквизитов(ОбъектСопоставления, СопоставленныеРеквизиты, ДополнительныеРеквизиты, РасчетСоответствий) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПолучитьДанныеСопоставленияРеквизитов(ОбъектСопоставления, СопоставленныеРеквизиты, ДополнительныеРеквизиты, РасчетСоответствий) 
```
</details>

## ПолучитьСопоставленныеЗначенияРеквизитаВидаНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Используется метод РаботаСНоменклатуройПереопределяемый.ПолучитьСопоставленныеЗначенияРеквизитаВидаНоменклатуры.
// Получение сопоставленных значений реквизита вида номенклатуры.
//
// Параметры:
//  ОбъектСопоставления - СправочникСсылка - ссылка на справочник виды номенклатуры.
//  РеквизитОбъекта	    - Строка, СправочникСсылка - реквизит объекта.
//  ТипЗначения	        - ОписаниеТипов - тип значений реквизита.
//  ЗначенияРеквизита   - ТаблицаЗначений - список сопоставленных реквизитов, колонки:
//   * Значение                                - СправочникСсылка, Строка, Число, Булево - сопоставленное значение.
//   * ИдентификаторЗначенияРеквизитаКатегории - Строка - идентификатор сопоставленного значения.
//   * ПредставлениеЗначенияРеквизитаКатегории - Строка - представление сопоставленного значения.
//
Процедура ПолучитьСопоставленныеЗначенияРеквизитаВидаНоменклатуры(Знач ОбъектСопоставления, Знач РеквизитОбъекта, Знач ТипЗначения, ЗначенияРеквизита) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПолучитьСопоставленныеЗначенияРеквизитаВидаНоменклатуры(ОбъектСопоставления, РеквизитОбъекта, ТипЗначения, ЗначенияРеквизита) 
```
</details>

## ИнициализацияСпискаСопоставленияПоИерархии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Используется метод РаботаСНоменклатуройПереопределяемый.ИнициализацияСпискаСопоставленияПоИерархии.
// Инициализация динамического списка сопоставления номенклатуры в форме сопоставления номенклатуры.
// Заполняется переопределяемый текст запроса и свойства списка.
//
// Параметры:
//  Список - ЭлементФормы - элемент динамического списка в форме.
//
Процедура ИнициализацияСпискаСопоставленияПоИерархии(Список) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ИнициализацияСпискаСопоставленияПоИерархии(Список) 
```
</details>

## ИнициализацияСпискаСопоставленияПоНоменклатуре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Используется метод РаботаСНоменклатуройПереопределяемый.ИнициализацияСпискаСопоставленияПоНоменклатуре.
// Инициализация динамического списка сопоставления номенклатуры в форме сопоставления номенклатуры.
// Заполняется переопределяемый текст запроса и свойства списка.
//
// Параметры:
//  Список - ЭлементФормы - элемент динамического списка в форме.
//
Процедура ИнициализацияСпискаСопоставленияПоНоменклатуре(Список) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ИнициализацияСпискаСопоставленияПоНоменклатуре(Список) 
```
</details>

## ИнициализацияЗапросаСоответствияЗначенийРеквизитовВидаНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Используется метод РаботаСНоменклатуройПереопределяемый.ИнициализацияЗапросаСоответствияЗначенийРеквизитовВидаНоменклатуры.
// Инициализация запроса соответствия значений реквизитов вида номенклатуры.
//
// В запросе необходимо вернуть таблицу содержащую количество значений
// реквизита в информационной базе и количество сопоставленных реквизитов.
// Параметры запроса: &РеквизитОбъекта, &ОбъектСопоставления.
// Поля запроса:
//  * КоличествоЗначенийРеквизита - Число - количество возможных значений реквизита.
//  * КоличествоСопоставленныхРеквизитов - Число - количество реквизитов, сопоставленных в базе.
//
// Параметры:
//  Запрос - Запрос - запрос инициализации, установки параметров
//
Процедура ИнициализацияЗапросаСоответствияЗначенийРеквизитовВидаНоменклатуры(Запрос) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ИнициализацияЗапросаСоответствияЗначенийРеквизитовВидаНоменклатуры(Запрос) 
```
</details>

## УстановитьСвойствоЭлементовФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Отсутствует необходимость в использовании.
//
// Устанавливает значение свойства элементов формы, если находит элемент на форме.
//
// Параметры:
//  ЭлементыФормы  - ВсеЭлементыФормы - элементы формы, среди которых содержится искомый элемент.
//  ИменаЭлементов - Массив из Строка, Строка, Структура - имена искомых элементов.
//  ИмяСвойства    - Строка - имя свойства, для которого будет устанавливаться значение.
//  Значение       - Произвольный - значение, которое будет установлено.
//  УстанавливатьДляПодчиненных - Булево - установить аналогичное свойство для подчиненных элементов искомых элементов.
//
Процедура УстановитьСвойствоЭлементовФормы(ЭлементыФормы, ИменаЭлементов, ИмяСвойства, Значение, УстанавливатьДляПодчиненных = Ложь) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.УстановитьСвойствоЭлементовФормы(ЭлементыФормы, ИменаЭлементов, ИмяСвойства, Значение, УстанавливатьДляПодчиненных);
```
</details>

## ЗаполнитьКонтактнуюИнформациюПоКонтактномуЛицу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Отсутствует необходимость в использовании.
//
// Заполнение контактной информации по контактному лицу.
//
// Параметры:
//  КонтактноеЛицо    - СправочникСсылка - контактное лицо в информационной базе, например СправочникСсылка.ФизическиеЛица.
//  ЭлектроннаяПочта  - Строка - адрес электронной почты.
//  Телефон           - Строка - номер телефона.
//  УведомлятьПоПочте - Булево - признак необходимости уведомления по электронной почте.
//  Перезаполнять     - Булево - признак необходимости перезаполнения информации.
//
Процедура ЗаполнитьКонтактнуюИнформациюПоКонтактномуЛицу(Знач КонтактноеЛицо, ЭлектроннаяПочта, Телефон, УведомлятьПоПочте, Знач Перезаполнять = Ложь) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ЗаполнитьКонтактнуюИнформациюПоКонтактномуЛицу(КонтактноеЛицо, ЭлектроннаяПочта, Телефон, УведомлятьПоПочте, Перезаполнять);
```
</details>

## ПолучитьПараметрыПоискаНоменклатурыСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Отсутствует необходимость в использовании.
// Получить параметры поиска номенклатуры сервиса.
//
// Параметры:
//  Номенклатура	 - Ссылка - номенклатура.
//  Характеристика	 - Ссылка - характеристика.
//  Результат		 - Структура - возвращаемые данные:
//   * НаименованиеНоменклатуры - Строка - имя номенклатуры.
//   * НаименованиеХарактеристики - Строка - наименование характеристики.
//   * Штрихкоды - Массив из Строка - штрихкоды по ссылке, тип строка.
//
Процедура ПолучитьПараметрыПоискаНоменклатурыСервиса(Знач Номенклатура, Знач Характеристика, Результат) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ПолучитьПараметрыПоискаНоменклатурыСервиса(Номенклатура, Характеристика, Результат) 
```
</details>

## ЗаполнитьРеквизитыНоменклатурыДляФормированияЗаказа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устарела. Следует использовать ТорговыеПредложенияПереопределяемый.ЗаполнитьСведенияОНоменклатуре
// Заполнение реквизитов номенклатуры в процедуре формирования заказа.
//
// Параметры:
//  Номенклатура - СправочникСсылка - ссылка на справочник номенклатура.
//  Результат	 - Структура - возвращаемые реквизиты ссылки справочника:
//    * ИспользованиеХарактеристик - Булево - признак использования характеристик номенклатуры.
//    * ЕдиницаИзмерения - СправочникСсылка - единица измерения номенклатуры.
//    * Упаковка - СправочникСсылка - упаковка номенклатуры.
//
Процедура ЗаполнитьРеквизитыНоменклатурыДляФормированияЗаказа(Знач Номенклатура, Результат) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ЗаполнитьРеквизитыНоменклатурыДляФормированияЗаказа(Номенклатура, Результат) 
```
</details>

## ДобавитьКомандуПоискаТорговыхПредложений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавление команды поиска торговых предложений в формах.
//
// Параметры:
//  КомандыСоздатьНаОсновании - ТаблицаЗначений - состав полей см. в функции ВводНаОсновании.СоздатьКоллекциюКомандСоздатьНаОсновании.
//
Процедура ДобавитьКомандуПоискаТорговыхПредложений(КомандыСоздатьНаОсновании) Экспорт
```

Пример вызова
```bsl
ТорговыеПредложенияПереопределяемый.ДобавитьКомандуПоискаТорговыхПредложений(КомандыСоздатьНаОсновании) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
