---
title: Транспортные контейнеры ЭДО
slug: erp-uh/транспортные-контейнеры-эдо
---


## СохранитьКонтейнер
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записывает транспортный контейнер в информационную базу.
//
// Параметры:
// 	ОписаниеКонтейнера - СтрокаТаблицыЗначений из см. СервисЭДО.НоваяТаблицаКонтейнеров
// 	КлючСинхронизации - см. СинхронизацияЭДОКлиентСервер.НовыйКлючСинхронизации
// 	КонтекстДиагностики - см. ОбработкаНеисправностейБЭД.НовыйКонтекстДиагностики
// 	ИмяБезРасширения - Строка - имя файла контейнера
// Возвращаемое значение:
// 	Структура:
// 	  * ТранспортныйКонтейнер - ДокументСсылка.ТранспортныйКонтейнерЭДО
// 	  * Объект - Произвольный - связанный с контейнером объект
Функция СохранитьКонтейнер(ОписаниеКонтейнера, КлючСинхронизации, КонтекстДиагностики, ИмяБезРасширения = "") Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.СохранитьКонтейнер(ОписаниеКонтейнера, КлючСинхронизации, КонтекстДиагностики, ИмяБезРасширения);
```
</details>

## ЗапросВходящихКонтейнеров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание запроса, в результате которого будут содержаться входящие контейнеры.
// Запрос содержит следующие поля:
//   * Ссылка - ДокументСсылка.ТранспортныйКонтейнерЭДО - транспортный контейнер
//   * ВнешнийУИД - Строка - внешний уникальный идентификатор.
//
// Параметры:
// 	ИмяВременнойТаблицы - Строка - таблица, в которую будет помещен результат запроса
// 	Отбор - см. НовыйОтборВходящихКонтейнеров
// Возвращаемое значение:
// 	- См. ОбщегоНазначенияБЭД.НовоеОписаниеЗапроса
Функция ЗапросВходящихКонтейнеров(ИмяВременнойТаблицы, Отбор = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.ЗапросВходящихКонтейнеров(ИмяВременнойТаблицы, Отбор);
```
</details>

## НовыйОтборВходящихКонтейнеров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание отбора входящих контейнеров. См. ЗапросВходящихКонтейнеров.
//
// Возвращаемое значение:
// 	Структура - Описание:
// * ВнешнийИдентификатор - Строка - имя параметра, содержащего внешние идентификаторы контейнеров
Функция НовыйОтборВходящихКонтейнеров() Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.НовыйОтборВходящихКонтейнеров() 
```
</details>

## ДополнитьКонтейнерамиКРаспаковке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет контейнеры, которые будут распаковываться, нераспакованными контейнерами.
//
// Параметры:
//  Контейнеры - Массив из ДокументСсылка.ТранспортныйКонтейнерЭДО - контейнеры к распаковке
//  ИдентификаторыУчетныхЗаписей - Массив из Строка - учетные записи организации
Процедура ДополнитьКонтейнерамиКРаспаковке(Контейнеры, ИдентификаторыУчетныхЗаписей) Экспорт
```

Пример вызова
```bsl
ТранспортныеКонтейнерыЭДО.ДополнитьКонтейнерамиКРаспаковке(Контейнеры, ИдентификаторыУчетныхЗаписей) 
```
</details>

## СоздатьКонтейнер
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает транспортный контейнер.
//
// Параметры:
//  ДанныеОбъектов - см. СинхронизацияЭДО.НовыеДанныеОбъектов
//  КонтекстДиагностики - см. ОбработкаНеисправностейБЭД.НовыйКонтекстДиагностики
//
// Возвращаемое значение:
//  См. НовоеОписаниеКонтейнера
Функция СоздатьКонтейнер(ДанныеОбъектов, КонтекстДиагностики = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.СоздатьКонтейнер(ДанныеОбъектов, КонтекстДиагностики);
```
</details>

## ОбъектыКонтейнеров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает объекты контейнеров.
//
// Параметры:
// 	Контейнеры - Массив из ДокументСсылка.ТранспортныйКонтейнерЭДО
// Возвращаемое значение:
// 	Соответствие из КлючИЗначение:
//    * Ключ - ДокументСсылка.ТранспортныйКонтейнерЭДО
//    * Значение - ДокументСсылка.СообщениеЭДО
Функция ОбъектыКонтейнеров(Контейнеры) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.ОбъектыКонтейнеров(Контейнеры) 
```
</details>

## ПрисоединенныеФайлыКонтейнеров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПрисоединенныеФайлыКонтейнеров(Контейнеры) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.ПрисоединенныеФайлыКонтейнеров(Контейнеры) 
```
</details>

## ПослеОтправкиКонтейнера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. СинхронизацияЭДОСобытия.ПослеОтправкиОбъекта
Процедура ПослеОтправкиКонтейнера(Объект, Контейнер, ОшибкаПередачи, КонтекстДиагностики, Отказ) Экспорт
```

Пример вызова
```bsl
ТранспортныеКонтейнерыЭДО.ПослеОтправкиКонтейнера(Объект, Контейнер, ОшибкаПередачи, КонтекстДиагностики, Отказ) 
```
</details>

## ИзменитьСтатусКонтейнера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменяет статус транспортного контейнера.
//
// Параметры:
// 	ТранспортныйКонтейнер - ДокументСсылка.ТранспортныйКонтейнерЭДО
// 	Статус - ПеречислениеСсылка.СтатусыТранспортныхСообщенийБЭД
// 	КонтекстДиагностики - см. ОбработкаНеисправностейБЭД.НовыйКонтекстДиагностики
// 	Комментарий - Строка - описание причины изменения статуса
// Возвращаемое значение:
// 	Булево - Истина, если статус контейнера изменен
Функция ИзменитьСтатусКонтейнера(ТранспортныйКонтейнер, Статус, КонтекстДиагностики = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.ИзменитьСтатусКонтейнера(ТранспортныйКонтейнер, Статус, КонтекстДиагностики, );
```
</details>

## РаспаковатьКонтейнеры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры:
//  Контейнеры - Массив из ДокументСсылка.ТранспортныйКонтейнерЭДО
//  Отпечатки - см. КриптографияБЭДКлиентСервер.НовыеРезультатыПолученияОтпечатков
//  КонтекстДиагностики - см. ОбработкаНеисправностейБЭД.НовыйКонтекстДиагностики
//
// Возвращаемое значение:
//  См. СформироватьДанныеОбъектов
Функция РаспаковатьКонтейнеры(Контейнеры, Отпечатки, КонтекстДиагностики) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.РаспаковатьКонтейнеры(Контейнеры, Отпечатки, КонтекстДиагностики) 
```
</details>

## РаспаковатьФайлКонтейнера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Распаковывает архив транспортного контейнера.
//
// Параметры:
// 	Файл - ДвоичныеДанные - ZIP-архив
// 	                  - см. РаботаСФайламиБЭД.НовоеОписаниеФайла
// 	КонтекстДиагностики - см. ОбработкаНеисправностейБЭД.НовыйКонтекстДиагностики
// Возвращаемое значение:
// 	Структура:
// * Карточка - см. ПрочитатьКарточкуЭлектронногоДокумента
// * Метаданные - см. ПрочитатьФайлМетаданных
// * Ошибка - см. ПрочитатьФайлОшибки
// * Картинки - см. РаботаСФайламиБЭД.НовоеОписаниеФайла
// * Доверенности - см. ПрочитатьКарточкуМЧД
Функция РаспаковатьФайлКонтейнера(Файл, КонтекстДиагностики = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.РаспаковатьФайлКонтейнера(Файл, КонтекстДиагностики);
```
</details>

## ДвоичныеДанныеТранспортногоКонтейнера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает транспортный контейнер в виде zip-архива.
//
// Параметры:
//	ДанныеОбъекта - СтрокаТаблицыЗначений из см. СинхронизацияЭДО.НовыеДанныеОбъектов
//  КонтекстДиагностики - см. ОбработкаНеисправностейБЭД.НовыйКонтекстДиагностики
// Возвращаемое значение:
//  ДвоичныеДанные
Функция ДвоичныеДанныеТранспортногоКонтейнера(ДанныеОбъекта, КонтекстДиагностики = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.ДвоичныеДанныеТранспортногоКонтейнера(ДанныеОбъекта, КонтекстДиагностики);
```
</details>

## ПриДобавленииОбработчиковОбновления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. СинхронизацияЭДОСобытия.ПриДобавленииОбработчиковОбновления.
Процедура ПриДобавленииОбработчиковОбновления(Обработчики) Экспорт
```

Пример вызова
```bsl
ТранспортныеКонтейнерыЭДО.ПриДобавленииОбработчиковОбновления(Обработчики) 
```
</details>

## ЗапросКонтейнеровОбъектовДляОтправки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗапросКонтейнеровОбъектовДляОтправки(Отбор, ИмяВременнойТаблицы) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.ЗапросКонтейнеровОбъектовДляОтправки(Отбор, ИмяВременнойТаблицы) 
```
</details>

## НовыйОтборКонтейнеровОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НовыйОтборКонтейнеровОбъектов() Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.НовыйОтборКонтейнеровОбъектов() 
```
</details>

## ОбработатьОшибкуЗагрузкиОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбработатьОшибкуЗагрузкиОбъекта(ДанныеОбъекта, КонтекстДиагностики, ТекстОшибки, МожноОтказатьсяОтЗагрузки = Ложь) Экспорт
```

Пример вызова
```bsl
ТранспортныеКонтейнерыЭДО.ОбработатьОшибкуЗагрузкиОбъекта(ДанныеОбъекта, КонтекстДиагностики, ТекстОшибки, МожноОтказатьсяОтЗагрузки);
```
</details>

## ПараметрыКонтейнера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры транспортного контейнера.
//
// Параметры:
// 	ИдентификаторДокументооборота - Строка
// 	ИдентификаторСообщения - Строка
// 	ИдентификаторПакета - Строка
// 	СпособОбмена - ПеречислениеСсылка.СпособыОбменаЭД
// 	ИдентификаторУчетнойЗаписи - Строка
// 	ВидСервисаЭДО - ПеречислениеСсылка.ВидыСервисовЭДО
// Возвращаемое значение:
// 	Структура:
// * Отправитель - Строка - идентификатор отправителя
// * Получатель - Строка - идентификатор получателя
// * Организация - ОпределяемыйТип.Организация
// * Контрагент - ОпределяемыйТип.КонтрагентБЭД
// * ДоговорКонтрагента - ОпределяемыйТип.ДоговорСКонтрагентомЭДО
// * СпособОбмена - ПеречислениеСсылка.СпособыОбменаЭД
// * ВнешнийУИД - Строка
// * АдресРесурсаКонтрагента - Строка
// * Объект - Произвольный
// * Статус - ПеречислениеСсылка.СтатусыТранспортныхСообщенийБЭД
// * ВидСервисаЭДО - Булево
Функция ПараметрыКонтейнера(ИдентификаторДокументооборота, ИдентификаторСообщения, ИдентификаторПакета, Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.ПараметрыКонтейнера(ИдентификаторДокументооборота, ИдентификаторСообщения, ИдентификаторПакета, );
```
</details>

## ПодтвердитьПолучениеКонтейнеров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подтверждает получение всех неподтвержденных контейнеров в сервисе оператора ЭДО.
//
// Параметры:
//  КлючиСинхронизации - см. СинхронизацияЭДОКлиентСервер.НовыеКлючиСинхронизации
//  КонтекстДиагностики - см. ОбработкаНеисправностейБЭД.НовыйКонтекстДиагностики
Процедура ПодтвердитьПолучениеКонтейнеров(КлючиСинхронизации, КонтекстДиагностики) Экспорт
```

Пример вызова
```bsl
ТранспортныеКонтейнерыЭДО.ПодтвердитьПолучениеКонтейнеров(КлючиСинхронизации, КонтекстДиагностики) 
```
</details>

## ПодтвердитьПолучениеКонтейнера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подтверждает получение контейнера в сервисе оператора ЭДО.
//
// Параметры:
//  Контейнер - ДокументСсылка.ТранспортныйКонтейнерЭДО
//  ВнешнийУИД - Строка
//  КлючСинхронизации - см. СинхронизацияЭДОКлиентСервер.НовыйКлючСинхронизации
//  КонтекстДиагностики - см. ОбработкаНеисправностейБЭД.НовыйКонтекстДиагностики
Процедура ПодтвердитьПолучениеКонтейнера(Контейнер, ВнешнийУИД, КлючСинхронизации, КонтекстДиагностики) Экспорт
```

Пример вызова
```bsl
ТранспортныеКонтейнерыЭДО.ПодтвердитьПолучениеКонтейнера(Контейнер, ВнешнийУИД, КлючСинхронизации, КонтекстДиагностики) 
```
</details>

## КонтейнерОтправлен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КонтейнерОтправлен(Контейнер) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.КонтейнерОтправлен(Контейнер) 
```
</details>

## ДанныеДляОтправки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные транспортного контейнера для отправки.
//
// Параметры:
//  ТранспортныйКонтейнер - ДокументСсылка.ТранспортныйКонтейнерЭДО
//
// Возвращаемое значение:
//  Структура:
//   * СпособОбменаЭД - ПеречислениеСсылка.СпособыОбменаЭД
//   * Отправитель - Строка
//   * Получатель - Строка
//   * АдресРесурсаКонтрагента - ПеречислениеСсылка.СпособыОбменаЭД
//   * АдресРесурсаОрганизации - Строка, СправочникСсылка.УчетныеЗаписиЭлектроннойПочты -
Функция ДанныеДляОтправки(ТранспортныйКонтейнер) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.ДанныеДляОтправки(ТранспортныйКонтейнер) 
```
</details>

## ДанныеДляОтправкиПоМассиву
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные транспортных контейнеров для отправки.
//
// Параметры:
//  ТранспортныйКонтейнер - массив, элементы ДокументСсылка.ТранспортныйКонтейнерЭДО
//
// Возвращаемое значение:
// 	КлючИЗначение:
// 		Ключ - ДокументСсылка.ТранспортныйКонтейнерЭДО
// 		Значение -
//  		Структура:
//   			* СпособОбменаЭД - ПеречислениеСсылка.СпособыОбменаЭД
//  			* Отправитель - Строка
//  			* Получатель - Строка
//   			* АдресРесурсаКонтрагента - ПеречислениеСсылка.СпособыОбменаЭД
//   			* АдресРесурсаОрганизации - Строка, СправочникСсылка.УчетныеЗаписиЭлектроннойПочты -
Функция ДанныеДляОтправкиПоМассиву(ТранспортныеКонтейнеры) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.ДанныеДляОтправкиПоМассиву(ТранспортныеКонтейнеры) 
```
</details>

## СтатусыНеРаспакованныхТранспортныхСообщенийБЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив статусов не распакованных транспортных сообщений БЭД.
//
// Возвращаемое значение:
//  Массив из ПеречислениеСсылка.СтатусыТранспортныхСообщенийБЭД
//
Функция СтатусыНеРаспакованныхТранспортныхСообщенийБЭД() Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.СтатусыНеРаспакованныхТранспортныхСообщенийБЭД() 
```
</details>

## ПрочитатьКарточкуМЧД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Читает карточку МЧД из ТК и возвращает результат.
//
// Параметры:
//  ИмяФайла - Строка
//  КаталогРаспаковки - Строка
//
// Возвращаемое значение:
//  Соответствие из КлючИЗначение:
//   * Ключ - Строка - Хеш удостоверяемой подписи
//   * Значение - см. НовоеОписаниеДанныхДоверенности
Функция ПрочитатьКарточкуМЧД(ИмяФайла, КаталогРаспаковки) Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.ПрочитатьКарточкуМЧД(ИмяФайла, КаталогРаспаковки) 
```
</details>

## НовоеОписаниеДанныхДоверенности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает пустое описание данных доверенности.
//
// Возвращаемое значение:
//  Структура:
// * НомерДоверенности - Строка
// * ДоверительИНН - Строка
// * СсылкаНаРеестр - Строка
// * СсылкаНаДоверенностьВРеестре - Строка
// * Доверенность - см. РаботаСФайламиБЭД.НовоеОписаниеФайла
// * Подпись - см. РаботаСФайламиБЭД.НовоеОписаниеФайла
// * ДатаВыдачи - Дата
// * ДатаОкончания - Дата
// * ЭтоФайловаяДоверенность - Булево
Функция НовоеОписаниеДанныхДоверенности() Экспорт
```

Пример вызова
```bsl
Результат = ТранспортныеКонтейнерыЭДО.НовоеОписаниеДанныхДоверенности() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
