---
title: Универсальный обмен с банками
slug: erp-uh/универсальный-обмен-с-банками
---


## СведенияОСервисе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает общую информацию об указанном сервисе обмена с банками.
//
// Параметры:
//  Сервис - ПеречислениеСсылка.СервисыОбменаСБанками - Тип сервиса обмена с банками.
//
// Возвращаемое значение:
//  Структура - Содержит ключи:
//		* ДанныеАктуальны - Булево - признак того, что данные сервиса актуальны, их обновление не требуется.
//		* ОписаниеОшибки  - Строка - Текст ошибки, если возникла, или пустая строка, если нет ошибок.
//		* ТребуетсяПодключениеИнтернетПоддержки - Булево - признак того, что для работы сервиса необходимо подключить Интернет-поддержку.
//
Функция СведенияОСервисе(Сервис) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.СведенияОСервисе(Сервис) 
```
</details>

## АктуализироватьДанныеСервиса_СФлагамиОшибок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет в базе данные информацию о банках и характеристиках из веб-сервиса.
//
// Параметры:
//  Сервис - ПеречислениеСсылка.СервисыОбменаСБанками - Тип сервиса обмена с банками.
//
// Возвращаемое значение:
//   Структура   - содержит флаг ошибки и контект из места ее возникновения.
//                * флаг ОшибкаАвторизацииПоЛогину - см. АвторизацияНаСервере()
//                * флаг ОшибкаПриПолученииТикета - см. АвторизацияНаСервере()
//                * флаг ОшибкаПриПолученииДанных - см. ПолучитьИнформациюОСервисеССервера()
//                * флаг Ошибка - прочая неклассифицированная ошибка. См. ключ ОписаниеОшибки из АвторизацияНаСервере()
//                * структура без ключей - актуализация прошла без ошибок.
//
Функция АктуализироватьДанныеСервиса_СФлагамиОшибок(Сервис) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.АктуализироватьДанныеСервиса_СФлагамиОшибок(Сервис));
```
</details>

## АктуализироватьДанныеСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывает актуализацию данных сервиса и по флагам ошибок заполняет имя события, которым завершилось обновление данных сервиса.
// Может занимать длительное время, рекомендуется вызывать внутри фонового задания.
//
// Параметры:
//  Сервис       - ПеречислениеСсылка.СервисыОбменаСБанками - Тип сервиса обмена с банками.
//
// Возвращаемое значение:
//  Структура - см. УниверсальныйОбменСБанкамиКлиентСервер.РезультатОбновленияДанныхСервиса()
//
Функция АктуализироватьДанныеСервиса(Сервис) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.АктуализироватьДанныеСервиса(Сервис) 
```
</details>

## ЗапуститьУниверсальныйОбменСБанкамиПоСервису
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик параметризованного регламентного задания УниверсальныйОбменСБанками.
//
// Параметры:
//  Сервис                    - ПеречислениеСсылка.СервисОбменаСБанками - сервис, для связи с которым периодически запускается задание.
//  АдресПолученныхТранзакций - Строка - адрес временного хранилища, в который помещается массив новых транзакций.
//  Отбор                     - Структура - структура с параметрами отбора документооборотов.
//    *Организация - СправочникСсылка.Организация - организация для отбора.
//    *Банк - СправочникСсылка.БанкиУниверсальногоОбмена - банк для отбора.
Процедура ЗапуститьУниверсальныйОбменСБанкамиПоСервису(Сервис, АдресПолученныхТранзакций = Неопределено, Отбор = Неопределено) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ЗапуститьУниверсальныйОбменСБанкамиПоСервису(Сервис, АдресПолученныхТранзакций, Отбор);
```
</details>

## ХарактеристикиУслугБанков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значения характеристик по их именам для указанного сервиса.
// У банков сервиса должен быть установлен признак Активен.
//
// Параметры:
//  Сервис - ПеречислениеСсылка.СервисыОбменаСБанками - Тип сервиса обмена с банками.
//	Характеристики - Строка, Массив - Имена характеристик, которые требуется вернуть.
//		Если не указаны, то возвращаются значения всех имеющихся характеристик.
//	Банки - Массив - Массив ссылок на справочник БанкиУниверсальногоОбмена,
//		для которых требуется вернуть характеристики.
//		Если не передан, то возвращаются данные по всем банкам.
//
// Возвращаемое значение:
//  ТаблицаЗначений - Содержит колонки:
//		* Банк - СправочникСсылка.БанкиУниверсальногоОбмена - Банк.
//		* Характеристика - Строка - Имя характеристики.
//		* Значение - ХранилищеЗначения - Значение характеристики.
//
Функция ХарактеристикиУслугБанков(Сервис, Характеристики = Неопределено, Банки = Неопределено, ВозвращатьНеактивные = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ХарактеристикиУслугБанков(Сервис, Характеристики, Банки, ВозвращатьНеактивные);
```
</details>

## РеквизитыБанков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает подробную информацию для указанного списка банков.
//
// Параметры:
//  Банки - Массив - Массив ссылок на справочник БанкиУниверсальногоОбмена.
//	Поля - Строка, Массив - Имена полей через запятую, которые необходимо вернуть.
//		Если не указан, то загружаются все поля.
//		Используется для сокращения времени загрузки информации из базы, которая требуется редко.
//		В качестве имен полей необходимо указывать имена колонок возвращаемой таблицы (см. Возвращаемое значение).
//
// Возвращаемое значение:
//  ТаблицаЗначений - Содержит следующие колонки:
//		* Банк   - СправочникСсылка.БанкиУниверсальногоОбмена - Банк.
//		* Наименование - Строка - Краткое наименование банка.
//		* НаименованиеПолное - Строка - Полное официальое наименование банка.
//		* ИНН    - Строка - ИНН банка.
//		* ОГРН   - Строка - ОГРН банка.
//		* Адрес  - Строка - Юридический адрес банка в формате JSON, как определено в подсистеме КонтактнаяИнформация БСП.
//		* СписокБИК - Массив - Массив строк с БИК-ами отделений банка.
//		* Логотип - ДвоичныеДанные - Двоичные данные с картинкой логотипам банка.
//
//	Колонки таблицы, имена которых не были запрошены при вызове функции, содержат пустое значение.
//
Функция РеквизитыБанков(Банки, Знач Поля = "") Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.РеквизитыБанков(Банки, Поля);
```
</details>

## РеквизитыБанка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает подробную информацию для конкретного банка.
//
// Параметры:
//  Банк - СправочникСсылка.БанкиУниверсальногоОбмена - Банк.
//	Поля - Строка, Массив - Список имен полей через запятую, которые необходимо вернуть.
//		См. имена колонок таблицы, возвращаемой функцией РеквизитыБанков().
//
// Возвращаемое значение:
//	Структура - Содержит ключи как у колонок таблицы, возвращаемой функцией РеквизитыБанков().
//
Функция РеквизитыБанка(Банк, Поля = "") Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.РеквизитыБанка(Банк, Поля);
```
</details>

## ДатаПоследнегоОбновленияСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дату последнего обращения к сервису.
//
// Параметры:
//	Сервис - ПеречислениеСсылка.СервисыОбменаСБанками
//
// Возвращаемое значение:
//	Дата
//
Функция ДатаПоследнегоОбновленияСервиса(Сервис) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ДатаПоследнегоОбновленияСервиса(Сервис) 
```
</details>

## ХарактеристикиСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение общих характеристик сервиса без привязки к конкретным банкам.
//
// Параметры:
//  Сервис - ПеречислениеСсылка.СервисыОбменаСБанками - Тип сервиса обмена с банками.
//
// Возвращаемое значение:
//	ХранилищеЗначения или Неопределено - значение характеристики
//
Функция ХарактеристикиСервиса(Сервис) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ХарактеристикиСервиса(Сервис) 
```
</details>

## СервисСуществует
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, возможно ли использовать сервис в данной конфигурации.
//
// Параметры:
//  ИмяСервиса   - Строка - идентификатор сервиса, совпадающий именем значения перечисления СервисыОбменаСБанками.
//
// Возвращаемое значение:
//   Булево      - Истина, если сервис можно использовать; иначе Ложь.
//
Функция СервисСуществует(ИмяСервиса) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.СервисСуществует(ИмяСервиса) 
```
</details>

## ВерсияСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает версию сервиса в формате X.Y.
//
// Параметры:
//	Сервис - Перечисление.СервисыОбменаСБанками - Ссылка на сервис.
//
// Возвращаемое значение:
//	Строка - версия сервиса или "", если сервис не определен.
//
Функция ВерсияСервиса(Сервис) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ВерсияСервиса(Сервис) 
```
</details>

## СемействоКонфигураций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает идентификатор семейства конфигураций.
//
// Возвращаемое значение:
//	Строка - идентификатор семейства конфигураций.
//
Функция СемействоКонфигураций() Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.СемействоКонфигураций() 
```
</details>

## ИмяКонфигурации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя конфигурации.
//
// Возвращаемое значение:
//	Строка - имя конфигурации.
//
Функция ИмяКонфигурации() Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ИмяКонфигурации() 
```
</details>

## ВерсияКонфигурации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает версию текущей конфигурации.
//
// Возвращаемое значение:
//	Строка - версия текущей конфигурации.
//
Функция ВерсияКонфигурации() Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ВерсияКонфигурации() 
```
</details>

## СоставВерсииКонфигурации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает составные элементы версии конфигурации.
//
// Параметры:
//  ВерсияКонфигурации - Строка - строковое представление версии конфигурации.
//
// Возвращаемое значение:
//	Структура - составные элементы версии конфигурации. См. функцию НовыйСоставВерсииКонфигурации().
//
Функция СоставВерсииКонфигурации(ВерсияКонфигурации) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.СоставВерсииКонфигурации(ВерсияКонфигурации) 
```
</details>

## ПодготовитьДанныеДляОтветныхТранзакций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПодготовитьДанныеДляОтветныхТранзакций(Сервис, ВходящиеТранзакции) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ПодготовитьДанныеДляОтветныхТранзакций(Сервис, ВходящиеТранзакции) 
```
</details>

## НайтиТранзакциюПоИдентификатору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НайтиТранзакциюПоИдентификатору(Идентификатор) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.НайтиТранзакциюПоИдентификатору(Идентификатор) 
```
</details>

## НайтиТранзакциюВТаблице
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строку данных транзакции указанного типа с наибольшей датой, но не ранее указанной даты.
// Возвращается самая последняя по дате транзакция.
//
// Параметры:
//	ТаблицаДанныхТранзакций - ТаблицаЗначений - результат выполнения функции РеквизитыТранзакций.
//	ТипТранзакции - ПеречислениеСсылка.ТипыТранзакцийОбменаСБанками,
//			ПеречислениеСсылка.ТипыТранзакцийОбменаСБанками<ИмяСервиса>, Массив - тип транзакции для поиска или массив типов транзакций.
//	НеРанееДаты - Дата - дата для фильрации транзакций по ДатаТранспорта.
//	Основание - СправочникСсылка.ТранзакцииОбменаСБанками - транзакция-основание.
//	ВозвращатьВсеНайденные - Булево - если Истина, то будут возвращены все найденные транзакции, по умолчанию возвращается самая последняя по дате.
// Возвращаемое значение:
//	СтрокаТаблицыЗначений - строка с данными транзакции.
Функция НайтиТранзакциюВТаблице(Знач ТаблицаДанныхТранзакций, Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.НайтиТранзакциюВТаблице(ТаблицаДанныхТранзакций, );
```
</details>

## ОтправитьТранзакцииНаСервер
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет отправку подготовленных транзакций (транспортных контейнеров)
// на сервер обмена с банками.
//
// Параметры:
//	Транзакции - Массив - Содержит элементы типа СправочникСсылка.ТранзакцииОбменаСБанками.
//
// Возвращаемое значение:
//	Структура - Содержит ключи:
//		* Выполнено - Булево - Признак успешного выполнения.
//		* ОписаниеОшибки - Строка - Текст ошибки.
//		* КоличествоОтправленных - Число - количество отправленных транзакций.
//
Функция ОтправитьТранзакцииНаСервер(Сервис, Транзакции, ПараметрыПрогрессаВыполнения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ОтправитьТранзакцииНаСервер(Сервис, Транзакции, ПараметрыПрогрессаВыполнения);
```
</details>

## УстановитьУсловиеИПараметрЗапросаИзОтбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьУсловиеИПараметрЗапросаИзОтбора(Отбор, Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.УстановитьУсловиеИПараметрЗапросаИзОтбора(Отбор, );
```
</details>

## ОрганизацияПредмета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОрганизацияПредмета(Сервис, Предмет) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ОрганизацияПредмета(Сервис, Предмет) 
```
</details>

## ДобавитьНаборФильтровПоТранзакцямИзОтбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьНаборФильтровПоТранзакцямИзОтбора(Отбор, Запрос, ВключаяПомеченныеНаУдаление = Ложь) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ДобавитьНаборФильтровПоТранзакцямИзОтбора(Отбор, Запрос, ВключаяПомеченныеНаУдаление);
```
</details>

## ПротоколОбработкиОтчетностиБанком
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПротоколОбработкиОтчетностиБанком(ПредметИлиТранзакция, ТипыДокументовПротокола, ТипыТранзакцийПротокола = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ПротоколОбработкиОтчетностиБанком(ПредметИлиТранзакция, ТипыДокументовПротокола, ТипыТранзакцийПротокола);
```
</details>

## ТранзакцияОшибки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТранзакцияОшибки(Документооборот) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ТранзакцияОшибки(Документооборот) 
```
</details>

## ТранзакцииПоТипу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает транзакции указанного типа
//
// Параметры:
//  Тип - ОпределяемыйТип.ТипыТранзакцийОбменаСБанками - тип транзакции для фильтра.
//  Отбор - Структура - структура с параметрами фильтрации.
// Возвращаемое значение:
//  Массив - Содержит СправочникСсылка.ТранзакцииОбменаСБанками.
//
Функция ТранзакцииПоТипу(Сервис, ТипТранзакции, Знач Отбор = Неопределено, ВключаяПомеченныеНаУдаление = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ТранзакцииПоТипу(Сервис, ТипТранзакции, Отбор, ВключаяПомеченныеНаУдаление);
```
</details>

## ТранзакцииПоПредмету
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает транзакции обмена с банками, которые связаны с переданным предметом.
//
// Параметры:
//  Предмет - ЛюбаяСсылка - Ссылка на предмет обмена.
//	Отбор - Структура - Описывает условия отбора (необязательный). Может содержать один или несколько ключей:
//		* Организация - СправочникСсылка.Организация, Массив - Ссылка или массив ссылок организаций.
//		* Банк - СправочникСсылка.БанкиУниверсальногоОбмена, Массив - Ссылка или массив ссылок банков.
//		* Статус - ПеречислениеСсылка.СтатусыТранзакций, Массив - Ссылка или массив ссылок статусов.
//		* Документооборот - СправочникСсылка.ДокументооборотыОбменаСБанками, Массив - Ссылка или массив ссылок документооборотов.
//		* ТипТранзакции - ПеречислениеСсылка.ТипыТранзакцийОбменаСБанкамиXXX, Массив - Ссылка или массив ссылок типов транзакций.
//
// Возвращаемое значение:
//  Массив - Содержит СправочникСсылка.ТранзакцииОбменаСБанками.
//
Функция ТранзакцииПоПредмету(Предмет, Знач Отбор = Неопределено, ВключаяПомеченныеНаУдаление = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ТранзакцииПоПредмету(Предмет, Отбор, ВключаяПомеченныеНаУдаление);
```
</details>

## ТранзакцииПоДокументообороту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает транзакции указанного документооборота, отсортированные по убыванию Даты.
//
// Параметры:
//  Документооборот - СправочникСсылка.ДокументооборотыОбменаСБанками - Ссылка на документооборот.
// Возвращаемое значение:
//  Массив - Содержит СправочникСсылка.ТранзакцииОбменаСБанками.
//
Функция ТранзакцииПоДокументообороту(Документооборот, Знач Отбор = Неопределено, ВключаяПомеченныеНаУдаление = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ТранзакцииПоДокументообороту(Документооборот, Отбор, ВключаяПомеченныеНаУдаление);
```
</details>

## ДокументооборотыПоПредмету
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает документообороты обмена с банками, которые связаны с переданным предметом.
//
// Параметры:
//  Предмет - ЛюбаяСсылка - Ссылка на предмет обмена.
//	Отбор - Структура - Описывает условия отбора (необязательный). Может содержать один или несколько ключей:
//		* Организация - СправочникСсылка.Организация, Массив - Ссылка или массив ссылок организаций.
//		* Банк - СправочникСсылка.БанкиУниверсальногоОбмена, Массив - Ссылка или массив ссылок банков.
//
// Возвращаемое значение:
//  Массив - Содержит СправочникСсылка.ДокументооборотыОбменаСБанками.
//
Функция ДокументооборотыПоПредмету(Предмет, Знач Отбор = Неопределено, ВключаяПомеченныеНаУдаление = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ДокументооборотыПоПредмету(Предмет, Отбор, ВключаяПомеченныеНаУдаление);
```
</details>

## ПоследнийДокументооборотПоПредмету
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПоследнийДокументооборотПоПредмету(Предмет, Знач Отбор = Неопределено, ВключаяПомеченныеНаУдаление = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ПоследнийДокументооборотПоПредмету(Предмет, Отбор, ВключаяПомеченныеНаУдаление);
```
</details>

## РеквизитыТранзакций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу значений со свойствами переданных транзакций.
//
// Параметры:
//  Транзакции - Массив - Содержит ссылки на транзакции.
//  Сервис     - Перечисление.СервисыОбменаСБанками - сервис для фильтрации запроса к регистру статусов.
// Возвращаемое значение:
//  ТаблицаЗначений - См. переменную Результат.
//
Функция РеквизитыТранзакций(Транзакции, Сервис = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.РеквизитыТранзакций(Транзакции, Сервис);
```
</details>

## РеквизитыТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает свойства указанной транзакции.
//
// Параметры:
//	Транзакция - СправочникСсылка.ТранзакцииОбменаСБанками - Ссылка на транзакцию.
//
// Возвращаемое значение:
//	Структура - Содержит ключи, одноименные колонка из результата функции РеквизитыТранзакций().
//
Функция РеквизитыТранзакции(Транзакция) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.РеквизитыТранзакции(Транзакция) 
```
</details>

## РеквизитыДокументооборотов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает свойства указанных документоооборотов.
//
// Параметры:
//  Документообороты - Массив - Содержит ссылки на справочник ДокументооборотыОбменаСБанками.
//
// Возвращаемое значение:
//  ТаблицаЗначений - см. переменную Результат
//
Функция РеквизитыДокументооборотов(Документообороты) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.РеквизитыДокументооборотов(Документообороты) 
```
</details>

## РеквизитыДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает свойства указанного документооборота.
//
// Параметры:
//  Документооборот - СправочникСсылка.ДокументооборотыОбменаСБанками - Ссылка на документооборот.
//
// Возвращаемое значение:
//  Структура - Содержит ключи, одноименные колонкам результата функции РеквизитыДокументооборотов().
//
Функция РеквизитыДокументооборота(Документооборот) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.РеквизитыДокументооборота(Документооборот) 
```
</details>

## ПометитьНаУдалениеТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помечает на удаление указанную транзакцию.
//
// Параметры:
//	Транзакция - СправочникСсылка.ТранзакцииОбменаСБанками - Ссылка на транзакцию.
//
Процедура ПометитьНаУдалениеТранзакции(Знач Транзакции) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ПометитьНаУдалениеТранзакции(Транзакции) 
```
</details>

## ПометитьНаУдалениеДокументооборот
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помечает на удаление указанный документооборот.
//
// Параметры:
//  Документооборот - СправочникСсылка.ДокументооборотыОбменаСБанками - Ссылка на документооборот.
//
Процедура ПометитьНаУдалениеДокументооборот(Документооборот) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ПометитьНаУдалениеДокументооборот(Документооборот) 
```
</details>

## УстановитьСтатусОжиданияОтветаОтБанка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменяет статус ожидания ответа от банка.
//
// Параметры:
//  Документооборот - СправочникСсылка.ДокументооборотыОбменаСБанками - Ссылка на документооборот.
//
Функция УстановитьСтатусОжиданияОтветаОтБанка(Документооборот, ОжидаетсяОтвет) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.УстановитьСтатусОжиданияОтветаОтБанка(Документооборот, ОжидаетсяОтвет) 
```
</details>

## ЗавершитьДокументооборот
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает дату завершения документооборота и признак ожидания ответа от банка.
Функция ЗавершитьДокументооборот(Документооборот, ДатаЗавершения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ЗавершитьДокументооборот(Документооборот, ДатаЗавершения);
```
</details>

## ТранзакцииТребующиеРасшифровки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает идентификаторы нерасшифрованных транзакций, поступивших в рамках указанного типа сервиса обмена.
//
// Параметры:
//  Сервис - ПеречислениеСсылка.СервисыОбменаСБанками - Тип сервиса обмена.
//  Организации - Массив, СправочникСсылка.Организации - Организация или массив организаций,
//		для которой требуется получить нерасшифрованные транзации.
//		Необязательный.
//  СписокТранзакций - Массив - транзакции, которые требуется проверить на необходимость расшифровки.
//		Необязательный.
// Возвращаемое значение:
//  Массив - Содержит ссылки на справочник ТранзакцииОбменаСБанками.
//
Функция ТранзакцииТребующиеРасшифровки(Сервисы = Неопределено, Организации = Неопределено, Транзакции = Неопределено, Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ТранзакцииТребующиеРасшифровки(Сервисы, Организации, Транзакции, );
```
</details>

## ПрефиксИмяФайлаПодписиПрисоединенныеФайлы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПрефиксИмяФайлаПодписиПрисоединенныеФайлы() Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ПрефиксИмяФайлаПодписиПрисоединенныеФайлы() 
```
</details>

## ПараметрыСоздатьТранзакцииИзДанныхЖурналаОперацийСФайлами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПараметрыСоздатьТранзакцииИзДанныхЖурналаОперацийСФайлами() Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ПараметрыСоздатьТранзакцииИзДанныхЖурналаОперацийСФайлами() 
```
</details>

## СоздатьТранзакцииИзДанныхЖурналаОперацийСФайлами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// создает транзакции из данных регистра сведений ЖурналОперацийСФайламиОбменаСБанками.
//
// Параметры:
//  Параметры - Структура - параметры создания транзакций см. функцию ПараметрыСоздатьТранзакцииИзДанныхЖурналаОперацийСФайлами.
//
// Возвращаемое значение:
//  Структура - результат выполнения функции
//		* Выполнено - признак успешного выполнения операции.
//		* Транзакции - Массив - созданные транзакции.
//		* ОписаниеОшибки - Строка - описание ошибки при создании транзакций, заполняется, если в поле Выполнено возвращается Ложь.
Функция СоздатьТранзакцииИзДанныхЖурналаОперацийСФайлами(Параметры) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.СоздатьТранзакцииИзДанныхЖурналаОперацийСФайлами(Параметры) 
```
</details>

## ПолучитьСписокТиповДокументовТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив с типам документов для указанного сервиса и транзакции.
//
// Параметры:
//  Сервис - ПеречислениеСсылка.СервисыОбменаСБанками - Тип сервиса обмена.
//	ТипТранзакции - ПеречислениеСсылка.* - Значение перечисления из определямого типа ТипыТранзакцийОбменаСБанками.
//
// Возвращаемое значение:
//	Массив - Содержит значения перечисления из определяемого типа ТипыДокументовОбменаСБанками.
//
Функция ПолучитьСписокТиповДокументовТранзакции(Сервис, ТипТранзакции) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ПолучитьСписокТиповДокументовТранзакции(Сервис, ТипТранзакции) 
```
</details>

## ПредметТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПредметТранзакции(Транзакция) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ПредметТранзакции(Транзакция) 
```
</details>

## ВременныеДанныеТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает информацию о временных файлах транзакции, сами данные и результат криптоопераций,
// при установке соответсвующих флагов.
// кроме данных регистра возвращаются адреса на содержимое регистра
Функция ВременныеДанныеТранзакции(Идентификатор, Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ВременныеДанныеТранзакции(Идентификатор, );
```
</details>

## ПараметрыПомещенияВЖурналОперацийСФайлами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров для помещения во временные данные транзакции
// для подписания и последующей отправки.
//
// Возвращаемое значение:
//	Структура
//
Функция ПараметрыПомещенияВЖурналОперацийСФайлами() Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ПараметрыПомещенияВЖурналОперацийСФайлами() 
```
</details>

## ПоместитьВЖурналОперацияСФайлами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает исходные данные файла для отправки во временный пул файлов, которые требуется подписать и отправить.
//
// Параметры:
//	Параметры - Структура - см. ПараметрыПомещенияВЖурналОперацийСФайлами().
//  ОписаниеОшибки - Строка - Текст ошибки, если она возникла в процессе работы.
//
// Возвращаемое значение:
//	Структура - Содержит ключи:
//		* Выполнено - Булево - Истина, если операция успешно выполнена.
//		* ОписаниеОшибки - Строка - Текст ошибки, если возникла.
//
Функция ПоместитьВЖурналОперацияСФайлами(Параметры) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ПоместитьВЖурналОперацияСФайлами(Параметры) 
```
</details>

## ВыбратьЗаписиЖурналаОперацийСФайламиПоИдентификатору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает из регистра комплект файлов по идентификатору.
//
Функция ВыбратьЗаписиЖурналаОперацийСФайламиПоИдентификатору(Идентификатор, ВозвращатьИсходныеДанные = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ВыбратьЗаписиЖурналаОперацийСФайламиПоИдентификатору(Идентификатор, ВозвращатьИсходныеДанные);
```
</details>

## УдалитьЗаписиЖурналаОперацийСФайламиПоИдентификатору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция УдалитьЗаписиЖурналаОперацийСФайламиПоИдентификатору(Идентификатор) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.УдалитьЗаписиЖурналаОперацийСФайламиПоИдентификатору(Идентификатор) 
```
</details>

## ОчиститьХранилищаЗначенийЖурналаОперацийСФайлами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОчиститьХранилищаЗначенийЖурналаОперацийСФайлами(Идентификатор, УстановитьПометкуОЗавершении = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ОчиститьХранилищаЗначенийЖурналаОперацийСФайлами(Идентификатор, УстановитьПометкуОЗавершении);
```
</details>

## ПодготовитьАрхивыВЖурналеОперацийСФайлами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПодготовитьАрхивыВЖурналеОперацийСФайлами(Идентификатор, ОтпечатокСертификата, ПараметрыПрогрессаВыполнения) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ПодготовитьАрхивыВЖурналеОперацийСФайлами(Идентификатор, ОтпечатокСертификата, ПараметрыПрогрессаВыполнения) 
```
</details>

## МаркерыБезопасностиСервисаКриптографии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция МаркерыБезопасностиСервисаКриптографии() Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.МаркерыБезопасностиСервисаКриптографии() 
```
</details>

## УстановитьМаркерыБезопасностиСервисаКриптографии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Копия метода СервисКриптографииСлужебный.УстановитьМаркерыБезопасности
Процедура УстановитьМаркерыБезопасностиСервисаКриптографии(МаркерыБезопасности) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.УстановитьМаркерыБезопасностиСервисаКриптографии(МаркерыБезопасности) 
```
</details>

## ПодписатьИЗашифроватьДанныеВЖурналеОперацийСФайлами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет подписание и шифрование файлов данных в регистре сведений
// ЖурналОперацийСФайламиОбменаСБанками с помощью сертификата электронной подписи в облаке.
//
// Параметры:
//	Идентификатор - Строка - Строка с уникальным идентификатором комплекта файлов, которые необходимо обработать.
//	ОтпечатокСертификата - Строка - Отпечаток сертификата организации, которым необходимо использовать.
//  ПараметрыПрогрессаВыполнения - Структура - будет передаваться при вызове ДлительныеОперации.СообщитьПрогресс().
//                                             Если параметр не задан, то сообщения о прогрессе формироваться не будут.
//  ФормироватьОтветноеСообщениеБанка - Булево - параметр для тестирования,
//  ПараметрыПроверкиСертификата - Структура - см. УниверсальныйОбменСБанкамиКлиентСервер.ПараметрыОтбораСертификата
// Возвращаемое значение:
//	Структура - Содержит ключи:
//		*
//
Функция ПодписатьИЗашифроватьДанныеВЖурналеОперацийСФайлами( Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ПодписатьИЗашифроватьДанныеВЖурналеОперацийСФайлами();
```
</details>

## РасшифроватьИПроверитьПодписьВЖурналеОперацийСФайлами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Расшифровывает и проверяет подписи в журнале операций. Может возвращать предупреждения.
Функция РасшифроватьИПроверитьПодписьВЖурналеОперацийСФайлами(Идентификатор, Транзакция) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.РасшифроватьИПроверитьПодписьВЖурналеОперацийСФайлами(Идентификатор, Транзакция) 
```
</details>

## ОписаниеСтатусаДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру с полями статуса документооборота.
//
// Возвращаемое значение:
//   Структура   - описывает статус взаимодействия в рамках определенного документооборота:
//                 * Завершен - Булево - если Истина, то дальнейших сообщений не будет.
//                 * ДатаЗавершения - Дата, Неопределено - если Неопределено, то в качестве даты завершения
//                                                         будет установлена текущая дата;
//                 * ОжидаетсяОтвет - Булево - Истина, если ожидается сообщение от банка;
//
Функция ОписаниеСтатусаДокументооборота() Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ОписаниеСтатусаДокументооборота() 
```
</details>

## ПолучитьТранзакцииДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьТранзакцииДокументооборота(Документооборот, Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ПолучитьТранзакцииДокументооборота(Документооборот, );
```
</details>

## СоставТранспортногоКонтейнера
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание файлов, содержащихся в транспортном контейнере указанной транзакции обмена.
//
// Параметры:
//	Транзакция    - СправочникСсылка.ТранзакцииОбменаСБанками - Ссылка на транзакцию.
//
// Возвращаемое значение:
//  ТаблицаЗначений - см. ПолучитьВложенияТранзакции().
//
Функция СоставТранспортногоКонтейнера(Транзакция) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.СоставТранспортногоКонтейнера(Транзакция) 
```
</details>

## ПолучитьВложенияТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает содержимое файлов из транспортного контейнера указанной транзакции.
//
// Параметры:
//	Транзакция   - СправочникСсылка.ТранзакцииОбменаСБанками, СправочникОбъект.ТранзакцииОбменаСБанками, Массив - Ссылка на транзакцию.
//  ПараметрыРезультата - Структура - задает колонки, которые будут у таблицы-результата:
//        * Реквизиты - Массив - имена колонок-реквизитов справочника;
//        * Данные - Булево - добавить колонку "Данные", куда поместить хранилища значений с извлеченными файлами;
//        * Адрес - Булево - добавить колонку "Адрес", куда поместить адреса временных хранилищ с извлеченными файлами.
//  Отбор        - Структура - Ключ = имя реквизита справочника ТранзакцииОбменаСБанкамиСодержимоеПрисоединенныеФайлы;
//                             Значение = конкретное значение или массив (список) значений для отбора.
//
// Возвращаемое значение:
//   ТаблицаЗначений - данные из справочника ТранзакцииОбменаСБанкамиСодержимоеПрисоединенныеФайлы.
//
Функция ПолучитьВложенияТранзакции(Транзакция, ПараметрыРезультата = Неопределено, Отбор = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ПолучитьВложенияТранзакции(Транзакция, ПараметрыРезультата, Отбор);
```
</details>

## ПараметрыСобытияДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПараметрыСобытияДокументооборота() Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ПараметрыСобытияДокументооборота() 
```
</details>

## НоваяГруппаСобытий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НоваяГруппаСобытий(Идентификатор, Представление) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.НоваяГруппаСобытий(Идентификатор, Представление) 
```
</details>

## ДанныеГруппСобытий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДанныеГруппСобытий() Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ДанныеГруппСобытий());
```
</details>

## ДобавитьГруппуСобытий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьГруппуСобытий(ДанныеГрупп, Группа) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ДобавитьГруппуСобытий(ДанныеГрупп, Группа) 
```
</details>

## ГруппыСобытийСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ГруппыСобытийСервиса(Сервис) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ГруппыСобытийСервиса(Сервис) 
```
</details>

## ГруппаНовогоСобытияДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ГруппаНовогоСобытияДокументооборота(ПараметрыСобытия) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ГруппаНовогоСобытияДокументооборота(ПараметрыСобытия));
```
</details>

## НайтиГруппуСобытий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НайтиГруппуСобытий(ДанныеГрупп, Идентификатор) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.НайтиГруппуСобытий(ДанныеГрупп, Идентификатор) 
```
</details>

## УстановитьПризнакПоказатьПользователю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьПризнакПоказатьПользователю(Приемник, Источник) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.УстановитьПризнакПоказатьПользователю(Приемник, Источник));
```
</details>

## ПолучитьОтправленоПолученоНовогоСобытияДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьОтправленоПолученоНовогоСобытияДокументооборота(ПараметрыСобытия) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ПолучитьОтправленоПолученоНовогоСобытияДокументооборота(ПараметрыСобытия));
```
</details>

## ЗаписатьНовоеСобытиеДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаписатьНовоеСобытиеДокументооборота(ПараметрыСобытия) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ЗаписатьНовоеСобытиеДокументооборота(ПараметрыСобытия) 
```
</details>

## ДатаПоследнегоОбновленияСобытий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ДатаПоследнегоОбновленияСобытий(Сервис) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ДатаПоследнегоОбновленияСобытий(Сервис) 
```
</details>

## НовоеДеревоНовыхСобытий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает пустое дерево значений для сохранения списка новых событий обмена с банками.
//
// Возвращаемое значение:
//	ДеревоЗначений.
//
Функция НовоеДеревоНовыхСобытий() Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.НовоеДеревоНовыхСобытий() 
```
</details>

## ЗаполнитьДеревоНовое
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьДеревоНовое(Сервис, ДеревоНовое, Автообмен = Ложь, ТолькоНепоказанные = Ложь, ВыводитьГруппуЕслиНетНовых = Ложь) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ЗаполнитьДеревоНовое(Сервис, ДеревоНовое, Автообмен, ТолькоНепоказанные, ВыводитьГруппуЕслиНетНовых);
```
</details>

## ЗаполнитьСтрокиДерева
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСтрокиДерева(ДанныеГрупп, ДеревоНовое, ВыборкаДетали, ИдентификаторГруппы, Автообмен = Ложь, ВыводитьГруппуЕслиНетНовых = Ложь) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ЗаполнитьСтрокиДерева(ДанныеГрупп, ДеревоНовое, ВыборкаДетали, ИдентификаторГруппы, Автообмен, ВыводитьГруппуЕслиНетНовых);
```
</details>

## Отступ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция Отступ(Просмотрено = Ложь, ДанныеГруппы = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.Отступ(Просмотрено, ДанныеГруппы);
```
</details>

## НадписьНовыхНет
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НадписьНовыхНет(ДанныеГруппы) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.НадписьНовыхНет(ДанныеГруппы));
```
</details>

## ЗаголовокНедавноПросмотренных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЗаголовокНедавноПросмотренных(ДанныеГруппы) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ЗаголовокНедавноПросмотренных(ДанныеГруппы));
```
</details>

## ЭлементДерева
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭлементДерева() Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ЭлементДерева());
```
</details>

## ЕстьИзмененияВДеревеНовых
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЕстьИзмененияВДеревеНовых(НовоеДеревоНовых) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ЕстьИзмененияВДеревеНовых(НовоеДеревоНовых) 
```
</details>

## ОтметитьДеревоПросмотренным
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОтметитьДеревоПросмотренным(Новое) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ОтметитьДеревоПросмотренным(Новое) 
```
</details>

## ОтметитьСсылкуПоказаннойПользователю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОтметитьСсылкуПоказаннойПользователю(Предмет) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ОтметитьСсылкуПоказаннойПользователю(Предмет) 
```
</details>

## ТипСодержимогоПоИмениФайла
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает тип содержимого по имени файла. Для файлов типа txt возвращается пустое значение.
//
// Параметры:
// 		ИмяФайла - Строка - исходное имя файла для помещения в контейнер.
//
// Возвращаемое значение:
//	 ПеречислениеСсылка.ТипыСодержимогоФайловОбменаСБанками
//
Функция ТипСодержимогоПоИмениФайла(ИмяФайла) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ТипСодержимогоПоИмениФайла(ИмяФайла) 
```
</details>

## ПриПолученииТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриПолученииТранзакции(Транзакция, Результат) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ПриПолученииТранзакции(Транзакция, Результат) 
```
</details>

## СтатусДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при получении и расшифровке транзакций.
//
// Параметры:
//  Документооборот - СправочникСсылка.ДокументооборотыОбменаСБанками - набор взаимодействий с банком по определенному
//                                                                      предмету обмена (например, заявке на кредит).
//
// Возвращаемое значение:
//   Структура   - см. УниверсальныйОбменСБанками.ОписаниеСтатусаДокументооборота()
//
Функция СтатусДокументооборота(Документооборот) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.СтатусДокументооборота(Документооборот) 
```
</details>

## ПриРасшифровкеТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается после расшифровки всех файлов транспортного контейнера, если криптография происходит на сервере или в случае ошибки.
// Для поддержки случая криптографии на клиенте необходимо переопределить
// УниверсальныйОбменСБанкамиКлиентПереопределяемый.ПослеРасшифровкиТранспортногоКонтейнера().
//
// Параметры:
//  Транзакция - СправочникСсылка.ТранзакцииОбменаСБанками - Элемент справочника, созданный на основании данных контейнера.
//  Результат - Структура - Содержит ключи:
//		* Выполнено - Булево - признак успешности выполения операции.
//		* ОписаниеОшибки  - Строка - Текст ошибки, если возникла, или пустая строка, если нет ошибок.
//		* Предупреждения  - Строка - Предупреждения, возникшие при расшифровке и проверке подписи.
//		* ОтмененоПользователем  - Булево - признак отмены пользователем.
//		* ПодписьНеДействительна  - Булево - Истина, если подпись под одним из документов неверна.
//		* НеизвестныйСертификатПодписи  - Булево - Истина, если подпись выполнена неизвестным сертификатом.
Процедура ПриРасшифровкеТранзакции(Транзакция, Результат) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ПриРасшифровкеТранзакции(Транзакция, Результат) 
```
</details>

## ПриОтправкеТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается после отправки транзакции или при ошибке отправки.
//
// Параметры:
//  Транзакция - СправочникСсылка.ТранзакцииОбменаСБанками - Элемент справочника, созданный на основании данных контейнера.
//  Результат - Структура - Содержит ключи:
//		* Выполнено - Булево - признак успешности выполения операции.
//		* ОписаниеОшибки  - Строка - Текст ошибки, если возникла, или пустая строка, если нет ошибок.
Процедура ПриОтправкеТранзакции(Транзакция, Результат) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ПриОтправкеТранзакции(Транзакция, Результат) 
```
</details>

## ЕстьКритическиеОшибкиДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЕстьКритическиеОшибкиДокументооборота(Сервис, Документооборот, ДополнительныеПараметры) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ЕстьКритическиеОшибкиДокументооборота(Сервис, Документооборот, ДополнительныеПараметры) 
```
</details>

## ТекущееСостояниеДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Текущее состояние отправки
//
// Параметры:
//  Ссылка					 - ДокументСсылка, СправочникСсылка - ссылка на объект, отправляемый в контролирующие органы.
//  КонтролирующийОрган		 - Строка или Перечисление.ТипыКонтролирующихОрганов
//  ДополнительныеПараметры	 - Структура:
//		Если содержит поле "ПолучатьОшибкиОтправки", то в результате возращаются поля НеотправленныеИзвещения и ЕстьКритическиеОшибки.
//		Если содержит поле "ПоказыватьПомеченныеНаУдаление", то анализируеются даже помеченные на удаление отправки.
//		Если содержит поле "ПолучатьДаты", то возвращаются даты смены состояния, иначе возврадается пустая дата.
//		Если содержит поле "Отправка", то возвращается информация по этой отправке(циклу обмена или отправке), иначе по последней.
//
// Возвращаемое значение:
//  В случае ошибки или отсуствия данных, возвращается значение Неопределено.
//	Если данные есть, то возвращается структура с полями:
//	ТекущийЭтапОтправки - структура с полями:
//		ТекстНадписи - Строка - текст, отображаемый в панели отправки объекта
//		ТекстСтатуса - Строка - текст, отображаемый в колонке Состояние таблиц формы Отчетность
//		Дата - Дата - Дата текущего этапа. Возращается, если ДополнительныеПараметры содержат поле "ПолучатьДаты".
//		КомментарийКСостоянию
//		НаименованиеПротокола
//		Протокол	 - Ссылка на транспортное сообщение или отправку или Неопределено.
//		СостояниеСдачиОтчетности - ПеречислениеСсылка.СостояниеСдачиОтчетности
//		ЭтапПройден - Булево
//	НеотправленныеИзвещения - Структура, поля перечислены ниже.
//		Возращается, если ДополнительныеПараметры содержат поле "ПолучатьОшибкиОтправки".
//			МассивСообщенийНеИмеющихПодтверждений - Массив
//			МассивНеотправленныхПодтверждений - Массив
//			ЕстьНеотправленныеИзвещения - Булево
//	ЕстьКритическиеОшибки - Булево.
//		Возращается, если ДополнительныеПараметры содержат поле "ПолучатьОшибкиОтправки".
Функция ТекущееСостояниеДокументооборота(Знач Документооборот, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанками.ТекущееСостояниеДокументооборота(Документооборот, ДополнительныеПараметры);
```
</details>

## ПриЗаполненииРазрешенийНаДоступКВнешнимРесурсам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. РаботаВБезопасномРежимеПереопределяемый.ПриЗаполненииРазрешенийНаДоступКВнешнимРесурсам
//
Процедура ПриЗаполненииРазрешенийНаДоступКВнешнимРесурсам(ЗапросыРазрешений) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ПриЗаполненииРазрешенийНаДоступКВнешнимРесурсам(ЗапросыРазрешений) 
```
</details>

## ПриЗаполненииТиповОбщихДанныхПоддерживающихСопоставлениеСсылокПриЗагрузке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ВыгрузкаЗагрузкаДанныхПереопределяемый.ПриЗаполненииТиповОбщихДанныхПоддерживающихСопоставлениеСсылокПриЗагрузке.
Процедура ПриЗаполненииТиповОбщихДанныхПоддерживающихСопоставлениеСсылокПриЗагрузке(Типы) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ПриЗаполненииТиповОбщихДанныхПоддерживающихСопоставлениеСсылокПриЗагрузке(Типы) 
```
</details>

## ПриОпределенииНастроекРегламентныхЗаданий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет следующие свойств регламентных заданий:
//  - зависимость от функциональных опций.
//  - возможность выполнения в различных режимах работы программы.
//  - прочие параметры.
//
// Параметры:
//  Настройки - ТаблицаЗначений - таблица значений с колонками:
//    * РегламентноеЗадание - ОбъектМетаданных:РегламентноеЗадание - регламентное задание.
//    * ФункциональнаяОпция - ОбъектМетаданных:ФункциональнаяОпция - функциональная опция,
//        от которой зависит регламентное задание.
//    * ЗависимостьПоИ      - Булево - если регламентное задание зависит более, чем
//        от одной функциональной опции и его необходимо включать только тогда,
//        когда все функциональные опции включены, то следует указывать Истина
//        для каждой зависимости.
//        По умолчанию Ложь - если хотя бы одна функциональная опция включена,
//        то регламентное задание тоже включено.
//    * ВключатьПриВключенииФункциональнойОпции - Булево, Неопределено - если Ложь, то при
//        включении функциональной опции регламентное задание не будет включаться. Значение
//        Неопределено соответствует значению Истина.
//        По умолчанию - неопределено.
//    * ДоступноВПодчиненномУзлеРИБ - Булево, Неопределено - Истина или Неопределено, если регламентное
//        задание доступно в РИБ.
//        По умолчанию - неопределено.
//    * ДоступноВАвтономномРабочемМесте - Булево, Неопределено - Истина или Неопределено, если регламентное
//        задание доступно в автономном рабочем месте.
//        По умолчанию - неопределено.
//    * ДоступноВМоделиСервиса      - Булево, Неопределено - Истина или Неопределено, если регламентное
//        задание доступно в модели сервиса.
//        По умолчанию - неопределено.
//    * РаботаетСВнешнимиРесурсами  - Булево - Истина, если регламентное задание модифицирует данные
//        во внешних источниках (получение почты, синхронизация данных и т.п.).
//        По умолчанию - Ложь.
//    * Параметризуется             - Булево - Истина, если регламентное задание параметризованное.
//        По умолчанию - Ложь.
//
// Например:
//	Настройка = Настройки.Добавить();
//	Настройка.РегламентноеЗадание = Метаданные.РегламентныеЗадания.ОбновлениеСтатусовДоставкиSMS;
//	Настройка.ФункциональнаяОпция = Метаданные.ФункциональныеОпции.ИспользоватьПочтовыйКлиент;
//	Настройка.ДоступноВМоделиСервиса = Ложь;
//
Процедура ПриОпределенииНастроекРегламентныхЗаданий(Настройки) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ПриОпределенииНастроекРегламентныхЗаданий(Настройки) 
```
</details>

## ОбработчикиИнициализацииПараметровСеанса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Для задания обработчиков параметров сеанса следует использовать шаблон:
// Обработчики.Вставить("<ИмяПараметраСеанса>|<НачалоИмениПараметраСеанса*>", "Обработчик");
//
// Примечание. Символ '*'используется в конце имени параметра сеанса и обозначает,
//             что один обработчик будет вызван для инициализации всех параметров сеанса
//             с именем, начинающимся на слово НачалоИмениПараметраСеанса
//
Процедура ОбработчикиИнициализацииПараметровСеанса(Обработчики) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ОбработчикиИнициализацииПараметровСеанса(Обработчики) 
```
</details>

## ПриОпределенииПсевдонимовОбработчиков
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет соответствие имен методов их псевдонимам для вызова из очереди заданий.
// См. ОчередьЗаданийПереопределяемый.ПриОпределенииПсевдонимовОбработчиков.
//
// Параметры:
//  СоответствиеИменПсевдонимам - Соответствие -
//    * Ключ - псевдоним метода, например ОчиститьОбластьДанных.
//    * Значение - имя метода для вызова, например РаботаВМоделиСервиса.ОчиститьОбластьДанных.
//        В качестве значения можно указать Неопределено, в этом случае считается что имя
//        совпадает с псевдонимом.
//
Процедура ПриОпределенииПсевдонимовОбработчиков(СоответствиеИменПсевдонимам) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.ПриОпределенииПсевдонимовОбработчиков(СоответствиеИменПсевдонимам) 
```
</details>

## СброситьВерсиюБанковИУслуг
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает значение реквизита "Версия" справочника "БанкиУниверсальногоОбмена" равным 0.
// Может быть использована для принудительного обновления данных в этом справочнике при
// следующей синхронизации с сервером обмена.
Процедура СброситьВерсиюБанковИУслуг() Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанками.СброситьВерсиюБанковИУслуг() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
