---
title: Универсальный обмен с банками клиент
slug: erp-uh/универсальный-обмен-с-банками-клиент
---


## ПодобратьСертификатОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает отпечаток сертификата, который может использоваться для подписания
// документов организации на указанную дату.
// Прекращает поиск при нахождении первого подходящего сертификата.
//
// Параметры:
//   ПараметрыОтбора - Структура - структура с полями:
//		* Сервис        - ПеречислениеСсылка.СервисыОбменаСБанками - сервис, для которого подбирается сертификат.
//		* Организация   - СправочникСсылка.Организации - Организация, для которой подбирается сертификат.
//		* Дата          - Дата - Предполагаемая дата использования сертификата.
//	ОповещениеОПодбореСертификата - ОписаниеОповещения - Оповещение, вызываемое после окончания поиска.
//                  Параметры обработчика оповещения:
//			        * РезультатПоискаСертификата - Структура - Содержит ключи:
//				     ** Выполнено - Булево - Истина, если сертификат успешно найден.
//				     ** ОписаниеОшибки - Строка - Текст возникшей ошибки.
//				     ** ОтпечатокСертификата - Строка - Отпечаток найденного сертификата.
//				     ** ЭтоЭлектроннаяПодписьВМоделиСервиса - Булево - Истина, если сертификат является "облачным".
//			        * ДополнительныеПараметры - Произвольный - Дополнительные параметры оповещения.
//
Процедура ПодобратьСертификатОрганизации(ПараметрыОтбора, ОповещениеОПодбореСертификата) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиКлиент.ПодобратьСертификатОрганизации(ПараметрыОтбора, ОповещениеОПодбореСертификата) 
```
</details>

## ПараметрыКриптографии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура открывает пользователю форму выбора сертификата криптографии (опционально) и
// ввода пароля для контейнера закрытого ключа.
//
// Параметры:
//   ОповещениеОбратногоВызова - ОписаниеОповещения - Оповещение, вызываемое после окончания ввода параметров.
//                  Параметры обработчика оповещения:
//			        * РезультатПолученияПараметров - Структура - Содержит ключи:
//				     ** Выполнено - Булево - Истина, если сертификат успешно найден.
//				     ** ОписаниеОшибки - Строка - Текст возникшей ошибки.
//				     ** ОтпечатокСертификата - Строка - Отпечаток найденного сертификата.
//				     ** ЭтоЭлектроннаяПодписьВМоделиСервиса - Булево - Истина, если сертификат является "облачным".
//				     ** ОтмененоПользователем - Булево - Истина, если пользователь отменил ввод параметров.
//   ПараметрыФормы - Структура - см. УниверсальныйОбменСБанкамиКлиентСервер.НовыеДополнительныеПараметрыКриптографии()
//
Процедура ПараметрыКриптографии(ОповещениеОбратногоВызова, ПараметрыФормы) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиКлиент.ПараметрыКриптографии(ОповещениеОбратногоВызова, ПараметрыФормы) 
```
</details>

## ИнициализироватьСервисКриптографии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет подготовительные действия для возможности работы с сервисом криптографии
// с указанным облачным сертификатом.
//
// Параметры:
//	ОтпечатокСертификата - Строка - Отпечаток сертификата, который планируется использовать в дальнейшем
//    для работы с сервисом криптографии.
//
//  ОписаниеОповещения - ОписаниеОповещения - Обработчик, который будет вызыван после выполнения
//	  инициализации сервиса криптографии. Параметры обработчика:
//		* Результат - Структура - Содержит ключи:
//			** Выполнено - Булево - Истина, если сервис криптографии успешно инициализирован.
//			** ОписаниеОшибки - Строка - Текст ошибки, если возникла.
//
Процедура ИнициализироватьСервисКриптографии(ОтпечатокСертификата, ОписаниеОповещения) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиКлиент.ИнициализироватьСервисКриптографии(ОтпечатокСертификата, ОписаниеОповещения) 
```
</details>

## ПараметрыПодготовкиТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структурe с параметрами для процедуры ПодготовитьТранзакцию().
//
// Возвращаемое значение:
//	Структура - См. переменную Результат.
//
Функция ПараметрыПодготовкиТранзакции() Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанкамиКлиент.ПараметрыПодготовкиТранзакции() 
```
</details>

## ПодготовитьТранзакцию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает транспортный контейнер и транзакцию для отправки на сервер.
// Подготовка включает подписание, шифрование и упаковку всех вложений в один архив для передачи.
//
// Параметры:
//	ОписаниеОповещенияОЗавершении - ОписаниеОповещения - Оповещение, вызываемое после завершения процесса подготовки.
//		В обработчик оповещения передаются:
//			* Результат - Структура с ключами:
//				** Выполнено - Булево - Содержит признак успешного выполнения.
//				** ОписаниеОшибки - Строка - Содержит описание возникшей ошибки.
//				** Вложения - Массив - данные вложений.
//				** Получатели - Массив - получатели транзакции СправочникСсылка.БанкиУниверсальногоОбмена.
//				** ПользовательОтменилПодготовкуТранзакции - Булево - Истина, если при запросе параметров криптографии была нажата кнопка отмена.
//
//	Параметры - Структура - см. ПараметрыПодготовкиТранзакции().
//
Процедура ПодготовитьТранзакцию(ОписаниеОповещенияОЗавершении, Параметры) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиКлиент.ПодготовитьТранзакцию(ОписаниеОповещенияОЗавершении, Параметры) 
```
</details>

## ПараметрыРасшифроватьНерасшифрованныеТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структурe с параметрами для процедуры РасшифроватьНерасшифрованныеТранзакции().
//
// Возвращаемое значение:
//  Структура - см. переменную Результат.
//
Функция ПараметрыРасшифроватьНерасшифрованныеТранзакции() Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанкамиКлиент.ПараметрыРасшифроватьНерасшифрованныеТранзакции() 
```
</details>

## РасшифроватьНерасшифрованныеТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет расшифровку и проверку подписи для транзакций обмена с банками.
//
// Параметры:
//  ОповещениеОбратногоВызова - Оповещение, Неопределено - оповещение возврата из процедуры или Неопределено.
//	Параметры - Структура - См. ПараметрыРасшифроватьНерасшифрованныеТранзакции()
//
Процедура РасшифроватьНерасшифрованныеТранзакции(ОповещениеОбратногоВызова, Параметры) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиКлиент.РасшифроватьНерасшифрованныеТранзакции(ОповещениеОбратногоВызова, Параметры) 
```
</details>

## РасшифроватьДанныеТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет расшифровку данных для транзакции обмена с банками.
//
// Параметры:
//  ОповещениеОбратногоВызова - Оповещение - оповещение возврата из процедуры.
//	Транзакция - СправочникСсылка.ТранзакцииОбменаСБанками - Ссылка на транзакцию.
//	КэшСертификатов - Соответствие - Используется для кэширования сертификатов между вызовами.
//	ФормаВладелец - ФормаКлиентскогоПриложения - форма владелец.
//	ВозвращатьОшибкуПриОтменеВводаПароля - Булево - Если Истина, то при отмене ввода будет возвращена ошибка.
//	МенеджерыКриптографии
Процедура РасшифроватьДанныеТранзакции(ОповещениеОбратногоВызова, Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиКлиент.РасшифроватьДанныеТранзакции(ОповещениеОбратногоВызова, );
```
</details>

## ДоступнаРаботаСZIPАрхивом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак доступности работы с объектами ЧтениеZIPФайла и ЗаписьZIPФайла из клиентского контекста.
//
// Возвращаемое значение:
//	Булево - Истина, если работа с объектами ZIP доступна.
//
Функция ДоступнаРаботаСZIPАрхивом() Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанкамиКлиент.ДоступнаРаботаСZIPАрхивом() 
```
</details>

## ПоказатьОшибку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПоказатьОшибку(ПредметИлиТранзакция, Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиКлиент.ПоказатьОшибку(ПредметИлиТранзакция, );
```
</details>

## ПоказатьФормуСостоянияДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму этапов отправки документооборота.
// Параметры:
//   Документооборот - СправочникСсылка.ДокументооборотыОбменаСБанками - ссылка на документооборот
//   ДополнительныеПараметры - Структура - структура параметров с необязательными ключами:
//     * Наименование - Строка - наименование документооборота на форме.
//   ПараметрыФормы - Структура - структура параметров с необязательными ключами,
//     в качестве ключей передаются параметры функции ОткрытьФорму: РежимОткрытияОкна, Владелец, Уникальность, Окно, ОписаниеОповещенияОЗакрытии
//
Процедура ПоказатьФормуСостоянияДокументооборота(Документооборот, Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиКлиент.ПоказатьФормуСостоянияДокументооборота(Документооборот, );
```
</details>

## ПоказатьФормуНовыхСобытий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПоказатьФормуНовыхСобытий(Сервис = Неопределено, Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиКлиент.ПоказатьФормуНовыхСобытий(Сервис, );
```
</details>

## ПоказатьСертификат
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает сертификат для просмотра в специализированной форме.
//
// Параметры:
//  Сертификат - Структура
//    * СерийныйНомер - Строка - серийный номер сертификата.
//    * Поставщик     - Строка - издатель сертификата.
//    * Отпечаток     - Строка - отпечаток сертификата. Используется для поиска сертификата если не указаны СерийныйНомер и Поставщик.
//    * Адрес         - Строка - адрес файла сертификата.
//
//	ФормаВладелец - ФормаКлиентскогоПриложения - владелец формы.
//
Процедура ПоказатьСертификат(Сертификат, ФормаВладелец = Неопределено) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиКлиент.ПоказатьСертификат(Сертификат, ФормаВладелец);
```
</details>

## ВыбратьСертификат
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает окно выбора сертификата.
//
// Параметры:
//	ОповещенияОЗавершение - ОписаниеОповещения - Оповещение, которое необходимо вызвать после выбора.
//	НачальноеЗначениеВыбора - Строка, Массив из Строка - Отпечаток сертификата, которые выбран по умолчанию.
//	ПараметрыОтбора - Структура - Параметры отбора сертификатов, см. УниверсальныйОбменСБанкамиКлиентСервер.ПараметрыОтбораСертификата().
//
Процедура ВыбратьСертификат(ОповещенияОЗавершение, НачальноеЗначениеВыбора, ПараметрыОтбора) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиКлиент.ВыбратьСертификат(ОповещенияОЗавершение, НачальноеЗначениеВыбора, ПараметрыОтбора) 
```
</details>

## ОтобразитьПредставлениеСертификата
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура - Отображает представления сертификатов в полях ввода
//
// Параметры:
//  ВыполняемоеОповещение	- ОписаниеОповещения - Описание процедуры, принимающей результат (не обязательный).
//  ПараметрыОтображения 	- Структура - описание параметров отображения сертификатов
//		* ПолеВвода         - ПолеФормы - поле формы, в котором выводится представление сертификата.
//										  Будет подкрашено красным, если в сертификате есть ошибка.
//  	* Сертификат - Строка - отпечаток сертификата.
//		* ИмяРеквизитаПредставлениеСертификата - Строка - имя реквизита представления сертификат.
//		* Форма								   - ФормаКлиентскогоПриложения - форма, в которой выводится представление сертификата.
//		* ЭтоЭлектроннаяПодписьВМоделиСервиса  - Булево - определяет системное хранилище: локальное или защищенное хранилище на сервере.
//		* ТекстПодсказкиПоСертификату - Строка - текст подсказки для сертификата.
//
Процедура ОтобразитьПредставлениеСертификата(ВыполняемоеОповещение = Неопределено, ПараметрыОтображения) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиКлиент.ОтобразитьПредставлениеСертификата(ВыполняемоеОповещение, ПараметрыОтображения) 
```
</details>

## ЭтоОблачныйСертификатПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак того, что указанный сертификат является облачным.
//
// Параметры:
//	Отпечаток - Строка - Отпечаток проверяемого сертификата.
//
// Возвращаемое значение:
//	Булево - Истина, если сертификат является облачным, иначе Ложь.
//
Функция ЭтоОблачныйСертификатПользователя(Отпечаток) Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанкамиКлиент.ЭтоОблачныйСертификатПользователя(Отпечаток) 
```
</details>

## ПоказатьРезультатОбмена
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПоказатьРезультатОбмена() Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиКлиент.ПоказатьРезультатОбмена() 
```
</details>

## РезультатПолученияПараметровКриптографии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция РезультатПолученияПараметровКриптографии() Экспорт
```

Пример вызова
```bsl
Результат = УниверсальныйОбменСБанкамиКлиент.РезультатПолученияПараметровКриптографии() 
```
</details>

## ЗаписатьСобытиеВЖурнал
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Фиксирует событие в журнале регистрации, заполняя часть параметров по-умолчанию.
// Использует кеширование сообщений на клиенте.
//
// Параметры:
//  Комментарий  - Строка или ИнформацияОбОшибке - комментарий к событию.
//  ВариантСобытия - Строка - должна быть получена с использованием НСтр("", ОбщегоНазначенияКлиентСервер.КодОсновногоЯзыка())
//  Уровень      - Строка - если не заполнено, то "Ошибка"; иначе варианты имен перечисления УровеньЖурналаРегистрации.
//  ЗаписатьСобытие - Булево - признак, что необходимо сейчас же обратиться на сервер и зафиксировать событие.
//
Процедура ЗаписатьСобытиеВЖурнал(Знач Комментарий = "", Знач ВариантСобытия = "", Знач Уровень = "", ЗаписатьСобытие = Истина) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиКлиент.ЗаписатьСобытиеВЖурнал(Комментарий, ВариантСобытия, Уровень, ЗаписатьСобытие);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
