---
title: Универсальный обмен с банками служебный переопределяемый
slug: erp-uh/универсальный-обмен-с-банками-служебный-переопределяемый
---


## ПриПолученииТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при получении нового транспортного контейнера, его распаковки
// и записи на основании него элемента справочника ТранзакцииОбменаСБанками,
// но до расшифровки и проверки подписи. Также вызывается в случае ошибки.
//
// Параметры:
//  Транзакция - СправочникСсылка.ТранзакцииОбменаСБанками - Элемент справочника, созданный на основании данных контейнера.
//  Результат - Структура - Содержит ключи:
//		* Выполнено - Булево - признак успешности выполения операции.
//		* ОписаниеОшибки  - Строка - Текст ошибки, если возникла, или пустая строка, если нет ошибок.
//		* ИдентификаторТранзакции  - Строка - идентификатор транзакции.
//		* Документооборот  - СправочникСсылка.ДокументооборотыОбменаСБанками - документооборот, в рамках которого была получена транзакция.
//
Процедура ПриПолученииТранзакции(Транзакция, Результат) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ПриПолученииТранзакции(Транзакция, Результат) 
```
</details>

## ПриРасшифровкеТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается после расшифровки всех файлов транспортного контейнера, если криптография происходит на сервере или в случае ошибки.
// Для поддержки случая криптографии на клиенте необходимо переопределить
// УниверсальныйОбменСБанкамиКлиентПереопределяемый.ПослеРасшифровкиТранспортногоКонтейнера().
//
// Параметры:
//  Транзакция - СправочникСсылка.ТранзакцииОбменаСБанками - Элемент справочника, созданный на основании данных контейнера.
//  Результат - Структура - Содержит ключи:
//		* Выполнено - Булево - признак успешности выполения операции.
//		* ОписаниеОшибки  - Строка - Текст ошибки, если возникла, или пустая строка, если нет ошибок.
//		* Предупреждения  - Строка - Предупреждения, возникшие при расшифровке и проверке подписи.
//		* ОтмененоПользователем  - Булево - признак отмены пользователем.
//		* ПодписьНеДействительна  - Булево - Истина, если подпись под одним из документов неверна.
//		* НеизвестныйСертификатПодписи  - Булево - Истина, если подпись выполнена неизвестным сертификатом.
//
Процедура ПриРасшифровкеТранзакции(Транзакция, Результат) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ПриРасшифровкеТранзакции(Транзакция, Результат) 
```
</details>

## ПриОтправкеТранзакции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается после отправки транзакции или при ошибке отправки.
//
// Параметры:
//  Транзакция - СправочникСсылка.ТранзакцииОбменаСБанками - Элемент справочника, созданный на основании данных контейнера.
//  Результат - Структура - Содержит ключи:
//		* Выполнено - Булево - признак успешности выполения операции.
//		* ОписаниеОшибки  - Строка - Текст ошибки, если возникла, или пустая строка, если нет ошибок.
//
Процедура ПриОтправкеТранзакции(Транзакция, Результат) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ПриОтправкеТранзакции(Транзакция, Результат) 
```
</details>

## ПослеЗавершенияОбменаПоСервису
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПослеЗавершенияОбменаПоСервису(Сервис) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ПослеЗавершенияОбменаПоСервису(Сервис) 
```
</details>

## ПослеЗагрузкиДанныхУслугиБанка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается после загрузки данных услуги банка, полученных с сервера.
//
// Параметры:
//	УслугаБанка   - СправочникСсылка.УслугиБанков - ссылка на элемент справочника, данные которого были обновлены.
//
Процедура ПослеЗагрузкиДанныхУслугиБанка(УслугаБанка, ИмяСервиса) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ПослеЗагрузкиДанныхУслугиБанка(УслугаБанка, ИмяСервиса) 
```
</details>

## ОпределитьВерсиюСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет версию сервиса, если он имеется в конфигурации.
//
// Параметры:
//	Сервис        - Перечисление.СервисыОбменаСБанками - Ссылка на сервис.
//	ВерсияСервиса - Строка - возвращаемый параметр. Версия сервиса в формате X.Y .
//
Процедура ОпределитьВерсиюСервиса(Сервис, ВерсияСервиса) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ОпределитьВерсиюСервиса(Сервис, ВерсияСервиса) 
```
</details>

## ИмяСервисаНаПорталеИТС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя сервиса, которое используется при получении тикета на портале ИТС.
// Если возвращается пустая строка, то будет использовано значение по умолчанию.
// Параметры:
//   Сервис - Значение перечисления - значение, определяющее сервис для которого необходимо получить имя сервиса на портале
//   Имя - Строка - имя сервиса на портале ИТС
//
Процедура ИмяСервисаНаПорталеИТС(Сервис, Имя) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ИмяСервисаНаПорталеИТС(Сервис, Имя) 
```
</details>

## ПеречислениеХарактеристикСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращеает тип перечисления характеристик сервиса.
// Возвращаемые перечисления должны быть включены в состав определяемого типа ХарактеристикиСервисовУниверсальногоОбменаСБанками
//
// Параметры:
//  Сервис - Значение перечисления - значение, определяющее сервис для которого необходимо получить тип перечисления характеристик.
//
Процедура ПеречислениеХарактеристикСервиса(Сервис, Перечисление) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ПеречислениеХарактеристикСервиса(Сервис, Перечисление) 
```
</details>

## СтатусДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при получении и расшифровке транзакций.
//
// Параметры:
//  Документооборот - СправочникСсылка.ДокументооборотыОбменаСБанками - набор взаимодействий с банком по определенному
//                                                                      предмету обмена (например, заявке на кредит).
//
// Возвращаемое значение:
//   Структура   - см. УниверсальныйОбменСБанками.ОписаниеСтатусаДокументооборота()
//
Процедура СтатусДокументооборота(Документооборот, ОписаниеСтатуса) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.СтатусДокументооборота(Документооборот, ОписаниеСтатуса) 
```
</details>

## СписокСервисовДляАвтоматическойПроверкиВходящихТранзакций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает спискок сервисов обмена с банками, для которых проверяется наличие входящих транзакций на сервере.
//
// Параметры:
//   Сервисы - Массив Из ПеречислениеСсылка.СервисыОбменаСБанками - в параметре возвращается список сервисов
//                                                             для проверки входящих транзакций в регламентном задании.
//
Процедура СписокСервисовДляАвтоматическойПроверкиВходящихТранзакций(Сервисы) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.СписокСервисовДляАвтоматическойПроверкиВходящихТранзакций(Сервисы) 
```
</details>

## МакетСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращеает макет с перечислением характеристик сервиса.
//
// Параметры:
//  Сервис       - ПеречислениеСсылка.СервисыОбменаСБанками - значение, определяющее сервис для которого необходимо
//                                                            получить тип перечисления характеристик.
//  Макет        - ТабличныйДокумент - один из общих макетов.
//
Процедура МакетСервиса(Сервис, Макет) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.МакетСервиса(Сервис, Макет) 
```
</details>

## ОпределитьСервисПоСсылке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В параметре Сервис возвращает строковый идентификатор сервиса на основании анализа параметра СсылкаНаСервис.
// Параметры:
//   Сервис      - Перечисление.СервисыОбменаСБанками - значение перечисления СервисыОбменаСБанками.
//   ИмяСервиса  - Строка - в этот параметр возвращается строковый идентификатор сервиса после анализа параметра Сервис.
//
Процедура ОпределитьСервисПоСсылке(Сервис, ИмяСервиса) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ОпределитьСервисПоСсылке(Сервис, ИмяСервиса) 
```
</details>

## ОпределитьСервисПоИдентификаторуНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В параметре Сервис возвращает значение перечисления СервисыОбменаСБанками на основании анализа параметра ИмяСервиса.
//
// Параметры:
//   ИмяСервиса  - Строка - строковый идентификатор сервиса.
//   Сервис      - Перечисление.СервисыОбменаСБанками - возвращаемое значение перечисления.
//
Процедура ОпределитьСервисПоИдентификаторуНаСервере(ИмяСервиса, Сервис) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ОпределитьСервисПоИдентификаторуНаСервере(ИмяСервиса, Сервис) 
```
</details>

## ТаблицаЭтаповОтправки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет переданную таблицу этапов отправки.
//
// Параметры:
//	Документооборот - СправочникСсылка.ДокументооборотыОбменаСБанками - Документооборот обмена с банками.
//	ДополнительныеПараметры - Структура - Дополнительные параметры для формы состояния обмена.
//	ТаблицаЭтаповОтправки - ТаблицаЗначений - см. УниверсальныйОбменСБанками.ЗаготовкаТаблицыЭтаповОтправки().
//
Процедура ТаблицаЭтаповОтправки(Документооборот, ДополнительныеПараметры, ТаблицаЭтаповОтправки) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ТаблицаЭтаповОтправки(Документооборот, ДополнительныеПараметры, ТаблицаЭтаповОтправки) 
```
</details>

## ЕстьКритическиеОшибкиДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЕстьКритическиеОшибкиДокументооборота(Сервис, Документооборот, ДополнительныеПараметры, Результат) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ЕстьКритическиеОшибкиДокументооборота(Сервис, Документооборот, ДополнительныеПараметры, Результат) 
```
</details>

## НеотправленныеИзвещения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет данные неотправленных извещений.
//
// Параметры:
// 	Сервис - ПеречислениеСсылка.СервисыОбменаСБанками - Сервис обмена.
//	Отбор - Структура - Отбор для УниверсальныйОбменСБанками.ТранзакцииПоТипу().
//	ДанныеИзвещений - Структура - см. УниверсальныйОбменСБанками.НеотправленныеИзвещения()
//
Процедура НеотправленныеИзвещения(Сервис, Отбор, ДанныеИзвещений) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.НеотправленныеИзвещения(Сервис, Отбор, ДанныеИзвещений) 
```
</details>

## ПредставлениеПредмета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПредставлениеПредмета(Сервис, Предмет, БезИмениБанка, Представление) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ПредставлениеПредмета(Сервис, Предмет, БезИмениБанка, Представление) 
```
</details>

## СведенияОПредмете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СведенияОПредмете(Сервис, Предмет, Сведения, СписокРеквизитов = Неопределено) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.СведенияОПредмете(Сервис, Предмет, Сведения, СписокРеквизитов);
```
</details>

## ГруппаНовогоСобытияДокументооборота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ГруппаНовогоСобытияДокументооборота(Сервис, ПараметрыСобытия, Группа) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ГруппаНовогоСобытияДокументооборота(Сервис, ПараметрыСобытия, Группа) 
```
</details>

## ДатаПоследнегоОбновленияСобытий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДатаПоследнегоОбновленияСобытий(Сервис, Дата) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ДатаПоследнегоОбновленияСобытий(Сервис, Дата) 
```
</details>

## ГруппыСобытийСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ГруппыСобытийСервиса(Сервис, ДанныеГрупп) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ГруппыСобытийСервиса(Сервис, ДанныеГрупп) 
```
</details>

## ПодготовитьДанныеДляОтветныхТранзакций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПодготовитьДанныеДляОтветныхТранзакций(Сервис, ВходящиеТранзакции, Результат) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ПодготовитьДанныеДляОтветныхТранзакций(Сервис, ВходящиеТранзакции, Результат) 
```
</details>

## ТребуетсяРасшифроватьДанныеХарактеристики
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ТребуетсяРасшифроватьДанныеХарактеристики(Сервис, Характеристика, Результат) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ТребуетсяРасшифроватьДанныеХарактеристики(Сервис, Характеристика, Результат) 
```
</details>

## ТребуетсяРасшифроватьДанныеСервиса
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ТребуетсяРасшифроватьДанныеСервиса(Сервис, Результат) Экспорт
```

Пример вызова
```bsl
УниверсальныйОбменСБанкамиСлужебныйПереопределяемый.ТребуетсяРасшифроватьДанныеСервиса(Сервис, Результат) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
