---
title: Управление данными об изделиях клиент сервер
slug: erp-uh/управление-данными-об-изделиях-клиент-сервер
---


## ПараметрыВыбораСпецификаций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры выбора спецификаций для номенклатуры.
//
// Возвращаемое значение:
// 	Структура - из:
//  * ДоступныеТипы - Массив - доступные типы спецификаций
//  * ДоступныеСтатусы - Массив - доступные статусы спецификаций
//  * ДоступныСпецификацииСПроизводствомНаСтороне - Булево - признак доступности спецификаций с производством на стороне
//  * ДоступныСпецификацииНаПобочныйВыход - Булево - признак отображения спецификаций по фиксированной стоимости
//  * ПолучитьСпецификацииПоНоменклатуре - Булево - признак отбора по заданной номенклатуре
//  * СвязиПараметровВыбора - Соответствие - связи параметров выбора
//  * РеквизитыСпецификации - Строка - список реквизитов спецификации
//
Функция ПараметрыВыбораСпецификаций() Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ПараметрыВыбораСпецификаций() 
```
</details>

## ПараметрыДействияПроверитьЗаполнитьСпецификацию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры необходимые для выполнения действия "ПроверитьЗаполнитьСпецификацию".
//
// Параметры:
//  Объект							- ДанныеФормыСтруктура 			- Текущий объект
//  ТекущиеДанные					- ДанныеФормыЭлементКоллекции 	- Строка коллекции в которой происходит выбор спецификации
//  ПараметрыВыбораСпецификаций		- Структура 					- Параметры выбора спецификации
//  Форма							- ФормаКлиентскогоПриложения				- форма
//  ДополнительныеПараметры			- Структура 					- Дополнительные параметры вызова
//
// Возвращаемое значение:
//  Структура - список параметров.
//
Функция ПараметрыДействияПроверитьЗаполнитьСпецификацию(Объект, Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ПараметрыДействияПроверитьЗаполнитьСпецификацию(Объект, );
```
</details>

## УстановитьПараметрыВыбораСпецификаций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Установить параметры выбора спецификаций в форме
//
// Параметры:
//  Элемент						 - ПолеФормы, Массив - поле ввода спецификации или список полей
//  ПараметрыВыбораСпецификаций	 - см. ПараметрыВыбораСпецификаций
//
Процедура УстановитьПараметрыВыбораСпецификаций(Элемент, ПараметрыВыбораСпецификаций) Экспорт
```

Пример вызова
```bsl
УправлениеДаннымиОбИзделияхКлиентСервер.УстановитьПараметрыВыбораСпецификаций(Элемент, ПараметрыВыбораСпецификаций) 
```
</details>

## УстановитьПараметрыВыбораНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает параметры выбора для номенклатуры.
//
// Параметры:
//  Элемент - Массив, ПолеФормы - поле для ввода номенклатуры
//  Форма - ФормаКлиентскогоПриложения - форма для которой производится установка параметров выбора:
//  	* Объект  - ДанныеФормыСтруктура - объект, для которого производится установка параметров выбора:
//  		* ТипПроизводственногоПроцесса - ПеречислениеСсылка.ТипыПроизводственныхПроцессов
//  		* Ссылка - СправочникСсылка.РесурсныеСпецификации,ДокументСсылка.ЗаказНаПроизводство2_2
//  	* ИсточникСоставаНаборовВПроизводстве - ПеречислениеСсылка.ИсточникиСоставаНаборовВПроизводстве
//
Процедура УстановитьПараметрыВыбораНоменклатуры(Элемент, Форма) Экспорт
```

Пример вызова
```bsl
УправлениеДаннымиОбИзделияхКлиентСервер.УстановитьПараметрыВыбораНоменклатуры(Элемент, Форма) 
```
</details>

## ПоляСтруктурыДанныхОбИзделииДляВыбораСпецификации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Перечень полей, определяющих выбор спецификации номенклатуры
//
// Возвращаемое значение:
//  Строка - перечень полей
//
Функция ПоляСтруктурыДанныхОбИзделииДляВыбораСпецификации() Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ПоляСтруктурыДанныхОбИзделииДляВыбораСпецификации() 
```
</details>

## СтруктураДанныхОбИзделииДляВыбораСпецификации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор структуры данных для выбора спецификации номенклатуры
//
// Возвращаемое значение:
//  Структура - структура данных
//
Функция СтруктураДанныхОбИзделииДляВыбораСпецификации() Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.СтруктураДанныхОбИзделииДляВыбораСпецификации() 
```
</details>

## ТекстыОформленияСпособовАвтовыбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Текст оформления способов автовыбора.
//
// Возвращаемое значение:
//  Соответствие из ПеречислениеСсылка.СпособыАвтовыбораНоменклатуры,ПеречислениеСсылка.СпособыАвтовыбораХарактеристики
Функция ТекстыОформленияСпособовАвтовыбора() Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ТекстыОформленияСпособовАвтовыбора() 
```
</details>

## ОписаниеФункцийКонструктораФормул
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание функций используемых в конструкторе формул
//
// Параметры:
//  ИмяГруппы - Строка - имя группы в дереве формул конструктора
//
// Возвращаемое значение:
//  Массив из см. РаботаСФормуламиКлиентСервер.ОписаниеФункцииОбщегоМодуля - описание функций внешних модулей.
//
Функция ОписаниеФункцийКонструктораФормул(ИмяГруппы = "") Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ОписаниеФункцийКонструктораФормул(ИмяГруппы);
```
</details>

## ОписаниеФункцииКонструктораФормулОкрВверх
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание функции ОкрВверх для конструктора формул
//
// Возвращаемое значение:
//  см. РаботаСФормуламиКлиентСервер.ОписаниеФункцииОбщегоМодуля
//
Функция ОписаниеФункцииКонструктораФормулОкрВверх() Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ОписаниеФункцииКонструктораФормулОкрВверх() 
```
</details>

## ОписаниеФункцииКонструктораФормулОкрВниз
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает описание функции ОкрВниз для конструктора формул
//
// Возвращаемое значение:
//  см. РаботаСФормуламиКлиентСервер.ОписаниеФункцииОбщегоМодуля
//
Функция ОписаниеФункцииКонструктораФормулОкрВниз() Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ОписаниеФункцииКонструктораФормулОкрВниз() 
```
</details>

## ВыборПоПорогу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выбирает значение согласно заданному порогу
//
// Параметры:
//  Параметр	 - Число	 - параметр
//  Значение	 - Число	 - значение
//  Порог		 - Число	 - порог
//  Значение2	 - Число	 - значение
//  Порог2		 - Число	 - порог
//  Значение3	 - Число	 - значение
//  Порог3		 - Число	 - порог
//  Значение4	 - Число	 - значение
//  Порог4		 - Число	 - порог
//  Значение5	 - Число	 - значение
//  Порог5		 - Число	 - порог
//
// Возвращаемое значение:
//  Число - результат выбора
//
Функция ВыборПоПорогу( Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ВыборПоПорогу();
```
</details>

## ПриВводеНовойСтрокиСАвтовыбором
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет стандартные действия при вводе новой строки таб. части, в которой предусмотрен автовыбор номенклатуры
//  - устанавливает способ автовыбора номенклатуры
//  - устанавливает способ автовыбора характеристики
//  - копирует настройки автовыбора.
//
// Параметры:
//  ДанныеСтроки			 - ДанныеФормыСтруктура	 - содержит данные строки
//  КлючСвязиИсточника		 - Число, Неопределено	 - ключ связи источника (при копировании строки)
//  СоответствиеСвойств		 - ДанныеФормыКоллекция	 - табличная часть "СоответствиеСвойств".
//
Процедура ПриВводеНовойСтрокиСАвтовыбором(ДанныеСтроки, КлючСвязиИсточника = Неопределено, СоответствиеСвойств = Неопределено) Экспорт
```

Пример вызова
```bsl
УправлениеДаннымиОбИзделияхКлиентСервер.ПриВводеНовойСтрокиСАвтовыбором(ДанныеСтроки, КлючСвязиИсточника, СоответствиеСвойств);
```
</details>

## ПриВводеНовойСтрокиСОтборомПоСвойствам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет стандартные действия при вводе новой строки в таблице, в которой предусмотрена возможность отбора по свойствам
//   - копирует настройки отбора
//
// Параметры:
//  ДанныеСтроки          - ДанныеФормыСтруктура   - содержит данные строки
//  КлючСвязиИсточника    - Число, Неопределено    - ключ связи источника (при копировании строки)
//  ОтборПоСвойствам      - ДанныеФормыКоллекция   - табличная часть "ОтборПоСвойствам"
Процедура ПриВводеНовойСтрокиСОтборомПоСвойствам(ДанныеСтроки, КлючСвязиИсточника = Неопределено, ОтборПоСвойствам = Неопределено) Экспорт
```

Пример вызова
```bsl
УправлениеДаннымиОбИзделияхКлиентСервер.ПриВводеНовойСтрокиСОтборомПоСвойствам(ДанныеСтроки, КлючСвязиИсточника, ОтборПоСвойствам);
```
</details>

## ПриИзмененииНоменклатурыВСтрокеСАвтовыбором
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет стандартные действия при изменении материала
//
Процедура ПриИзмененииНоменклатурыВСтрокеСАвтовыбором(ДанныеСтроки, Объект) Экспорт
```

Пример вызова
```bsl
УправлениеДаннымиОбИзделияхКлиентСервер.ПриИзмененииНоменклатурыВСтрокеСАвтовыбором(ДанныеСтроки, Объект) 
```
</details>

## ПриИзмененииХарактеристикиВСтрокеСАвтовыбором
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет стандартные действия при изменении характеристики
//
Процедура ПриИзмененииХарактеристикиВСтрокеСАвтовыбором(ДанныеСтроки, Объект) Экспорт
```

Пример вызова
```bsl
УправлениеДаннымиОбИзделияхКлиентСервер.ПриИзмененииХарактеристикиВСтрокеСАвтовыбором(ДанныеСтроки, Объект) 
```
</details>

## ПолуфабрикатПроизводимыйВПроцессе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция определяет является ли материал полуфабрикатом производимым в процессе
//
// Параметры:
//  ДанныеСтроки - ДанныеФормыСтруктура - содержит данные строки.
//
// Возвращаемое значение:
//   - Булево - Истина, если материал является полуфабрикатом и производится в процессе.
//
Функция ПолуфабрикатПроизводимыйВПроцессе(ДанныеСтроки) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ПолуфабрикатПроизводимыйВПроцессе(ДанныеСтроки) 
```
</details>

## ПолуфабрикатПроизводитсяНаЭтапе
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция определяет является ли материал полуфабрикатом производимым в процессе на этапе.
//
// Параметры:
//  ДанныеСтроки - ДанныеФормыСтруктура - содержит данные строки.
//
// Возвращаемое значение:
//   - Булево - Истина, если материал является полуфабрикатом и производится в процессе на этапе.
//
Функция ПолуфабрикатПроизводитсяНаЭтапе(ДанныеСтроки) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ПолуфабрикатПроизводитсяНаЭтапе(ДанныеСтроки) 
```
</details>

## ПолуфабрикатПроизводитсяПоСпецификации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция определяет является ли материал полуфабрикатом производимым в процессе по спецификации.
//
// Параметры:
//  ДанныеСтроки - ДанныеФормыСтруктура - содержит данные строки.
//
// Возвращаемое значение:
//   - Булево - Истина, если материал является полуфабрикатом и производится в процессе по спецификации.
//
Функция ПолуфабрикатПроизводитсяПоСпецификации(ДанныеСтроки) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ПолуфабрикатПроизводитсяПоСпецификации(ДанныеСтроки) 
```
</details>

## ЗаполнитьСпособПолученияМатериалаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСпособПолученияМатериалаПоУмолчанию(ДанныеСтроки) Экспорт
```

Пример вызова
```bsl
УправлениеДаннымиОбИзделияхКлиентСервер.ЗаполнитьСпособПолученияМатериалаПоУмолчанию(ДанныеСтроки) 
```
</details>

## МассивДоступныхТиповНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив доступных типов номенклатуры для таб.частей НСИ производства
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения
//  ИмяТЧ - Строка - Имя ТЧ
//
// Возвращаемое значение:
//  Массив - Массив доступных типов номенклатуры
Функция МассивДоступныхТиповНоменклатуры(Форма, ИмяТЧ = "") Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.МассивДоступныхТиповНоменклатуры(Форма, ИмяТЧ);
```
</details>

## УстановитьПараметрыВыбораМатериалов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает параметры выбора материалов в производственной НСИ
//
// Параметры:
//  Элемент - ПолеФормы
//  Форма - ФормаКлиентскогоПриложения
Процедура УстановитьПараметрыВыбораМатериалов(Элемент, Форма) Экспорт
```

Пример вызова
```bsl
УправлениеДаннымиОбИзделияхКлиентСервер.УстановитьПараметрыВыбораМатериалов(Элемент, Форма) 
```
</details>

## ДанныеОсновногоИзделияСпецификации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные основного изделия спецификации
//
// Параметры:
//  Объект	 - СправочникОбъект.РесурсныеСпецификации, Структура - спецификация.
//
// Возвращаемое значение:
//  Структура - данные основного изделия.
//
Функция ДанныеОсновногоИзделияСпецификации(Объект) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ДанныеОсновногоИзделияСпецификации(Объект) 
```
</details>

## ОсновнойРеквизитОсновногоИзделияСпецификации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает значение основного реквизита по данным основного изделия спецификации
//
// Параметры:
//  Объект  - СправочникОбъект.РесурсныеСпецификации, Структура - спецификация.
//  ОсновноеИзделие - см. ДанныеОсновногоИзделияСпецификации
//
// Возвращаемое значение:
//  Структура - данные основного реквизита
//
Функция ОсновнойРеквизитОсновногоИзделияСпецификации(Объект, ОсновноеИзделие = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ОсновнойРеквизитОсновногоИзделияСпецификации(Объект, ОсновноеИзделие);
```
</details>

## ПредставлениеЕдиницыИзмеренияПартииВыпуска
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает представление единицы измерения партии выпуска
//
// Параметры:
//  ОписаниеПартииВыпуска	 - Структура, Строка, СправочникСсылка.УпаковкиЕдиницыИзмерения	 - описание или единица измерения партии выпуска
//  Количество				 - Число														 - количество единиц/партий.
//
// Возвращаемое значение:
//  Строка - представление единицы измерения партии выпуска.
//
Функция ПредставлениеЕдиницыИзмеренияПартииВыпуска(ОписаниеПартииВыпуска = Неопределено, Количество = 0) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ПредставлениеЕдиницыИзмеренияПартииВыпуска(ОписаниеПартииВыпуска, Количество);
```
</details>

## УстановитьПараметрыВводаКоличестваЕдиницПартий
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает оформление для поля ввода количества единиц/партий
//
// Параметры:
//  ВыпускПроизвольнымиПорциями	 - Булево	 - Истина, если доступен выпуск произвольными порциями
//  Элемент						 - ПолеФормы - элемент управления.
//
Процедура УстановитьПараметрыВводаКоличестваЕдиницПартий(ВыпускПроизвольнымиПорциями, Элемент) Экспорт
```

Пример вызова
```bsl
УправлениеДаннымиОбИзделияхКлиентСервер.УстановитьПараметрыВводаКоличестваЕдиницПартий(ВыпускПроизвольнымиПорциями, Элемент) 
```
</details>

## ПредставлениеЭтапа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует представление этапа, которое можно использовать для вывода пользователю.
//
// Параметры:
//  СпецификацияПредставление			- Строка - Представление спецификации
//  ЭтапПредставление					- Строка - Представление этапа
//  МногоэтапныйПроизводственныйПроцесс	- Булево - Признак того что производственный процесс состоит из нескольких этапов
//  ЭтапВосстановленияБрака				- Булево - Признак того что этап создан для восстановление брака.
//
// Возвращаемое значение:
//   Строка   - представление этапа.
//
Функция ПредставлениеЭтапа(СпецификацияПредставление, ЭтапПредставление, МногоэтапныйПроизводственныйПроцесс, ЭтапВосстановленияБрака = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ПредставлениеЭтапа(СпецификацияПредставление, ЭтапПредставление, МногоэтапныйПроизводственныйПроцесс, ЭтапВосстановленияБрака);
```
</details>

## ПредставлениеСтатусаСпецификации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строковое представление статуса спецификации
//
// Параметры:
//  Статус			 - ПеречислениеСсылка.СтатусыСпецификаций	 - статус спецификации
//  НачалоДействия	 - Дата										 - начало периода действия
//  КонецДействия	 - Дата										 - конец периода действия
//  СтрокаСтатус	 - Строка									 - представление.
//
// Возвращаемое значение:
//  Строка - представление спецификации.
//
Функция ПредставлениеСтатусаСпецификации(Статус, НачалоДействия = '00010101', КонецДействия = '00010101', СтрокаСтатус = "") Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ПредставлениеСтатусаСпецификации(Статус, НачалоДействия, КонецДействия, СтрокаСтатус);
```
</details>

## ПараметрыДереваСпецификаций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры построения дерева спецификаций
//
// Возвращаемое значение:
//   - Структура - параметры построения дерева спецификации, содержит:
//   	* Номенклатура - СправочникСсылка.Номенклатура - номенклатура
//   	* ХарактеристикаНоменклатуры - СправочникСсылка.ХарактеристикиНоменклатуры - характеристика номенклатуры
//   	* Спецификация - СправочникСсылка.РесурсныеСпецификации - спецификация
//   	* Дата - Дата - дата подбора вложенных спецификаций
//   	* ПодразделениеДиспетчер - СправочникСсылка.СтруктураПредприятия - параметр назначения
//   	* НаправлениеДеятельности - СправочникСсылка.НаправленияДеятельности - параметр назанчения
//   	* ПараметрыВыбораСпецификаций - см. УправлениеДаннымиОбИзделиях.ПараметрыВыбораСпецификаций
//   	* ВыводитьЭтапы - Булево - признак вывода этапов
//   	* ВыводитьОперации - Булево - признак вывода операций
//   	* ВыводитьВыходныеИзделия - Булево - признак вывода выходных изделий
//   	* ВыводитьМатериалы - Булево - признак вывода материалов
//   	* ВыводитьТрудозатраты - Булево - признак вывода трудозатрат
//   	* ВыводитьЗаголовкиГруппировок - Булево - признак вывода заголовков группировок при печати
//   	* ВыводитьОстаткиТоваров - Булево - признак вывода остатков по складу
//   	* РазузловыватьПолуфабрикаты - Булево - признак необходимости разузлования полуфабрикатов
//   	* ДинамическоеСчитывание - Булево - режим динамического чтения узлов дерева
//   	* СохранятьДанные - Булево - признак сохранения данных
//   	* КлючСвязи - УникальныйИдентификатор -
//   	* УпаковкаВыходногоИзделия - СправочникСсылка.УпаковкиЕдиницыИзмерения -
//   	* КоличествоУпаковокВыходногоИзделия - Число -
//   	* КоличествоВыходногоИзделия - Число -
//   	* АдресВХранилище - Строка - адрес структуры заказа
//
Функция ПараметрыДереваСпецификаций() Экспорт
```

Пример вызова
```bsl
Результат = УправлениеДаннымиОбИзделияхКлиентСервер.ПараметрыДереваСпецификаций() 
```
</details>

## ДеревоСпецификацийПередРазворачиванием
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается перед раскрытием узла дерева спецификаций.
//
// Параметры:
//  Форма			 - ФормаКлиентскогоПриложения	 - управляемая форма, на которой расположено дерево спецификаций
//  Идентификатор	 - Число			 - строка, которая будет развернута
//  Отказ			 - Булево			 - признак отказа от раскрытия узла.
//
Процедура ДеревоСпецификацийПередРазворачиванием(Форма, Идентификатор, Отказ) Экспорт
```

Пример вызова
```bsl
УправлениеДаннымиОбИзделияхКлиентСервер.ДеревоСпецификацийПередРазворачиванием(Форма, Идентификатор, Отказ) 
```
</details>

## ДеревоСпецификацийПередСворачиванием
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается перед сворачиванием узла дерева спецификаций.
//
// Параметры:
//  Форма			 - ФормаКлиентскогоПриложения	 - управляемая форма, на которой расположено дерево спецификаций
//  Идентификатор	 - Число			 - строка, которая будет свернута
//  Отказ			 - Булево			 - признак отказа от сворачивания узла.
//
Процедура ДеревоСпецификацийПередСворачиванием(Форма, Идентификатор, Отказ) Экспорт
```

Пример вызова
```bsl
УправлениеДаннымиОбИзделияхКлиентСервер.ДеревоСпецификацийПередСворачиванием(Форма, Идентификатор, Отказ) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
