---
title: Управление производством вызов сервера
slug: erp-uh/управление-производством-вызов-сервера
---


## ПредставлениеЗаказа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует представление заказа на производство.
//
// Параметры:
//  Ссылка	 - ДокументСсылка.ЗаказНаПроизводство2_2 - заказ на производство
//  Префикс	 - Строка								 - префикс.
//
// Возвращаемое значение:
//  Строка - представление заказа на производство.
//
Функция ПредставлениеЗаказа(Ссылка, Префикс = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеПроизводствомВызовСервера.ПредставлениеЗаказа(Ссылка, Префикс);
```
</details>

## ПолноеПредставлениеЗаказа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует полное представление заказа на производство.
//
// Параметры:
//  Ссылка	 - ДокументСсылка.ЗаказНаПроизводство2_2 - заказ на производство
//  Префикс	 - Строка								 - префикс.
//
// Возвращаемое значение:
//  Строка - полное представление заказа на производство.
//
Функция ПолноеПредставлениеЗаказа(Ссылка, Префикс = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеПроизводствомВызовСервера.ПолноеПредставлениеЗаказа(Ссылка, Префикс);
```
</details>

## ПредставлениеЭтапа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует представление этапа производства по данным документа.
//
// Параметры:
//  ДанныеЭтапа - см. Документы.ЭтапПроизводства2_2.ПредставлениеЭтапа.
//
// Возвращаемое значение:
//  Строка - представление этапа производства.
//
Функция ПредставлениеЭтапа(ДанныеЭтапа) Экспорт
```

Пример вызова
```bsl
Результат = УправлениеПроизводствомВызовСервера.ПредставлениеЭтапа(ДанныеЭтапа) 
```
</details>

## УстановитьДатуПоОтметке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает дату с учетом переданной отметки
//
// Параметры:
//  Отметка		 - Булево	 - отметка
//  ПолеДата	 - Дата		 - реквизит, в котором нужно установить дату
//  ДатаСобытия	 - Дата		 - устанавливаемая дата
//  Затереть	 - Булево	 - признак, что дату нужно установить принудительно.
//
Процедура УстановитьДатуПоОтметке(Отметка, ПолеДата, ДатаСобытия = Неопределено, Затереть = Ложь) Экспорт
```

Пример вызова
```bsl
УправлениеПроизводствомВызовСервера.УстановитьДатуПоОтметке(Отметка, ПолеДата, ДатаСобытия, Затереть);
```
</details>

## ЗначенияЗаполненияНовогоЭтапаПроизводства
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значения заполнения нового этапа производства
//
// Параметры:
//  Распоряжение				 - ДокументСсылка.ЗаказНаПроизводство2_2 			 - заказ на производство
//  НазначениеПродукция			 - СправочникСсылка.Назначения						 - назначение продукции ( при обособлении по целевому назначению )
//  ПартияПроизводства			 - СправочникСсылка.ПартииПроизводства				 - партия производства
//  ТипПроизводственногоПроцесса - ПеречислениеСсылка.ТипыПроизводственныхПроцессов	 - тип производственного процесса.
//  Спецификация				 - СправочникСсылка.РесурсныеСпецификации			 - ресурсная спецификация.
//
// Возвращаемое значение:
//  Структура - значения заполнения нового этапа производства:
//   * Распоряжение                     - ДокументСсылка.ЗаказНаПроизводство2_2 -
//   * ДинамическаяСтруктура            - Булево -
//   * Организация                      - СправочникСсылка.Организации -
//   * ХозяйственнаяОперация            - ПеречислениеСсылка.ХозяйственныеОперации -
//   * НаправлениеДеятельности          - СправочникСсылка.НаправленияДеятельности -
//   * Партнер                          - СправочникСсылка.Партнеры -
//   * Договор                          - СправочникСсылка.ДоговорыКонтрагентов -
//   * ВыпускПодДеятельность            - ПеречислениеСсылка.ТипыНалогообложенияНДС -
//   * ОперацияКакРаспоряжениеВыработки - см. УправлениеПроизводством.ИспользуетсяОперацияКакРаспоряжениеВыработки
//   * ВидЦены                          - см. Справочники.ВидыЦен.ВидЦеныПлановойСтоимостиТМЦ
//   * Валюта                           - см. ДоходыИРасходыСервер.ПолучитьВалютуУправленческогоУчета
//   * ВариантПриемкиТоваров            - ПеречислениеСсылка.ВариантыПриемкиТоваров -
//   * НазначениеПродукция              - СправочникСсылка.Назначения -
//   * ПартияПроизводства               - СправочникСсылка.ПартииПроизводства -
//   * ТипПроизводственногоПроцесса     - ПеречислениеСсылка.ТипыПроизводственныхПроцессов -
//   * Спецификация                     - СправочникСсылка.РесурсныеСпецификации -
//   * ОтветственноеПодразделение       - см. Справочники.РесурсныеСпецификации.ОтветственноеПодразделение
//
Функция ЗначенияЗаполненияНовогоЭтапаПроизводства(Распоряжение, Экспорт
```

Пример вызова
```bsl
Результат = УправлениеПроизводствомВызовСервера.ЗначенияЗаполненияНовогоЭтапаПроизводства(Распоряжение, );
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
