---
title: Установка цен сервер
slug: erp-uh/установка-цен-сервер
---


## ПостроитьДеревоЦен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует таблицу цен на форме
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - Форма. Может содержать:
//    * Объект - ОбработкаОбъект.ПрайсЛист, ДокументОбъект.УстановкаЦенНоменклатуры - ДанныеФормыСтруктура
//    * ВыбранныеЦены - ТаблицаЗначений - с колонками:
//      ** Ссылка - СправочникСсылка.ВидыЦен, СправочникСсылка.ВидыЦенПоставщиков - Виды цен
//      ** Идентификатор - Строка - Идентификатор для формул
//      ** Наименование - Строка - Наименование видов цен
//    * СохраненныеДокументы - ТаблицаЗначений - (необязательное) с колонками:
//      ** Ссылка - ДокументСсылка.РегистрацияЦенНоменклатурыПоставщика -
//    * Элементы - ЭлементыФормы - Могут содержать:
//      ** ДеревоЦен - ДеревоЗначений, ТаблицаФормы, ДанныеФормыЭлементДерева, ДанныеФормыДерево - основной элемент формы с деревом цен
//    * ДеревоЦен - ДеревоЗначений, ТаблицаФормы, ДанныеФормыЭлементДерева, ДанныеФормыДерево - основной элемент формы с деревом цен
//    * КомпоновщикНастроекОтбор - КомпоновщикНастроекКомпоновкиДанных
//  ИмяТаблицы - Строка - Имя таблицы
//
Процедура ПостроитьДеревоЦен(Форма) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ПостроитьДеревоЦен(Форма) 
```
</details>

## ИнициализироватьСтруктуруКэшаДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет инициализацию структуры кэша данных
//
// Параметры:
//  КэшДанных - Структура - кэш данных.
//
// Возвращаемое значение:
//  Структура - структура со свойствами:
//   * ТаблицаСоответствияНоменклатурыСтрокамДереваТоваров - ТаблицаЗначений, Неопределено - Соответствие номенклатуры.
//   * КурсыВалют - ТаблицаЗначений, Неопределено, Соответствие - Курсы валют.
//   * СоответствиеВидовЦенИменамКолонокТаблицыТоваров - Соответствие - Соответствие видов цен именам колонок.
//
Функция ИнициализироватьСтруктуруКэшаДанных(КэшДанных = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ИнициализироватьСтруктуруКэшаДанных(КэшДанных);
```
</details>

## СоздатьТаблицуНоменклатурыПоДеревуЦен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Копирует в таблицу значений номенклатуру с характеристиками из дерева цен
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ДобавлятьВсеСтроки - Булево
//
// Возвращаемое значение:
//  ТаблицаЗначений - таблица с колонками:
//   * НоменклатураПартнера - СправочникСсылка.НоменклатураКонтрагентов - Номенклатура поставщика.
//   * Номенклатура           - СправочникСсылка.Номенклатура - Номенклатура.
//   * Характеристика         - СправочникСсылка.ХарактеристикиНоменклатуры - Характеристика номенклатуры.
//
Функция СоздатьТаблицуНоменклатурыПоДеревуЦен(Форма, ДобавлятьВсеСтроки = Истина) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.СоздатьТаблицуНоменклатурыПоДеревуЦен(Форма, ДобавлятьВсеСтроки);
```
</details>

## СоздатьТаблицуНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает пустую таблицу для товаров (Без цен и упаковок).
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//
// Возвращаемое значение:
//  ТаблицаЗначений - таблица с колонками:
//   * НоменклатураПартнера - СправочникСсылка.НоменклатураКонтрагентов - Номенклатура поставщика.
//   * Номенклатура           - СправочникСсылка.Номенклатура - Номенклатура.
//   * Характеристика         - СправочникСсылка.ХарактеристикиНоменклатуры - Характеристика номенклатуры.
//
Функция СоздатьТаблицуНоменклатуры(Форма) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.СоздатьТаблицуНоменклатуры(Форма) 
```
</details>

## СоздатьТаблицуТовары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает пустую таблицу для товаров (С ценами и упаковками).
//
// Параметры:
//  ЭтоРегистрацияЦенПоставщика - Булево - Признак, что таблица создается для регистрации цен поставщика.
//  ИспользуетсяЦенообразование25 - Булево - Истина, используется новое ценообразование.
//
// Возвращаемое значение:
//  ТаблицаЗначений - таблица с колонками:
//   * НоменклатураПартнера - СправочникСсылка.НоменклатураКонтрагентов - Номенклатура поставщика.
//   * Номенклатура           - СправочникСсылка.Номенклатура - Номенклатура.
//   * Характеристика         - СправочникСсылка.ХарактеристикиНоменклатуры - Характеристика номенклатуры.
//   * ВидЦены                - СправочникСсылка.ВидыЦенПоставщиков,СправочникСсылка.ВидыЦен - Вид цены.
//   * Цена                   - Число - Цена.
//   * Упаковка               - СправочникСсылка.УпаковкиЕдиницыИзмерения - Упаковка.
//
Функция СоздатьТаблицуТовары(ЭтоРегистрацияЦенПоставщика, ИспользуетсяЦенообразование25 = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.СоздатьТаблицуТовары(ЭтоРегистрацияЦенПоставщика, ИспользуетсяЦенообразование25);
```
</details>

## ЗагрузитьНастройкиОтбораПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует реквизит КомпоновщикНастроекОтбор, используемый в механизмах отбора товаров.
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//
Процедура ЗагрузитьНастройкиОтбораПоУмолчанию(Форма) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ЗагрузитьНастройкиОтбораПоУмолчанию(Форма) 
```
</details>

## ЗагрузитьСправочникВидовЦен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные о видах цен, правилах расчета и отборах, пользовательские настройки для расчета.
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  НастройкиКомпоновкиДанных - ТаблицаЗначений - Таблица значений, пользовательские настройки компоновки данных,
//                                                сохраненные в документе.
//  МассивВидовЦен - Массив из СправочникСсылка.ВидыЦен -
//                 - Массив из СправочникСсылка.ВидыЦенПоставщиков -
//  ТаблицаНастроекВидовЦен - ТаблицаЗначений - описание см. ИнициализироватьТаблицуВыбранныхЦен
//
// Возвращаемое значение:
//  ТаблицаЗначений - Таблица с колонками:
//   * Ссылка - СправочникСсылка.ВидыЦен - Вид цены
//   * Наименование - Строка - Наименование вида цен
//   * Статус - ПеречислениеСсылка.СтатусыДействияВидовЦен - Статус вида цен
//   * ПометкаУдаления - Булево - Признак пометки на удаление вида цен
//   * РеквизитДопУпорядочивания - Число - Реквизит доп упорядочивания
//   * УстанавливатьЦенуПриВводеНаОсновании - Булево - Устанавливать цену при вводе на основании
//   * СпособЗаданияЦены - ПеречислениеСсылка.СпособыЗаданияЦен - Способ задания цены
//   * Идентификатор - Строка - Идентификатор для формул
//   * ПорогСрабатывания - Число - Порог срабатывания
//   * ВалютаЦены - СправочникСсылка.Валюты - Валюта цены
//   * Формула - Строка - Формула
//   * БазовыйВидЦены - Строка - Идентификатор базового вида цены
//   * Наценка - Число - Наценка
//   * СхемаКомпоновкиДанных - Строка - Имя предопределенного макета схемы компоновки данных
//   * ЗапрещенныйВидЦены - Булево - Признак того, что вид цены запрещен
//   * ЦеновыеГруппы - ТаблицаЗначений - с колонками:
//     ** ЦеноваяГруппа - СправочникСсылка.ЦеновыеГруппы - Ценовая группа, для которой определяется алгоритм расчета цены
//     ** Формула - Строка - Определяет правила расчета цены для ценовой группы
//     ** БазовыйВидЦены - Строка - Идентификатор базового вида цены
//     ** Наценка - Число - Наценка
//   * ПорогиСрабатывания - ТаблицаЗначений - с колонками:
//     ** ЦеноваяГруппа - СправочникСсылка.ЦеновыеГруппы - Ценовая группа, для которой определяется алгоритм расчета цены
//     ** ПорогСрабатывания - ОпределяемыйТип.ДенежнаяСуммаНеотрицательная - Определяет правила расчета цены для ценовой группы
//   * ВлияющиеВидыЦен - ТаблицаЗначений - с колонками:
//     ** ВлияющийВидЦен - СправочникСсылка.ВидыЦен - Влияющий вид цен
//   * ПравилаОкругленияЦены - ТаблицаЗначений - с колонками:
//     ** НижняяГраницаДиапазонаЦен - ОпределяемыйТип.ДенежнаяСуммаНеотрицательная - Минимальное значение цены, начиная с которого применяется правило округления
//     ** ТочностьОкругления - ОпределяемыйТип.ДенежнаяСуммаНеотрицательная - Определяет точность округления цены
//     ** ПсихологическоеОкругление - ОпределяемыйТип.ДенежнаяСуммаНеотрицательная - Вычитать из результата
//   * ВариантОкругления - ПеречислениеСсылка.ВариантыОкругления - Вариант округления
//   * Уровень - Число - Уровень
//   * ВлияющиеЦены - СписокЗначений - Влияющие цены.
//   * ЗависимыеЦены - СписокЗначений - Зависимые цены.
//   * ИмяКолонки - Строка - Имя колонки.
//   * АдресСхемыКомпоновкиДанных - Строка - Адрес схемы компоновки данных.
//   * АдресНастроекСхемыКомпоновкиДанных - Строка - Адрес настроек схемы компоновки данных.
//   * НайденыОбязательныеПараметры - Булево - Найдены обязательные параметры.
//   * Параметры - Строка - Описание параметров.
//
Функция ЗагрузитьСправочникВидовЦен(Форма, НастройкиКомпоновкиДанных, МассивВидовЦен = Неопределено, ТаблицаНастроекВидовЦен = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ЗагрузитьСправочникВидовЦен(Форма, НастройкиКомпоновкиДанных, МассивВидовЦен, ТаблицаНастроекВидовЦен);
```
</details>

## ЗагрузитьСправочникВидовЦенПоставщика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные о видах цен поставщика.
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//
// Возвращаемое значение:
//  ТаблицаЗначений - Таблица видов цен поставщика:
//   * Ссылка - СправочникСсылка.ВидыЦенПоставщиков - Вид цены поставщика
//   * Наименование - Строка - Наименование вида цен
//   * ПометкаУдаления - Булево - Признак пометки на удаление вида цен
//   * Валюта - СправочникСсылка.Валюты - Валюта цены
//   * ЦенаВключаетНДС - Булево - Цена включает НДС
//   * ЗапрещенныйВидЦены - Булево - Признак того, что вид цены запрещен
//   * ИмяКолонки - см. ИмяКолонкиПоВидуЦены
//
Функция ЗагрузитьСправочникВидовЦенПоставщика(Форма) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ЗагрузитьСправочникВидовЦенПоставщика(Форма) 
```
</details>

## ЗагрузитьТаблицуНастройкиКомпоновкиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу настроек компоновки данных из документа.
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//
// Возвращаемое значение:
//  ТаблицаЗначений - Настройки компоновки данных:
//  * ВидЦены - СправочникСсылка.ВидыЦен - Виды цен
//  * НастройкиКомпоновкиДанных - НастройкиКомпоновкиДанных
//  * ПараметрыКомпоновкиДанных - ПараметрыКомпоновкиДанныхТаблицыСхемыЗапроса
//
Функция ЗагрузитьТаблицуНастройкиКомпоновкиДанных(Форма) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ЗагрузитьТаблицуНастройкиКомпоновкиДанных(Форма) 
```
</details>

## ИнициализироватьВыбранныеЦены
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует на форма таблицу "Выбранные цены"
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  МассивВидовЦен - Массив из СправочникСсылка.ВидыЦен
//                 - Массив из СправочникСсылка.ВидыЦенПоставщиков
//  ТаблицаВидовЦен - ТаблицаЗначений - таблица видов цен
//
Процедура ИнициализироватьВыбранныеЦены(Форма, МассивВидовЦен = Неопределено, ТаблицаВидовЦен = Неопределено) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ИнициализироватьВыбранныеЦены(Форма, МассивВидовЦен, ТаблицаВидовЦен);
```
</details>

## ПеречитатьВыбранныеЦены
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Перечитать выбранные цены
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//
Процедура ПеречитатьВыбранныеЦены(Форма) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ПеречитатьВыбранныеЦены(Форма) 
```
</details>

## ДобавитьТоварыПоставщика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу настроек компоновки данных из документа
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ТаблицаТовары - ТаблицаЗначений - таблица с добавляемыми товарами
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//
// Возвращаемое значение:
//  ТаблицаЗначений - соответствие номенклатуры и характеристики с добавленной строкой дерева цен.
//
Функция ДобавитьТоварыПоставщика(Форма, Знач ТаблицаТовары, КэшДанных) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ДобавитьТоварыПоставщика(Форма, ТаблицаТовары, КэшДанных) 
```
</details>

## ДобавитьТовары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу настроек компоновки данных из документа
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ТаблицаТовары - ТаблицаЗначений - таблица с добавляемыми товарами
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//
// Возвращаемое значение:
//  ТаблицаЗначений - соответствие номенклатуры и характеристики с добавленной строкой дерева цен.
//
Функция ДобавитьТовары(Форма, Знач ТаблицаТовары, КэшДанных) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ДобавитьТовары(Форма, ТаблицаТовары, КэшДанных) 
```
</details>

## ДобавитьТоварыПоОтбору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу настроек компоновки данных из документа
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  АдресВоВременномХранилище - Строка - Адрес таблицы товаров во временном хранилище
//  ТаблицаТовары - ТаблицаЗначений - Добавляемые товары
//  ЗаполняемыйВидЦен - СправочникСсылка.ВидыЦен - К ценам по данному виду цен будет добавлен признак ручного изменения
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//  ОбновлятьСтарыеЦены - Булево - Истина, вызывать обновление старых цен
Процедура ДобавитьТоварыПоОтбору(Форма, Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ДобавитьТоварыПоОтбору(Форма, );
```
</details>

## ОбновитьДанныеВСтрокеПоЦенамУпаковкам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьДанныеВСтрокеПоЦенамУпаковкам(СтрокаДереваЦен, ПараметрыЗаполнения) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ОбновитьДанныеВСтрокеПоЦенамУпаковкам(СтрокаДереваЦен, ПараметрыЗаполнения));
```
</details>

## РассчитатьЦеныПоИдентификаторуСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет расчет цен в строке по идентификатору
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ИдентификаторСтроки - Число - Идентификатор строки
//  ЗагружатьЦеныИзИБ - Булево - Указывает на необходимость загрузки цен из информационной базы
//  ИзмененноеПоле - Строка - поле, в котором изменена цена
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
Процедура РассчитатьЦеныПоИдентификаторуСтроки(Форма, Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.РассчитатьЦеныПоИдентификаторуСтроки(Форма, );
```
</details>

## РассчитатьЦеныПоИдентификаторуСтроки2_5
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет расчет цен в строке по идентификатору
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения -
//  ИдентификаторСтроки - Число -
//  ЗагружатьЦеныИзИБ - Булево - Указывает на необходимость загрузки цен из информационной базы
//  ИзмененноеПоле - Строка - поле, в котором изменена цена.
//  КэшДанных - см. УстановкаЦенСервер.ИнициализироватьСтруктуруКэшаДанных
//
Процедура РассчитатьЦеныПоИдентификаторуСтроки2_5(Форма, Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.РассчитатьЦеныПоИдентификаторуСтроки2_5(Форма, );
```
</details>

## РассчитатьЦены
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает цены в таблице цен
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ПараметрыРасчета - Структура - Параметры расчета
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//
Процедура РассчитатьЦены(Форма, ПараметрыРасчета, КэшДанных = Неопределено) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.РассчитатьЦены(Форма, ПараметрыРасчета, КэшДанных);
```
</details>

## ЗаполнитьЦеныИзДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает цены в таблице цен
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ПараметрыРасчета - Структура
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//
Процедура ЗаполнитьЦеныИзДокументов(Форма, ПараметрыРасчета, КэшДанных = Неопределено) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ЗаполнитьЦеныИзДокументов(Форма, ПараметрыРасчета, КэшДанных);
```
</details>

## ЗагрузитьЗначенияЦенИзДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает значения базовых цен в таблицу
//
// Параметры:
// 	Форма - см. ПостроитьДеревоЦен.Форма
// 	ТаблицаНоменклатуры - ТаблицаЗначений - Таблица, в которую будут загружены значения цен
//  МассивСтрокВидовЦен - Массив из СправочникСсылка.ВидыЦен -
//                      - Массив из СправочникСсылка.ВидыЦенПоставщиков -
//  ДокументыУстановкиЦен - Массив из ДокументСсылка.УстановкаЦенНоменклатуры -
// 	КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//
Процедура ЗагрузитьЗначенияЦенИзДокументов(Форма, Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ЗагрузитьЗначенияЦенИзДокументов(Форма, );
```
</details>

## РассчитатьВсеЦены
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет расчет базовых, заполняемых по данным информационной базы и рассчитываемых цен.
//
// Параметры:
// 	Форма - см. ПостроитьДеревоЦен.Форма
// 	КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
Процедура РассчитатьВсеЦены(Форма, КэшДанных) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.РассчитатьВсеЦены(Форма, КэшДанных) 
```
</details>

## РассчитатьВычисляемыеЦены
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет расчет вычисляемых цен
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ТаблицаНоменклатуры - ДанныеФормыКоллекция - Таблица, в которой осуществляется расчет цен
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//  ВидыЦен - Массив из СправочникСсылка.ВидыЦен -
//          - Массив из СправочникСсылка.ВидыЦенПоставщиков -
//  ТолькоНезаполненные - Булево - Указывает на необходимость расчета ранее заполненных цен
//  ИзмененноеПоле - Строка - Наименование измененного поля
//  МассивФормул - Массив - Данные по формулам
//
Процедура РассчитатьВычисляемыеЦены(Форма, Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.РассчитатьВычисляемыеЦены(Форма, );
```
</details>

## РассчитатьФормулыВБезопасномРежиме
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура - Рассчитать формулы в безопасном режиме
// Рассчитывает формулы построчно для переданной таблицы. Вызывается с предварительной установкой безопасного режима.
// Параметры:
//  Параметры	 - Структура - Структура параметров с обязательными реквизитами:
//	* ФормулыДляРасчета - ТаблицаЗначений
//	* СсылкаНаОбъект    - ДокументСсылка, Неопределено - (в случае, если ссылка отсутствует).
//
Процедура РассчитатьФормулыВБезопасномРежиме(Параметры) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.РассчитатьФормулыВБезопасномРежиме(Параметры) 
```
</details>

## ВычислитьЦеныПоДаннымИБ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вычисляет цены, рассчитываемые по данным информационной базы
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ТаблицаНоменклатуры - ТаблицаЗначений - Таблица, в которой необходимо заполнить цены
//  МассивСтрокВидовЦен - Массив из СправочникСсылка.ВидыЦен -
//                      - Массив из СправочникСсылка.ВидыЦенПоставщиков -
//  ТолькоНезаполненные - Булево - указывает на необходимость вычисления только незаполненных цен.
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//
Процедура ВычислитьЦеныПоДаннымИБ(Форма, Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ВычислитьЦеныПоДаннымИБ(Форма, );
```
</details>

## УдалитьТоварыБезИзмененныхЦен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Удаляет товары без измененных цен из дерева цен
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ПоИзменениямЗаДень - Булево
//
Процедура УдалитьТоварыБезИзмененныхЦен(Форма, ПоИзменениямЗаДень = Ложь) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.УдалитьТоварыБезИзмененныхЦен(Форма, ПоИзменениямЗаДень);
```
</details>

## ИзменитьЦеныНаПроцент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Изменяет цены на процент
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ПараметрыРасчета - Структура - Структура параметров расчета
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//
Процедура ИзменитьЦеныНаПроцент(Форма, ПараметрыРасчета, КэшДанных = Неопределено) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ИзменитьЦеныНаПроцент(Форма, ПараметрыРасчета, КэшДанных);
```
</details>

## ИзменитьЦены
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает для выделенных строк заданные цены
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ПараметрыРасчета - Структура - Структура параметров расчета
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//
Процедура ИзменитьЦены(Форма, ПараметрыРасчета, КэшДанных = Неопределено) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ИзменитьЦены(Форма, ПараметрыРасчета, КэшДанных);
```
</details>

## ЗагрузитьБазовыеЦены
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет загрузку базовых цен в таблицу цен
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//
Процедура ЗагрузитьБазовыеЦены(Форма, КэшДанных) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ЗагрузитьБазовыеЦены(Форма, КэшДанных) 
```
</details>

## ЗагрузитьЗначенияБазовыхЦен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загружает значения базовых цен в таблицу
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
// 	ТаблицаНоменклатуры - ТаблицаЗначений - Таблица, в которую будут загружены значения цен
// 	КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
// 	ДополнительныеПараметры - Структура - содержит:
// 	* МассивСтрокВидовЦен - Массив из СправочникСсылка.ВидыЦен - Массив видов цен
//                        - Массив из СправочникСсылка.ВидыЦенПоставщиков -
// 	* ДатаДокумента - Дата - Дата загрузки цен
// 	* ПроцентИзмененияЦены - Число - Процент, на который необходимо изменить цену
// 	* ПрименятьОкругление - Булево - Указывает на необходимость применения округления.
//
Процедура ЗагрузитьЗначенияБазовыхЦен(Форма, Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ЗагрузитьЗначенияБазовыхЦен(Форма, );
```
</details>

## ОбновитьСтарыеЦеныНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет старые цены номенклатуры в дереве цен
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//  ТаблицаНоменклатуры - ТаблицаЗначений, Неопределено - Данные по добавляемым строкам
//
Процедура ОбновитьСтарыеЦеныНоменклатуры(Форма, КэшДанных = Неопределено, ТаблицаНоменклатуры = Неопределено) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ОбновитьСтарыеЦеныНоменклатуры(Форма, КэшДанных, ТаблицаНоменклатуры);
```
</details>

## ДополнитьТаблицуТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает таблицу товаров (Номенклатура, Характеристика, ВидЦены, Упаковка, Цена) из дерева цен.
//
// Параметры:
//  ТаблицаТоваров - см. СоздатьТаблицуТовары
//
// Возвращаемое значение:
//  ТаблицаЗначений - Дополненная таблица товаров
//
Функция ДополнитьТаблицуТоваров(ТаблицаТоваров) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ДополнитьТаблицуТоваров(ТаблицаТоваров) 
```
</details>

## ТаблицаТовары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает таблицу товаров (Номенклатура, Характеристика, ВидЦены, Упаковка, Цена) из дерева цен.
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//  Параметры - Структура - дополнительных параметров:
//  * ТолькоИзмененные - Булево - только по измененным ценам.
//  * ПоИзменениямЗаДень - Булево - по измененным ценам за день.
//  ТаблицаНоменклатуры - ТаблицаЗначений, Неопределено - данные по загржаемым товарам
//
// Возвращаемое значение:
//  см. СоздатьТаблицуТовары
//
Функция ТаблицаТовары(Форма, КэшДанных = Неопределено, Параметры = Неопределено, ТаблицаНоменклатуры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ТаблицаТовары(Форма, КэшДанных, Параметры, ТаблицаНоменклатуры);
```
</details>

## ЗагрузитьСтарыеЦеныНоменклатурыПредприятия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет загрузку старых цен для строк таблицы
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ТаблицаНоменклатуры - см. СоздатьТаблицуТовары
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//  ТаблицаНоменклатурыЗапрещеннойКРедактированию - ТаблицаЗначений - Таблица запрещенной к редактированию номенлатуры
//
Процедура ЗагрузитьСтарыеЦеныНоменклатурыПредприятия(Форма, ТаблицаНоменклатуры, КэшДанных, ТаблицаНоменклатурыЗапрещеннойКРедактированию = Неопределено) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ЗагрузитьСтарыеЦеныНоменклатурыПредприятия(Форма, ТаблицаНоменклатуры, КэшДанных, ТаблицаНоменклатурыЗапрещеннойКРедактированию);
```
</details>

## ЗагрузитьСтарыеЦеныНоменклатурыПредприятия2_5
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет загрузку старых цен для строк таблицы
//
Процедура ЗагрузитьСтарыеЦеныНоменклатурыПредприятия2_5(Форма, ТаблицаНоменклатуры, КэшДанных, ТаблицаНоменклатурыЗапрещеннойКРедактированию = Неопределено) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ЗагрузитьСтарыеЦеныНоменклатурыПредприятия2_5(Форма, ТаблицаНоменклатуры, КэшДанных, ТаблицаНоменклатурыЗапрещеннойКРедактированию);
```
</details>

## ЗагрузитьСтарыеЦеныНоменклатурыПоставщика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет загрузку старых цен для строк таблицы
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ТаблицаНоменклатуры - см. СоздатьТаблицуТовары
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//
Процедура ЗагрузитьСтарыеЦеныНоменклатурыПоставщика(Форма, ТаблицаНоменклатуры, КэшДанных) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ЗагрузитьСтарыеЦеныНоменклатурыПоставщика(Форма, ТаблицаНоменклатуры, КэшДанных) 
```
</details>

## ЗагрузитьСтарыеЦеныНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет загрузку старых цен для строк таблицы
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ТаблицаНоменклатуры - см. СоздатьТаблицуТовары
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//
Процедура ЗагрузитьСтарыеЦеныНоменклатуры(Форма, ТаблицаНоменклатуры, КэшДанных) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ЗагрузитьСтарыеЦеныНоменклатуры(Форма, ТаблицаНоменклатуры, КэшДанных) 
```
</details>

## ЗагрузитьСтарыеЦеныНоменклатурыПрайсЛист
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет загрузку старых цен для строк таблицы
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ТаблицаНоменклатуры - см. СоздатьТаблицуТовары
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//  ТаблицаНоменклатурыЗапрещеннойКРедактированию - ТаблицаЗначений - Таблица запрещенной к редактированию номенлатуры
//
Процедура ЗагрузитьСтарыеЦеныНоменклатурыПрайсЛист(Форма, ТаблицаНоменклатуры, КэшДанных, ТаблицаНоменклатурыЗапрещеннойКРедактированию = Неопределено) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ЗагрузитьСтарыеЦеныНоменклатурыПрайсЛист(Форма, ТаблицаНоменклатуры, КэшДанных, ТаблицаНоменклатурыЗапрещеннойКРедактированию);
```
</details>

## ЗагрузитьСтарыеЦеныНоменклатурыПрайсЛист2_5
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет загрузку старых цен для строк таблицы
//
Процедура ЗагрузитьСтарыеЦеныНоменклатурыПрайсЛист2_5(Форма, ТаблицаНоменклатуры, КэшДанных, ТаблицаНоменклатурыЗапрещеннойКРедактированию = Неопределено) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ЗагрузитьСтарыеЦеныНоменклатурыПрайсЛист2_5(Форма, ТаблицаНоменклатуры, КэшДанных, ТаблицаНоменклатурыЗапрещеннойКРедактированию);
```
</details>

## ЗагрузитьСтарыеЦеныНоменклатурыПоставщикаПрайсЛист
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет загрузку старых цен для строк таблицы
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ТаблицаНоменклатуры - см. СоздатьТаблицуТовары
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//
Процедура ЗагрузитьСтарыеЦеныНоменклатурыПоставщикаПрайсЛист(Форма, ТаблицаНоменклатуры, КэшДанных) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ЗагрузитьСтарыеЦеныНоменклатурыПоставщикаПрайсЛист(Форма, ТаблицаНоменклатуры, КэшДанных) 
```
</details>

## ПереформироватьТаблицуЦен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует таблицу цен на форме
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ПересчитатьЦены - Булево - Указывает на необходимость перерасчета цен.
//
Процедура ПереформироватьТаблицуЦен(Форма, ПересчитатьЦены = Ложь) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ПереформироватьТаблицуЦен(Форма, ПересчитатьЦены);
```
</details>

## ПоместитьСтрокуЦенВТабличнуюЧасть
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Копирует цены по всем видам из таблицы формы ДеревоЦен в строку табличной части Товары объекта.
//
// Параметры:
//  Параметры - Структура - Параметры помещения строки в табличную часть, включает:
//     * Форма - см. ПостроитьДеревоЦен.Форма
//     * ТабличныеЧасти - Массив из ТабличнаяЧасть
//  СтрокаЦен - ДанныеФормыЭлементКоллекции - Строка дерева цен, которую необходимо поместить в табличную часть.
//
Процедура ПоместитьСтрокуЦенВТабличнуюЧасть(Параметры, СтрокаЦен) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ПоместитьСтрокуЦенВТабличнуюЧасть(Параметры, СтрокаЦен) 
```
</details>

## ПоместитьВидыЦенВТабличнуюЧасть
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Копирует виды цен из таблицы формы ВыбранныеЦены в табличную часть ВидыЦен объекта.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - Форма:
// * Объект - ОбработкаОбъект.ПрайсЛист, ДокументОбъект.УстановкаЦенНоменклатуры -
// * ВыбранныеЦены - ТаблицаЗначений -:
// ** Ссылка - СправочникСсылка.ВидыЦен, СправочникСсылка.ВидыЦенПоставщиков -
// ** Идентификатор - Строка -
// ** Наименование - Строка -
// * СохраненныеДокументы - ТаблицаЗначений -:
// ** Ссылка - ДокументСсылка.РегистрацияЦенНоменклатурыПоставщика -
// * Элементы - ЭлементыФормы -:
// ** ДеревоЦен - ДеревоЗначений, ТаблицаФормы, ДанныеФормыЭлементДерева, ДанныеФормыДерево -
// * ДеревоЦен - ДеревоЗначений, ТаблицаФормы, ДанныеФормыЭлементДерева, ДанныеФормыДерево -
// * КомпоновщикНастроекОтбор - КомпоновщикНастроекКомпоновкиДанных -
//  ТабличнаяЧасть - ДокументТабличнаяЧасть.УстановкаЦенНоменклатуры.ВидыЦен - Табличная часть
//  СохранятьНастройкиКомпоновкиДанных - Булево - Сохранять настройки компоновки данных
Процедура ПоместитьВидыЦенВТабличнуюЧасть(Форма, Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ПоместитьВидыЦенВТабличнуюЧасть(Форма, );
```
</details>

## ЗагрузитьИзExcel
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Загрузить из excel
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  МассивСтруктурВидыЦен	 - Массив - Виды цен
//  МассивСтруктурТовары	 - Массив - Товары
//
// Возвращаемое значение:
//  Структура - Результат загрузки.
//
Функция ЗагрузитьИзExcel(Форма, МассивСтруктурВидыЦен, МассивСтруктурТовары) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ЗагрузитьИзExcel(Форма, МассивСтруктурВидыЦен, МассивСтруктурТовары) 
```
</details>

## УстановитьПризнакРучногоИзмененияВычисляемыхЦен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Установить признак ручного изменения вычисляемых цен
//
// Параметры:
//  Форма 				- см. ПостроитьДеревоЦен.Форма
//  ТаблицаНоменклатуры	 - ТаблицаЗначений - Номенклатура, по которой изменены цены
//  ИзмененноеПоле		 - Строка - Имя измененного поля
//  КэшДанных					 - Соответствие - Кэш данных.
//
Процедура УстановитьПризнакРучногоИзмененияВычисляемыхЦен(Форма, Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.УстановитьПризнакРучногоИзмененияВычисляемыхЦен(Форма, );
```
</details>

## УстановитьПризнакРучногоИзмененияДляВидовЦен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Установить признак ручного изменения для видов цен
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ТаблицаНоменклатуры	 - ТаблицаЗначений - Номенклатура, по которой изменены цены
//  МассивСтрокЗависимыхВидовЦен - Массив - Зависимые виды цен
//  КэшДанных					 - Соответствие - Кэш данных.
//
Процедура УстановитьПризнакРучногоИзмененияДляВидовЦен(Форма, Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.УстановитьПризнакРучногоИзмененияДляВидовЦен(Форма, );
```
</details>

## КурсыВалют
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает последние курсы валют во временное хранилище.
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//
Процедура КурсыВалют(Форма, КэшДанных) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.КурсыВалют(Форма, КэшДанных) 
```
</details>

## КоэффициентыУпаковокНоменклатурыДереваТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу с колонками Упаковка и Коэффициент.
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма.
//  ТаблицаНоменклатуры - ДанныеФормыКоллекция - Таблица, в которой осуществляется расчет цен
//  КэшДанных - Структура - Кэш данных.
//
// Возвращаемое значение:
//  Соответствие - соответствие номенклатуры и коэффициентов упаковок.
//
Функция КоэффициентыУпаковокНоменклатурыДереваТоваров(Форма, ТаблицаНоменклатуры = Неопределено, КэшДанных = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.КоэффициентыУпаковокНоменклатурыДереваТоваров(Форма, ТаблицаНоменклатуры, КэшДанных);
```
</details>

## КоэффициентыУпаковокНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу с колонками Номенклатура, Упаковка и Коэффициент.
//
// Параметры:
//  ТаблицаУпаковокНоменклатуры - ТаблицаЗначений - содержит номенклатуры и упаковки, для которых необходимо получить коэффициенты.
//
// Возвращаемое значение:
//  Соответствие - соответствие номенклатуры и коэффициентов упаковок.
//
Функция КоэффициентыУпаковокНоменклатуры(ТаблицаУпаковокНоменклатуры) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.КоэффициентыУпаковокНоменклатуры(ТаблицаУпаковокНоменклатуры) 
```
</details>

## ЗагрузитьТабличнуюЧастьТовары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет загрузку цен для всех строк табличной части товары
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//
Процедура ЗагрузитьТабличнуюЧастьТовары(Форма, КэшДанных) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ЗагрузитьТабличнуюЧастьТовары(Форма, КэшДанных) 
```
</details>

## ПоместитьЦеныВТабличнуюЧасть
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Копирует цены из таблицы формы ДеревоЦен в табличную часть Товары объекта
//
// Параметры:
// Параметры - Структура - где:
//  * Форма    - см. ПостроитьДеревоЦен.Форма.
//  * СохранятьБазовые - Булево - указывает на необходимость помещения в табличную часть базовых видов цен.
//
Процедура ПоместитьЦеныВТабличнуюЧасть(Параметры) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ПоместитьЦеныВТабличнуюЧасть(Параметры) 
```
</details>

## НоменклатураБезИерархии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура НоменклатураБезИерархии(СтрокиИерархии,МассивСтрок) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.НоменклатураБезИерархии(СтрокиИерархии, МассивСтрок));
```
</details>

## ИмяКолонкиПоВидуЦены
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает уникальное имя колонки дерева цен по ссылке на вид цены
//
// Параметры:
//  ВидЦены - СправочникСсылка.ВидыЦен - Ссылка на вид цены
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//
// Возвращаемое значение:
//  Строка - Имя колонки вида цены.
//
Функция ИмяКолонкиПоВидуЦены(ВидЦены, КэшДанных) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ИмяКолонкиПоВидуЦены(ВидЦены, КэшДанных) 
```
</details>

## НайтиСтрокуДереваЦен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет поиск строки дерева цен по полям (Номенклатура, Характеристика).
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ВходящиеДанныеПоиска - Структура, ВыборкаИзРезультатаЗапроса - входящие параметры для поиска
//  КэшДанных - см. ИнициализироватьСтруктуруКэшаДанных
//  ОбновитьТаблицуСоответвия - Булево - Истина, если строчку не нашли, возможно Таблица устарела, необходимо поробовать ее обновить
//
// Возвращаемое значение:
//  СтрокаДереваЗначений, ДанныеФормыЭлементКоллекции - найденная строка дерева цен.
//
Функция НайтиСтрокуДереваЦен(Форма, ВходящиеДанныеПоиска, КэшДанных, ОбновитьТаблицуСоответвия = Истина) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.НайтиСтрокуДереваЦен(Форма, ВходящиеДанныеПоиска, КэшДанных, ОбновитьТаблицуСоответвия);
```
</details>

## ВернутьНайденнуюСтрокуДереваЦен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ВернутьНайденнуюСтрокуДереваЦен(Форма, КэшДанных, Отбор, Знач ОбновитьТаблицуСоответвия) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ВернутьНайденнуюСтрокуДереваЦен(Форма, КэшДанных, Отбор, ОбновитьТаблицуСоответвия));
```
</details>

## ВыбранныеВидыЦенВТаблицу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Сохраняет выбранные виды цен в таблицу значений
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ДляРедактирования - Булево
//
// Возвращаемое значение:
//  ТаблицаЗначений - см. ИнициализироватьТаблицуВыбранныхЦен
//
Функция ВыбранныеВидыЦенВТаблицу(Форма, ДляРедактирования = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ВыбранныеВидыЦенВТаблицу(Форма, ДляРедактирования);
```
</details>

## ИнициализироватьТаблицуВыбранныхЦен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Инициализирует таблицу значений выбранных цен
//
// Возвращаемое значение:
//  ТаблицаЗначений - Таблица для хранения выбранных цен
//
Функция ИнициализироватьТаблицуВыбранныхЦен() Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ИнициализироватьТаблицуВыбранныхЦен() 
```
</details>

## ЗависимыеОтВидаЦеныВидыЦен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает виды цен, зависимые от заданного вида цены
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  СтрокаВидЦены - ДанныеФормыЭлементКоллекции - Строка таблицы Выбранные Цены.
//
// Возвращаемое значение:
//  Массив из СправочникСсылка.ВидыЦен - Зависимые виды цен
//
Функция ЗависимыеОтВидаЦеныВидыЦен(Форма, СтрокаВидЦены) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ЗависимыеОтВидаЦеныВидыЦен(Форма, СтрокаВидЦены) 
```
</details>

## ДеревоЦенУпаковкаВалютаПриИзменении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик ПриИзменении дерева цен
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ИдентификаторСтроки - Число
//  ИмяТекущейКолонки - Строка
//  СтрокаПроверки - Строка - Упаковка или Валюта
//
Процедура ДеревоЦенУпаковкаВалютаПриИзменении(Форма, ИдентификаторСтроки, ИмяТекущейКолонки, СтрокаПроверки = "Упаковка") Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ДеревоЦенУпаковкаВалютаПриИзменении(Форма, ИдентификаторСтроки, ИмяТекущейКолонки, СтрокаПроверки);
```
</details>

## ДеревоЦенУпаковкаЗаказаПриИзменении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик ПриИзменении дерева цен
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ИдентификаторСтроки - Число
//  ИмяТекущейКолонки - Строка
//
Процедура ДеревоЦенУпаковкаЗаказаПриИзменении(Форма, ИдентификаторСтроки, ИмяТекущейКолонки) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ДеревоЦенУпаковкаЗаказаПриИзменении(Форма, ИдентификаторСтроки, ИмяТекущейКолонки) 
```
</details>

## ДеревоЦенМинимальнаяПартияПриИзменении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик ПриИзменении дерева цен
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  ИдентификаторСтроки - Число
//  ИмяТекущейКолонки - Строка
//
Процедура ДеревоЦенМинимальнаяПартияПриИзменении(Форма, ИдентификаторСтроки, ИмяТекущейКолонки) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ДеревоЦенМинимальнаяПартияПриИзменении(Форма, ИдентификаторСтроки, ИмяТекущейКолонки) 
```
</details>

## ЗаполненыОбязательныеПараметрыСхемКомпоновкиДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет заполнение обязательных параметров схем компоновки данных для выбранных видов цен.
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  СообщатьПользователюОбОшибках - Булево - Выдавать сообщение пользователю о каждой найденной ошибке.
//
// Возвращаемое значение:
//  Булево - Найдены ошибки заполнения обязательных параметров.
//
Функция ЗаполненыОбязательныеПараметрыСхемКомпоновкиДанных(Форма, СообщатьПользователюОбОшибках = Истина) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ЗаполненыОбязательныеПараметрыСхемКомпоновкиДанных(Форма, СообщатьПользователюОбОшибках);
```
</details>

## ПроверитьКорректностьЗаполненияДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет корректность заполнения документа установки цен
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
//  Отказ - Булево - признак отказа от записи документа
//
Процедура ПроверитьКорректностьЗаполненияДокумента(Форма, Отказ) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ПроверитьКорректностьЗаполненияДокумента(Форма, Отказ) 
```
</details>

## СохранитьНастройкуПорядкаВидовЦенПоставщика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет настройку порядка видов цен поставщика.
//
// Параметры:
//  Форма - см. ПостроитьДеревоЦен.Форма
// Возвращаемое значение:
// 	Булево - Истина - элементы заблокированы
Функция СохранитьНастройкуПорядкаВидовЦенПоставщика(Форма) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.СохранитьНастройкуПорядкаВидовЦенПоставщика(Форма) 
```
</details>

## ОчиститьСохраненныеДокументы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Очистить массив сохраненные документы.
//
// Параметры:
//  СохраненныеДокументы - ТаблицаЗначений - Сохраненные документы:
//     							* Ссылка - ДокументСсылка
//  					 - Массив из ДокументСсылка - Сохраненные документы
//  ИдентификаторФормы - УникальныйИдентификатор - Идентификатор формы.
//  УдалитьДокументы - Булево - Если истина, то удалить документы. Если Ложь, то разблокировать для редактирования.
//
Процедура ОчиститьСохраненныеДокументы(СохраненныеДокументы, ИдентификаторФормы, УдалитьДокументы = Ложь) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ОчиститьСохраненныеДокументы(СохраненныеДокументы, ИдентификаторФормы, УдалитьДокументы);
```
</details>

## НайтиСтрокуВидаЦенВДереве
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Осуществляет поиск строки с определенным видом цен в дереве
//
// Параметры:
//  Дерево - ДеревоЗначений - Дерево, в котором осуществляется поиск
//  ВидЦены - СправочникСсылка.ВидыЦен - Ссылка на вид цен, который необходимо найти.
//
// Возвращаемое значение:
//  СтрокаДереваЗначений - найденный вид цены
//
Функция НайтиСтрокуВидаЦенВДереве(Дерево, ВидЦены) Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.НайтиСтрокуВидаЦенВДереве(Дерево, ВидЦены) 
```
</details>

## ДобавитьТоварыПоОтборамСКД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьТоварыПоОтборамСКД(Форма, ЭтоАвтообновлениеЦен = Ложь) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ДобавитьТоварыПоОтборамСКД(Форма, ЭтоАвтообновлениеЦен);
```
</details>

## ДобавитьТоварыДляОбнуленияЦенПоОтборамСКД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьТоварыДляОбнуленияЦенПоОтборамСКД(Форма) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ДобавитьТоварыДляОбнуленияЦенПоОтборамСКД(Форма) 
```
</details>

## ПолучитьЗапрещеннуюКРедактированиюНоменклатуру
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные по запрещенной к редактированию номенклатуры во видам цен
//
// Параметры:
//  СтруктураФормы - Структура - дополнительные параметры
//  ТаблицаНоменклатуры - ТаблицаЗначений - данные по номенклатуре
//
// Возвращаемое значение:
//  ТаблицаЗначений - данные по номенклатуре по которой запрещено редактировать данные:
// * Номенклатура - СправочникСсылка.Номенклатура -
// * ХарактеристикаЦО - СправочникСсылка.ХарактеристикиНоменклатурыДляЦенообразования -
// * СерияЦО - СправочникСсылка.СерииНоменклатурыДляЦенообразования -
// * УпаковкаЦО - СправочникСсылка.УпаковкиЕдиницыИзмерения -
// * Характеристика - СправочникСсылка.ХарактеристикиНоменклатуры -
// * ВидЦены - СправочникСсылка.ВидыЦен -
Функция ПолучитьЗапрещеннуюКРедактированиюНоменклатуру( Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ПолучитьЗапрещеннуюКРедактированиюНоменклатуру();
```
</details>

## ПолучитьСтруктуруОтбораДанныхПоНоменклатуре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить структуру отбора данных по номенклатуре.
//
// Возвращаемое значение:
//  Структура - Получить структуру отбора данных по номенклатуре:
// * ЗначенияОтбора
// * Дата
// * ИспользуетсяЦенообразование25
// * ИспользоватьХарактеристикиНоменклатуры
// * ИспользоватьСерииНоменклатуры
// * ИспользоватьУпаковкиНоменклатуры
Функция ПолучитьСтруктуруОтбораДанныхПоНоменклатуре() Экспорт
```

Пример вызова
```bsl
Результат = УстановкаЦенСервер.ПолучитьСтруктуруОтбораДанныхПоНоменклатуре() 
```
</details>

## ПолучитьДанныеПоНоменклатуре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПолучитьДанныеПоНоменклатуре(НастройкиОтбора, ТаблицаНоменклатуры) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.ПолучитьДанныеПоНоменклатуре(НастройкиОтбора, ТаблицаНоменклатуры) 
```
</details>

## УстановитьПометкуИзмененныхФормул
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Установить пометку измененных формул.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения -
//  ДеревоЦен - ДеревоЗначений - Дерево значений цен
//  ВидЦены - СправочникСсылка.ВидыЦен, Неопределено - Вид цены
Процедура УстановитьПометкуИзмененныхФормул(Форма, ДеревоЦен = Неопределено, ВидЦены = Неопределено) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.УстановитьПометкуИзмененныхФормул(Форма, ДеревоЦен, ВидЦены);
```
</details>

## УстановитьПометкуИзмененныхФормулВКолонке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьПометкуИзмененныхФормулВКолонке(Форма, ДеревоЦен, Знач ИмяКолонки) Экспорт
```

Пример вызова
```bsl
УстановкаЦенСервер.УстановитьПометкуИзмененныхФормулВКолонке(Форма, ДеревоЦен, ИмяКолонки));
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
