---
title: Учет НДС клиент
slug: erp-uh/учет-ндс-клиент
---


## ВыбратьДокументНДСДляПередачиФНС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму списка документов НДС в режиме выбора, в качестве описания оповещения
// при открытии формы используется ОписаниеОповещения, передаваемое в параметрах процедуры.
//
// Параметры:
//	ОписаниеОповещения	- ОписаниеОповещения - Описание оповещения при выборе.
//	ПараметрыОтбора	- Структура - Задает начальные значения отборов. Поля структуры:
//		* Организация - СправочникСсылка.Организации - Организация.
//
Процедура ВыбратьДокументНДСДляПередачиФНС(ОписаниеОповещения, ПараметрыОтбора) Экспорт
```

Пример вызова
```bsl
УчетНДСКлиент.ВыбратьДокументНДСДляПередачиФНС(ОписаниеОповещения, ПараметрыОтбора) 
```
</details>

## ПроверкаЗаписиСтрокТабличныхЧастей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция проверяет для переданной формы не превышает ли количество строк в табличной части (табличных частях)
// максимально возможное для записи в базу данных.
// Если лимит возможного количества строк превышен, то пользователю предлагается перенести лишние строки
// в новый документ (новые документы).
//
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - форма документа
//   ПараметрыПереносаСтрокТЧ - Структура - структура входных параметров с ключами:
//     * ТабличныеЧасти          - Соответствие - соотствие между проверяемой табличной частью и подчиненной.
//               * Ключ             - Строка - имя проверяемой табличной части
//               * Значение         - Структура - структура с ключами:
//....................* КоличествоСтрокДляПереноса - Число - обязательный ключ в него записывается вычисляемое в функции
//..........................................................количество строк для переноса проверяемой табличной части.
//                    * ПодчиненныеТабличныеЧасти - Массив - необязательный ключ массив подчинённых табличных частей,
//                                                            строки из которых нужно перенести в новый документ.
//                    * ПодчиненнаяТЧМаксимальноеКоличествоСтрок - Строка - имя подчиненной табличной части с
//                                                                          максимальным количеством строк.
//                    * МаксимальноеКоличествоСтрокВДокументе    - Число - максимальное количество строк основной
//                                                                         табличной части в новом документе.
//     * РеквизитыДокумента      - Строка - список реквизитов для копирования из документа.
//     * РежимЗаписи             - РежимЗаписиДокумента - режим записи документа.
// Возвращаемое значение:
//  - Булево - Истина, если количество строк табличной части документа превышает
//             максимальное количество строк, хранимое платформой в табличной части.
//
//  Если количество строк подчинной табличной части превышает количество строк основной табличной части и максимально
//   возможное количество для записи в базу данных, то в структуру, связанную с основной табличной частью
//   добавляется ключи:
//  * ПодчиненнаяТЧМаксимальноеКоличествоСтрок - Строка - имя подчиненной табличной части с максимальным
//                                                        количеством строк.
//  * МаксимальноеКоличествоСтрокВДокументе    - Число - максимальное количество строк основной табличной
//                                                       части в новом документе.
Функция ПроверкаЗаписиСтрокТабличныхЧастей(Форма, ПараметрыПереносаСтрокТЧ) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСКлиент.ПроверкаЗаписиСтрокТабличныхЧастей(Форма, ПараметрыПереносаСтрокТЧ) 
```
</details>

## ПеренестиСтрокиТабличныхЧастейВДругойДокумент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура оповещает об успехе, либо неудачи переноса в новый документ (новые документы)
// строк, которые превыщают лимит количества записи строк табличной части (табличных частей) в базу данных.
// Внутри себя вызывает функцию разбиения табличной части (табличных частей) на несколько документов.
//
// Параметры:
//   ПараметрыПереносаСтрокТЧ - Структура - структура входных параметров с ключами:
//     * ТабличныеЧасти          - Соответвие - соотствие между проверяемой табличной частью и подчиненной.
//               * Ключ             - Строка - имя проверяемой табличной части
//               * Значение         - Структура - структура с ключами:
//....................* КоличествоСтрокДляПереноса - Число - обязательный ключ в него записывается вычисляемое в функции
//..........................................................количество строк для переноса проверяемой табличной части.
//                    * ПодчиненныеТабличныеЧасти - Массив - необязательный ключ является массивом подчинённых
//                                                           табличных частей для переноса строк в новый документ.
//     * РеквизитыДокумента          - Строка - список реквизитов для копирования из документа.
//     * РежимЗаписи                 - РежимЗаписиДокумента - режим записи документа.
//     * МаксимальноеКоличествоСтрок - Число - максимальное количество строк, хранимое платформой в табличной части.
//     * Объект                      - ДанныеФормыСтруктура - объект клиентской формы документа, для которого нужно
//                                                            перености строки табличных частей в новый документ.
//
Процедура ПеренестиСтрокиТабличныхЧастейВДругойДокумент(ПараметрыПереносаСтрокТЧ) Экспорт
```

Пример вызова
```bsl
УчетНДСКлиент.ПеренестиСтрокиТабличныхЧастейВДругойДокумент(ПараметрыПереносаСтрокТЧ) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
