---
title: Учет НДС клиент сервер
slug: erp-uh/учет-ндс-клиент-сервер
---


## РассчитатьСуммуНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает сумму НДС исходя из суммы и флагов налогообложения.
//
// Параметры:
//  Сумма            - Число - сумма от которой надо рассчитывать налоги;
//  СуммаВключаетНДС - Булево - признак включения НДС в сумму ("внутри" или "сверху");
//  СтавкаНДС        - Число - процентная ставка НДС.
//
// Возвращаемое значение:
//  Число - полученная сумма НДС.
//
Функция РассчитатьСуммуНДС(Сумма, СуммаВключаетНДС, СтавкаНДС) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСКлиентСервер.РассчитатьСуммуНДС(Сумма, СуммаВключаетНДС, СтавкаНДС) 
```
</details>

## ПересчитатьЦенуПриИзмененииФлаговНалогов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Производит пересчет цен при изменении флагов учета налогов.
// Пересчет зависит от способа заполнения цен, при заполнении По ценам номенклатуры (при продаже)
// хочется избегать ситуаций, когда компания  «теряет деньги» при пересчете налогов.
// Поэтому если в документе флаг "Учитывать налог" выключен, то цены должны браться напрямую из справочника,
// потому что хочется продавать по той же цене, независимо от режима налогообложения.
// Например, если отпускная цена задана с НП для избежания ошибок округления, то это не значит,
// что при отпуске без НП мы должны продать дешевле. Если же флаг учета налога в документе включен,
// то цены должны пересчитываться при подстановке в документ:
// налог должен включаться или не включаться в зависимости от флага включения налога в типе цен.
// При заполнении по ценам контрагентов (при покупке) хочется хранить цены поставщиков.
// Поэтому нужно пересчитывать всегда по установленным флагам в документе и в типе цен.
// Это гарантирует, что при записи цен в регистр и последующем их чтении,
// например, при заполнении следующего документа, мы с точностью до ошибок округления при пересчете
// получим те же самые цены.
//
// Параметры:
//  Цена                - Число - Пересчитываемое значение цены.
//  ЦенаВключаетНДС     - Булево - Определяет содержит ли переданное значение цены НДС.
//  СуммаВключаетНДС    - Булево - Определяет должно ли новое значение цены включать НДС.
//  СтавкаНДС           - Число - Ставка НДС.
//
// Возвращаемое значение:
//  Число - Новое значение цены.
//
Функция ПересчитатьЦенуПриИзмененииФлаговНалогов(Цена, ЦенаВключаетНДС, Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСКлиентСервер.ПересчитатьЦенуПриИзмененииФлаговНалогов(Цена, ЦенаВключаетНДС, );
```
</details>

## Версия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает номер версии подсистемы НДС.
//
// Параметры:
//  Дата - Дата - Проверяемая дата.
//
// Возвращаемое значение:
//  Число - номер версии.
//
Функция Версия(Дата) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСКлиентСервер.Версия(Дата) 
```
</details>

## ВерсияКодовВидовОпераций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет версию перечня кодов видов операций для отчетности по НДС на переданную дату.
//
// Параметры:
//   Период - Дата - дата, на которую требуется определить версию перечня видов операций.
// Возвращаемое значение:
//  Число - номер версии кодов видов операций:
//          1 - перечень, утвержденный приказом ФНС 14.02.2012 N ММВ-7-3/83@;
//          2 - перечень, утвержденный письмом ФНС от 22.01.2015 N ГД-4-3/794@;
//          3 - перечень, утвержденный приказом ФНС от 14.03.2016 N ММВ-7-3/136@.
Функция ВерсияКодовВидовОпераций(Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСКлиентСервер.ВерсияКодовВидовОпераций(Период) 
```
</details>

## ПолучитьКодПоСКНП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Документы по учету НДС для передачи в электронном виде

// Возвращает код периода для передачи книг и журналов по НДС в электронном виде
//
// Параметры:
//	Период - Дата - Дата налогового периода.
//	Реорганизация - Булево - Признак реорганизации.
//
// Возвращаемое значение:
//	Строка - Строковый код налогового периода.
//
Функция ПолучитьКодПоСКНП(Период, Реорганизация = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСКлиентСервер.ПолучитьКодПоСКНП(Период, Реорганизация);
```
</details>

## ОтобразитьПоясненияКПериодуОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отображает текстовое пояснение по корректности выбора периода формирования отчета.
//
// Параметры:
//	Форма - ФормаКлиентскогоПриложения - Форма отчета.
//
Процедура ОтобразитьПоясненияКПериодуОтчета(Форма) Экспорт
```

Пример вызова
```bsl
УчетНДСКлиентСервер.ОтобразитьПоясненияКПериодуОтчета(Форма) 
```
</details>

## ФормаОтчетаОрганизацияПериодПриИзменении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается их обработчиков при смене организации в формах отчетов по НДС.
//
// Параметры:
//	Форма - ФормаКлиентскогоПриложения - Форма отчета.
//
Процедура ФормаОтчетаОрганизацияПериодПриИзменении(Форма) Экспорт
```

Пример вызова
```bsl
УчетНДСКлиентСервер.ФормаОтчетаОрганизацияПериодПриИзменении(Форма) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
