---
title: Учет НДС переопределяемый
slug: erp-uh/учет-ндс-переопределяемый
---


## ОтчетностьПоНДСПредставляется
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет нужно или нет представлять отчетность за квартал, внутри которого находится переданная дата.
// Параметры:
//  Организация - СправочникСсылка.Организации - организация
//  Период      - Дата - на которую определяется необходимость представления отчетности по НДС.
//
// Возвращаемое значение:
//  Булево - Истина - отчетность по НДС необходимо представить,
//           Ложь   - отчетность по НДС не представляется.
Функция ОтчетностьПоНДСПредставляется(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ОтчетностьПоНДСПредставляется(Организация, Период) 
```
</details>

## ПериодОтчетаСоответствуетНалоговому
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет соответствие выбранного в отчете периода налоговому.
// Параметры:
//  Организация   - СправочникСсылка.Организация - организация, для которой определяется налоговый период,
//  НачалоПериода - Дата - начало периода отчета,
//  КонецПериода  - Дата - конец периода отчета.
//
// Возвращаемое значение:
//  Булево - Истина - период соответствует налоговому, можно формировать отчет по стандартной форме (с шапкой и подписями)
//           Ложь   - период не соответствует налоговому, отчет формируется без шапки и подписей.
Функция ПериодОтчетаСоответствуетНалоговому(Организация, НачалоПериода, КонецПериода) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ПериодОтчетаСоответствуетНалоговому(Организация, НачалоПериода, КонецПериода) 
```
</details>

## НачалоНалоговогоПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет начало налогового периода по НДС.
// Параметры:
//  Организация - СправочникСсылка.Организации
//  Период      - Дата - внутри налогового периода, для которого необходимо определить начало.
//
// Возвращаемое значение:
//  Дата - начало налогового периода по НДС, если отчетность в данном периоде представляется
//         или начало квартала, если отчетность не представляется.
Функция НачалоНалоговогоПериода(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.НачалоНалоговогоПериода(Организация, Период) 
```
</details>

## ДатыРасположеныВнутриОдногоНалоговогоПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, находятся ли переданные даты внутри одного налогового периода по НДС.
// Параметры:
//  Организация   - СправочникСсылка.Организация - организация.
//  НачалоПериода - Дата - начало периода отчета.
//  КонецПериода  - Дата - конец периода отчета.
//
// Возвращаемое значение:
//  Булево - Истина - переданные даты находятся внутри одного налогового периода,
//           Ложь   - даты расположены в разных налоговых периодах.
Функция ДатыРасположеныВнутриОдногоНалоговогоПериода(Организация, НачалоПериода, КонецПериода) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ДатыРасположеныВнутриОдногоНалоговогоПериода(Организация, НачалоПериода, КонецПериода) 
```
</details>

## БлижайшийНалоговыйПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ближайший налоговый период.
// См. Перечисления.ВариантыРасширенногоПервогоНалоговогоПериода.БлижайшийНалоговыйПериод.
//
// Параметры:
//	Организация - СправочникСсылка.Организации - Организация.
//	Период - Дата - Дата периода.
//
// Возвращаемое значение:
//	Структура - Содержит ключи:
//    * Период - Дата - стандартное начало налогового периода (например, 01 июля для третьего квартала);
//    * Начало - Дата - фактическое начало налогового периода (может совпадать со стандартным началом или
//               датой регистрации организации;
//    * Конец  - Дата - дата с указанием времени.
//
Функция БлижайшийНалоговыйПериод(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.БлижайшийНалоговыйПериод(Организация, Период) 
```
</details>

## ФормаОтчетаПриСозданииНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФормаОтчетаПриСозданииНаСервере(Форма) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.ФормаОтчетаПриСозданииНаСервере(Форма) 
```
</details>

## ФормаОтчетаОбработатьВыборПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ФормаОтчетаОбработатьВыборПериода(Форма) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.ФормаОтчетаОбработатьВыборПериода(Форма) 
```
</details>

## ДополнитьИнформациейОРНПТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьИнформациейОРНПТ(ДополнительнаяИнформация, СтруктураПараметров, Запрос, ПоискРНПТПоОснованию = Ложь) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.ДополнитьИнформациейОРНПТ(ДополнительнаяИнформация, СтруктураПараметров, Запрос, ПоискРНПТПоОснованию);
```
</details>

## ДополнитьПокупкиИнформациейОНомерахДекларацийНаТовары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьПокупкиИнформациейОНомерахДекларацийНаТовары(ДополнительнаяИнформация, СтруктураПараметров, Запрос) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.ДополнитьПокупкиИнформациейОНомерахДекларацийНаТовары(ДополнительнаяИнформация, СтруктураПараметров, Запрос) 
```
</details>

## ДополнитьИнформациейОПосредникахИПлатежах
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьИнформациейОПосредникахИПлатежах(ДополнительнаяИнформация, СтруктураПараметров, Запрос) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.ДополнитьИнформациейОПосредникахИПлатежах(ДополнительнаяИнформация, СтруктураПараметров, Запрос) 
```
</details>

## ДополнитьИнформациейОТНВЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьИнформациейОТНВЭД(ДополнительнаяИнформация, Запрос) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.ДополнитьИнформациейОТНВЭД(ДополнительнаяИнформация, Запрос) 
```
</details>

## ДополнитьПродажиИнформациейОНомерахДекларацийНаТовары
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьПродажиИнформациейОНомерахДекларацийНаТовары(ДополнительнаяИнформация, СтруктураПараметров, Запрос) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.ДополнитьПродажиИнформациейОНомерахДекларацийНаТовары(ДополнительнаяИнформация, СтруктураПараметров, Запрос) 
```
</details>

## ПреобразоватьПоказателиРНПТКСторнирующейЗаписи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПреобразоватьПоказателиРНПТКСторнирующейЗаписи(МассивСвРегНом) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.ПреобразоватьПоказателиРНПТКСторнирующейЗаписи(МассивСвРегНом) 
```
</details>

## ТекстЗапросаПодготовкаСведенийРНПТЖурнал
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекстЗапросаПодготовкаСведенийРНПТЖурнал() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ТекстЗапросаПодготовкаСведенийРНПТЖурнал() 
```
</details>

## ОпределитьДатуИНомерСчетаФактурыДляПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает структуру реквизитов счета-фактуры для вывода в табличные документы книги покупок и книги продаж.
//
// Параметры:
// 	ЗаписьКниги - ВыборкаИзРезультатаЗапроса - Строка выборки, содержащая регистрационную запись книги покупок или продаж.
//
// Возвращаемое значение:
//	Структура - см. НовыйПредставлениеСчетаФактуры.
//
Функция ОпределитьДатуИНомерСчетаФактурыДляПечати(ЗаписьКниги) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ОпределитьДатуИНомерСчетаФактурыДляПечати(ЗаписьКниги) 
```
</details>

## НовыйПредставлениеСчетаФактуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает реквизиты счета-фактуры для формирования ее представления.
//
// Возвращаемое значение:
//	Структура -  см. Результат.
//
Функция НовыйПредставлениеСчетаФактуры() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.НовыйПредставлениеСчетаФактуры() 
```
</details>

## ПредставлениеИсправленногоКорректировочногоСчетаФактуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет представление счета-фактуры данными о корректировочном счете-фактуре.
//
// Параметры:
//	ПредставлениеСчетаФактуры - см. НовыйПредставлениеСчетаФактуры.
// 	ЗаписьКниги - ВыборкаИзРезультатаЗапроса - Строка выборки, содержащая регистрационную запись книги покупок или продаж.
//
// Возвращаемое значение:
//	Структура - см. НовыйПредставлениеСчетаФактуры.
//
Функция ПредставлениеИсправленногоКорректировочногоСчетаФактуры(ПредставлениеСчетаФактуры, ЗаписьКниги) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ПредставлениеИсправленногоКорректировочногоСчетаФактуры(ПредставлениеСчетаФактуры, ЗаписьКниги) 
```
</details>

## ОпределитьНаличиеСчетовФактурПолученных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция определяет наличие счетов-фактур, полученных по документам,
// которые могут являться основаниями для ввода счетов-фактур полученных.
//
// Применяется для контроля за наличием в ИБ информации о наличии счетов-фактур.
//
// Параметры:
//  ПараметрыПоискаСчетовФактур - Структура - параметры поиска счетов-фактур.
//                                См. конструктор параметров УчетНДС.НовыйПараметрыПоискаСчетовФактур:
//   * НачалоПериода - Дата - Начальная дата выборки (включительно, с 00:00:00)
//   * КонецПериода  - Дата - Конечная дата выборки (включительно, по 23:59:59)
//   * Организация   - СправочникСсылка.Организации - Организация, по которой
//                     осуществляется поиск. Если организация не задана, то поиск
//                     ведется по всем организациям.
//   * Фильтр        - Документ.Ссылка, Массив, Неопределено - Документ или список документов,
//                     по которым осуществляется поиск.
//                     Если не задан, поиск осуществляется по всем документам,
//                     которые могут являться основаниями для ввода счетов-фактур
//                     полученных.
//   * ВсеКромеФильтра  - Булево - Признак отбора документов, не входящих в Фильтр.
//
//   * НаличиеСчетаФактуры - Булево, Неопределено - Признак отбора документов:
//                           Истина - искать документы, по которым существуют счета-фактуры.
//                           Ложь - искать документы, по которым счета-фактуры отсутствуют.
//                           Неопределено - поиск осуществляется для всех документов.
//                           Неопределено - осуществляется поиск всех счетов-фактур.
//   * ДатаСФНеБолее    - Дата, Неопределено - крайняя дата поиска счетов-фактур.
//   * ИскатьПоОборотам - Булево - Истина - поиск осуществляется по оборотам регистра накопления НДСПредъявленный,
//                                 Ложь - поиск осуществляется по остаткам.
//
// Возвращаемое значение:
//  ТаблицаЗначений - Таблица значений - Состав колонок:
//   * Документ - ДокументСсылка - Документ, по которому производился поиск счета-фактуры полученного.
//   * СчетФактура - ДокументСсылка, Неопределено - Ссылка на счет-фактуру полученный.
//
Функция ОпределитьНаличиеСчетовФактурПолученных(ПараметрыПоискаСчетовФактур) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ОпределитьНаличиеСчетовФактурПолученных(ПараметрыПоискаСчетовФактур) 
```
</details>

## ПолучитьСтавкуНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает процент НДС.
//
// Параметры:
//	СтавкаНДС - ПеречислениеСсылка.СтавкиНДС - Значение ставки НДС.
//	ПрименяютсяСтавки4и2 - Булево - Признак применения ставок 4% и 2%.
//
// Возвращаемое значение:
//	Число - Процент НДС.
//
Функция ПолучитьСтавкуНДС(СтавкаНДС, ПрименяютсяСтавки4и2 = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ПолучитьСтавкуНДС(СтавкаНДС, ПрименяютсяСтавки4и2);
```
</details>

## ПолучитьМассивПустыхИсправленныхСчетовФактур
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// КОРРЕКТИРОВОЧНЫЕ И ИСПРАВИТЕЛЬНЫЕ СЧЕТА-ФАКТУРЫ

// Функция возвращает массив пустых ссылок на документы, являющиеся типами для ИсправленногоСчетаФактуры.
//
// Возвращаемое значение:
//	Массив - Пустые ссылки типов измерения ИсправленныйСчетФактура.
//
Функция ПолучитьМассивПустыхИсправленныхСчетовФактур() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ПолучитьМассивПустыхИсправленныхСчетовФактур() 
```
</details>

## ПреобразоватьДокументыВСчетаФактуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает таблицу значений со ссылками на документы счета-фактуры,
// которые записываются в субконто субсчетов 19 и в регистры НДС по таблице первичных
// документов поступлений. Используется в отчете "ОтчетПоНаличиюСчетовФактур".
//
// Параметры:
//	ТаблицаДокументов - ТаблицаЗначений - Содержит колонки:
//		* Документ - ДокументСсылка.* - Ссылка на первичный документ поступления.
//
// Возвращаемое значение:
//	ТаблицаЗначений - Таблица с колонкой "СчетФактура".
//
Функция ПреобразоватьДокументыВСчетаФактуры(ТаблицаДокументов) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ПреобразоватьДокументыВСчетаФактуры(ТаблицаДокументов) 
```
</details>

## ВерсияПостановленияНДС1137
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//	ВСПОМОГАТЕЛЬНЫЕ ПРОЦЕДУРЫ И ФУНКЦИИ

// Возвращает версию постановления Правительства РФ от 26.12.2011 г. № 1137.
//
// Параметры:
//  Период  -  Дата - В данном параметре передается
//             дата на которую необходимо определить версию постановления.
// Возвращаемое значение:
//  Число   -  версия постановления,
//              1 - исходная версия постановления Правительства РФ от 26.12.2011 г. № 1137;
//              2 - постановление Правительства РФ от 26.12.2011 г. № 1137 в редакции постановления № 952;
//              3 - постановление Правительства РФ от 26.12.2011 г. № 1137 в редакции постановления № 735;
//              4 - постановление Правительства РФ от 26.12.2011 г. № 1137 в редакции постановления № 981;
//              5 - постановление Правительства РФ от 26.12.2011 г. № 1137 в редакции постановления № 534;
//              6 - постановление Правительства РФ от 26.12.2011 г. № 1137 с изменениями по ФЗ № 389;
//              7 - постановление Правительства РФ от 26.12.2011 г. № 1137 в редакции постановления № 1096.
//
Функция ВерсияПостановленияНДС1137(Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ВерсияПостановленияНДС1137(Период) 
```
</details>

## ПрименяетсяПостановление15
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак применения постановления Правительства от 19.01.2019 г. № 15
// в котором утверждена форма книги продаж с добавлением граф по ставке 20%
// и отменена обязанность по выставлению покупателем счета-фактуры при возврате товаров, принятых на учет.
// Дата вступления в силу постановления 01.04.2019.
// Однако постановление можно применять с 1 января 2019 года,
// т.к. в соответствии с НК РФ ставка 20% применяется именно с этого момента.
Функция ПрименяетсяПостановление15(Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ПрименяетсяПостановление15(Период) 
```
</details>

## ПрименяетсяПостановление1448
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак применения постановления Правительства №1448 от 29 октября 2024 года.
Функция ПрименяетсяПостановление1448(Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ПрименяетсяПостановление1448(Период) 
```
</details>

## ЗаполняетсяРаздел7ДекларацииНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает признак автоматического заполнения раздела 7 Декларации по НДС.
//
Функция ЗаполняетсяРаздел7ДекларацииНДС(Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ЗаполняетсяРаздел7ДекларацииНДС(Период) 
```
</details>

## КодВидаОперацииКомиссия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает код вида операции для регистрации счета-фактуры по смешанным операциям в журнале счетов-фактур по комиссии.
//
// Параметры:
// 	КодВидаОперации - Строка - Код вида операции счета-фактуры.
// 	Период - Дата - Период записи журнала.
//
// Возвращаемое значение:
// 	КодВидаОперацииКомиссия - Строка - Код вида операции для журнала счетов-фактур по комиссии.
//
Функция КодВидаОперацииКомиссия(КодВидаОперации, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.КодВидаОперацииКомиссия(КодВидаОперации, Период) 
```
</details>

## ТипыДокументовРучныхОперацийНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает типы документов, являющихся ручными операциями по НДС.
//
// Возвращаемое значение:
//	Массив - Массив со значениями типов документов.
//
Функция ТипыДокументовРучныхОперацийНДС() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ТипыДокументовРучныхОперацийНДС() 
```
</details>

## НомерСчетаФактурыНаПечать
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает номер счета-фактуры на печать с учетом индекса обособленного подразделения.
//
// Параметры:
// 	 Номер - Строка - Номер документа ИБ.
//   УдалитьПользовательскийПрефикс - Булево - Признак необходимости исключения пользовательского префикса из номера.
// 	 ОбособленноеПодразделение - Булево -  Признак того, что организация является обособленным подразделением.
// 	 ЦифровойИндексОбособленногоПодразделения - Число - Цифровой индекс обособленного подразделения.
//
// Возвращаемое значение:
// 	НомерНаПечать - Строка - Номер счета-фактуры на печать.
//
Функция НомерСчетаФактурыНаПечать(Номер, УдалитьПользовательскийПрефикс, ОбособленноеПодразделение, ЦифровойИндексОбособленногоПодразделения) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.НомерСчетаФактурыНаПечать(Номер, УдалитьПользовательскийПрефикс, ОбособленноеПодразделение, ЦифровойИндексОбособленногоПодразделения) 
```
</details>

## ТекстЗапросаКорректировочныеСчетаФактуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает текст запроса, выбирающего корректировочные счета-фактуры.
// Используется в отчете "Журнал учета счетов-фактур 1137".
//
// Параметры:
//	Запрос - Запрос - Объект Запрос, с помощью которого будет выполнен текст запроса.
//	Период - Дата - Последняя дата периода, за который строится запрос.
//	Отбор  - Структура - Структура отбора, содержащая следующие ключи:
//		* СписокОрганизаций - СписокЗначений - Список организаций, по которым строится запрос.
//		* Контрагент - Структура - Настройки отбора по контрагенту (необязательный ключ)
//			** ВидСравнения - ВидСравнения - Вид сравнения
//			** Значение - СправочникСсылка.Контрагенты - Ссылка на контрагента для отбора.
//
// Возвращаемое значение:
//	Строка - Текст запроса, формирующего таблицу со следующими полями:
//		* СчетФактура - ДокументСсылка.* - Ссылка на документ счета-фактуры.
//		* Организация - СправочникСсылка.Организации - Организация из счета-фактуры.
//
Функция ТекстЗапросаКорректировочныеСчетаФактуры(Запрос, Период, Отбор) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ТекстЗапросаКорректировочныеСчетаФактуры(Запрос, Период, Отбор) 
```
</details>

## ТекстЗапросаСчетаФактурыПолученныеГдеОрганизацияЯвляетсяПоставщиком
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает текст запроса со списком документов счетов-фактур полученных,
// в которых сама организация выступает в роли поставщика в книге покупок.
//
// Возвращаемое значение:
//	Строка - Текст запроса, формирующего таблицу со следующими полями:
//		* СчетФактура - ДокументСсылка.* - Ссылка на документ счета-фактуры.
//		* Организация - СправочникСсылка.Организации - Организация из счета-фактуры.
//		* ГоловнаяОрганизация - СправочникСсылка.Организации - Головная организация.
//		* ЭтоКорректировкаРеализации 	- Булево - Истина, если счет-фактура относится к корректировке реализации.
//
Функция ТекстЗапросаСчетаФактурыПолученныеГдеОрганизацияЯвляетсяПоставщиком() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ТекстЗапросаСчетаФактурыПолученныеГдеОрганизацияЯвляетсяПоставщиком() 
```
</details>

## ТекстЗапросаСчетаФактурыВыданныеГдеОрганизацияЯвляетсяПокупателем
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает текст запроса со списком документов счетов-фактур выданных,
// в которых сама организация выступает в роли покупателя в книге продаж.
//
// Возвращаемое значение:
//	Строка - Текст запроса.
//
Функция ТекстЗапросаСчетаФактурыВыданныеГдеОрганизацияЯвляетсяПокупателем() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ТекстЗапросаСчетаФактурыВыданныеГдеОрганизацияЯвляетсяПокупателем() 
```
</details>

## ТекстЗапросаСчетаФактурыИсправленияКнигиПокупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает текст запроса со списком документов счетов-фактур из
// книги покупок, которые могут являться регистраторами исправительных записей.
//
// Возвращаемое значение:
//	Строка - Текст запроса, формирующего таблицу со следующими полями:
//		* СчетФактура - ДокументСсылка.* - Ссылка на документ счета-фактуры.
//		* Организация - СправочникСсылка.Организации - Организация из счета-фактуры.
//		* ГоловнаяОрганизация - СправочникСсылка.Организации - Головная организация.
//		* ЭтоКорректировкаПоступления 	- Булево - Истина, если счет-фактура относится к корректировке поступления.
//		* ЭтоКорректировкаРеализации 	- Булево - Истина, если счет-фактура относится к корректировке реализации.
//
Функция ТекстЗапросаСчетаФактурыИсправленияКнигиПокупок() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ТекстЗапросаСчетаФактурыИсправленияКнигиПокупок() 
```
</details>

## ТекстЗапросаСчетаФактурыИсправленияКнигиПродаж
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает текст запроса со списком документов счетов-фактур из
// книги продаж, которые могут являться регистраторами исправительных записей.
//
// Возвращаемое значение:
//	Строка - Текст запроса, формирующего таблицу со следующими полями:
//		* СчетФактура - ДокументСсылка.* - Ссылка на документ счета-фактуры.
//		* Организация - СправочникСсылка.Организации - Организация из счета-фактуры.
//		* ГоловнаяОрганизация - СправочникСсылка.Организации - Головная организация.
//		* ЭтоКорректировкаПоступления 	- Булево - Истина, если счет-фактура относится к корректировке поступления.
//		* ЭтоКорректировкаРеализации 	- Булево - Истина, если счет-фактура относится к корректировке реализации.
//
Функция ТекстЗапросаСчетаФактурыИсправленияКнигиПродаж() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ТекстЗапросаСчетаФактурыИсправленияКнигиПродаж() 
```
</details>

## ТекстЗапросаНомераГТДпоСчетамФактурам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает запрос для получения информации о ГТД и стране происхождения
// для счетов фактур.
//
// Параметры:
//	Запрос - Запрос - Объект запрос, с помощью которого будет выполняться обращение к базе данных.
//
// Возвращаемое значение:
//	Строка - Текст запроса для получения таблица со следующими полями:
//		* СчетФактура - ДокументСсылка.* - Ссылка на документ, представляющий счет-фактуру.
//		* СтранаПроисхождения - СправочникСсылка.СтраныМира - Страна происхождения товара.
//		* НомерГТД - СправочникСсылка.НомераГТД - Таможенная декларация, указанная в счете-фактуре.
//
Функция ТекстЗапросаНомераГТДпоСчетамФактурам(Запрос) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ТекстЗапросаНомераГТДпоСчетамФактурам(Запрос) 
```
</details>

## ТекстЗапросаСводныеКомиссионныеСчетаФактуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает текст запроса, выбирающего сводные комиссионные счета-фактуры.
// Используется в отчете "Журнал учета счетов-фактур 1137".
//
// Параметры:
//	Запрос - Запрос - Объект запрос, с помощью которого будет выполняться обращение к базе данных.
//	Период - ДатаВремя - Конец периода формирования отчета.
//	Отбор - Структура - Структура отбора с ключами:
//		* СписокОрганизаций - СписокЗначений - список организаций, по которым строится отчет.
//		* Контрагент (необязательный) - Структура с ключами:
//			** ВидСравнения - ВидСравнения.
//			** Значение - СправочникСсылка.Контрагенты - Ссылка на контрагента.
//
// Возвращаемое значение:
//	Строка - Текст запроса для получения таблица со следующими полями:
//		* СчетФактура - ДокументСсылка.* - Ссылка на документ, представляющий счет-фактуру.
//		* Организация - СправочникСсылка.Организации - Организация, к которой относится счет-фактура.
//		* ЧастьЖурналаУчетаСчетовФактур - ПеречислениеСсылка.ЧастиЖурналаУчетаСчетовФактур.
//
//
Функция ТекстЗапросаСводныеКомиссионныеСчетаФактуры(Запрос, Период, Отбор) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ТекстЗапросаСводныеКомиссионныеСчетаФактуры(Запрос, Период, Отбор) 
```
</details>

## ТекстЗапросаРеквизитыКонтрагентовДокументовОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает запрос для получения информации о документах оплаты.
//
// Параметры:
//	Запрос - Запрос - Объект запрос, с помощью которого будет выполняться обращение к базе данных.
//
// Возвращаемое значение:
//	Строка - Текст запроса для получения таблица со следующими полями:
//		* СчетФактураДокумент - ДокументСсылка.* - Ссылка на документ, представляющий счет-фактуру.
//		* СчетФактураДата - ДатаВремя - Дата документа счета-фактуры.
//		* ПродавецСсылка - СправочникСсылка.Контрагенты - Продавец из счета-фактуры.
//		* ДатаПлатежногоДокумента - ДатаВремя - Дата платежного документа, которым оплачен счет-фактура.
//		* НомерПлатежногоДокумента - Строка - Номер платежного документа, которым оплачен счет-фактура.
//
Функция ТекстЗапросаРеквизитыКонтрагентовДокументовОплаты(Запрос) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ТекстЗапросаРеквизитыКонтрагентовДокументовОплаты(Запрос) 
```
</details>

## ТекстЗапросаСчетаФактурыВыставленныеНеплательщикамиНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает текст запроса для получения раздела 12 Декларации по НДС с 2015 г.
// "Сведения из счетов-фактур, выставленных лицами, указанными в п.5 ст.173 НК РФ".
//
// Параметры:
//	Запрос - Запрос - Объект запрос, с помощью которого будет выполняться обращение к базе данных.
//	СписокОрганизаций - СписокЗначений - Список ссылок на организации, по которым строится отчет.
//	НачалоПериода - ДатаВремя - Начало периода формирования отчета.
//	КонецПериода - ДатаВремя - Конец периода формирования отчета.
//
// Возвращаемое значение:
//	Строка - Текст запроса для получения таблица со следующими полями:
//		* Номер - Строка - Номер документа счета-фактуры.
//		* Дата - ДатаВремя - Дата документа счета-фактуры.
//		* Контрагент - СправочникСсылка.Контрагенты - Контрагент из счета-фактуры.
//		* КППКонтрагента - Строка - КПП контрагента из счета-фактуры.
//		* СуммаНДСДокумента - Число - Сумма НДС по счету-фактуре.
//		* СуммаДокумента - Число - Общая сумма с НДС по счету-фактуре.
//		* ВалютаДокумента - СправочникСсылка.Валюты - Валюта счета-фактуры.
//		* Ссылка - ДокументСсылка.* - Ссылка на документ счет-фактура.
//
Функция ТекстЗапросаСчетаФактурыВыставленныеНеплательщикамиНДС(Запрос, СписокОрганизаций, НачалоПериода, КонецПериода) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ТекстЗапросаСчетаФактурыВыставленныеНеплательщикамиНДС(Запрос, СписокОрганизаций, НачалоПериода, КонецПериода) 
```
</details>

## ТекстЗапросаНеподтвержденныеРеализации0
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает текст запроса для сопоставления счетов-фактур, выписанных при неподтверждении 0%,
// с исходными документами отгрузки, которые не были подтверждены.
// В текст запроса можно использовать параметры запроса:
//	* Организация - Список организаций, по которым строится декларация НДС.
//	* НачалоПериода - Дата - Дата начала периода декларации НДС.
//	* КонецПериода - Дата - Дата окончания периода декларации НДС.
//
// Возвращаемое значение:
//	Строка - Текст запроса, возвращающего таблицу с колонками:
//		* СчетФактура - ДокументСсылка.* - Ссылка на счет-фактуру, выписанную при неподтверждении 0%.
//		* ДокументОтгрузки - ДокументСсылка.* - Ссылка на документ реализации по 0%, который не был подтвержден.
//
Функция ТекстЗапросаНеподтвержденныеРеализации0() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ТекстЗапросаНеподтвержденныеРеализации0() 
```
</details>

## ОткрыватьПомощникИзМакета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает ИСТИНА, если из отчетов НДС необходимо открывать помощник.
//
// Параметры:
//	Организация - СправочникСсылка.Организации - Организация по которой строится отчет.
//	Период - Дата - Дата налогового периода, за который строится отчет.
//
// Возвращаемое значение:
//	Булево - Признак необходимости открытия помощника.
//
Функция ОткрыватьПомощникИзМакета(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ОткрыватьПомощникИзМакета(Организация, Период) 
```
</details>

## ПолучитьМакетОткрытияПомощника
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает макет для помощника по НДС.
//
// Параметры:
//	Организация - СправочникСсылка.Организации - Организация по которой строится отчет.
//	Период - Дата - Дата налогового периода, за который строится отчет.
//
// Возвращаемое значение:
//	ТабличныйДокумент - Табличный документ с макетом.
//
Функция ПолучитьМакетОткрытияПомощника(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ПолучитьМакетОткрытияПомощника(Организация, Период) 
```
</details>

## ПолучитьДатуНачалаДействияПостановления1137
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьДатуНачалаДействияПостановления1137() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ПолучитьДатуНачалаДействияПостановления1137() 
```
</details>

## ПодготовитьПараметрыКнигиПокупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует книгу покупок внутри фонового задания.
//
// Параметры:
//	ПараметрыОтчета - Структура - Структура параметров фонового задания,
//						см. ПодготовитьПараметрыОтчета в отчете книга покупок.
//	АдресХранилища - Строка - Адрес временного хранилища, в которое поместить результат отчета.
//
Процедура ПодготовитьПараметрыКнигиПокупок(ПараметрыОтчета, АдресХранилища) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.ПодготовитьПараметрыКнигиПокупок(ПараметрыОтчета, АдресХранилища) 
```
</details>

## ПодготовитьПараметрыКнигиПродаж
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует книгу продаж внутри фонового задания.
//
// Параметры:
//	ПараметрыОтчета - Структура - Структура параметров фонового задания,
//						см. ПодготовитьПараметрыОтчета в отчете книга продаж.
//	АдресХранилища - Строка - Адрес временного хранилища, в которое поместить результат отчета.
//
Процедура ПодготовитьПараметрыКнигиПродаж(ПараметрыОтчета, АдресХранилища) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.ПодготовитьПараметрыКнигиПродаж(ПараметрыОтчета, АдресХранилища) 
```
</details>

## РегистрационныеСведенияНаДаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура подготавливает в менеджере временных таблиц таблицу
// сведениями о переданных контрагента и организациях на указанные даты.
//
// Параметры:
//	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - менеджер, в который помещается таблицы.
//		На входе содержит таблицу СсылкиНаДаты с колонками:
//			* Ссылка - СправочникСсылка.Контрагенты, СправочникСсылка.Организации - контрагент или организация,
//						для которых требуется получить сведения.
//			* ДатаСведений - Дата - Дата, на которую необходимо получить данные.
//
//		На выходе содержит таблицу СведенияОСсылкахНаДаты с колонками:
//			* Ссылка - СправочникСсылка.Контрагенты, СправочникСсылка.Организации - контрагент или организация.
//			* ДатаСведений - Дата - Дата, на которую получены данные.
//			* Наименование - Строка - Наименование контрагента или организации для вывода в отчете.
//			* ИНН - Строка - ИНН контрагента или организации.
//			* КПП - Строка - КПП контрагента или организации.
//
Процедура РегистрационныеСведенияНаДаты(МенеджерВременныхТаблиц) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.РегистрационныеСведенияНаДаты(МенеджерВременныхТаблиц) 
```
</details>

## СформироватьЭлектронныеДокументы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает пакет электронных представлений документов.
//
// Параметры:
//  ВыгружаемыеДокументы - Массив - перечень документов, для которых
//                 необходимо получить электронные представления в виде двоичных данных.
//  УникальныйИдентификатор - УникальныйИдентификатор - уникальный идентификатор, по которому
//                 осуществляется привязка двоичных данных во временном хранилище.
//
// Возвращаемое значение:
//   Соответствие - соответствие переданных ссылок на документы и массива структур с полями:
//                 ТипФайла - Строка - описание типа файла;
//                 ИмяФайла - Строка - имя файла с расширением;
//                 АдресВременногоХранилища - Строка - адрес временного хранилища, в котором размещены двоичные данные файла.
//
Функция СформироватьЭлектронныеДокументы(ВыгружаемыеДокументы, УникальныйИдентификатор = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.СформироватьЭлектронныеДокументы(ВыгружаемыеДокументы, УникальныйИдентификатор);
```
</details>

## ДополнитьСведенияОПоказателяхОтчетаНДСФормаОтчета2017Кв1Раздел7
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьСведенияОПоказателяхОтчетаНДСФормаОтчета2017Кв1Раздел7(ПоказателиОтчета) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.ДополнитьСведенияОПоказателяхОтчетаНДСФормаОтчета2017Кв1Раздел7(ПоказателиОтчета) 
```
</details>

## ЗаполнитьОтчетНДСФормаОтчета2017Кв1Раздел7
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьОтчетНДСФормаОтчета2017Кв1Раздел7(ПараметрыЗапросов, Контейнер) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.ЗаполнитьОтчетНДСФормаОтчета2017Кв1Раздел7(ПараметрыЗапросов, Контейнер) 
```
</details>

## ИмяРегистраМестоНахожденияОС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Возвращает Имя регистра местонахождения ОС
//
Функция ИмяРегистраМестоНахожденияОС() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.ИмяРегистраМестоНахожденияОС() 
```
</details>

## СуммаНДССМежценовойРазницы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура подготавливает в менеджере временных таблиц таблицу
// с суммами НДС с межценовой разницы.
//
// Параметры:
//	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - менеджер, в который помещается таблицы.
//
//		На выходе содержит таблицу НДССМежценовойРазницы с колонками:
//			* СуммаНДСМежценоваяРазницаОсновнаяРасчетнаяСтавка - Число - сумма НДС с межценовой разницы по ставкам 20/120, 16,67%.
//			* СуммаНДСМежценоваяРазницаПониженнаяРасчетнаяСтавка - Число - сумма НДС с межценовой разницы по ставкам 10/110, 9,09%.
//
Процедура СуммаНДССМежценовойРазницы(МенеджерВременныхТаблиц, ПараметрыОсновногоЗапроса) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.СуммаНДССМежценовойРазницы(МенеджерВременныхТаблиц, ПараметрыОсновногоЗапроса) 
```
</details>

## ПослеЗаписиНаСервереДокументаНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается после записи документа ФормированиеЗаписейРаздела7ДекларацииНДС
//
// Параметры:
//	Форма - ФормаКлиентскогоПриложения - Форма документа.
//	ТекущийОбъект - ДокументСсылка -  Записываемый объект
//	ПараметрыЗаписи - Структура - Содержит параметры записи
//
Процедура ПослеЗаписиНаСервереДокументаНДС(Форма, ТекущийОбъект, ПараметрыЗаписи) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.ПослеЗаписиНаСервереДокументаНДС(Форма, ТекущийОбъект, ПараметрыЗаписи) 
```
</details>

## ПриСозданииНаСервереДокументаНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при создании документа ФормированиеЗаписейРаздела7ДекларацииНДС
//
// Параметры:
//	Форма - ФормаКлиентскогоПриложения - Форма документа.
//	Отказ - Булево - Признак отказа
//	СтандартнаяОбработка - Булево - Признак стандартной обработки
//
Процедура ПриСозданииНаСервереДокументаНДС(Форма, Отказ, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.ПриСозданииНаСервереДокументаНДС(Форма, Отказ, СтандартнаяОбработка) 
```
</details>

## ПриЧтенииНаСервереДокументаНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при чтении документа ФормированиеЗаписейРаздела7ДекларацииНДС
//
// Параметры:
//	Форма - ФормаКлиентскогоПриложения - Форма документа.
//	ТекущийОбъект - ДокументСсылка -  Записываемый объект
//
Процедура ПриЧтенииНаСервереДокументаНДС(Форма, ТекущийОбъект) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.ПриЧтенииНаСервереДокументаНДС(Форма, ТекущийОбъект) 
```
</details>

## РеквизитыОрганизацииДляОтчетностиПоНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает реквизиты организации
//
// Параметры:
// Организация - СправочникСсылка.Организации - Справочник Организации
//
// Возвращаемое значение:
//    - Структура
//            - ИностраннаяОрганизация - Булево
//            - КПП - Строка
//
Функция РеквизитыОрганизацииДляОтчетностиПоНДС(Организация) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСПереопределяемый.РеквизитыОрганизацииДляОтчетностиПоНДС(Организация) 
```
</details>

## ТекстЗапросаРеестрНДСПриложение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Текст запроса реестр НДСПриложение.
//
// Параметры:
//  Запрос -  Запрос.
//  ПараметрыОтчета - СписокЗначений -  параметры фомирования отчета
Процедура ТекстЗапросаРеестрНДСПриложение(Запрос, ПараметрыОтчета) Экспорт
```

Пример вызова
```bsl
УчетНДСПереопределяемый.ТекстЗапросаРеестрНДСПриложение(Запрос, ПараметрыОтчета) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
