---
title: Учет НДС РФ клиент сервер
slug: erp-uh/учет-ндс-рф-клиент-сервер
---


## ПроверитьКорректностьНомераТаможеннойДекларации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру регистрационного номера таможенной декларации по переданному полному номеру декларации на товары,
// а также проверяет корректность ввода номера таможенной декларации.
// Регистрационный номер не будет определен если "полный" номер таможенной декларации не соответствует структуре номера
// декларации, выдаваемой российскими таможенными органами.
//
// Регистрационный номер таможенной декларации может быть получен из "полного" номера таможенной декларации или
// регистрационного номера при условиях:
// 1. Длина номера таможенной декларации от 17 до 28 символов.
// 2. Количество элементов, разделенных знаком дробь ("/") 3 или 4.
// 3. Длина первого элемента 2, 5 или 8 символов, второго 6, третьего 7 или 8 (в этом случае первые два символа "ОБ" или
//    "ЗВ"), четвертого (при наличии) от 1 до 3 символов.
// 4. Второй элемент можно преобразовать в дату.
//
// Регистрационный номер таможенной декларации будет получен из "полного" номера таможенной декларации путем отсечения
// последнего (4-го) элемента номера.
//
// Параметры:
//	НомерТаможеннойДекларации - Строка - номер таможенной декларации или регистрационный номер таможенной декларации.
//	НачалоКорректногоПериода - Дата - дата начала периода проверки.
//	КонецКорректногоПериода - Дата - дата окончания периода проверки.
//
// Возвращаемое значение:
//	Структура:
//		* РегистрационныйНомер - Строка - регистрационный номер таможенной декларации либо пустая строка, если его
//											не удалось определить.
//		* ПорядковыйНомерТовара - Строка - порядковый номер товара из графы 32 ДТ.
//		* КодОшибки - Число - код ошибки, расшифровка см. ТекстОшибкиВНомереТаможеннойДекларации.
//
Функция ПроверитьКорректностьНомераТаможеннойДекларации(НомерТаможеннойДекларации, Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСРФКлиентСервер.ПроверитьКорректностьНомераТаможеннойДекларации(НомерТаможеннойДекларации, );
```
</details>

## ТекстОшибкиВНомереТаможеннойДекларации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текстовое описание ошибки при вводе номера таможенной декларации.
//
// Параметры:
//	КодОшибки - Число - код ошибки
//
// Возвращаемое значение:
//	Строка - текстовое описание ошибки в номере таможенной декларации.
//
Функция ТекстОшибкиВНомереТаможеннойДекларации(КодОшибки) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСРФКлиентСервер.ТекстОшибкиВНомереТаможеннойДекларации(КодОшибки) 
```
</details>

## ЛимитДоходовДляПримененияСтавокНДСПриУСН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает базовый лимит доходов налогоплательщика для применения ставок НДС при УСН,
// действующий на указанную дату, без учета коэффициента-дефлятора.
//
// Параметры:
//  СтавкаНДС - ПеречислениеСсылка.СтавкиНДС.
//  Дата - Дата - Дата, на которую получаем базовый лимит.
//
// Возвращаемое значение:
//  Число
//
Функция ЛимитДоходовДляПримененияСтавокНДСПриУСН(СтавкаНДС, Дата) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСРФКлиентСервер.ЛимитДоходовДляПримененияСтавокНДСПриУСН(СтавкаНДС, Дата) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
