---
title: Учет НДС УП
slug: erp-uh/учет-ндс-уп
---


## НастройкиУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает настройки учета НДС.
//
// Возвращаемое значение:
// 	 Структура - Параметры учета НДС:
// 	   * ИспользоватьУчетНДС - Булево, Произвольный - Значение опции использования учета НДС
// 	   * ОсновноеНалогообложениеНДСПродажи - ПеречислениеСсылка.ТипыНалогообложенияНДС - Основное налогообложение НДС организации.
// 	   * ОсновнойВидДеятельностиНДСЗакупки - ПеречислениеСсылка.ТипыНалогообложенияНДС - Основной вид деятельности НДС закупки товаров.
// 	   * РаздельныйУчетНДС - Булево, Произвольный - Признак наличия в ИБ организаций, использующих раздельный учет НДС по налогообложению.
// 	   * ИспользоватьЗаполнениеРаздела7ДекларацииПоНДС - Булево - Признак использования Раздела 7 в декларации.
// 	   * ПродажиНаЭкспорт - Булево, Произвольный - Применения экспортных операций.
// 	   * ЭкспортНесырьевыхТоваров - Булево - Признак того, что осуществляется экспорт несырьевых товаров.
// 	   * ЭкспортСырьевыхТоваровУслуг - Булево - Признак того, что осуществляется экспорт сырьевых товаров, работ или услуг.
// 	   * ДатаРазделенияЭкспорта - Дата - Дата начала применения 150-ФЗ, разделение экспорта на сырьевой и несырьевой.
// 	   * ПродажаТоваровОблагаемыхНДСУПокупателя - Булево - Признак того, что осуществляется реализация товаров с обратным обложением НДС.
// 	                                                       При реализации таких товаров НДС начисляет не продавец, а покупатель (налоговый агент).
// 	   * ПокупкаТоваровОблагаемыхНДСУПокупателя - Булево - Признак того, что осуществляется приобретение товаров с обратным обложением НДС.
// 	   * ДатаНачалаУчетаНДСПоНаправлениямДеятельности - Дата - Дата, начиная с которой ведется учет входящего НДС в разрезе направлений деятельности.
// 	   * ДатаОтраженияВозвратовКорректировочнымиСФ - Дата - Дата, начиная с которой возвраты отражаются КСФ.
// 	   * РеверсивноеОбложениеНДС - Булево, Произвольный - примение операций с реверсивным обложением НДС
//
Функция НастройкиУчета() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.НастройкиУчета() 
```
</details>

## ПараметрыУчетаПоОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры учета НДС, установленные для организации в заданном периоде.
//
// Параметры:
// 	Организация - СправочникСсылка.Организации - Организация, для которой необходимо получить параметры.
// 	Дата - Дата - Дата, на которую необходимо получить параметры учета.
// 	Склад - СправочникСсылка.Склады - Необязательный параметр. Склад, для которого необходимо определить применение EНВД.
// 	Подразделение - СправочникСсылка.СтруктураПредприятия - Необязательный параметр. Подразделение, для которого необходимо определить применение EНВД.
//
// Возвращаемое значение:
// 	 Структура - Параметры учета НДС по организации:
// 		* ОсновноеНалогообложениеНДСПродажи - ПеречислениеСсылка.ТипыНалогообложенияНДС - Основное налогообложение НДС организации.
// 		* ОсновнойВидДеятельностиНДСЗакупки - ПеречислениеСсылка.ТипыНалогообложенияНДС - Основной вид деятельности НДС закупки товаров.
// 		* НалогообложениеНДСРозничнойПродажи - ПеречислениеСсылка.ТипыНалогообложенияНДС - Налогообложение НДС розничной торговли.
// 		                                                                                   Значение получается с учетом переданного склада.
// 		* РаздельныйУчетНДС - Булево - Признак использование раздельного учета НДС.
// 		* ОсобыйПорядокУчетаНДСПриПроизводствеДЦ - Булево - Признак того, что организация учитывает НДС относящийся к производству продукции с
// 							длительным циклом производства особым образом.
// 		* ВариантУчетаНДСПриИзмененииВидаДеятельностиНаНеоблагаемую - ПеречислениеСсылка.ВариантыУчетаНДСПриИзмененииВидаДеятельностиНаНеоблагаемую
// 		                    - Определяет порядок учета НДС при изменении деятельности на необлагаемую.
// 		* СтатьяРасходов_НеОблагаетсяНДС - ПланВидовХарактеристикСсылка.СтатьиРасходов - Статья списания НДС при изменении деятельности на необлагаемую НДС.
// 		* АналитикаРасходов_НеОблагаетсяНДС - Характеристика.СтатьиРасходов - Аналитика списания НДС при изменении деятельности на необлагаемую НДС.
// 		* СтатьяРасходов_ОблагаетсяЕНВД - ПланВидовХарактеристикСсылка.СтатьиРасходов - Статья списания НДС при изменении деятельности на облагаемую ЕНВД.
// 		* АналитикаРасходов_ОблагаетсяЕНВД - Характеристика.СтатьиРасходов - Аналитика списания НДС при изменении деятельности на облагаемую ЕНВД.
//		* ФормироватьНДСПредъявленныйПриВключенииВСтоимость - Булево - Признак формирования НДСПредъявленный при включении в стоимость.
//		* СписыватьНДСПоРасходамНеПринимаемымВНУ - Булево - Признак списания НДС по расходам, не принимаемым в НУ.
//
Функция ПараметрыУчетаПоОрганизации(Знач Организация, Знач Дата, Знач Склад = Неопределено,  Знач Подразделение = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ПараметрыУчетаПоОрганизации(Организация, Дата, Склад, Подразделение);
```
</details>

## ОрганизацииБезНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список доступных организаций, у которых на Дату применяется НО ПродажаНеОблагаетсяНДС
//
// Параметры:
//   Период - Дата
//
// Возвращаемое значение:
// 	Массив из СправочникСсылка.Организации - Организации, у которых на Дату применяется НО ПродажаНеОблагаетсяНДС.
//
Функция ОрганизацииБезНДС(Знач Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ОрганизацииБезНДС(Период) 
```
</details>

## ВидыДеятельностиНДСУчитываетсяВСтоимости
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список типов налогообложения, НДС по которым никогда не принимается к возмещению.
//
// Возвращаемое значение:
// 	Массив из ПеречислениеСсылка.ТипыНалогообложенияНДС - Виды деятельности НДС, по которым НДС включается в стоимость.
//
Функция ВидыДеятельностиНДСУчитываетсяВСтоимости() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ВидыДеятельностиНДСУчитываетсяВСтоимости() 
```
</details>

## ВидыДеятельностиНДСПринимаетсяКВозмещению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список видов деятельности, НДС по которым принимается к возмещению:
// - в полном объеме или частично;
// - по общим или особым правилам.
//
// Возвращаемое значение:
// 	Массив из ПеречислениеСсылка.ТипыНалогообложенияНДС - Виды деятельности НДС, по которым НДС принимается к вычету.
//
Функция ВидыДеятельностиНДСПринимаетсяКВозмещению() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ВидыДеятельностиНДСПринимаетсяКВозмещению() 
```
</details>

## ТипыНалогообложенияНДСНеоблагаемые
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив типов налогообложения.
// Параметры:
//   ДляАвансов - Булево
//
// Возвращаемое значение:
// 	Массив из ПеречислениеСсылка.ТипыНалогообложенияНДС - массив типов налогообложения
Функция ТипыНалогообложенияНДСНеоблагаемые(ДляАвансов = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ТипыНалогообложенияНДСНеоблагаемые(ДляАвансов);
```
</details>

## НалогообложенияПродажНДСНеУчитываетсяВСтоимости
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список типов налогообложения НДС, по которым НДС не учитывается в стоимости,
// а подлежит принятию к вычету (при выполнении условий).
//
// Возвращаемое значение:
// 	Массив из ПеречислениеСсылка.ТипыНалогообложенияНДС - массив типов налогообложения
//
Функция НалогообложенияПродажНДСНеУчитываетсяВСтоимости() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.НалогообложенияПродажНДСНеУчитываетсяВСтоимости() 
```
</details>

## ТипыНалогообложенияНДСНеУчитываетсяВСтоимости
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив типов налогообложения, являющийся объединением двух массивов.
//
// Возвращаемое значение:
// 	Массив из ПеречислениеСсылка.ТипыНалогообложенияНДС - массив типов налогообложения
//
Функция ТипыНалогообложенияНДСНеУчитываетсяВСтоимости() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ТипыНалогообложенияНДСНеУчитываетсяВСтоимости() 
```
</details>

## ВидыДеятельностиНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив типов налогообложения НДС, которые могут выступать видами деятельности.
//
// Возвращаемое значение:
// 	Массив из ПеречислениеСсылка.ТипыНалогообложенияНДС - массив типов налогообложения
Функция ВидыДеятельностиНДС() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ВидыДеятельностиНДС() 
```
</details>

## СтавкаНДСПоНоменклатуреИНалогообложению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ставку НДС операции по номенклатуре и типу налогообложения НДС.
//
// Параметры:
//   Номенклатура - СправочникСсылка.Номенклатура - Номенклатура из которой необходимо получить ставку НДС.
//   НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Налогообложение НДС операции.
//   Организация - СправочникСсылка.Организации - Организация документа
//   Дата - Дата - Дата операции
//   УказаннаяСтавкаНДС - СправочникСсылка.СтавкиНДС
//
// Возвращаемое значение:
//   СправочникСсылка.СтавкиНДС - Ставка НДС по номенклатуре и типу налогообложения
//
Функция СтавкаНДСПоНоменклатуреИНалогообложению(Номенклатура, НалогообложениеНДС, Организация, Дата, УказаннаяСтавкаНДС = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СтавкаНДСПоНоменклатуреИНалогообложению(Номенклатура, НалогообложениеНДС, Организация, Дата, УказаннаяСтавкаНДС);
```
</details>

## СтавкаНДСНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает ставку НДС номенклатуры
//
// Параметры:
//  Номенклатура - СправочникСсылка.Номенклатура - Номенклатура, для которой необходимо получить ставку НДС.
//  Организация - СправочникСсылка.Организации - Организация, для которой необходимо получить ставку НДС
//  Дата -  Дата - Дата, на которую необходимо получить ставку НДС.
//
// Возвращаемое значение:
//  СправочникСсылка.СтавкиНДС -
//
Функция СтавкаНДСНоменклатуры(Номенклатура, Организация, Дата) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СтавкаНДСНоменклатуры(Номенклатура, Организация, Дата) 
```
</details>

## СтавкаНДСПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение ставки НДС по умолчанию.
//
// Параметры:
//  Организация - СправочникСсылка.Организации - Организация, для которой необходимо определить ставку по умолчанию.
//  Дата - Дата - дата на которую необходимо получить ставку НДС по умолчанию,
//               если дата пустая, то будет получена ставка НДС на текущую дату.
//  РасчетнаяСтавка - Булево - указывает необходимость получения расчетной ставки НДС X/(100 + X).
//   НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Налогообложение НДС, для которого необходимо получить ставку.
//   			Если Неопределено, то ставка получается для налогообложения ПродажаОблгаетсяНДС.
// Возвращаемое значение:
//  СправочникСсылка.СтавкиНДС - значение ставки НДС.
//
Функция СтавкаНДСПоУмолчанию(Знач Организация, Знач Дата = Неопределено, Знач РасчетнаяСтавка = Ложь, Знач НалогообложениеНДС = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СтавкаНДСПоУмолчанию(Организация, Дата, РасчетнаяСтавка, НалогообложениеНДС);
```
</details>

## СтавкаНДСОсновнойСтраны
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение ставки НДС по основной стране регистрации.
//
// Параметры:
//  Дата - Дата - дата на которую необходимо получить ставку НДС по умолчанию,
//               если дата пустая, то будет получена ставка НДС на текущую дату.
// Возвращаемое значение:
//  СправочникСсылка.СтавкиНДС - значение ставки НДС.
//
Функция СтавкаНДСОсновнойСтраны(Знач Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СтавкаНДСОсновнойСтраны(Дата);
```
</details>

## НезначащаяСтавка
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет является ли ставка незначащей (Процент = 0)
//
// Параметры:
//  СтавкаНДС - СправочникСсылка.СтавкиНДС - Значение ставки НДС.
//
// Возвращаемое значение:
//  Булево -
//
Функция НезначащаяСтавка(СтавкаНДС) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.НезначащаяСтавка(СтавкаНДС) 
```
</details>

## УстановитьПараметрыЗапросаСтавкиНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает значение параметров запроса:
// * СтавкаНДСБезНДС
// * СтавкаНДСПоУмолчанию
// * СтавкаНДСНаЭкспорт
// * Дата
// * СтранаРегистрации
// исходя из соответствующих типов налогообложения.
//
// Параметры:
//  ПараметрыЗапроса - Структура - Параметры запроса получения данных, в котором необходимо установить параметры.
//  Организация - СправочникСсылка.Организации - Организация, для которой необходимо получить ставки НДС
//  Дата - Дата - Дата, на которую необходимо получить ставки НДС.
//
Процедура УстановитьПараметрыЗапросаСтавкиНДС(ПараметрыЗапроса, Организация, Дата) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.УстановитьПараметрыЗапросаСтавкиНДС(ПараметрыЗапроса, Организация, Дата) 
```
</details>

## ТекстЗапросаСтавкаНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает фрагмент запроса для получения ставки НДС исходя из типа налогообложения.
// При использовании данного текста в запросе необходимо установить параметры (см. УчетНДСУП.УстановитьПараметрыЗапросаСтавкиНДС).
//
// Параметры:
//  ВыражениеНалогообложениеНДС - Строка - Выражение получения налогообложения в запросе.
//  ВыражениеНоменклатура - Строка, Неопределено - Выражение получения номенклатуры в запросе.
//                                                 Если заполнено, то Ставка НДС для типа налогообложения ПродажаОблагаетсяНДС получается из номенклатуры.
//                                                 Если Неопределено, то для типа налогообложения ПродажаОблагаетсяНДС используется ставка НДС по умолчанию.
//  ВыражениеВозвращатьМногооборотнуюТару - Строка, Неопределено - Выражение признака возврата многооборотной тары.
//                                                                 Если тара возвращается то используется ставка "Без НДС".
//                                                                 В противном случае ставка НДС определяется по общим правилам.
//
// Возвращаемое значение:
// 	Строка - Фрагмент текста запроса
//
Функция ТекстЗапросаСтавкаНДС(ВыражениеНалогообложениеНДС, ВыражениеНоменклатура = Неопределено, ВыражениеВозвращатьМногооборотнуюТару = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ТекстЗапросаСтавкаНДС(ВыражениеНалогообложениеНДС, ВыражениеНоменклатура, ВыражениеВозвращатьМногооборотнуюТару);
```
</details>

## ЗаполнитьСтавкуНДСДляПлатежей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет ставку НДС для платежей по типу налогообложения
//
// Параметры:
//  СтавкаНДС - СправочникСсылка.СтавкиНДС - Текущее значение ставки НДС.
//  ТипНалогообложенияНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Налогобложение для поиска ставки НДС.
//  Организация - СправочникСсылка.Организации - Организация, для которой необходимо заполнить ставку НДС
//  Дата - СправочникСсылка.Организации - Дата, на которую необходимо Заполнить ставку НДС
//
Процедура ЗаполнитьСтавкуНДСДляПлатежей(СтавкаНДС, Знач ТипНалогообложенияНДС, Организация, Дата) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ЗаполнитьСтавкуНДСДляПлатежей(СтавкаНДС, ТипНалогообложенияНДС, Организация, Дата) 
```
</details>

## ПолучитьДанныеВыбораСтавкиНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет данные выбора ставки НДС
//
// Параметры:
// 	 ДанныеВыбора - СписокЗначений из СправочникСсылка.СтавкиНДС - Данные выбора
// 	 Параметры - Структура - Параметры выбора:
// 	 	* Отбор - Структура - содержит:
// 	 		** Ссылка - ПеречислениеСсылка.ТипыНалогообложенияНДС -
// 	 СтандартнаяОбработка - Булево - флаг стандартной обработки события
//
Процедура ПолучитьДанныеВыбораСтавкиНДС(ДанныеВыбора, Параметры, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ПолучитьДанныеВыбораСтавкиНДС(ДанныеВыбора, Параметры, СтандартнаяОбработка) 
```
</details>

## СтавкаНДСПоТипуНалогообложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает ставку НДС по типу налогообложения из табличной части справочника СтавкиНДС
//
// Параметры:
//  ТипНалогообложенияНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Данные для поиска ставки НДС.
//  Организация - СправочникСсылка.Организации - Организация, для которой необходимо получить ставку НДС
//  Дата - Дата - Дата, на которую необходимо получить ставку НДС.
//
// Возвращаемое значение:
//  СправочникСсылка.СтавкиНДС -
//
Функция СтавкаНДСПоТипуНалогообложения(ТипНалогообложенияНДС, Организация, Дата) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СтавкаНДСПоТипуНалогообложения(ТипНалогообложенияНДС, Организация, Дата) 
```
</details>

## СтавкаНДСКорректна
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет ставку НДС по типу налогообложения, организации и дате
//
// Параметры:
//  СтавкаНДС - СправочникСсылка.СтавкиНДС - Проверяемая ставка НДС.
//  ТипНалогообложенияНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Данные для поиска ставки НДС.
//  Организация - СправочникСсылка.Организации - Организация, для которой необходимо получить ставку НДС
//  Дата -  Дата - Дата, на которую необходимо получить ставку НДС.
//
// Возвращаемое значение:
//  Булево
//
Функция СтавкаНДСКорректна(СтавкаНДС, Знач ТипНалогообложенияНДС, Организация, Дата) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СтавкаНДСКорректна(СтавкаНДС, ТипНалогообложенияНДС, Организация, Дата) 
```
</details>

## СтавкаНДСНоменклатурыПакетно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ставку НДС для текущей обрабатываемой строки табличной части в механизмах пакетной обработки строк
// табличных частей.
//
// Параметры:
//   КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения.
//
// Возвращаемое значение:
//   СправочникСсылка.СтавкиНДС - Ставка НДС по номенклатуре в текущей строке табличной части.
//
Функция СтавкаНДСНоменклатурыПакетно(КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СтавкаНДСНоменклатурыПакетно(КэшированныеЗначения) 
```
</details>

## СтавкаНДСПоНоменклатуреИНалогообложениюПакетно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ставку НДС операции по номенклатуре и типу налогообложения НДС, используется при обработке строк табличных
// частей.
//
// Параметры:
//   Номенклатура - СправочникСсылка.Номенклатура, Неопределено - Номенклатура из которой необходимо получить ставку НДС.
//   НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Налогообложение НДС операции.
//   КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения.
//
// Возвращаемое значение:
//   СправочникСсылка.СтавкиНДС - Ставка НДС по номенклатуре в текущей строке табличной части и типу налогообложения.
//
Функция СтавкаНДСПоНоменклатуреИНалогообложениюПакетно(Номенклатура, НалогообложениеНДС, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СтавкаНДСПоНоменклатуреИНалогообложениюПакетно(Номенклатура, НалогообложениеНДС, КэшированныеЗначения) 
```
</details>

## СтавкаНДСПоТипуНалогообложенияПакетно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает ставку НДС по типу налогообложения из табличной части справочника СтавкиНДС
//
// Параметры:
//  ТипНалогообложенияНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Данные для поиска ставки НДС.
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения.
//
// Возвращаемое значение:
//  СправочникСсылка.СтавкиНДС - значение ставки НДС.
//
Функция СтавкаНДСПоТипуНалогообложенияПакетно(ТипНалогообложенияНДС, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СтавкаНДСПоТипуНалогообложенияПакетно(ТипНалогообложенияНДС, КэшированныеЗначения) 
```
</details>

## СтавкаНДСПоУмолчаниюПакетно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение ставки НДС по умолчанию.
//
// Параметры:
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения.
//  РасчетнаяСтавка - Булево - указывает необходимость получения расчетной ставки НДС X/(100 + X).
//   НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Налогообложение НДС, для которого необходимо получить ставку.
//   			Если Неопределено, то ставка получается для налогообложения ПродажаОблгаетсяНДС.
// Возвращаемое значение:
//  СправочникСсылка.СтавкиНДС - значение ставки НДС.
//
Функция СтавкаНДСПоУмолчаниюПакетно(КэшированныеЗначения, Знач РасчетнаяСтавка = Ложь, Знач НалогообложениеНДС = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СтавкаНДСПоУмолчаниюПакетно(КэшированныеЗначения, РасчетнаяСтавка, НалогообложениеНДС);
```
</details>

## ДополнитьТекстЗапросаСтавкаНДСПоСпискуНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для заполнения поля СтавкаНДС по данным
// номенклатуры при обработке строк табличной части.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаСтавкаНДСПоСпискуНоменклатуры(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ДополнитьТекстЗапросаСтавкаНДСПоСпискуНоменклатуры(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаСтавкаПоСтавкеНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для  расчета суммы с НДС при пакетной обработке
// строк табличной части.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаСтавкаПоСтавкеНДС(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ДополнитьТекстЗапросаСтавкаПоСтавкеНДС(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаСтавкаПоСтавкеНДССуффикс
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для  расчета суммы с НДС при пакетной обработке
// строк табличной части.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ДополнитьТекстЗапросаСтавкаПоСтавкеНДССуффикс(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ДополнитьТекстЗапросаСтавкаПоСтавкеНДССуффикс(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ЗаполнитьКолонкуДатаПолученияСтавки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет колонку ДатаПолученияСтавки в промежуточной таблице, сформированной на основе обрабатываемых строк табличной
// части в механизмах пакетной обработки строк табличных частей.
//
// Параметры:
//  ОбрабатываемаяКоллекция - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.КоллекцияСтрок
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧВЦикле.Действия
//  КэшированныеЗначения - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ЗаполнитьКолонкуДатаПолученияСтавки(ОбрабатываемаяКоллекция, СтруктураДействий, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ЗаполнитьКолонкуДатаПолученияСтавки(ОбрабатываемаяКоллекция, СтруктураДействий, КэшированныеЗначения) 
```
</details>

## УстановитьВидимостьКомандыЗаполнитьСтавкуНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура - Установить видимость команды заполнить ставку НДС
//
// Параметры:
//  Форма				 - ФормаКлиентскогоПриложения - Форма с командой заполнения ставки НДС.
//  ИмяЭлемента	 - Строка - Имя команды формы. По-умолчанию "ТоварыЗаполнитьСтавкуНДС".
//
Процедура УстановитьВидимостьКомандыЗаполнитьСтавкуНДС(Форма, ИмяЭлемента = "ТоварыЗаполнитьСтавкуНДС") Экспорт
```

Пример вызова
```bsl
УчетНДСУП.УстановитьВидимостьКомандыЗаполнитьСтавкуНДС(Форма, ИмяЭлемента);
```
</details>

## ЗаполнитьНалогообложениеНДСЗакупки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет соответствие указанного в документе закупки Налогообложения НДС операции документа.
// Если переданное значение не заполнено или некорректное,
// то оно заполняется значением из договора закупки или значением по умолчанию.
//
// Параметры:
// 	НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Налогообложения НДС документа закупки.
// 	ПараметрыЗаполнения - См. УчетНДСУПКлиентСервер.ПараметрыЗаполненияНалогообложенияНДСЗакупки.
// 	КэшированныеЗначенияПараметров - Произвольный - Значение реквизита кэшированных значений параметров учета НДС.
//
Процедура ЗаполнитьНалогообложениеНДСЗакупки(НалогообложениеНДС, ПараметрыЗаполнения, КэшированныеЗначенияПараметров = Неопределено) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ЗаполнитьНалогообложениеНДСЗакупки(НалогообложениеНДС, ПараметрыЗаполнения, КэшированныеЗначенияПараметров);
```
</details>

## ЗаполнитьСписокВыбораНалогообложенияНДСЗакупки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет список доступных для выбора значений налогообложения НДС исходя из операции документа.
//
// Параметры:
// 	ЭлементНалогообложениеНДС - ПолеФормы - Элемент формы, в котором указывается налогообложение НДС.
// 	НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Выбранное в документе значение налогообложения НДС.
// 	ПараметрыЗаполнения - См. УчетНДСУПКлиентСервер.ПараметрыЗаполненияНалогообложенияНДСЗакупки.
// 	КэшированныеЗначенияПараметров - Произвольный - Значение реквизита кэшированных значений параметров учета НДС.
//
Процедура ЗаполнитьСписокВыбораНалогообложенияНДСЗакупки(ЭлементНалогообложениеНДС, НалогообложениеНДС, ПараметрыЗаполнения, КэшированныеЗначенияПараметров = Неопределено) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ЗаполнитьСписокВыбораНалогообложенияНДСЗакупки(ЭлементНалогообложениеНДС, НалогообложениеНДС, ПараметрыЗаполнения, КэшированныеЗначенияПараметров);
```
</details>

## ПроверитьЗаполнениеДокументаЗакупкиПоНалогообложениюНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет возможность проведения документа с указанным налогообложением НДС.
//
// Параметры:
//	Объект - ДокументОбъект - Данные документа закупки.
// 	НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Налогообложения НДС документа закупки.
// 	ПараметрыПроверки - Произвольный.
// 	Отказ - Булево - Признак отказа проведения документа.
//
Процедура ПроверитьЗаполнениеДокументаЗакупкиПоНалогообложениюНДС(Объект, НалогообложениеНДС, ПараметрыПроверки, Отказ) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ПроверитьЗаполнениеДокументаЗакупкиПоНалогообложениюНДС(Объект, НалогообложениеНДС, ПараметрыПроверки, Отказ) 
```
</details>

## ПараметрыПроверкиЗаполнениеДокументаПоНалогообложениюНДСЗакупки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров для проверки заполнения документа закупки по налогообложению НДС.
//
// Возвращаемое значение:
//	Структура - Структура с полями:
//	         * ИмяТабличнойЧасти - Строка - Имя табличной части закупаемых ценностей.
//	         * ИмяРеквизитаСтатьяРасходов - Строка - Имя реквизита табличной части, в которой указывается статья отражения расходов.
//	         * ИмяРеквизитаАналитикаРасходов - Строка - Имя реквизита табличной части, в которой указывается аналитика отражения расходов.
//
Функция ПараметрыПроверкиЗаполнениеДокументаПоНалогообложениюНДСЗакупки() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ПараметрыПроверкиЗаполнениеДокументаПоНалогообложениюНДСЗакупки() 
```
</details>

## УстановитьУсловноеОформлениеСуммНДСПоНалогообложениюЗакупки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление для ставки НДС, суммы НДС, суммы с НДС по налогообложению закупки.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - Содержит данную форму.
//  ИмяПоляВводаСтавкиНДС - Строка - Наименование элемента формы, содержащего ставку НДС,
//                                   если оно отличается от "ТоварыСтавкаНДС".
//  ИмяПоляВводаСуммыНДС - Строка - Наименование элемента формы, содержащего сумму НДС,
//                                  если оно отличается от "ТоварыСуммаНДС".
//  ИмяПоляВводаСуммыСНДС - Строка - Наименование элемента формы, содержащего сумму с НДС,
//                                   если оно отличается от "ТоварыСуммаСНДС".
//
Процедура УстановитьУсловноеОформлениеСуммНДСПоНалогообложениюЗакупки(Форма, Экспорт
```

Пример вызова
```bsl
УчетНДСУП.УстановитьУсловноеОформлениеСуммНДСПоНалогообложениюЗакупки(Форма, );
```
</details>

## УстановитьУсловноеОформлениеСуммНДСПоСтавкеНДСЗакупки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление для суммы НДС, суммы с НДС по ставке НДС закупки.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - Содержит данную форму
//  ИмяПоляВводаСтавкиНДС - Строка - Наименование элемента формы, содержащего ставку НДС,
//                                  если оно отличается от "ТоварыСтавкаНДС".
//  ИмяПоляВводаСуммыНДС - Строка - Наименование элемента формы, содержащего сумму НДС,
//                                  если оно отличается от "ТоварыСуммаНДС".
//
Процедура УстановитьУсловноеОформлениеСуммНДСПоСтавкеНДСЗакупки(Форма, Экспорт
```

Пример вызова
```bsl
УчетНДСУП.УстановитьУсловноеОформлениеСуммНДСПоСтавкеНДСЗакупки(Форма, );
```
</details>

## ЗаполнитьВидДеятельностиНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет вид деятельности раздельного учета НДС по переданным параметрам заполнения.
// Параметры:
// 	ВидДеятельностиНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Реквизит документа приобретения.
// 	ПараметрыЗаполнения - См. УчетНДСУПКлиентСервер.ПараметрыЗаполненияВидаДеятельностиНДС
// 	КэшированныеЗначенияПараметров - Произвольный - Значение реквизита кэшированных значений параметров учета НДС.
//
Процедура ЗаполнитьВидДеятельностиНДС(ВидДеятельностиНДС, ПараметрыЗаполнения, КэшированныеЗначенияПараметров = Неопределено) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ЗаполнитьВидДеятельностиНДС(ВидДеятельностиНДС, ПараметрыЗаполнения, КэшированныеЗначенияПараметров);
```
</details>

## ЗаполнитьСписокВыбораВидаДеятельностиНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет список доступных для выбора видов деятельности раздельного учета НДС исходя учетной политики и операций документа.
//
// Параметры:
// 	ЭлементВидДеятельностиНДС - ПолеФормы - Элемент формы, в котором указывается вид деятельности НДС.
// 	ВидДеятельностиНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Выбранное в документе значение вида деятельности раздельного учета НДС.
// 	ПараметрыЗаполнения - См. УчетНДСУПКлиентСервер.ПараметрыЗаполненияВидаДеятельностиНДС.
// 	КэшированныеЗначенияПараметров - Произвольный - Значение реквизита кэшированных значений параметров учета НДС.
//
Процедура ЗаполнитьСписокВыбораВидаДеятельностиНДС(ЭлементВидДеятельностиНДС, ВидДеятельностиНДС, ПараметрыЗаполнения, КэшированныеЗначенияПараметров = Неопределено) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ЗаполнитьСписокВыбораВидаДеятельностиНДС(ЭлементВидДеятельностиНДС, ВидДеятельностиНДС, ПараметрыЗаполнения, КэшированныеЗначенияПараметров);
```
</details>

## ПроверитьЗаполнениеДокументаПоВидуДеятельностиНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет возможность проведения документа с указанным видом деятельности раздельного учета НДС.
//
// Параметры:
// 	Объект - ДокументОбъект - Данные документа.
// 	ВидДеятельностиНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Вид деятельности раздельного учета НДС.
// 	ПараметрыПроверки - Произвольный
// 	Отказ - Булево - Признак отказа проведения документа.
//
Процедура ПроверитьЗаполнениеДокументаПоВидуДеятельностиНДС(Объект, ВидДеятельностиНДС, ПараметрыПроверки, Отказ) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ПроверитьЗаполнениеДокументаПоВидуДеятельностиНДС(Объект, ВидДеятельностиНДС, ПараметрыПроверки, Отказ) 
```
</details>

## ПараметрыПроверкиЗаполненияДокументаПоВидуДеятельностиНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров для проверки заполнения документа по виду деятельности раздельного учета НДС.
//
// Возвращаемое значение:
// Структура - Структура с ключами:
// 			* ИмяТабличнойЧасти - Строка - Имя табличной части, в которой указываются ценности.
// 			* ИмяРеквизитаСтатьяРасходов - Строка - Имя реквизита табличной части, в которой указывается статья отражения расходов (необязательный).
// 			* ИмяРеквизитаАналитикаРасходов - Строка - Имя реквизита табличной части, в которой указывается аналитика отражения расходов (необязательный).
// 			* ИмяРеквизитаСтатьяАктивовПассивов - Строка - Имя реквизита табличной части, в которой указывается статья отражения прочих активов (необязательный).
// 			* ИмяРеквизитаАналитикаАктивовПассивов - Строка - Имя реквизита табличной части, в которой указывается аналитика отражения прочих активов (необязательный).
//
Функция ПараметрыПроверкиЗаполненияДокументаПоВидуДеятельностиНДС() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ПараметрыПроверкиЗаполненияДокументаПоВидуДеятельностиНДС() 
```
</details>

## СчетаФактурыПолученныеНаОсновании
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает коллекцию свойств, описывающих счета-фактуры/заявления о ввозе товаров, зарегистрированные на основании документа закупки или возврата
//
// Параметры:
// 	ПараметрыРегистрации - См. УчетНДСУПКлиентСервер.ПараметрыРегистрацииСчетовФактурПолученных
//
// Возвращаемое значение:
// 	Структура - Структура с ключами:
//		* Представление - Строка, ФорматированнаяСтрока - описание документов, зарегистрированных на основании документа закупки или возврата.
//		* СчетаФактуры - Массив из ДокументСсылка - ДокументСсылка.СчетФактураПолученный, ДокументСсылка.СчетФактураПолученныйНалоговыйАгент, ДокументСсылка.ЗаявлениеОВвозеТоваров - ссылки на счет-фактуру/заявление о ввозе товаров.
//		* ДокументПоОснованиюТребуется - Булево - признак необходимости ввода хотя бы одного документа по основанию
//		* ЕстьПравоИнтерактивногоДобавленияДокументаПоОснованию - Булево - признак наличия права для интерактивного добавления документа по основанию.
//		* ЕстьРасхождения - Булево
//
Функция СчетаФактурыПолученныеНаОсновании(ПараметрыРегистрации) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СчетаФактурыПолученныеНаОсновании(ПараметрыРегистрации) 
```
</details>

## АктуализироватьСчетаФактурыПолученныеПередЗаписью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается в обработчике ПередЗаписью() документа закупки.
// Отменяет проведение счета-фактуры, если отменяется проведение документа закупки или его реквизиты не соответствуют параметрам регистрации.
// Помечает на удаление счета-фактуры, если помечается на удаление документ закупки.
//
// Параметры:
// 	ПараметрыРегистрации - См. УчетНДСУПКлиентСервер.ПараметрыРегистрацииСчетовФактурПолученных.
// 	РежимЗаписи - РежимЗаписиДокумента - Режим записи документа.
// 	ПометкаУдаления - Булево - Пометка удаления документа закупки.
// 	Проведен - Булево - Пометка проведения документа.
//
Процедура АктуализироватьСчетаФактурыПолученныеПередЗаписью(ПараметрыРегистрации, Знач РежимЗаписи, Знач ПометкаУдаления, Знач Проведен) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.АктуализироватьСчетаФактурыПолученныеПередЗаписью(ПараметрыРегистрации, РежимЗаписи, ПометкаУдаления, Проведен) 
```
</details>

## АктуализироватьСчетаФактурыПолученныеПриПроведении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается в обработчике ОбработкаПроведения() документа закупки.
// Выполняет проведение счетов-фактур по данным документа закупки.
//
// Параметры:
// 	ПараметрыРегистрации - См. УчетНДСУПКлиентСервер.ПараметрыРегистрацииСчетовФактурПолученных.
//
Процедура АктуализироватьСчетаФактурыПолученныеПриПроведении(ПараметрыРегистрации) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.АктуализироватьСчетаФактурыПолученныеПриПроведении(ПараметрыРегистрации) 
```
</details>

## АктуализироватьСчетаФактурыПолученныеПриУдаленииПроведения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается в обработчике ОбработкаУдаленияПроведения() документа закупки после записи движений.
//
// Параметры:
// 	ПараметрыРегистрации - См. УчетНДСУПКлиентСервер.ПараметрыРегистрацииСчетовФактурПолученных.
//
Процедура АктуализироватьСчетаФактурыПолученныеПриУдаленииПроведения(ПараметрыРегистрации) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.АктуализироватьСчетаФактурыПолученныеПриУдаленииПроведения(ПараметрыРегистрации) 
```
</details>

## СчетаФактурыПолученныеПоДокументамОснованиям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает счета-фактуры полученные, зарегистрированные на основании документов.
//
// Параметры:
// 	ДокументыОснования - ДокументСсылка, Массив  из ДокументСсылка - Документ или массив документов-оснований счетов-фактур полученных.
// 	ТолькоПроведенные - Булево - Признак того, что нужно вернуть только проведенные документы.
//
// Возвращаемое значение:
// 	ТаблицаЗначений - Таблица счетов-фактур, зарегистрированных на основании:
// 	   * ДокументОснование - ДокументСсылка - Ссылка на документ-основание, у которого есть счет-фактура.
// 	   * Ссылка - ДокументСсылка - Ссылка на счет-фактуру полученный.
// 	   * РучнаяКорректировкаСуммДокумента - Булево - Истина, если суммы счета-фактуры были изменены вручную пользователем.
//
Функция СчетаФактурыПолученныеПоДокументамОснованиям(ДокументыОснования, ТолькоПроведенные = Истина) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СчетаФактурыПолученныеПоДокументамОснованиям(ДокументыОснования, ТолькоПроведенные);
```
</details>

## ВозможноСписаниеНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описание
//
// Параметры:
// 	СтароеНалогообложение - ПеречислениеСсылка.ТипыНалогообложенияНДС -
// 	НовоеНалогообложение - ПеречислениеСсылка.ТипыНалогообложенияНДС -
// Возвращаемое значение:
// 	Булево - Описание
Функция ВозможноСписаниеНДС(СтароеНалогообложение, НовоеНалогообложение) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ВозможноСписаниеНДС(СтароеНалогообложение, НовоеНалогообложение) 
```
</details>

## ЗаполнитьНалогообложениеНДСПродажи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет соответствие указанного в документе продажи Налогообложения НДС настройкам учета НДС и операции документа.
// Если переданное значение не заполнено или некорректное, то оно заполняется значением из НСИ.
//
// Параметры:
// 	НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Налогообложения НДС документа продажи.
// 	ПараметрыЗаполнения - См. УчетНДСУПКлиентСервер.ПараметрыЗаполненияНалогообложенияНДСПродажи
// 	КэшированныеЗначенияПараметров - Произвольный - Значение реквизита кэшированных значений параметров учета НДС.
//
Процедура ЗаполнитьНалогообложениеНДСПродажи(НалогообложениеНДС, ПараметрыЗаполнения, КэшированныеЗначенияПараметров = Неопределено) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ЗаполнитьНалогообложениеНДСПродажи(НалогообложениеНДС, ПараметрыЗаполнения, КэшированныеЗначенияПараметров);
```
</details>

## ЗаполнитьСписокВыбораНалогообложенияНДСПродажи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет список доступных для выбора значений налогообложения НДС исходя из настроек учета НДС операции документа.
//
// Параметры:
// 	ЭлементНалогообложениеНДС - ПолеФормы - Элемент формы, в котором указывается налогообложение НДС.
// 	НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Выбранное в документе значение налогообложения НДС.
// 	ПараметрыЗаполнения - См. УчетНДСУПКлиентСервер.ПараметрыЗаполненияНалогообложенияНДСПродажи
// 	КэшированныеЗначенияПараметров - Произвольный - Значение реквизита кэшированных значений параметров учета НДС.
//
Процедура ЗаполнитьСписокВыбораНалогообложенияНДСПродажи(ЭлементНалогообложениеНДС, НалогообложениеНДС, ПараметрыЗаполнения, КэшированныеЗначенияПараметров = Неопределено) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ЗаполнитьСписокВыбораНалогообложенияНДСПродажи(ЭлементНалогообложениеНДС, НалогообложениеНДС, ПараметрыЗаполнения, КэшированныеЗначенияПараметров);
```
</details>

## ПараметрыЗаполненияВидовЗапасовПоНалогообложению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает ограничения на типы запасов, которые можно продавать по указанному налогообложению
//
// Параметры:
// 	ОтборыВидовЗапасов - см. Справочники.ВидыЗапасов.ПараметрыОтбораВидовЗапасов
// 	Организация - СправочникСсылка.Организации -
// 	Дата - Дата -
// 	НалогообложениеНДС - Неопределено, ПеречислениеСсылка.ТипыНалогообложенияНДС -
Процедура ПараметрыЗаполненияВидовЗапасовПоНалогообложению(ОтборыВидовЗапасов, Организация, Дата, НалогообложениеНДС = Неопределено) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ПараметрыЗаполненияВидовЗапасовПоНалогообложению(ОтборыВидовЗапасов, Организация, Дата, НалогообложениеНДС);
```
</details>

## УстановитьУсловноеОформлениеКодаТНВЭДПоНалогообложениюПродажи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление поля "Код ТН ВЭД" по налогообложению продажи.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - Содержит данную форму
//  ИмяТЧ - Строка - Наименование табличной части документа, если оно отличается от "Товары".
//                   В табличной части должно присутствовать поле ТипНоменклатуры.
//  ЕстьНоменклатура - Булево - признак пономенклатурных продаж
//
Процедура УстановитьУсловноеОформлениеКодаТНВЭДПоНалогообложениюПродажи(Форма, ИмяТЧ = "Товары", ЕстьНоменклатура = Истина) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.УстановитьУсловноеОформлениеКодаТНВЭДПоНалогообложениюПродажи(Форма, ИмяТЧ, ЕстьНоменклатура);
```
</details>

## УстановитьУсловноеОформлениеСуммНДСПоНалогообложениюПродажи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление для ставки НДС, суммы НДС, суммы с НДС по налогообложению продажи.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - Содержит данную форму
//  ИмяПоляВводаСтавкиНДС - Строка - Наименование элемента формы, содержащего ставку НДС,
//                                   если оно отличается от "ТоварыСтавкаНДС".
//  ИмяПоляВводаСуммыНДС - Строка - Наименование элемента формы, содержащего сумму НДС,
//                                  если оно отличается от "ТоварыСуммаНДС".
//  ИмяПоляВводаСуммыСНДС - Строка - Наименование элемента формы, содержащего сумму с НДС,
//                                   если оно отличается от "ТоварыСуммаСНДС".
//
Процедура УстановитьУсловноеОформлениеСуммНДСПоНалогообложениюПродажи(Форма, Экспорт
```

Пример вызова
```bsl
УчетНДСУП.УстановитьУсловноеОформлениеСуммНДСПоНалогообложениюПродажи(Форма, );
```
</details>

## ВидДеятельностиПоНалогообложениюНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет вид деятельности раздельного учета НДС исходя из налогообложения НДС продажи.
//
// Параметры:
//	НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС -
//	Организация - СправочникСсылка.Организации
//	Дата - Дата
//
// Возвращаемое значение:
//	ПеречислениеСсылка.ТипыНалогообложенияНДС -
//
Функция ВидДеятельностиПоНалогообложениюНДС(НалогообложениеНДС, Организация = Неопределено, Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ВидДеятельностиПоНалогообложениюНДС(НалогообложениеНДС, Организация, Дата);
```
</details>

## ТекстЗапросаКорректностьВыбораНоменклатурыПоНалогообложениюНДСПродажи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текст запроса проверки корректности выбора номенклатуры по налогообложению НДС в документе продажи
//
// Параметры:
//	ПараметрыЗапроса - Структура - Параметры запроса контроля, который могут быть дополнены
//
// Возвращаемое значение:
// 	Строка - Текст запроса
//
Функция ТекстЗапросаКорректностьВыбораНоменклатурыПоНалогообложениюНДСПродажи(ПараметрыЗапроса) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ТекстЗапросаКорректностьВыбораНоменклатурыПоНалогообложениюНДСПродажи(ПараметрыЗапроса) 
```
</details>

## СообщитьОбОшибкахКорректностьВыбораНоменклатурыПоНалогообложениюНДСПродажи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обрабатывает результат выполнения контроля корректности выбора номенклатуры по налогообложению НДС в документе продажи
//
// Параметры:
//	Выборка - ВыборкаИзРезультатаЗапроса - Результат запроса контроля
//	ДокументПродажи - ДокументСсылка - Документ, по которому выполнялся контроль
//	ИмяТЧ - Строка - Имя табличной части для формирования сообщения об ошибке
//	ПредставлениеТЧ - Строка - Представление табличной части для формирования сообщения об ошибке
//	Отказ - Булево - Флаг отказа, который надо установить в случае наличия проблем.
//
Процедура СообщитьОбОшибкахКорректностьВыбораНоменклатурыПоНалогообложениюНДСПродажи(Знач Выборка, Знач ДокументПродажи, Знач ИмяТЧ, Знач ПредставлениеТЧ, Отказ) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.СообщитьОбОшибкахКорректностьВыбораНоменклатурыПоНалогообложениюНДСПродажи(Выборка, ДокументПродажи, ИмяТЧ, ПредставлениеТЧ, Отказ) 
```
</details>

## СчетаФактурыВыданныеНаОсновании
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает
// - текст отображения счетов-фактур, зарегистрированных на основании документа продажи.
// - ссылки данные счета-фактуры.
//
// Параметры:
// 	ПараметрыРегистрации - См. УчетНДСУПКлиентСервер.ПараметрыРегистрацииСчетовФактурВыданных
// Возвращаемое значение:
// 	Структура - Описание:
// * ЕстьПравоИнтерактивногоДобавленияДокументаПоОснованию - Булево -
// * ДокументПоОснованиюТребуется - Булево -
// * СчетаФактуры - Массив из ДокументСсылка
// * Представление - ФорматированнаяСтрока -
Функция СчетаФактурыВыданныеНаОсновании(ПараметрыРегистрации) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СчетаФактурыВыданныеНаОсновании(ПараметрыРегистрации) 
```
</details>

## СчетаФактурыОбщиеНаОсновании
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает
// - текст отображения счетов-фактур, зарегистрированных на основании документа продажи.
// - ссылки данные счета-фактуры.
//
// Параметры:
// 	ПараметрыРегистрацииВыданныхСФ - См. УчетНДСУПКлиентСервер.ПараметрыРегистрацииСчетовФактурВыданных
// 	ПараметрыРегистрацииПолученныхСФ - См. УчетНДСУПКлиентСервер.ПараметрыРегистрацииСчетовФактурПолученных
// Возвращаемое значение:
// 	Структура - Описание:
// * Представление - ФорматированнаяСтрока - Строка представления счетов-фактур в документе продажи.
// * СчетаФактуры - Массив из ДокументСсылка - Массив счетов-фактур, зарегистрированных на основании документа продажи.
// * ЕстьПравоИнтерактивногоДобавленияДокументаПоОснованию - Булево -
// * ДокументПоОснованиюТребуется - Булево -.
Функция СчетаФактурыОбщиеНаОсновании(ПараметрыРегистрацииВыданныхСФ, ПараметрыРегистрацииПолученныхСФ) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СчетаФактурыОбщиеНаОсновании(ПараметрыРегистрацииВыданныхСФ, ПараметрыРегистрацииПолученныхСФ) 
```
</details>

## АктуализироватьСчетаФактурыВыданныеПередЗаписью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается в обработчике ПередЗаписью() документа продажи.
// Отменяет проведение счетов-фактур, если отменяется проведение документа продажи или его реквизиты не соответствуют параметрам регистрации.
// Помечает на удаление счета-фактуры, если документ продажи помечается на удаление.
//
// Параметры:
// 	ПараметрыРегистрации - См. УчетНДСУПКлиентСервер.ПараметрыРегистрацииСчетовФактурВыданных.
// 	РежимЗаписи - РежимЗаписиДокумента - Режим записи документа.
// 	ПометкаУдаления - Булево - Пометка удаления документа продажи.
// 	Проведен - Булево - Пометка проведения документа.
//
Процедура АктуализироватьСчетаФактурыВыданныеПередЗаписью(ПараметрыРегистрации, Знач РежимЗаписи, Знач ПометкаУдаления, Знач Проведен) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.АктуализироватьСчетаФактурыВыданныеПередЗаписью(ПараметрыРегистрации, РежимЗаписи, ПометкаУдаления, Проведен) 
```
</details>

## АктуализироватьСчетаФактурыВыданныеПриПроведении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается в обработчике ОбработкаПроведения() документа продажи.
// Выполняет проведение счетов-фактур по данным документа продажи.
//
// Параметры:
// 	ПараметрыРегистрации - См. УчетНДСУПКлиентСервер.ПараметрыРегистрацииСчетовФактурВыданных.
//
Процедура АктуализироватьСчетаФактурыВыданныеПриПроведении(ПараметрыРегистрации) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.АктуализироватьСчетаФактурыВыданныеПриПроведении(ПараметрыРегистрации) 
```
</details>

## АктуализироватьСчетаФактурыВыданныеПриУдаленииПроведения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается в обработчике ОбработкаУдаленияПроведения() документа продажи после записи движений.
//
// Параметры:
// 	ПараметрыРегистрации - См. УчетНДСУПКлиентСервер.ПараметрыРегистрацииСчетовФактурВыданных.
//
Процедура АктуализироватьСчетаФактурыВыданныеПриУдаленииПроведения(ПараметрыРегистрации) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.АктуализироватьСчетаФактурыВыданныеПриУдаленииПроведения(ПараметрыРегистрации) 
```
</details>

## СчетаФактурыВыданныеПоДокументамОснованиям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает счета-фактуры выданные, сформированные на основании документов продажи.
//
// Параметры:
// 	ДокументыОснования - ДокументСсылка, Массив из ДокументСсылка - Документ или массив документов-оснований счетов-фактур выданных.
// 	ТолькоПроведенные - Булево - Признак того, что нужно вернуть только проведенные счета-фактуры.
//
// Возвращаемое значение:
// 	ТаблицаЗначений - Таблица счетов-фактур, зарегистрированных на основании:
// 		* ДокументОснование - ДокументСсылка - Ссылка на документ-основание, у которого есть счет-фактура.
// 		* Ссылка - ДокументСсылка - Ссылка на счет-фактуру выданный.
// 		* Корректировочный - Булево - признак Корректировочный счета-фактуры.
// 		* Исправление - Булево - признак Исправление счета-фактуры.
//
Функция СчетаФактурыВыданныеПоДокументамОснованиям(ДокументыОснования, ТолькоПроведенные = Истина) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СчетаФактурыВыданныеПоДокументамОснованиям(ДокументыОснования, ТолькоПроведенные);
```
</details>

## ПолноеИмяСчетФактурыВыданный
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает полное наименование документа СчетФактураВыданный
//
// Возвращаемое значение:
// 	Строка, Неопределено - Описание
Функция ПолноеИмяСчетФактурыВыданный() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ПолноеИмяСчетФактурыВыданный() 
```
</details>

## ЗаполнитьСчетФактураВыданный
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет Счет-фактуру выданный по переданным параметрам регистрации, выполняет проведение документа.
// Если провести документ не удалось, то выполняет запись документа.
//
// Параметры:
//  СчетФактура - ДокументОбъект, ДокументСсылка - объект или ссылка счет-фактуры выданный
//  ПараметрыРегистрации - Структура - Значения реквизитов счет-фактуры. См. УчетНДСУПКлиентСервер.ПараметрыРегистрацииСчетовФактурВыданных
//
// Возвращаемое значение:
// 	Структура:
// 		* СообщениеОбОшибке - Строка - Сообщение об ошибке, если документ провести не удалось.
// 		* Проведен - Булево - Если удалось провести документ, то Истина. Иначе - Ложь.
//
Функция ЗаполнитьСчетФактураВыданный(СчетФактура, ПараметрыРегистрации) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ЗаполнитьСчетФактураВыданный(СчетФактура, ПараметрыРегистрации) 
```
</details>

## СформироватьИсправительныеСчетаФактурыПоИзмененнымДокументам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует исправительные счета-фактуры выданные по измененным документам-основаниям.
//
// Параметры:
//  ТаблицаИзмененныхДокументов	- ТаблицаЗначений - измененные документы продажи и их реквизиты:
//  	* Документ - ОпределяемыйТип.ОснованиеСчетФактураВыданный - Документ-основание.
//  	* Организация - СправочникСсылка.Организации - Организация документа-основания.
//  	* Дата - Дата - Дата документа-основания.
//  	* Ответственный - СправочникСсылка.Пользователи - Ответственный за документ-основание.
//
// Возвращаемое значение:
//  Массив из ДокументСсылка
//
Функция СформироватьИсправительныеСчетаФактурыПоИзмененнымДокументам(ТаблицаИзмененныхДокументов) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СформироватьИсправительныеСчетаФактурыПоИзмененнымДокументам(ТаблицаИзмененныхДокументов) 
```
</details>

## СчетаФактурыКомиссионеруНаОсновании
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает
// - текст отображения счетов-фактур, зарегистрированных на основании отчета по комиссии.
// - ссылки данные счета-фактуры.
//
// Параметры:
// 	ПараметрыРегистрации - См. УчетНДСУПКлиентСервер.ПараметрыРегистрацииСчетовФактурКомиссионеру
//
// Возвращаемое значение:
// 	Структура:
//		* Представление - ФорматированнаяСтрока - Строка представления счетов-фактур в отчета комиссионеру.
// 		* СчетаФактуры - Массив из ДокументСсылка.СчетФактураКомиссионеру - Массив счетов-фактур, зарегистрированных на основании отчета комиссионера.
//
Функция СчетаФактурыКомиссионеруНаОсновании(ПараметрыРегистрации) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.СчетаФактурыКомиссионеруНаОсновании(ПараметрыРегистрации) 
```
</details>

## АктуализироватьСчетаФактурыКомиссионеруПередЗаписью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается в обработчике ПередЗаписью() отчета комиссионера.
// Отменяет проведение счетов-фактур, если отменяется проведение отчета комиссионера или его реквизиты не соответствуют параметрам регистрации.
// Помечает на удаление счета-фактуры, если помечается на удаление отчет комиссионера.
//
// Параметры:
// 	ПараметрыРегистрации - См. УчетНДСУПКлиентСервер.ПараметрыРегистрацииСчетовФактурКомиссионеру
// 	РежимЗаписи - РежимЗаписиДокумента - Режим записи документа
// 	ПометкаУдаления - Булево - Пометка удаления отчета комиссионера.
// 	Проведен - Булево - Пометка проведения документа.
//
Процедура АктуализироватьСчетаФактурыКомиссионеруПередЗаписью(ПараметрыРегистрации, Знач РежимЗаписи, Знач ПометкаУдаления, Знач Проведен) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.АктуализироватьСчетаФактурыКомиссионеруПередЗаписью(ПараметрыРегистрации, РежимЗаписи, ПометкаУдаления, Проведен) 
```
</details>

## АктуализироватьСчетаФактурыКомиссионеруПриПроведении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается в обработчике ОбработкаПроведения() отчета комиссионера.
// Выполняет проведение счетов-фактур по данным отчета комиссионера.
//
// Параметры:
// 	ПараметрыРегистрации - См. УчетНДСУПКлиентСервер.ПараметрыРегистрацииСчетовФактурКомиссионеру
//
Процедура АктуализироватьСчетаФактурыКомиссионеруПриПроведении(ПараметрыРегистрации) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.АктуализироватьСчетаФактурыКомиссионеруПриПроведении(ПараметрыРегистрации) 
```
</details>

## АктуализироватьСчетаФактурыКомиссионеруПриУдаленииПроведения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается в обработчике ОбработкаУдаленияПроведения() отчета комиссионера после записи движений.
// Выполняет обновление распоряжений на оформление счетов-фактур комиссионеру.
//
// Параметры:
// 	ПараметрыРегистрации - См. УчетНДСУПКлиентСервер.ПараметрыРегистрацииСчетовФактурКомиссионеру
//
Процедура АктуализироватьСчетаФактурыКомиссионеруПриУдаленииПроведения(ПараметрыРегистрации) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.АктуализироватьСчетаФактурыКомиссионеруПриУдаленииПроведения(ПараметрыРегистрации) 
```
</details>

## АктуализироватьСчетаФактурыКомитентаПриПроведении
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается в обработчике ОбработкаПроведения() отчета комитенту.
// Выполняет обновление распоряжений на регистрацию счетов-фактур комитента.
//
// Параметры:
// 	СчетаФактурыВыданныеПокупателям - Массив из ДокументСсылка - Счета-фактуры, выданные покупателям, параметры которых сообщили комитенту.
// 	Отказ - Булево -
//
Процедура АктуализироватьСчетаФактурыКомитентаПриПроведении(СчетаФактурыВыданныеПокупателям, Отказ = Ложь ) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.АктуализироватьСчетаФактурыКомитентаПриПроведении(СчетаФактурыВыданныеПокупателям, Отказ);
```
</details>

## АктуализироватьСчетаФактурыКомитентаПриУдаленииПроведения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается в обработчике ОбработкаУдаленияПроведения() отчета комитента после вызова записи движений.
// Выполняет обновление распоряжений на регистрацию счетов-фактур комитента.
//
// Параметры:
// 	СчетаФактурыВыданныеПокупателям - Массив из ДокументСсылка.СчетФактураВыданный - Счета-фактуры, выданные покупателям, параметры которых сообщили комитенту.
//
Процедура АктуализироватьСчетаФактурыКомитентаПриУдаленииПроведения(СчетаФактурыВыданныеПокупателям) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.АктуализироватьСчетаФактурыКомитентаПриУдаленииПроведения(СчетаФактурыВыданныеПокупателям) 
```
</details>

## ДополнитьТаблицуДаннымиСчетовФактурВыданныхПокупателям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет временную таблицу товаров к оформлению отчета комитенту колонкой "СчетФактура".
// Данная колонка заполняется подобранными по параметрам счетами-фактурами, выданным покупателю комиссионных товаров.
// Исходная временная таблица должна содержать колонки, по которым осуществляется подбор счетов-фактур.
// 	Покупатель - СправочникСсылка.Контрагенты, СправочникСсылка.Организации - Покупатель комиссионных товаров.
// 	ДокументРеализации - ДокументСсылка - Документ реализации комиссионных товаров.
// 	ДатаСчетаФактуры - Дата - Дата выставления счета-фактуры.
// 	НомерСчетаФактуры - Строка - Номер счета-фактуры.
//
// Параметры:
// 	МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - Менеджер временных таблиц, содержащий таблицу товаров к оформлению.
// 	ИмяТаблицы - Строка - Имя временной таблицы товаров к оформлению отчета комитенту.
//
Процедура ДополнитьТаблицуДаннымиСчетовФактурВыданныхПокупателям(МенеджерВременныхТаблиц, ИмяТаблицы) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ДополнитьТаблицуДаннымиСчетовФактурВыданныхПокупателям(МенеджерВременныхТаблиц, ИмяТаблицы) 
```
</details>

## УстановитьЗаголовокСостоянияОплатыНДСПоСчетуФактуре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет заголовок команды просмотра состояния оплаты НДС по документу при возникновении
// события ИзменениеСостоянияОплатыНДСПоСчетуФактуре.
//
// Параметры:
// 	СчетФактура - ОпределяемыйТип.СчетФактура - Документ, требующий оплаты НДС.
// 	КомандаСостояния - КнопкаФормы - Элемент команды просмотра состояния.
// 	ОплатаЧерезЕдиныйЛицевойСчет - Булево - признак оплаты таможенных платежей через единый лицевой счет
Процедура УстановитьЗаголовокСостоянияОплатыНДСПоСчетуФактуре(СчетФактура, КомандаСостояния, ОплатаЧерезЕдиныйЛицевойСчет = Ложь) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.УстановитьЗаголовокСостоянияОплатыНДСПоСчетуФактуре(СчетФактура, КомандаСостояния, ОплатаЧерезЕдиныйЛицевойСчет);
```
</details>

## ДобавитьЭтап_РаспределениеНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет этап в таблицу этапов закрытия месяца.
// Элементы данной таблицы являются элементами второго уровня в дереве этапов в форме закрытия месяца.
//
// Параметры:
// 	ТаблицаЭтапов - См. Обработки.ОперацииЗакрытияМесяца.ЗаполнитьОписаниеЭтаповЗакрытияМесяца
// 	ТекущийРодитель - Строка - Идентификатор группы
//
Процедура ДобавитьЭтап_РаспределениеНДС(ТаблицаЭтапов,ТекущийРодитель) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ДобавитьЭтап_РаспределениеНДС(ТаблицаЭтапов, ТекущийРодитель) 
```
</details>

## Использование_РаспределениеНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура Использование_РаспределениеНДС(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.Использование_РаспределениеНДС(ПараметрыОбработчика) 
```
</details>

## Выполнить_РаспределениеНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура Выполнить_РаспределениеНДС(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.Выполнить_РаспределениеНДС(ПараметрыОбработчика) 
```
</details>

## ДобавитьЭтап_ФормированиеДвиженийПоНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет этап в таблицу этапов закрытия месяца.
// Элементы данной таблицы являются элементами второго уровня в дереве этапов в форме закрытия месяца.
//
// Параметры:
// 	ТаблицаЭтапов - См. Обработки.ОперацииЗакрытияМесяца.ЗаполнитьОписаниеЭтаповЗакрытияМесяца
// 	ТекущийРодитель - Строка - идентификатор группы.
Процедура ДобавитьЭтап_ФормированиеДвиженийПоНДС(ТаблицаЭтапов,ТекущийРодитель) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ДобавитьЭтап_ФормированиеДвиженийПоНДС(ТаблицаЭтапов, ТекущийРодитель) 
```
</details>

## Использование_ФормированиеДвиженийПоНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура Использование_ФормированиеДвиженийПоНДС(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.Использование_ФормированиеДвиженийПоНДС(ПараметрыОбработчика) 
```
</details>

## Выполнить_ФормированиеДвиженийПоНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура Выполнить_ФормированиеДвиженийПоНДС(ПараметрыОбработчика) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.Выполнить_ФормированиеДвиженийПоНДС(ПараметрыОбработчика) 
```
</details>

## СформироватьЗаданияПоДокументам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает записи регистра по данным документов, влияющих на учет НДС
//
// Параметры:
//   МассивДокументов - Массив Из ДокументСсылка - ссылки на документы.
//
Процедура СформироватьЗаданияПоДокументам(МассивДокументов) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.СформироватьЗаданияПоДокументам(МассивДокументов) 
```
</details>

## ОтразитьЗаписиРегистраЗаданияКФормированиюДвиженийПоНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует записи в регистр заданий по учету НДС, при изменении записей в контрольных регистрах.
//
// Параметры:
//  Документ - ДокументОбъект - регистратор движений регистров
//  МенеджерВременныхТаблиц - МенеджерВременныхТаблиц - менеджер временных таблиц, содержащий таблицы изменений регистров.
//
Процедура ОтразитьЗаписиРегистраЗаданияКФормированиюДвиженийПоНДС(Документ, МенеджерВременныхТаблиц) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ОтразитьЗаписиРегистраЗаданияКФормированиюДвиженийПоНДС(Документ, МенеджерВременныхТаблиц) 
```
</details>

## ДополнитьТекстЗапросаЗаданийКЗакрытиюМесяца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет текст запроса механизма формирования заданий закрытия месяца.
//
// Параметры:
// 	Запрос - Запрос - используется для установки параметров запроса.
// 	ТекстЗапроса - Строка - строка с текстом запроса.
// 	ТекстЗапросаВременныхТаблиц - Строка - строка с текстом запроса временных таблиц.
// 	ИменаВременныхТаблиц - Строка - массив имен создаваемых временных таблиц для последующего уничтожения.
//	ИсточникСвойствДокумента - ДокументОбъект, Структура - проводимый документ или результат функции ПроведениеДокументов.ЭмуляцияДокумента() для пакетного формирования заданий
Процедура ДополнитьТекстЗапросаЗаданийКЗакрытиюМесяца(Запрос, ТекстЗапроса, ТекстЗапросаВременныхТаблиц, ИменаВременныхТаблиц, ИсточникСвойствДокумента) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ДополнитьТекстЗапросаЗаданийКЗакрытиюМесяца(Запрос, ТекстЗапроса, ТекстЗапросаВременныхТаблиц, ИменаВременныхТаблиц, ИсточникСвойствДокумента) 
```
</details>

## ПередЗаписьюЗаданияКЗакрытиюМесяца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет доп. обработку заданий к закрытию месяца перед записью.
//
// Параметры:
// 	Месяц - Дата - Месяц, на который формируется задание.
// 	Операция - ПеречислениеСсылка.ОперацииЗакрытияМесяца - Операция закрытия месяца, на выполнение которой формируется задание.
// 	Организация - СправочникСсылка.Организации - Организация, по которой формируется задание.
// 	Документ - ДокументСсылка - Документ, проведение которого инициирует задание.
//
Процедура ПередЗаписьюЗаданияКЗакрытиюМесяца(Месяц, Операция, Организация, Документ) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ПередЗаписьюЗаданияКЗакрытиюМесяца(Месяц, Операция, Организация, Документ) 
```
</details>

## НоваяТаблицаИзмененийРасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает таблицу описания изменений расчетов для формирования заданий на отражение в учете НДС
//
// Возвращаемое значение:
//   ТаблицаЗначений   - таблица значений с колонками:
//     * Документ - ДокументСсылка - документ оплаты, расчетный документ, по которому оформлен счет-фактура
//     * Период - Дата - период изменений состояния расчетов по документу
//     * Контрагент - СправочникСсылка.Контрагенты - контрагент, по которому изменились расчеты.
//     * Организация - СправочникСсылка.Организации - организация, по которой изменились расчеты.
//
Функция НоваяТаблицаИзмененийРасчетов() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.НоваяТаблицаИзмененийРасчетов() 
```
</details>

## ОтразитьВУчетеНДСИзменениеРасчетовСПоставщиками
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет отражение в учете НДС изменение состояния взаиморасчетов с поставщиками.
//
// Параметры:
// 	ТаблицаИзменений - ТаблицаЗначений - таблица значений с колонками:
//		* Документ - ДокументСсылка - документ, по которому изменилось состояние взаиморасчетов
//		* Период - Дата - период изменения
//
Процедура ОтразитьВУчетеНДСИзменениеРасчетовСПоставщиками(ТаблицаИзменений) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ОтразитьВУчетеНДСИзменениеРасчетовСПоставщиками(ТаблицаИзменений) 
```
</details>

## ОтразитьВУчетеНДСИзменениеРасчетовСКлиентами
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет отражение в учете НДС изменение состояния взаиморасчетов с клиентами.
//
// Параметры:
// 	ТаблицаИзменений - ТаблицаЗначений - таблица значений с колонками:
//		* Документ - ДокументСсылка - документ, по которому изменилось состояние взаиморасчетов
//		* Период - Дата - период изменения
//
Процедура ОтразитьВУчетеНДСИзменениеРасчетовСКлиентами(ТаблицаИзменений) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ОтразитьВУчетеНДСИзменениеРасчетовСКлиентами(ТаблицаИзменений) 
```
</details>

## ОтразитьВУчетеНДСИзменениеРасчетовПоФинансовымИнструментам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет отражение в учете НДС изменение состояния расчетов по финансовым инструментам.
//
// Параметры:
// 	ТаблицаИзменений - ТаблицаЗначений - таблица значений с колонками:
//		* Документ - ДокументСсылка - документ, по которому изменилось состояние расчетов
//		* Период - Дата - период изменения
//
Процедура ОтразитьВУчетеНДСИзменениеРасчетовПоФинансовымИнструментам(ТаблицаИзменений) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ОтразитьВУчетеНДСИзменениеРасчетовПоФинансовымИнструментам(ТаблицаИзменений) 
```
</details>

## ОтразитьДокументыВУчетеНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет отражение документов в учете НДС.
//
// Параметры:
// 	 КонецПериода - Дата - Период, по который необходимо выполнить отражение.
// 	 МассивСсылок - Массив из ДокументСсылка - Документы, которые необходимо отразить в учете НДС.
//
Процедура ОтразитьДокументыВУчетеНДС(Знач КонецПериода, Знач МассивСсылок) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ОтразитьДокументыВУчетеНДС(КонецПериода, МассивСсылок) 
```
</details>

## ВыполнитьФормированиеДвиженийПоНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Отражает документы в учете НДС, если есть задания.
//
// Параметры:
// 	КонецПериода - Дата - Период, по который необходимо выполнить задания.
// 	Организация - СправочникСсылка.Организации, Массив из СправочникСсылка.Организации - Организация или массив организаций для отбора заданий.
// 	СчетаФактуры - ДокументСсылка, Массив из ДокументСсылка - Документ учета НДС или массив документов, по которым необходимо выполнить задания.
//
Процедура ВыполнитьФормированиеДвиженийПоНДС(КонецПериода, Организация = Неопределено, СчетаФактуры = Неопределено) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ВыполнитьФормированиеДвиженийПоНДС(КонецПериода, Организация, СчетаФактуры);
```
</details>

## ОписаниеОперацийИТиповДокументовДляЖурналаДокументовЗакупки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в переданную таблицу хозяйственные операции и документы учета НДС для журнала документов Закупки
//
// Параметры:
//  ХозяйственныеОперацииИДокументы - см. ОбщегоНазначенияУТ.НоваяТаблицаХозяйственныеОперацииИДокументы
//
Процедура ОписаниеОперацийИТиповДокументовДляЖурналаДокументовЗакупки(ХозяйственныеОперацииИДокументы) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ОписаниеОперацийИТиповДокументовДляЖурналаДокументовЗакупки(ХозяйственныеОперацииИДокументы) 
```
</details>

## ОписаниеОперацийИТиповДокументовДляЖурналаДокументовПродажи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в переданную таблицу хозяйственные операции и документы учета НДС для журнала документов Продажи
//
// Параметры:
//  ТЗХозОперацииИТипыДокументов - см. ОбщегоНазначенияУТ.НоваяТаблицаХозяйственныеОперацииИДокументы
//
Процедура ОписаниеОперацийИТиповДокументовДляЖурналаДокументовПродажи(ТЗХозОперацииИТипыДокументов) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ОписаниеОперацийИТиповДокументовДляЖурналаДокументовПродажи(ТЗХозОперацииИТипыДокументов) 
```
</details>

## ОписаниеОперацийИТиповДокументовДляЖурналаДокументовПереработки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в переданную таблицу хозяйственные операции и документы учета НДС для журнала документов переработки 2.4
//
// Параметры:
//  ТЗХозОперацииИТипыДокументов - см. ОбщегоНазначенияУТ.НоваяТаблицаХозяйственныеОперацииИДокументы
//
Процедура ОписаниеОперацийИТиповДокументовДляЖурналаДокументовПереработки(ТЗХозОперацииИТипыДокументов) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ОписаниеОперацийИТиповДокументовДляЖурналаДокументовПереработки(ТЗХозОперацииИТипыДокументов) 
```
</details>

## ОписаниеОперацийИТиповДокументовДляЖурналаДокументовПередачиВПереработку2_5
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет в переданную таблицу хозяйственные операции и документы учета НДС для журнала документов передачи в переработку 2.5
//
// Параметры:
//  ТЗХозОперацииИТипыДокументов - ТаблицаЗначений - таблица операций журнала документа
//
Процедура ОписаниеОперацийИТиповДокументовДляЖурналаДокументовПередачиВПереработку2_5(ТЗХозОперацииИТипыДокументов) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ОписаниеОперацийИТиповДокументовДляЖурналаДокументовПередачиВПереработку2_5(ТЗХозОперацииИТипыДокументов) 
```
</details>

## ОписаниеОперацийИТиповДокументовДляЖурналаДокументовПриемаВПереработку2_5
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТКА

// Добавляет в переданную таблицу хозяйственные операции и документы учета НДС для журнала документов приема в переработку 2.5
//
// Параметры:
//  ТЗХозОперацииИТипыДокументов - ТаблицаЗначений - таблица операций журнала документов
//
Процедура ОписаниеОперацийИТиповДокументовДляЖурналаДокументовПриемаВПереработку2_5(ТЗХозОперацииИТипыДокументов) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ОписаниеОперацийИТиповДокументовДляЖурналаДокументовПриемаВПереработку2_5(ТЗХозОперацииИТипыДокументов) 
```
</details>

## ОпределитьОбъектыСКомандамиОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры:
//  Объекты - Массив из ОбъектМетаданных.
//
Процедура ОпределитьОбъектыСКомандамиОтчетов(Объекты) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ОпределитьОбъектыСКомандамиОтчетов(Объекты) 
```
</details>

## НастроитьВариантыОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ВариантыОтчетовПереопределяемый.НастроитьВариантыОтчетов
//
Процедура НастроитьВариантыОтчетов(Настройки) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.НастроитьВариантыОтчетов(Настройки) 
```
</details>

## ЗаполнитьИсточникиДанныхДляПроверкиЗапретаИзменения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ДатыЗапретаИзмененияПереопределяемый.ЗаполнитьИсточникиДанныхДляПроверкиЗапретаИзменения
//
Процедура ЗаполнитьИсточникиДанныхДляПроверкиЗапретаИзменения(ИсточникиДанных) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ЗаполнитьИсточникиДанныхДляПроверкиЗапретаИзменения(ИсточникиДанных) 
```
</details>

## ПриОпределенииКомандПодключенныхКОбъекту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. ПодключаемыеКомандыПереопределяемый.ПриОпределенииКомандПодключенныхКОбъекту
//
Процедура ПриОпределенииКомандПодключенныхКОбъекту(НастройкиФормы, Источники, ПодключенныеОтчетыИОбработки, Команды) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ПриОпределенииКомандПодключенныхКОбъекту(НастройкиФормы, Источники, ПодключенныеОтчетыИОбработки, Команды) 
```
</details>

## ПриОпределенииОбъектовСКомандамиСозданияНаОсновании
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//
// Параметры:
//  Объекты - Массив из ОбъектМетаданных
//
Процедура ПриОпределенииОбъектовСКомандамиСозданияНаОсновании(Объекты) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ПриОпределенииОбъектовСКомандамиСозданияНаОсновании(Объекты) 
```
</details>

## ПриОпределенииОбъектовСКомандамиПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет объекты конфигурации, в модулях менеджеров которых размещена процедура ДобавитьКомандыПечати,
// формирующая список команд печати, предоставляемых этим объектом.
// Синтаксис процедуры ДобавитьКомандыПечати см. в документации к подсистеме.
//
// Параметры:
//  СписокОбъектов - Массив из ДокументОбъект - менеджеры объектов с процедурой ДобавитьКомандыПечати.
//
Процедура ПриОпределенииОбъектовСКомандамиПечати(СписокОбъектов) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ПриОпределенииОбъектовСКомандамиПечати(СписокОбъектов) 
```
</details>

## ПередДобавлениемКомандПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет список команд печати, получаемый функцией УправлениеПечатью.КомандыПечатиФормы.
// Используется для общих форм, у которых нет модуля менеджера для размещения в нем процедуры ДобавитьКомандыПечати,
// для случаев, когда штатных средств добавления команд в такие формы недостаточно. Например, если нужны свои команды,
// которых нет в других объектах.
//
// Параметры:
//  ИмяФормы             - Строка - полное имя формы, в которой добавляются команды печати;
//  КомандыПечати        - см. УправлениеПечатью.СоздатьКоллекциюКомандПечати
//  СтандартнаяОбработка - Булево - при установке значения Ложь не будет автоматически заполняться коллекция КомандыПечати.
//
Процедура ПередДобавлениемКомандПечати(ИмяФормы, КомандыПечати, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ПередДобавлениемКомандПечати(ИмяФормы, КомандыПечати, СтандартнаяОбработка) 
```
</details>

## ПриЗаполненииСписковСОграничениемДоступа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// См. УправлениеДоступомПереопределяемый.ПриЗаполненииСписковСОграничениемДоступа
//
Процедура ПриЗаполненииСписковСОграничениемДоступа(Списки) Экспорт
```

Пример вызова
```bsl
УчетНДСУП.ПриЗаполненииСписковСОграничениемДоступа(Списки) 
```
</details>

## РегистрыУчетаНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру регистров учета НДС
//
// Возвращаемое значение:
// 	Структура - Структура регистров НДС, где:
// 	     * Ключ - Строка - Имя регистра
// 	     * Значение - РегистрНакопленияНаборЗаписей - Набор записей регистра.
Функция РегистрыУчетаНДС() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.РегистрыУчетаНДС() 
```
</details>

## ИсточникиДанныхХозяйственныхОпераций
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает регистры учета НДС, которые могут быть использованы в качестве источник данных по хоз. операциям в МФУ и Бюджетировании.
//
// Возвращаемое значение:
// 	СписокЗначений из ОбъектМетаданных
//
Функция ИсточникиДанныхХозяйственныхОпераций() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ИсточникиДанныхХозяйственныхОпераций() 
```
</details>

## ОграничениеТоваровПоНалогообложению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает отбор для списка подбора номенклатуры в соответствии с налогообложением операции
//
// Параметры:
// 	НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - налогообложение операции, в рамках которой производится подбор
//
// Возвращаемое значение:
// 	Массив из Структура - массив структур отбора для справочника Номенклатура:
// 	* Реквизит - Строка
// 	* ВидСравнения - ВидСравненияКомпоновкиДанных
// 	* Значение - ПеречислениеСсылка.ТипыНалогообложенияНДС
//
Функция ОграничениеТоваровПоНалогообложению(НалогообложениеНДС) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ОграничениеТоваровПоНалогообложению(НалогообложениеНДС) 
```
</details>

## ОписаниеПараметровОперацииЗакрытияМесяца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует описание технологических параметров.
//
// Возвращаемое значение:
// 	ТаблицаЗначений:
//  * Имя - Строка -
//  * Наименование - Строка -
//  * Описание - Строка -
//  * СтарыеИмена - Строка -
//  * Родитель - Строка -
//  * ТипЗначения - ОписаниеТипов -
//  * ДиапазонС - Число, Дата -
//  * ДиапазонПо - Число, Дата -
//  * Скрыть - Булево -
//  * ЗначениеПоУмолчанию - Произвольный -
//  * ДополнительныеСвойства - Произвольный -
//
Функция ОписаниеПараметровОперацииЗакрытияМесяца() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУП.ОписаниеПараметровОперацииЗакрытияМесяца() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
