---
title: Учет НДС УП вызов сервера
slug: erp-uh/учет-ндс-уп-вызов-сервера
---


## ПрименяемыеТипыНалогообложенияНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список типов налогообложения операций продажи и/или закупки, доступных в конфигурации.
//
// Параметры:
// 	Продажи - Булево - Признак необходимости вернуть типы налогообложения продажи
// 	Закупки - Булево - Признак необходимости вернуть типы налогообложения закупки
// 	РаздельныйУчет - Булево - Признак необходимости дополнить видами деятельности НДС
//
// Возвращаемое значение:
// 	СписокЗначений из ПеречислениеСсылка.ТипыНалогообложенияНДС
//
Функция ПрименяемыеТипыНалогообложенияНДС(Продажи, Закупки, РаздельныйУчет) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУПВызовСервера.ПрименяемыеТипыНалогообложенияНДС(Продажи, Закупки, РаздельныйУчет) 
```
</details>

## СтавкаНДСПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение ставки НДС по умолчанию.
//
// Параметры:
// 	Организация - СправочникСсылка.Организации - Организация, для которой необходимо получить ставку НДС.
//  Дата - Дата - Дата, на которую необходимо получить ставку НДС по умолчанию.
//  РасчетнаяСтавка - Булево - указывает необходимость получения расчетной ставки НДС X/(100 + X).
//
// Возвращаемое значение:
//  СправочникСсылка.СтавкиНДС - значение ставки НДС.
//
Функция СтавкаНДСПоУмолчанию(Организация, Дата, РасчетнаяСтавка = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУПВызовСервера.СтавкаНДСПоУмолчанию(Организация, Дата, РасчетнаяСтавка);
```
</details>

## СписокНезначащихСтавок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список незначащих ставок НДС (процент = 0)
//
// Возвращаемое значение:
//  СписокЗначений из СправочникСсылка.СтавкиНДС - Список ставок НДС с процентной ставкой 0
//
Функция СписокНезначащихСтавок() Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУПВызовСервера.СписокНезначащихСтавок() 
```
</details>

## ЗначениеСтавкиНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает процент НДС.
//
// Параметры:
//	СтавкаНДС - СправочникСсылка.СтавкиНДС - Значение ставки НДС.
//
// Возвращаемое значение:
//	Число - Процент НДС.
//
Функция ЗначениеСтавкиНДС(СтавкаНДС) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУПВызовСервера.ЗначениеСтавкиНДС(СтавкаНДС) 
```
</details>

## СтавкаНДСПоТипуНалогообложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает ставку НДС по типу налогообложения из табличной части справочника СтавкиНДС
//
// Параметры:
//  ТипНалогообложенияНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - Данные для поиска ставки НДС.
//  Организация - СправочникСсылка.Организации - Организация, для которой необходимо получить ставку НДС
//  Дата -  Дата - Дата, на которую необходимо получить ставку НДС.
//
// Возвращаемое значение:
//  СправочникСсылка.СтавкиНДС -
//
Функция СтавкаНДСПоТипуНалогообложения(ТипНалогообложенияНДС, Организация, Дата) Экспорт
```

Пример вызова
```bsl
Результат = УчетНДСУПВызовСервера.СтавкаНДСПоТипуНалогообложения(ТипНалогообложенияНДС, Организация, Дата) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
