---
title: Учет прослеживаемых товаров клиент сервер локализация
slug: erp-uh/учет-прослеживаемых-товаров-клиент-сервер-локализация
---


## ДополнитьОписаниеНастроекЗаполненияСлужебныхРеквизитовТабличнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет структуру действий пересчета строки табличной части, с целью заполнения признака 'ВедетсяУчетПоРНПТ'.
//
// Параметры:
//	СтруктураДействий - Структура - описывает действия, где:
//		* Ключ - Строка - наименование действия.
//		* Значение - Структура - параметры действия.
//	ПараметрыДействияСоСтрокой - Структура, Неопределено - коллекция, ключом у которой выступает имя источника поля
//															номенклатура (для которой осуществляется проверка признака
//															прослеживаемости), например, "НоменклатураОприходование".
//															А значением - имя поля, хранящим сведения о признаке
//															прослеживаемости номенклатуры, например,
//															"ВедетсяУчетПоРНПТОприходование".
//
Процедура ДополнитьОписаниеНастроекЗаполненияСлужебныхРеквизитовТабличнойЧасти(СтруктураДействий, Экспорт
```

Пример вызова
```bsl
УчетПрослеживаемыхТоваровКлиентСерверЛокализация.ДополнитьОписаниеНастроекЗаполненияСлужебныхРеквизитовТабличнойЧасти(СтруктураДействий, );
```
</details>

## ПараметрыПолученияКоэффициентаРНПТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, содержащую поля значений, используемых для заполнения количества по РНПТ в строках табличной
// части документа.
//
// Параметры:
//	Объект - ДанныеФормыСтруктура, Структура - данные формы объекта, которые содержат:
//		* Ссылка - ДокументСсылка - ссылка на документ в ИБ, с которым осуществляется работа.
//	ИмяПоляМестоХранения - Строка - имя поля Склад или другого места хранения, находящегося в шапке объекта или табличной части.
//	МестоХраненияВТабличнойЧасти - Булево - признак наличия поля Склад или другого места хранения в табличной части объекта.
//	ИменаПолейССуффиксом - Неопределено, Структура - коллекция, содержащая имена рекизитов с суффиксом:
//		* Ключ - Строка - имя реквизита без суффикса, например "Номенклатура"
//		* Значение - Строка - имя реквизита с суффиксом, например "НоменклатураОприходование".
//
// Возвращаемое значение:
//	Структура - содержит следующие свойства:
//		* ИсключаемыйДокумент - ДокументСсылка - документ, движения которого исключаются при расчета коэффициента по РНПТ.
//		* Организация - СправочникСсылка.Организации - организация, для которой рассчитывается коэффициент по РНПТ.
//		* Соглашение - СправочникСсылка.СоглашенияСКлиентами - соглашение, для которого рассчитывается коэффициент по РНПТ.
//		* МестоХраненияВТабличнойЧасти - Булево - признак наличия поля Склад или другого места хранения в табличной части объекта.
//		* ИмяПоляМестоХранения - Строка - имя поля Склад или другого места хранения, находящегося в шапке объекта или табличной части.
//		* МестоХранения - СправочникСсылка.Склады - склад или другое место хранения, для которого рассчитывается коэффициент по РНПТ.
//		* ИменаПолейССуффиксом - Неопределено, Структура - коллекция, содержащая имена рекизитов с суффиксом:
//			** Ключ - Строка - имя реквизита без суффикса, например "Номенклатура"
//			** Значение - Строка - имя реквизита с суффиксом, например "НоменклатураОприходование".
//
Функция ПараметрыПолученияКоэффициентаРНПТ(Объект, ИмяПоляМестоХранения = "Склад", МестоХраненияВТабличнойЧасти = Ложь, Экспорт
```

Пример вызова
```bsl
Результат = УчетПрослеживаемыхТоваровКлиентСерверЛокализация.ПараметрыПолученияКоэффициентаРНПТ(Объект, ИмяПоляМестоХранения, МестоХраненияВТабличнойЧасти, );
```
</details>

## ДополнитьОписаниеНастроекПересчетаРеквизитовТабличнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет структуру действий пересчета строки табличной части, с целью пересчета поля 'КоличествоПоРНПТ'.
//
// Параметры:
//	Объект - ДанныеФормыСтруктура - данные формы объекта.
//	СтруктураДействий - Структура - описывает действия, где Ключ - наименование действия,
//									Значение - Структура - параметры действия.
//	ИмяПоляМестоХранения - Строка - имя поля Склад или другого места хранения, находящегося в шапке объекта или табличной части.
//	МестоХраненияВТабличнойЧасти - Булево - признак наличия поля Склад или другого места хранения в табличной части объекта.
//	Суффикс - Строка - Суффикс имени полей Количество и КоличествоПоРНПТ. Сообщает системе что нужно обращаться по
//	именам КоличествоСуффикс и КоличествоПоРНПТСуффикс.
//
Процедура ДополнитьОписаниеНастроекПересчетаРеквизитовТабличнойЧасти(Объект, Экспорт
```

Пример вызова
```bsl
УчетПрослеживаемыхТоваровКлиентСерверЛокализация.ДополнитьОписаниеНастроекПересчетаРеквизитовТабличнойЧасти(Объект, );
```
</details>

## ПолучитьКоэффициентРНПТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение коэффициента по РНПТ для текущей строки табличной части объекта по заданным параметрам.
//
// Параметры:
//	ПараметрыПересчета - см. УчетПрослеживаемыхТоваровКлиентСерверЛокализация.ПараметрыПолученияКоэффициентаРНПТ.
//	ТекущаяСтрока - Структура - строка табличной части для которой выполняется расчет коэффициента по РНПТ.
//	КэшированныеЗначения - Структура - кэшированные значения текущей строки табличной части.
//
// Возвращаемое значение:
//	Число - коэффициент по РНПТ.
//
Функция ПолучитьКоэффициентРНПТ(ПараметрыПересчета, ТекущаяСтрока, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
Результат = УчетПрослеживаемыхТоваровКлиентСерверЛокализация.ПолучитьКоэффициентРНПТ(ПараметрыПересчета, ТекущаяСтрока, КэшированныеЗначения) 
```
</details>

## РазбитьСтрокуЗавершение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается после разбиения строки, для корректного распределения количества по РНПТ.
// Может быть передана в обработку оповещения метода ОбщегоНазначенияУТКлиент.РазбитьСтрокуТЧ.
//
// Параметры:
//	НоваяСтрока - ДанныеФормыЭлементКоллекции - строка табличной части после выполнения разбиения.
//	ДополнительныеПараметры - Структура - со следующими ключами:
//		* ИсходнаяСтрока - ДанныеФормыЭлементКоллекции - ссылка на строку табличной части, которую разбиваем.
//		* ИсходноеКоличество - Число - количество исходной строки, до разбиения.
//
Процедура РазбитьСтрокуЗавершение(НоваяСтрока, ДополнительныеПараметры) Экспорт
```

Пример вызова
```bsl
УчетПрослеживаемыхТоваровКлиентСерверЛокализация.РазбитьСтрокуЗавершение(НоваяСтрока, ДополнительныеПараметры) 
```
</details>

## ДополнитьОписаниеПараметровРазбиенияСтрокиТабличнойЧасти
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет (или создает) структуру содержащую необходимую информацию для разбиения строки табличной части,
// с учетом количества по РНПТ.
//
// Параметры:
//	ТекущаяСтрока - Структура - выделенная строка табличной части.
//	ДополнительныеПараметры - Структура - одноименноый входящий параметр объекта ОписаниеОповещения.
//
// Возвращаемое значение:
//	Структура - свойства содержат необходимую информацию для разбиения строки табличной части
//				с учетом количества по РНПТ.
//
Функция ДополнитьОписаниеПараметровРазбиенияСтрокиТабличнойЧасти(ТекущаяСтрока, Экспорт
```

Пример вызова
```bsl
Результат = УчетПрослеживаемыхТоваровКлиентСерверЛокализация.ДополнитьОписаниеПараметровРазбиенияСтрокиТабличнойЧасти(ТекущаяСтрока, );
```
</details>

## СформироватьВедомость
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму отчета Ведомость прослеживаемых товаров в составе ОС с заданными параметрами.
//
// Параметры:
//	ПараметрыФормы - Структура - параметры для формирования отчета.
Процедура СформироватьВедомость(ПараметрыФормы) Экспорт
```

Пример вызова
```bsl
УчетПрослеживаемыхТоваровКлиентСерверЛокализация.СформироватьВедомость(ПараметрыФормы) 
```
</details>

## ОткрытьФормуПодбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Открывает форму подбора с заданными параметрами.
//
// Параметры:
//	ПараметрыПодбора - Структура - параметры для формирования отчета.
//  Форма - Форма - форма-владелец.
Процедура ОткрытьФормуПодбора(ПараметрыПодбора, Форма) Экспорт
```

Пример вызова
```bsl
УчетПрослеживаемыхТоваровКлиентСерверЛокализация.ОткрытьФормуПодбора(ПараметрыПодбора, Форма) 
```
</details>

## ИмяФормыПодбораПоОстаткамПрослеживаемхТоваровВОС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//	Возвращает имя формы подбора по остаткам прослеживаемых товаров в составе ОС
//
// Возвращаемое значение:
//	Строка - имя формы подбора по остаткам прослеживаемых товаров в составе ОС
//
Функция ИмяФормыПодбораПоОстаткамПрослеживаемхТоваровВОС() Экспорт
```

Пример вызова
```bsl
Результат = УчетПрослеживаемыхТоваровКлиентСерверЛокализация.ИмяФормыПодбораПоОстаткамПрослеживаемхТоваровВОС() 
```
</details>

## ЗаполнитьРегистрационныйНомерИСтранаВвоза
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет параметры таможенной декларации - регистрационный номер и признак того, декларировался ли товар в РФ.
// Порядок получения регистрационного номера таможенной декларации см. УчетНДСКлиентСерверЛокализация.ПроверитьКорректностьНомераТаможеннойДекларации.
// Если передан параметр ТипНомераГТД, который содержит не пустое значение, тогда РегистрационныйНомер заполнится
// в зависимости от значения параметра.
// Если РегистрационныйНомер примет значение пустой строки, будет установлен признак, что товар декларировался не в РФ.
//
// Параметры:
//	ДанныеНомера - Структура - коллекция, содержащая служебную информацию, получаемую из номера таможенной декларации.
//	НомерТаможеннойДекларации - Строка - номер таможенной декларации или регистрационный номер таможенной декларации.
//	ТипНомераГТД - ПеречислениеСсылка.ТипыНомеровГТД, Неопределено - тип элемента справочника НомераГТД.
//
Процедура ЗаполнитьРегистрационныйНомерИСтранаВвоза(ДанныеНомера, НомерТаможеннойДекларации, ТипНомераГТД = Неопределено) Экспорт
```

Пример вызова
```bsl
УчетПрослеживаемыхТоваровКлиентСерверЛокализация.ЗаполнитьРегистрационныйНомерИСтранаВвоза(ДанныеНомера, НомерТаможеннойДекларации, ТипНомераГТД);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
