---
title: Учет расходов по исследованиям и разработкам локализация
slug: erp-uh/учет-расходов-по-исследованиям-и-разработкам-локализация
---


## ПрименитьПовышающийКоэффициент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура применяет повышающий коэффициент к суммам признания расходов в НУ.
// Коэффициент применяется только к расходам по исследованиям и разработкам, входящим в перечень правительства РФ,
// по статьям с льготируемым видом расходов НУ. Расчет применения повышающего коэффициента фиксируется в регистре
// сведений РасчетПризнанияРасходовНИОКР.
//
// Параметры:
//  ТаблицаДвижений - ТаблицаЗначений - Таблица движений документа:
//   * СтатьяРасходов - ПланВидовХарактеристикСсылка.СтатьиРасходов
//   * АналитикаРасходов - Характеристика.СтатьиРасходов
//   * ВидДвижения - ВидДвиженияНакопления
//   * ИдентификаторФинЗаписи - Строка
//   * СуммаРегл - Число
//   * ПостояннаяРазница - Число
//   * ВременнаяРазница - Число
//   * ПрименятьКоэффициент - Булево.
//  ДокументПризнания - ДокументСсылка.ПризнаниеРасходовПоИсследованиямИРазработкам -
//  Организация - СправочникСсылка.Организации - Организация, для которой выполняется расчет.
//  ПериодРасчета - Дата - Дата выполнения расчета.
//
Процедура ПрименитьПовышающийКоэффициент(ТаблицаДвижений, ДокументПризнания, Организация, ПериодРасчета) Экспорт
```

Пример вызова
```bsl
УчетРасходовПоИсследованиямИРазработкамЛокализация.ПрименитьПовышающийКоэффициент(ТаблицаДвижений, ДокументПризнания, Организация, ПериодРасчета) 
```
</details>

## ВернутьДокументыКОтражению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает документы к отражению в регл. учете
//
// Параметры:
// 	ДокументыКОтражению -   ТаблицаЗначений,
// 							МенеджерВременныхТаблиц - Таблица документов, которые надо вернуть к отражению,
// 													  или менеджер временных таблиц имеющий таблицу ДокументыКОтражению
// 													  Таблица должна иметь колонки Документ, Организация, ДатаОтражения.
//
Процедура ВернутьДокументыКОтражению(МенеджерВТ) Экспорт
```

Пример вызова
```bsl
УчетРасходовПоИсследованиямИРазработкамЛокализация.ВернутьДокументыКОтражению(МенеджерВТ) 
```
</details>

## ОчиститьДвиженияДокументовПоПризнаниюРасходов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает блокировку и очищает движения локализуемвх регистров
//
// Параметры:
// 	МенеджерВТ - МенеджерВременныхТаблиц - содержит врменную таблицу ДокументыКОтражению с колонками:
// 	* Документ - ДокументСсылка.ПризнаниеРасходовПоИсследованиямИРазработкам -
Процедура ОчиститьДвиженияДокументовПоПризнаниюРасходов(МенеджерВТ) Экспорт
```

Пример вызова
```bsl
УчетРасходовПоИсследованиямИРазработкамЛокализация.ОчиститьДвиженияДокументовПоПризнаниюРасходов(МенеджерВТ) 
```
</details>

## ПовышающийКоэффициентКСуммамПризнанияРасходовВНУ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет размер повышающего коэффициента к суммам признания расходов в НУ
//
// Параметры:
// 	Период - Дата - Период действия.
//
// Возвращаемое значение:
// 	Число - Коэффициент к суммам признания расходов в НУ.
//
Функция ПовышающийКоэффициентКСуммамПризнанияРасходовВНУ(Знач Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетРасходовПоИсследованиямИРазработкамЛокализация.ПовышающийКоэффициентКСуммамПризнанияРасходовВНУ(Период) 
```
</details>

## ДобавитьКомандыОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьКомандыОтчетов(КомандыОтчетов, Параметры) Экспорт
```

Пример вызова
```bsl
УчетРасходовПоИсследованиямИРазработкамЛокализация.ДобавитьКомандыОтчетов(КомандыОтчетов, Параметры) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
