---
title: Учет УСН клиент сервер
slug: erp-uh/учет-усн-клиент-сервер
---


## ИспользуетсяКоэффициентДефлятор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о применении на указанную дату коэффициента-дефлятора
// для индексации базового лимита доходов, ограничивающих право применения УСН.
//
// Параметры:
//  Период - Дата - Дата, на которую получаем сведения об использовании дефлятора.
//
// Возвращаемое значение:
//  Булево - если Истина, то коэффициент-дефлятор применяется.
//
Функция ИспользуетсяКоэффициентДефлятор(Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНКлиентСервер.ИспользуетсяКоэффициентДефлятор(Период) 
```
</details>

## КоэффициентДефлятор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает размер коэффициента ежегодной индексации величины дохода УСН.
//
// Параметры:
//  Период - Дата - Дата, на которую необходимо получить коэффициент.
//
// Возвращаемое значение:
//  Число
//
Функция КоэффициентДефлятор(Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНКлиентСервер.КоэффициентДефлятор(Период) 
```
</details>

## РазрядностьОкругленияПоказателей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает точность округления показателей УСН при расчете налога.
//
// Параметры:
//  ДатаРасчета - Дата - дата, на которую необходимо определить точность округления.
//
// Возвращаемое значение:
//  Число - точность округления
//
Функция РазрядностьОкругленияПоказателей(ДатаРасчета) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНКлиентСервер.РазрядностьОкругленияПоказателей(ДатаРасчета) 
```
</details>

## НалоговыеСтавкиПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ставки налога УСН, указанные в НК РФ.
// Ставка УСН доходы - п. 1 ст. 346.20 НК РФ.
// Ставка УСН доходы минус расходы - п. 2 ст. 346.20 НК РФ.
// Ставка минимального налога УСН доходы минус расходы - п. 6 ст. 346.18 НК РФ.
// Повышенная ставка УСН доходы - п. 1.1 ст. 346.20 НК РФ.
// Повышенная ставка УСН доходы минус расходы - п. 2.1 ст. 346.20 НК РФ.
//
// Возвращаемое значение:
//  Структура - ставки налогов.
//    * СтавкаУСНДоходы - Число.
//    * СтавкаУСНДоходыМинусРасходы - Число.
//    * СтавкаМинимальногоНалогаУСНДоходыМинусРасходы - Число.
//    * СтавкаУСНДоходыПовышенная - Число
//    * СтавкаУСНДоходыМинусРасходыПовышенная - Число
//
Функция НалоговыеСтавкиПоУмолчанию(Период = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНКлиентСервер.НалоговыеСтавкиПоУмолчанию(Период);
```
</details>

## ДатаНачалаФормирования4РазделаКУДиР
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

///////////////////////////////////////////////////////////////////////////////
// Формирование Книги учета доходов и расходов

Функция ДатаНачалаФормирования4РазделаКУДиР() Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНКлиентСервер.ДатаНачалаФормирования4РазделаКУДиР() 
```
</details>

## ДатаОтменыФормирования4РазделаКУДиР
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дата, с которой отменяется формирование раздела IV "Уменьшение налога" Книги учета доходов и расходов.
// Приказ ФНС России от 07.11.2023 № ЕА-7-3/816@
// "Об утверждении форм книги учета доходов и расходов организаций
// и индивидуальных предпринимателей, применяющих упрощенную систему налогообложения,
// книги учета доходов индивидуальных предпринимателей, применяющих патентную систему
// налогообложения, и порядков их заполнения"
//
// Возвращаемое значение:
//  Дата - 01 января 2024 года
//
Функция ДатаОтменыФормирования4РазделаКУДиР() Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНКлиентСервер.ДатаОтменыФормирования4РазделаКУДиР() 
```
</details>

## ДатаНачалаДействияФормыКнигиДоходовПоПриказу_ЕА_7_3_816
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дату начала действия формы книги учета доходов по патенту
// по приказу ФНС от 07.11.2023 г. № ЕА-7-3/816@
//
// Возвращаемое значение:
//   Дата - 1 янаваря 2024 года
//
Функция ДатаНачалаДействияФормыКнигиДоходовПоПриказу_ЕА_7_3_816() Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНКлиентСервер.ДатаНачалаДействияФормыКнигиДоходовПоПриказу_ЕА_7_3_816() 
```
</details>

## ДатаНачалаФормирования5РазделаКУДиР
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дата начала формирования V раздела КУДиР.
//
// Возвращаемое значение:
//  Дата - Дата начала формирования V раздела КУДиР
Функция ДатаНачалаФормирования5РазделаКУДиР() Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНКлиентСервер.ДатаНачалаФормирования5РазделаКУДиР() 
```
</details>

## ДатаНачалаПрогрессивнойШкалы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дату начала действия прогрессивной шкалы УСН
//
// Возвращаемое значение:
//  Дата
//
Функция ДатаНачалаПрогрессивнойШкалы() Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНКлиентСервер.ДатаНачалаПрогрессивнойШкалы() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
