---
title: Учет УСН ПСН сервер
slug: erp-uh/учет-усн-псн-сервер
---


## ПараметрыПервичногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает структура параметров первичного документа
//
// Возвращаемое значение:
//	Структура:
//		- НомерВходящегоДокумента - строка, номер указанный в документе пользователем;
//		- Номер - строка, номер заданный системой при вводе документа;
//		- ДатаВходящегоДокумента - дата, дата указанная в документе пользователем;
//		- Дата - ДатаИВремя - дата и время, заданное системой при вводе документа.
//
Функция ПараметрыПервичногоДокумента() Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНПСНСервер.ПараметрыПервичногоДокумента() 
```
</details>

## РеквизитыПервичногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает реквизиты первичного документа для занесения в графу 2 КУДиР.
//	Параметры:
//		Документ - ДокументОбъект - документ, для которого делаются движения КУДиР;
//		ТЧ - ТабличнаяЧасть объекта - табличная часть, где содержатся данные о номере и дате первичного документа;
//		Строка - Число - номер строки табличной части документа, где содержатся данные о номере и дате первичного документа;
//		УказыватьВид - Булево - признак необходимости указывать в результате синоним документа (например "Реализация товаров и услуг №1 от 01.01.2001").
//			Значение по умолчанию - Ложь;
//
//	Возвращаемое значение:
//		Строка - строка вида "Реализация товаров и услуг №1 от 01.01.2001" или "№1 от 01.01.2001", в зависимости от признака УказыватьВид.
//
Функция РеквизитыПервичногоДокумента(Документ, Параметры = Неопределено, УказыватьВид = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНПСНСервер.РеквизитыПервичногоДокумента(Документ, Параметры, УказыватьВид);
```
</details>

## СторноЗаписейКУДиРПоОтбору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует набор сторнирующих записей регистра КнигаУчетаДоходовИРасходов, соответствующих отбору.
//
// Параметры:
//  ОтборЗаписей - Структура - в ключе передается имя поля регистра, в значении - значение отбора
//                             (отбор производится по равенству).
//
// Возвращаемое значение:
//   Массив из Структура - набор данных сторнирующих записей, см. РезультатЗапросаВМассивСтруктур.
//
Функция СторноЗаписейКУДиРПоОтбору(ОтборЗаписей) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНПСНСервер.СторноЗаписейКУДиРПоОтбору(ОтборЗаписей) 
```
</details>

## СторноЗаписейКУДиРЗаПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует набор сторнирующих записей регистра КнигаУчетаДоходовИРасходов за период, соответствующих отбору.
//
// Параметры:
//  ПериодЗаписей - СтандартныйПериод - период, за который требуется сторнировать найденные записи.
//  ДополнительныйОтбор - Структура - в ключе передается имя поля регистра, в значении - значение отбора
//                                     (отбор производится по равенству).
//                      - Неопределено - отбор не задан.
//
// Возвращаемое значение:
//   Массив из Структура - набор данных сторнирующих записей, см. РезультатЗапросаВМассивСтруктур.
//
Функция СторноЗаписейКУДиРЗаПериод(ПериодЗаписей, ДополнительныйОтбор = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНПСНСервер.СторноЗаписейКУДиРЗаПериод(ПериодЗаписей, ДополнительныйОтбор);
```
</details>

## НачалоРасчетаОперацийПоУСН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает периоды с которого для операций УСН и ПСН закрытия месяца данные становятся неактуальными.
// Параметры:
//	КонецРасчета - Дата - ищутся записи, сделанные раньше этой даты;
//	СписокОрганизаций - Массив - СправочникСсылка.Организации - ищутся записи, сделанные по переданным организациям;
//								Если значение не заполнено - отбор не учитывается.
// Возвращаемое значение:
//	Структура - содержащая даты начала расчета для каждой из операций УСН и ПСН, если данные актуальные возвращает КонецРасчета + 1:
//		* НачалоРасчетаПризнаниеРасходовПриУСН - Дата - дата начала расчета, с которой данные по операции признания расходов УСН становятся не актуальными;
//		* НачалоРасчетаСторноДоходовКУДиР - Дата - дата начала расчета, с которой данные по операции сторно записей доходов КУДиР для УСН и ПСН становятся не актуальными;
//		* НачалоРасчетаНалогаУСН - Дата - дата начала расчета, с которой данные по операции расчета налога УСН становятся не актуальными.
//
Функция НачалоРасчетаОперацийПоУСН(КонецРасчета, СписокОрганизаций = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНПСНСервер.НачалоРасчетаОперацийПоУСН(КонецРасчета, СписокОрганизаций);
```
</details>

## ОбновитьЗаданияКЗакрытиюМесяцаПриВыполненииРеглОперации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура вызывается из методов регламентных операций для записи в регистр сведений "ЗаданияКЗакрытиюМесяца"
//	данных о необходимости пересчета признания расходов (если изменяются организации с объектом налогообложения "Доходы минус расходы").
// Параметры:
//	Период - Дата - период пересчета;
//	СписокОрганизаций - Массив - СправочникСсылка.Организации - массив организаций, для которых запущена процедура пересчета.
//	ТолькоРасходы - Булево - Признак выборки подходящих организаций:
//		если Истина - будут выбираться организации на УСН, с объектом налогообложения "Доходы минус расходы",
//		если Ложь - будут выбираться организации на УСН вне зависимости от объекта налогообложения, значение по умолчанию - Истина;
//	КоличествоОбработанныхЭлементов - Число - Количество данных, обработанных данной процедурой (см. общий модуль "Производительность").
//
Процедура ОбновитьЗаданияКЗакрытиюМесяцаПриВыполненииРеглОперации(Период, СписокОрганизаций, ТолькоРасходы = Истина, КоличествоОбработанныхЭлементов = 0) Экспорт
```

Пример вызова
```bsl
УчетУСНПСНСервер.ОбновитьЗаданияКЗакрытиюМесяцаПриВыполненииРеглОперации(Период, СписокОрганизаций, ТолькоРасходы, КоличествоОбработанныхЭлементов);
```
</details>

## ОбновитьЗаданияКЗакрытиюМесяца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура записывает в регистр сведений "ЗаданияКЗакрытиюМесяца" данные о необходимости пересчета регл. операций по УСН,
// при отсутствии в регистре записей в этом периоде.
//	Параметры:
//		ВременнаяТаблица - МенеджерВременныхТаблиц - содержит таблицу:
//				* КонтрольныеДанныеПоУСНДоходыМинусРасходы - временная таблица с колонками:
//					** Организация - СправочникСсылка.Организации - организация для которой необходимо обновить данные пересчета;
//					** Документ - ДокументСсылка - документ, который вызвал необходимость обновления данных пересчета;
//					** Период - Дата - новая дата, на которую необходимо установить данные пересчета;
//					** Операция - ПеречислениеСсылка.ОперацииЗакрытияМесяца - операция для которой устанавливаем новые данные пересчета;
//		Операция - ПеречислениеСсылка.ОперацииЗакрытияМесяца - тип операции закрытия месяца, для которой происходит обновление
//					(в данном модуле актуален только для ПризнаниеРасходовПриУСН, РасчетНалогаУСН и СторноДоходовКУДиР);
//		КоличествоОбработанныхЭлементов - Число - Количество данных, обработанных данной процедурой (см. общий модуль "Производительность").
//
Процедура ОбновитьЗаданияКЗакрытиюМесяца(ВременнаяТаблица, Операция, КоличествоОбработанныхЭлементов = 0) Экспорт
```

Пример вызова
```bsl
УчетУСНПСНСервер.ОбновитьЗаданияКЗакрытиюМесяца(ВременнаяТаблица, Операция, КоличествоОбработанныхЭлементов);
```
</details>

## ДвиженияЗаписываютсяРегламентнойОперациейУСН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак записи движений по регистру механизмом признания расходов.
//
// Параметры:
//	НаборЗаписей - НаборЗаписей - набор записей регистра.
//
// Возвращаемое значение:
//	Булево - Истина, если движения записываются регламентной операцией признания расходов.
//
Функция ДвиженияЗаписываютсяРегламентнойОперациейУСН(НаборЗаписей) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНПСНСервер.ДвиженияЗаписываютсяРегламентнойОперациейУСН(НаборЗаписей) 
```
</details>

## НалоговыйПериодПропущен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, что не требуется сдавать отчетность и уплачивать налог за переданный период (год)
// по причине регистрации организации в декабре этого года (п. 2 статьи 55 НК РФ).
//
// Параметры:
//  Организация   	- СправочникСсылка.Организации - проверяемая организация
//  Период        	- Дата - проверяемый период
//	ДатаРегистрации - Дата - дата регистрации организации.
//
// Возвращаемое значение:
//   Булево   - Если ИСТИНА, это пропущенный период
//              (организация зарегистрирована в декабре переданного года, и для нее актуальны требования п.2 статьи 55
//              НК РФ).
//
Функция НалоговыйПериодПропущен(Организация, Период, ДатаРегистрации = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНПСНСервер.НалоговыйПериодПропущен(Организация, Период, ДатаРегистрации);
```
</details>

## НалоговыйПериодРасширен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, что переданный период находится в пределах расширенного первого налогового периода -
// с даты регистрации в декабре по конец следующего года после регистрации (п. 2 статьи 55 НК РФ).
//
// Параметры:
//  Организация   	- СправочникСсылка.Организации - проверяемая организация
//  Период        	- Дата - проверяемый период (в пределах расширенного налогового периода)
//	ДатаРегистрации - Дата - дата регистрации организации.
//
// Возвращаемое значение:
//   Булево   - Если ИСТИНА, это расширенный период
//             (организация зарегистрирована в декабре переданного или прошлого года,
//              и для нее актуальны требования п.2 статьи 55 НК РФ).
//
Функция НалоговыйПериодРасширен(Организация, Период, ДатаРегистрации = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНПСНСервер.НалоговыйПериодРасширен(Организация, Период, ДатаРегистрации);
```
</details>

## ТекстЗапросаТаблицаДействующихПатентовПодразделениям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает временную таблицу "ТаблицаДействующихПатентов" с колонками:
//		Патент - СправочникСсылка.Патенты - патент;
//		Подразделение - СправочникСсылка.СтруктураПредприятия - подразделение, для которого он применяется.
//
//	Параметры:
//		Запрос - Запрос - запрос, использующийся при проведении документа;
//		ТекстыЗапроса - СписокЗначений - список отдельных текстов запроса, испольщзующихся при проведении, с представлением - именем временной таблицы, которая создается;
//		ТолькоУникальные - Булево - если истина, то будут выбираться только те патенты, которые не применяются сразу для нескольких подразделений.
//
//	Возвращаемое значение:
//		Строка - текст, получившегося запроса.
//
Функция ТекстЗапросаТаблицаДействующихПатентовПодразделениям(Запрос, ТекстыЗапроса, ТолькоУникальные = Истина) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНПСНСервер.ТекстЗапросаТаблицаДействующихПатентовПодразделениям(Запрос, ТекстыЗапроса, ТолькоУникальные);
```
</details>

## ЗаполнитьЗаявлениеУтратаПраваПатентаФорма2014_1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет переданную в виде контейнера структуру данных отчета
//
// Параметры:
//  ПараметрыОтчета - Структура
//   * Организация - СправочникСсылка.Организации
//   * КодНалоговогоОргана - СправочникСсылка.РегистрацииВНалоговомОргане
//  Контейнер - Структура
//   * ДопСтроки - Таблица значений - Строки табличной части заявления
//   * ТитульныйЛист - Структура - Данные титульного листа заявления
//
Процедура ЗаполнитьЗаявлениеУтратаПраваПатентаФорма2014_1(ПараметрыОтчета, Контейнер) Экспорт
```

Пример вызова
```bsl
УчетУСНПСНСервер.ЗаполнитьЗаявлениеУтратаПраваПатентаФорма2014_1(ПараметрыОтчета, Контейнер) 
```
</details>

## ЗаполнитьЗаявлениеПрекращениеПатентаФорма2014_1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет переданную в виде контейнера структуру данных отчета
//
// Параметры:
//  ПараметрыОтчета - Структура
//   * Организация - СправочникСсылка.Организации
//   * КодНалоговогоОргана - СправочникСсылка.РегистрацииВНалоговомОргане
//  Контейнер - Структура
//   * ТитульныйЛист - Структура - Данные титульного листа заявления
//
Процедура ЗаполнитьЗаявлениеПрекращениеПатентаФорма2014_1(ПараметрыОтчета, Контейнер) Экспорт
```

Пример вызова
```bsl
УчетУСНПСНСервер.ЗаполнитьЗаявлениеПрекращениеПатентаФорма2014_1(ПараметрыОтчета, Контейнер) 
```
</details>

## ПолучитьСведенияОПоказателяхЗаявленияУтратаПраваФорма2014_1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет переданную в виде контейнера структуру показателей отчета
// правилами заполнения полей, доступных для автозаполнения
//
// Параметры:
//  ПоказателиОтчета - Структура
//   * Организация - СправочникСсылка.Организации
//   * КодНалоговогоОргана - СправочникСсылка.РегистрацииВНалоговомОргане
//
Процедура ПолучитьСведенияОПоказателяхЗаявленияУтратаПраваФорма2014_1(ПоказателиОтчета) Экспорт
```

Пример вызова
```bsl
УчетУСНПСНСервер.ПолучитьСведенияОПоказателяхЗаявленияУтратаПраваФорма2014_1(ПоказателиОтчета) 
```
</details>

## ПолучитьСведенияОПоказателяхЗаявленияПрекращениеПатентаФорма2014_1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет переданную в виде контейнера структуру показателей отчета
// правилами заполнения полей, доступных для автозаполнения
//
// Параметры:
//  ПоказателиОтчета - Структура
//   * Организация - СправочникСсылка.Организации
//   * КодНалоговогоОргана - СправочникСсылка.РегистрацииВНалоговомОргане
//
Процедура ПолучитьСведенияОПоказателяхЗаявленияПрекращениеПатентаФорма2014_1(ПоказателиОтчета) Экспорт
```

Пример вызова
```bsl
УчетУСНПСНСервер.ПолучитьСведенияОПоказателяхЗаявленияПрекращениеПатентаФорма2014_1(ПоказателиОтчета) 
```
</details>

## НовыйКонтекстРасчетаНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описывает контекст, в котором выполняется расчет налога УСН - организацию, период и т.п.
//
// Параметры:
//  Организация      - СправочникСсылка.Организации - налогоплательщик.
//  ПериодРасчета    - Дата - дата из последнего квартала отчетного периода, за который рассчитывается налог.
//
// Возвращаемое значение:
//  Структура    - состав см. в теле функции
//  Неопределено - расчет не имеет смысла: в указанный период организация еще не зарегистрирована, или не применяет УСН,
//                 или же налог в данном периоде не исчисляется в силу п. 2 статьи 55 НК РФ.
//
Функция НовыйКонтекстРасчетаНалога(Организация, ПериодРасчета) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНПСНСервер.НовыйКонтекстРасчетаНалога(Организация, ПериодРасчета) 
```
</details>

## НовыйКонтекстРегламентнойОперации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Описывает контекст выполнения ежеквартальных регламентных операций для УСН с объектом "доходы-расходы":
// организацию, период и т.п.
//
// Параметры:
//  Организация      - СправочникСсылка.Организации - налогоплательщик.
//  Период           - Дата - дата из квартала, в котором выполняется регламентная операция.
//
// Возвращаемое значение:
//  Структура    - состав см. в теле функции
//  Неопределено - расчет не имеет смысла: в указанный период организация еще не зарегистрирована,
//                 или не применяет УСН с объектом "доходы минус расходы",
//                 или же переданный квартал не является завершенным отчетным/налоговым периодом в силу п. 2 статьи 55
//                 НК РФ.
//
Функция НовыйКонтекстРегламентнойОперации(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНПСНСервер.НовыйКонтекстРегламентнойОперации(Организация, Период) 
```
</details>

## ЕстьПравоУменьшатьНалогНаТорговыйСбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, разрешено ли организации уменьшать налог за данный квартал на суммы уплаченного торгового сбора.
//
// Параметры:
//  Организация  - СправочникСсылка.Организации - организация-налогоплательщик.
//  Период       - Дата - дата в пределах последнего квартала отчетного (налогового) периода.
//
// Возвращаемое значение:
//   Булево   - если Истина, налог можно уменьшить на уплаченный торговый сбор.
//
Функция ЕстьПравоУменьшатьНалогНаТорговыйСбор(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНПСНСервер.ЕстьПравоУменьшатьНалогНаТорговыйСбор(Организация, Период) 
```
</details>

## ПрименяетсяОсвобождениеОтНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак того, применяется ли освобождение от уплаты налога по УСН
//
// Параметры:
//   Организация - СправочникСсылка.Организации - организация, для которой выполняется проверка освобождения от налога;
//   Период      - Дата - Дата, для которой определяется освобождение от налога.
//
// Возвращаемое значение:
//   Булево
//
Функция ПрименяетсяОсвобождениеОтНалога(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНПСНСервер.ПрименяетсяОсвобождениеОтНалога(Организация, Период) 
```
</details>

## ПараметрыПримененияПовышеннойСтавкиНалога
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о применении повышенной ставки налога в отчетном периоде
//
// Параметры:
//   КонтекстРасчета - Структура- см. НовыйКонтекстРасчетаНалога
//
// Возвращаемое значение:
//   Структура:
//      ПрименяетсяПовышеннаяСтавка - Булево - признак того, что в отчетном периоде применяется повышенная ставка
//      ПериодПревышенияЛимитов - Дата - отчетный период, в котором превышены границы применения
//           основной ставки УСН
//      НалоговаяБазаДоПревышенияЛимитов - Число - налоговая база за период, предшествующий кварталу
//           превышения границ применения основной ставки УСН.
//      НалогДоПревышенияЛимитов - Число - налог за период, предшествующий кварталу
//           превышения 1 порога лимитов применения УСН.
//      НалоговаяБазаДоПревышенияЛимитовТорговыйСбор - Число - налоговая база по деятельности, облагаемой
//           торговым сбором, за период, предшествующий кварталу превышения 1 порога лимитов применения УСН.
//      НалогДоПревышенияЛимитовТорговыйСбор - Число - налог по деятельности, облагаемой торговым сбором, за период,
//           предшествующий кварталу превышения 1 порога лимитов применения УСН.
//      Ошибки - Массив из Структура - массив ошибок, препятствующих расчету применения повышенной ставки налога.
//
Функция ПараметрыПримененияПовышеннойСтавкиНалога(КонтекстРасчета) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНПСНСервер.ПараметрыПримененияПовышеннойСтавкиНалога(КонтекстРасчета) 
```
</details>

## СредняяЧисленностьРаботников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения о средней численности наемных работников за отчетный период.
//
// Параметры:
//   Организация - СправочникСсылка.Организации - ссылка на организацию
//   НачалоПериода - Дата - начало анализа численности работников
//   КонецПериода - Дата - конец анализа численности работников
//   УчитыватьРучныеКорректировки - Булево - учитывать сведения о численности, указанные пользователем
//
// Возвращаемое значение:
//   - Число - средняя численность наемных работников за отчетный период (если -1, то нет наемных работников)
//   - Неопределено - нет сведений о средней численности работников
//
Функция СредняяЧисленностьРаботников(Организация, НачалоПериода, КонецПериода, УчитыватьРучныеКорректировки = Истина) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНПСНСервер.СредняяЧисленностьРаботников(Организация, НачалоПериода, КонецПериода, УчитыватьРучныеКорректировки);
```
</details>

## ОборотыКУДиРЗаПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сведения об оборотах книги учета доходов и расходов за отчетный период.
//
// Параметры:
//   Организация - СправочникСсылка.Организации - ссылка на организацию;
//   НачалоОтчетногоПериода - Дата;
//   КонецОтчетногоПериода - Дата;
//
// Возвращаемое значение:
//   - Структура:
//   	- Доходы - Число - сумма доходов за период;
//   	- ДоходыТорговыйСбор - Число - сумма доходов по торговому сбору за период;
//   	- Расходы - Число - сумма расходов за период.
//
Функция ОборотыКУДиРЗаПериод(Организация, НачалоОтчетногоПериода, КонецОтчетногоПериода) Экспорт
```

Пример вызова
```bsl
Результат = УчетУСНПСНСервер.ОборотыКУДиРЗаПериод(Организация, НачалоОтчетногоПериода, КонецОтчетногоПериода) 
```
</details>

## СформироватьДвиженияОтражениеРасходовПоИмущественнымНалогам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура формирует движения по регистру "КУДиР", при выполнении регламентной операции "РасчетТранспортногоНалога",
// вызывается из модуля объекта документа "РегламентнаяОперация".
//
// Параметры:
//	ТаблицаПлатон - ТаблицаЗначений - таблица расходов по Платону
//		(см. РасчетИмущественныхНалоговПереопределяемый.ТаблицыРасчетНалога);
//	Реквизиты  - ТаблицаЗначений - таблица реквизитов
//		(см. РегламентнаяОперация.ТекстЗапросаРасчетИмущественныхНалогов);
//	ДокументОбъект - ДокументОбъект.РегламентнаяОперация - проводимый документ регламентной операции,
//		в рамках которой выполняется отражение расходов в УСН;
//	Отказ - Булево - признак отказа от проведения документа.
//
Процедура СформироватьДвиженияОтражениеРасходовПоИмущественнымНалогам(ТаблицаПлатон, Реквизиты, ДокументОбъект, Отказ) Экспорт
```

Пример вызова
```bsl
УчетУСНПСНСервер.СформироватьДвиженияОтражениеРасходовПоИмущественнымНалогам(ТаблицаПлатон, Реквизиты, ДокументОбъект, Отказ) 
```
</details>

## ДополнитьТекстЗапросаЗаданийКЗакрытиюМесяца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет текст запроса механизма формирования заданий закрытия месяца.
//
// Параметры:
// 	Запрос - Запрос - используется для установки параметров запроса.
// 	ТекстЗапроса - Строка - строка с текстом запроса.
// 	ТекстЗапросаВременныхТаблиц - Строка - строка с текстом запроса временных таблиц.
// 	ИменаВременныхТаблиц - Строка - массив имен создаваемых временных таблиц для последующего уничтожения.
Процедура ДополнитьТекстЗапросаЗаданийКЗакрытиюМесяца(Запрос, ТекстЗапроса, ТекстЗапросаВременныхТаблиц, ИменаВременныхТаблиц) Экспорт
```

Пример вызова
```bsl
УчетУСНПСНСервер.ДополнитьТекстЗапросаЗаданийКЗакрытиюМесяца(Запрос, ТекстЗапроса, ТекстЗапросаВременныхТаблиц, ИменаВременныхТаблиц) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
