---
title: Учетная политика переопределяемый
slug: erp-uh/учетная-политика-переопределяемый
---


## Существует
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция Существует(Организация, Период, ВыводитьСообщениеОбОтсутствииУчетнойПолитики = Ложь, ДокументСсылка = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.Существует(Организация, Период, ВыводитьСообщениеОбОтсутствииУчетнойПолитики, ДокументСсылка);
```
</details>

## ПлательщикНалогаНаПрибыль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТ

// Возвращает признак, является ли организация плательщиком налога на прибыль.
// Параметры:
//	Организация - Массив, СписокЗначений, СправочникСсылка.Организации - организация, для которой определяется необходимость оплаты налога на прибыль;
//	Период - Дата - дата, на начало месяца которой определяется необходимость оплаты налога на прибыль.
//
// Возвращаемое значение:
//	Булево - Истина, если организация на дату является плательщиком налога на прибыль. В противном случае - ложь.
//
Функция ПлательщикНалогаНаПрибыль(знач Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПлательщикНалогаНаПрибыль(знач Организация, Период) 
```
</details>

## ПоддержкаПБУ18
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак необходимости применения для организации ПБУ18.
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется необходимость применения ПБУ18;
//	Период - Дата - дата, на начало месяца которой определяется необходимость применения ПБУ18.
//
// Возвращаемое значение:
//	Булево - Истина, если организация на дату применяет ПБУ18. В противном случае - ложь.
//
Функция ПоддержкаПБУ18(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПоддержкаПБУ18(Организация, Период) 
```
</details>

## ЗаполнитьПараметрыПБУ18
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет структуру признаков, относящихся к применению ПБУ 18 для организации.
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется необходимость применения ПБУ18;
//	Период - Дата - дата, на начало месяца которой определяется необходимость применения ПБУ18.
//	ПараметрыПБУ18 - Структура - см. УчетнаяПолитика.ПараметрыПБУ18()
//
Процедура ЗаполнитьПараметрыПБУ18(Организация, Период, ПараметрыПБУ18) Экспорт
```

Пример вызова
```bsl
УчетнаяПолитикаПереопределяемый.ЗаполнитьПараметрыПБУ18(Организация, Период, ПараметрыПБУ18) 
```
</details>

## ВедетсяУчетПостоянныхИВременныхРазниц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак ведения учета постоянных разниц.
//
// Параметры:
//	Организация- Массив, СправочникСсылка.Организации - организация, для которой определяется признак;
//	Период - Дата - дата, на начало месяца которой определяется признак.
//
// Возвращаемое значение:
//	Булево - Истина, если организация ведет учет постоянных разниц.
//
Функция ВедетсяУчетПостоянныхИВременныхРазниц(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ВедетсяУчетПостоянныхИВременныхРазниц(Организация, Период) 
```
</details>

## МетодНачисленияАмортизацииНУ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает метод начисления амортизации (Линейный, Нелинейный, ПоЕНАОФ).
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется метод начисления;
//	Период - Дата - дата, на которую определяется метод начисления.
//
// Возвращаемое значение:
//	ПеречислениеСсылка.МетодыНачисленияАмортизации - метод начисления амортизации налогового учета, применяемый для данной организации на указанную дату.
//	Значение по умолчанию: Линейный.
//
Функция МетодНачисленияАмортизацииНУ(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.МетодНачисленияАмортизацииНУ(Организация, Период) 
```
</details>

## СписыватьСтоимостьМалоценныхТМЦНаРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает необходимость списания стоимости ТМЦ в эксплуатации.
//
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется настройка.
//	Период - Дата - дата, на которую определяется настройка.
//
// Возвращаемое значение:
//	Булево - Истина, если стоимость списывается.
//
Функция СписыватьСтоимостьМалоценныхТМЦНаРасходы(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.СписыватьСтоимостьМалоценныхТМЦНаРасходы(Организация, Период) 
```
</details>

## БазаРаспределенияКосвенныхРасходовПоВидамДеятельности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает базу распределения косвенных расходов: доходы от реализации или доходы от реализации и внереализационные.
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется база распределения;
//	Период - Дата - дата, на начало месяца которой определяется база распределения.
//
// Возвращаемое значение:
//	ПеречислениеСсылка.БазыРаспределенияКосвенныхРасходовПоВидамДеятельности - база распределения косвенных расходов, применяемая для данной организации на указанную дату.
//	Значение по умолчанию: Доходы от реализации.
//
Функция БазаРаспределенияКосвенныхРасходовПоВидамДеятельности(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.БазаРаспределенияКосвенныхРасходовПоВидамДеятельности(Организация, Период) 
```
</details>

## ИспользуетсяДелениеНаДолгосрочныеКраткосрочныеАктивыОбязательства
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак использования деления активов и обязательств на краткосрочные и долгосрочные.
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется база распределения;
//	Период - Дата - дата, на начало месяца которой определяется база распределения.
//
// Возвращаемое значение:
//	Булево
//
Функция ИспользуетсяДелениеНаДолгосрочныеКраткосрочныеАктивыОбязательства(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ИспользуетсяДелениеНаДолгосрочныеКраткосрочныеАктивыОбязательства(Организация, Период) 
```
</details>

## СистемаНалогообложения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//-- НЕ УТ

// Возвращает систему налогообложения применяемую организацией: общая или упрощенная.
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется система налогообложения;
//	Период - Дата - дата, на начало месяца которой определяется система налогообложения.
//
// Возвращаемое значение:
//	ПеречислениеСсылка.СистемыНалогообложения - система налогообложения, применяемая для данной организации на указанную дату.
//	Значение по умолчанию: Общая.
//
Функция СистемаНалогообложения(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.СистемаНалогообложения(Организация, Период) 
```
</details>

## ПлательщикНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры учетной политики по НДС

// Возвращает признак, является ли организация плательщиком налога на добавленную стоимость (НДС).
// Определяется на основании того, применяет ли организация упрощенную систему налогообложения. Если применяет - то не является плательщиком НДС.
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется признак оплаты НДС;
//	Период - Дата - дата, на начало месяца которой определяется необходимость оплаты НДС.
//
// Возвращаемое значение:
//	Булево - Истина, если организация на дату является плательщиком налога на добавленную стоимость. В противном случае - ложь.
//
Функция ПлательщикНДС(Знач Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПлательщикНДС(Организация, Период) 
```
</details>

## ПлательщикНДСПрименяющийУСН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПлательщикНДСПрименяющийУСН(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПлательщикНДСПрименяющийУСН(Организация, Период) 
```
</details>

## ПрименяетсяОсвобождениеОтУплатыНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак освобождения организации от уплаты НДС.
//
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется признак освобождения от уплаты НДС;
//	Период - Дата - дата, на которую определяется признак освобождения от уплаты НДС.
//
// Возвращаемое значение:
//	Булево - Истина, если организация на дату освобождается от уплаты НДС. Всегда возвращается Ложь.
//
Функция ПрименяетсяОсвобождениеОтУплатыНДС(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПрименяетсяОсвобождениеОтУплатыНДС(Организация, Период) 
```
</details>

## Учитывать5ПроцентныйПорог
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТ

// Возвращает признак учета 5% порога выручки не облагаемой НДС от общей выручки для организации на начало месяца указанной даты.
//
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется признак учета 5% порога;
//	Период - Дата - дата, на которую определяется признак учета 5% порога.
//
// Возвращаемое значение:
//	Булево - Истина, если организация на дату учитывает 5% порог. В противном случае - ложь.
//
Функция Учитывать5ПроцентныйПорог(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.Учитывать5ПроцентныйПорог(Организация, Период) 
```
</details>

## ПравилоОтбораАвансовДляРегистрацииСчетовФактур
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//-- НЕ УТ

// Возвращает правило отбора авансов для регистрации счетов-фактур
//
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой необходимо определить правило отбора авансов
//	Период - Дата - дата, на которую определяется правило отбора авансов.
//
// Возвращаемое значение:
//	ПеречислениеСсылка.ПорядокРегистрацииСчетовФактурНаАванс - Правило отбора авансов
//
Функция ПравилоОтбораАвансовДляРегистрацииСчетовФактур(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПравилоОтбораАвансовДляРегистрацииСчетовФактур(Организация, Период) 
```
</details>

## ПериодичностьФормированияВычетовИВосстановленийНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Возвращает периодичность формирования вычетов и восстановлений НДС
//
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой необходимо определить
//										периодичность формирования вычетов и восстановлений НДС
//	Период - Дата - дата, на которую определяется периодичность формирования вычетов и восстановлений НДС
//
// Возвращаемое значение:
//	ПеречислениеСсылка.Периодичность - Периодичность формирования вычетов и восстановлений НДС
//
Функция ПериодичностьФормированияВычетовИВосстановленийНДС(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПериодичностьФормированияВычетовИВосстановленийНДС(Организация, Период) 
```
</details>

## ПлательщикЕНВД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры учетной политики по ЕНВД

// Возвращает признак, применяет ли организация единый налог на вмененный доход (ЕНВД).
//
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется применяет ли она ЕНВД;
//	Период - Дата - дата, на которую определяется применение ЕНВД.
//
// Возвращаемое значение:
//	Булево - Истина, если организация на дату является плательщиком единого налога на вмененный доход. В противном случае - ложь.
//
Функция ПлательщикЕНВД(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПлательщикЕНВД(Организация, Период) 
```
</details>

## ПлательщикЕНВДЗаПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, являлась ли организация плательщиком единого налога на вмененный доход (ЕНВД) в течении указанного периода.
//
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется применение ЕНВД;
//	НачалоПериода - Дата - начало периода, для которого определяется применение организацией ЕНВД;
//	КонецПериода - Дата - конец периода, для которого определяется применение организацией ЕНВД.
//
// Возвращаемое значение:
//	Булево - Истина, если организация в течении указанного периода являлась плательщиком ЕНВД (хотя бы раз). В противном случае - ложь.
//
Функция ПлательщикЕНВДЗаПериод(Организация, НачалоПериода, КонецПериода) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПлательщикЕНВДЗаПериод(Организация, НачалоПериода, КонецПериода) 
```
</details>

## ПрименяетсяУСН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры учетной политики по УСН

// Возвращает признак применения для организации упрошенной системы налогообложения.
// Параметры:
//	Организация - Массив, СправочникСсылка.Организации - организация или массив организаций, для которых необходимо определить применение УСН;
//	Период - Дата - дата, на начало месяца которой определяется признак применения УСН.
//
// Возвращаемое значение:
//	Булево - Истина, если для организации (или если для хотя бы одной организации из списка) на дату
//				применяется упрощенная система налогообложения. В противном случае - ложь.
//
Функция ПрименяетсяУСН(Знач Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПрименяетсяУСН(Организация, Период) 
```
</details>

## ПрименяетсяПСН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ Локализация

// Возвращает признак использования патента для организации.
// Параметры:
//	Организация - СправочникСсылка.Организации- организация, для которых необходимо определить применение ПСН;
//	Период - Дата - дата, которой определяется признак применения ПСН.
//
// Возвращаемое значение:
//	Булево - Истина, если для организации установлено использование патентов в учетной политике на дату.
//				В противном случае - ложь.
//
Функция ПрименяетсяПСН(Знач Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПрименяетсяПСН(Организация, Период) 
```
</details>

## ПрименяетсяАУСН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак использования АУСН для организации.
// Параметры:
//	Организация - СправочникСсылка.Организации- организация, для которых необходимо определить применение АУСН;
//	Период - Дата - дата, которой определяется признак применения АУСН.
//
// Возвращаемое значение:
//	Булево - Истина, если для организации установлено использование патентов в учетной политике на дату.
//				В противном случае - ложь.
//
Функция ПрименяетсяАУСН(Знач Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПрименяетсяАУСН(Организация, Период) 
```
</details>

## ПриРеформацииБалансаЗзакрывать90И91СчФилиаловЧерез79Сч
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак закрытия 91 И 90 счетов по организации.
// Параметры:
//	Организация - СправочникСсылка.Организации- организация, для которых необходимо определить применение АУСН;
//	Период - Дата - дата, которой определяется признак применения АУСН.
//
// Возвращаемое значение:
//	Булево - Истина, если для организации установлено закрытие 91 и 90 счетов через 79 счет на дату.
//				В противном случае - ложь.
//
Функция ПриРеформацииБалансаЗзакрывать90И91СчФилиаловЧерез79Сч(Знач Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПриРеформацииБалансаЗзакрывать90И91СчФилиаловЧерез79Сч(Организация, Период) 
```
</details>

## ЗаполнятьКУДиР
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак необходимости заполнения книги учета доходов и расходов для организации.
// Такая необходимость присутствует, когда организация применяет УСН или ПСН.
// Параметры:
//	Организация - СправочникСсылка.Организации- организация, для которых необходимо определить необходимость заполнения КУДиР;
//	Период - Дата - дата, для которой определяется необходимость заполнения КУДиР.
//
// Возвращаемое значение:
//	Булево - Истина, если для организации установлено использование патентов (или УСН) в учетной политике на дату.
//				В противном случае - ложь.
//
Функция ЗаполнятьКУДиР(Знач Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ЗаполнятьКУДиР(Организация, Период) 
```
</details>

## ИспользуетсяПСН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак использования патента в программе.
//
// Возвращаемое значение:
//	Булево - Истина, если для какой-либо из организаций установлено использование патентов в учетной политике.
//				В противном случае - ложь.
//
Функция ИспользуетсяПСН() Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ИспользуетсяПСН() 
```
</details>

## ПрименяетсяУСНДоходыМинусРасходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Возвращает признак применения объекта налогообложения "Доходы, уменьшенные на величину расходов",
//	который используется для организации на упрощенной системе налогообложения.
// Параметры:
//	Организация - Массив, СправочникСсылка.Организации - организация или массив организаций,
//					для которых необходимо определить применение объекта налогообложения "ДоходыМинусРасходы";
//	Период - Дата - дата, на которую анализируется учетная политика организации.
//
// Возвращаемое значение:
//	Булево - Истина, если для организации (или если для хотя бы одной организации из списка) на дату
//				применяется объект налогообложения "ДоходыМинусРасходы". В противном случае - ложь.
//
Функция ПрименяетсяУСНДоходыМинусРасходы(Знач Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПрименяетсяУСНДоходыМинусРасходы(Организация, Период) 
```
</details>

## ПрименяетсяУСНДоходы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак применения объекта налогообложения "Доходы",
//	который используется для организации на упрощенной системе налогообложения.
// Параметры:
//	Организация - Массив, СправочникСсылка.Организации - организация или массив организаций,
//					для которых необходимо определить применение объекта налогообложения "Доходы";
//	Период - Дата - дата, на которую анализируется учетная политика организации.
//
// Возвращаемое значение:
//	Булево - Истина, если для организации (или если для хотя бы одной организации из списка) на дату
//				применяется объект налогообложения "Доходы". В противном случае - ложь.
//
Функция ПрименяетсяУСНДоходы(Знач Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПрименяетсяУСНДоходы(Организация, Период) 
```
</details>

## ОрганизацииНаУСНЗаПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив организаций, находящихся на УСН за определенный период.
// Параметры:
//	НачалоПериода - Дата - дата, на начало месяца которой определяется список организаций на УСН;
//	КонецПериода - Дата - дата, на конец месяца которой определяется список организаций на УСН.
//
// Возвращаемое значение:
//	Массив - СправочникСсылка.Организации - все организации, применяющие УСН в течении указанного периода.
//
Функция ОрганизацииНаУСНЗаПериод(НачалоПериода, КонецПериода) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ОрганизацииНаУСНЗаПериод(НачалоПериода, КонецПериода) 
```
</details>

## ПрименяетсяУСНЗаПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак применения для организации упрошенной системы налогообложения за определенный период.
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой необходимо определить применение УСН с объектом налогообложения "Доходы минус расходы";
//	НачалоПериода - Дата - дата, на начало месяца которой определяется признак применения УСН с объектом налогообложения "Доходы минус расходы";
//	КонецПериода - Дата - дата, на конец месяца которой определяется признак применения УСН с объектом налогообложения "Доходы минус расходы";
//	ОбъектНалогообложения - ПеречислениеСсылка.ОбъектыНалогообложенияПоУСН - ссылка на объект налогообложения, если требуется получить признак
//		применения конкретного объекта налогообложения, если не заполнен - получает признак непосредственного применения УСН.
//
// Возвращаемое значение:
//	Булево - Истина, если для организации в какой-либо из отрезков указанного периода применялась упрощенная система налогообложения с объектом налогообложения "Доходы минус расходы".
//				В противном случае - ложь.
//
Функция ПрименяетсяУСНЗаПериод(Организация, НачалоПериода, КонецПериода, ОбъектНалогообложения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПрименяетсяУСНЗаПериод(Организация, НачалоПериода, КонецПериода, ОбъектНалогообложения);
```
</details>

## СтавкаНалогаУСН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТ

// Определяет ставку налога УСН для организации на конкретную дату.
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой получается ставка налога УСН;
//	Период - Дата - дата, на начало которой определяется ставка налога УСН.
//
// Возвращаемое значение:
//	Число - ставка налога УСН, указанная для учетной политики организации на переданную дату.
//
Функция СтавкаНалогаУСН(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.СтавкаНалогаУСН(Организация, Период) 
```
</details>

## НалоговыеКаникулыУСН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет признак применения налоговых каникул для организации на УСН.
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, из учетной политики которой берется требуемое значение;
//	Период - Дата - дата, на которую анализируется учетная политика организации.
//
// Возвращаемое значение:
//	Булево - признак применения налоговых каникул УСН.
//
Функция НалоговыеКаникулыУСН(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.НалоговыеКаникулыУСН(Организация, Период) 
```
</details>

## ОбъектНалогообложенияУСН
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает объект налогообложения который используется для организации на упрощенной системе налогообложения.
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, из учетной политики которой берется требуемое значение;
//	Период - Дата - дата, на которую анализируется учетная политика организации.
//
// Возвращаемое значение:
//	ПеречислениеСсылка.ОбъектыНалогообложенияПоУСН - объект налогообложения, указанный для учетной политики организации на переданную дату.
//
Функция ОбъектНалогообложенияУСН(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ОбъектНалогообложенияУСН(Организация, Период) 
```
</details>

## ИспользуетсяТрудНаемныхРаботников
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак применения труда наемных работников, который используется для организации на упрощенной системе налогообложения.
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, из учетной политики которой берется требуемое значение;
//	Период - Дата - дата, на которую анализируется учетная политика организации.
//
// Возвращаемое значение:
//	Булево - признак использования труда наемных работников, указанный для учетной политики организации на переданную дату.
//
Функция ИспользуетсяТрудНаемныхРаботников(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ИспользуетсяТрудНаемныхРаботников(Организация, Период) 
```
</details>

## ФормироватьРезервыПоСомнительнымДолгам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры учетной политики по резервам по сомнительным долгам

// Возвращает признак формирования резервов по сомнительным долгам для организации в бухгалтерском учете.
// Для определения используется функция "ПараметрыУчетнойПолитики" модуля менеджера регистра сведений "УчетнаяПолитикаОрганизаций".
//
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется признак формирования резервов по сомнительным долгам;
//	Период - Дата - дата, на начало месяца которой определяется формирования резервов по сомнительным долгам.
//
// Возвращаемое значение:
//	Булево - Истина, если организация на дату формирует резервы по сомнительным долгам в бухгалтерском учете. В противном случае - ложь.
//
Функция ФормироватьРезервыПоСомнительнымДолгам(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ФормироватьРезервыПоСомнительнымДолгам(Организация, Период) 
```
</details>

## ФормироватьРезервыПоСомнительнымДолгамНУ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак формирования резервов по сомнительным долгам для организации в налоговом учете.
// Для определения используется функция "ПараметрыУчетнойПолитики" модуля менеджера регистра сведений "УчетнаяПолитикаОрганизаций".
//
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется признак формирования резервов по сомнительным долгам;
//	Период - Дата - дата, на начало месяца которой определяется формирования резервов по сомнительным долгам.
//
// Возвращаемое значение:
//	Булево - Истина, если организация на дату формирует резервы по сомнительным долгам в налоговом учете. В противном случае - ложь.
//
Функция ФормироватьРезервыПоСомнительнымДолгамНУ(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ФормироватьРезервыПоСомнительнымДолгамНУ(Организация, Период) 
```
</details>

## ТекстЗапросаУчетнойПолитикиПоПериодам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ТекстЗапросаУчетнойПолитикиПоПериодам() Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ТекстЗапросаУчетнойПолитикиПоПериодам() 
```
</details>

## ПлательщикТорговогоСбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает признак, является ли организация плательщиком торгового сбора.
//
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется признак оплаты торгового сбора;
//	Период - Дата - дата, на которую определяется признак оплаты торгового сбора.
//
// Возвращаемое значение:
//	Булево - Истина, если организация имеет активные (не снятые с учета) торговые точки. В противном случае - ложь.
// (см. функцию ТорговыйСбор.ИспользуютсяТорговыеТочки)
//
Функция ПлательщикТорговогоСбора(Организация, Период) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПлательщикТорговогоСбора(Организация, Период) 
```
</details>

## ПлательщикТорговогоСбораЗаПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, являлась ли организация плательщиком торгового сбора в течении указанного периода.
//
// Параметры:
//	Организация - СправочникСсылка.Организации - организация, для которой определяется признак оплаты торгового сбора;
//	НачалоПериода - Дата - начало периода, для которого определяется признак оплаты торгового сбора;
//	КонецПериода - Дата - конец периода, для которого определяется признак оплаты торгового сбора.
//
// Возвращаемое значение:
//	Булево - Истина, если организация в течении указанного периода являлась плательщиком торгового сбора (хотя бы раз). В противном случае - ложь.
// (см. функцию ТорговыйСбор.ИспользуютсяТорговыеТочкиЗаПериод)
//
Функция ПлательщикТорговогоСбораЗаПериод(Организация, НачалоПериода, КонецПериода) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ПлательщикТорговогоСбораЗаПериод(Организация, НачалоПериода, КонецПериода) 
```
</details>

## ЗначенияРесурсаУчетнойПолитикиЗаПериод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//-- НЕ УТ

// Определяет, применялся ли для организации признак, указанный в первом параметре, в течении указанного периода.
//
// Параметры:
//	ИмяРесурса - Строка - имя ресурса регистра сведений "УчетныеПолитикиОрганизаций" с типом "Булево";
//	Организация - СправочникСсылка.Организации - организация, для которой определяется значение ресурса;
//	НачалоПериода - Дата - начало периода, для которого определяется значение ресурса;
//	ОкончаниеПериода - Дата - конец периода, для которого определяется значение ресурса.
//
// Возвращаемое значение:
//	Булево - Истина, если для организации в течении указанного периода, значение ресурса хотя бы раз принимало значение "Истина". В противном случае - ложь.
//
Функция ЗначенияРесурсаУчетнойПолитикиЗаПериод(ИмяРесурса, Организация, НачалоПериода, ОкончаниеПериода) Экспорт
```

Пример вызова
```bsl
Результат = УчетнаяПолитикаПереопределяемый.ЗначенияРесурсаУчетнойПолитикиЗаПериод(ИмяРесурса, Организация, НачалоПериода, ОкончаниеПериода) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
