---
title: Физические лица УТ
slug: erp-uh/физические-лица-ут
---


## ФамилияИмяОтчество
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует структуру, содержащую информацию о фамилии, имени и отчестве физического лица.
// Строка формируется в зависимости от типа переданного параметра:
//	- либо по истории ФИО элемента справочника ФизическиеЛица,
// 	- либо разбором строки, содержащей полную ФИО.
//
// Параметры:
//  ФизическоеЛицо - Строка, СправочникСсылка.ФизическиеЛица - источник информации о ФИО
//  Дата - Дата - дата для получения истории ФИО, имеет смысл если в первом параметре передана ссылка.
//
// Возвращаемое значение:
//	Структура - со свойствами
//		Фамилия  - Строка
//		Имя      - Строка
//		Отчество - Строка
//
Функция ФамилияИмяОтчество(ФизическоеЛицо, Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ФизическиеЛицаУТ.ФамилияИмяОтчество(ФизическоеЛицо, Дата);
```
</details>

## ФамилияИнициалыФизЛица
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует строку, содержащую фамилию и инициалы физического лица.
// Строка формируется в зависимости от типа переданного параметра:
//	- либо по истории ФИО элемента справочника ФизическиеЛица,
// 	- либо разбором строки, содержащей полную ФИО.
//
// Параметры:
//  ФизическоеЛицо - Строка, СправочникСсылка.ФизическиеЛица - источник информации о ФИО
//  Дата - Дата - дата для получения истории ФИО, имеет смысл если в первом параметре передана ссылка.
//
// Возвращаемое значение:
//  Строка - Фамилия И. О.
//
Функция ФамилияИнициалыФизЛица(ФизическоеЛицо, Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ФизическиеЛицаУТ.ФамилияИнициалыФизЛица(ФизическоеЛицо, Дата);
```
</details>

## КраткийСоставФизЛиц
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразовывает переданный массив физических лиц в строку.
// Используется для представления краткого состава документов.
//
// Параметры:
//	ФизическиеЛица - Массив из СправочникСсылка.ФизическиеЛица - массив элементов типа СправочникСсылка.ФизическиеЛица,
//	ДатаАктуальности - Дата - дата для получения фамилии, имени и отчества.
//  МаксимальнаяДлинаСтроки - Число - Максимальная длина строки
//
// Возвращаемое значение:
//  Строка - Краткий состав физ лиц
//
Функция КраткийСоставФизЛиц(ФизическиеЛица, ДатаАктуальности, МаксимальнаяДлинаСтроки = 100) Экспорт
```

Пример вызова
```bsl
Результат = ФизическиеЛицаУТ.КраткийСоставФизЛиц(ФизическиеЛица, ДатаАктуальности, МаксимальнаяДлинаСтроки);
```
</details>

## ПодразделениеФизическогоЛица
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает подразделение указанного физического лица.
//
// Параметры:
//  ФизическоеЛицо - СправочникСсылка.ФизическиеЛица - источник информации о подразделении.
//
// Возвращаемое значение:
//  СправочникСсылка.СтруктураПредприятия - Подразделение пользователя.
//
Функция ПодразделениеФизическогоЛица(ФизическоеЛицо) Экспорт
```

Пример вызова
```bsl
Результат = ФизическиеЛицаУТ.ПодразделениеФизическогоЛица(ФизическоеЛицо) 
```
</details>

## ПолучитьДокументФизическогоЛицаПоУмолчанию
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные документа физического лица.
// Если документ не найден или документов больше одного, то возвращается пустая структура.
//
// Параметры:
//  ФизическоеЛицо - СправочникСсылка.ФизическиеЛица - источник информации о документе
//  ВидДокумента - СправочникСсылка.ВидыДокументовФизическихЛиц - вид документа физического лица
//  Дата - Дата - дата для получения истории документов физического лица.
//
// Возвращаемое значение:
//  Структура - данные документа физического лица,
//		поля соответствуют ресурсам регистра ДокументыФизическихЛиц.
//
Функция ПолучитьДокументФизическогоЛицаПоУмолчанию(ФизическоеЛицо, ВидДокумента = Неопределено, Дата = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ФизическиеЛицаУТ.ПолучитьДокументФизическогоЛицаПоУмолчанию(ФизическоеЛицо, ВидДокумента, Дата);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
