---
title: Финансовая отчетность вызов сервера
slug: erp-uh/финансовая-отчетность-вызов-сервера
---


## ПоместитьЭлементВХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает данные переданной строки вида отчета во временное хранилище формы.
//
// Параметры:
//  ПомещаемыйОбъект - СправочникОбъект.ЭлементыФинансовыхОтчетов, Структура - помещаемый объект.
//  АдресХранилища - Строка, УникальныйИдентификатор - адрес временного хранилища
//  ОчиститьСсылки - Булево - Если истина тогда ссылка элемента справочника и ссылка владельца отчета будут очищены.
//  					При записи такого элемента отчета будет сформирована новая ссылка т.о. помещаемый элемент
//  					будет скопирован.
//
// Возвращаемое значение:
//   Строка   - Адрес элемента в хранилище.
//
Функция ПоместитьЭлементВХранилище(ПомещаемыйОбъект, АдресХранилища = Неопределено, ОчиститьСсылки = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ФинансоваяОтчетностьВызовСервера.ПоместитьЭлементВХранилище(ПомещаемыйОбъект, АдресХранилища, ОчиститьСсылки);
```
</details>

## ПоместитьКопиюЭлементаВХранилище
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает данные переданной строки вида отчета во временное хранилище формы без ссылки элемента справочника.
// При записи такого элемента отчета будет сформирована новая ссылка т.о. помещаемый элемент будет скопирован.
//
// Параметры:
//  ПомещаемыйОбъект - Произвольный - помещаемый объект
//  АдресХранилища - Строка - адрес временного хранилища.
//
// Возвращаемое значение:
//   Строка - Адрес элемента в хранилище.
//
Функция ПоместитьКопиюЭлементаВХранилище(ПомещаемыйОбъект, АдресХранилища = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ФинансоваяОтчетностьВызовСервера.ПоместитьКопиюЭлементаВХранилище(ПомещаемыйОбъект, АдресХранилища);
```
</details>

## ДанныеЭлементаОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает данные элемента отчета
//
// Параметры:
// 	ЭлементОтчета - СправочникОбъект.ЭлементыФинансовыхОтчетов, Структура - Описание
// 	ЗначенияРеквизитов - Соответствие, Неопределено - Описание:
// * Ключ - СправочникСсылка.ЭлементыФинансовыхОтчетов -
// * Значение - см. ФинансоваяОтчетностьКлиентСервер.СтруктураЭлементаОтчета
// Возвращаемое значение:
// 	Структура, Неопределено, Произвольный - Описание:
// * ИсточникиЗначений - ТаблицаЗначений - описание:
// 		** Источник - СправочникСсылка.ЭлементыФинансовыхОтчетов, Строка - элемент или его адрес во временном хранилище.
// 		** ДобавляемыеЗначенияДокумента - Булево -
// * РасшифровкаПолейОтбораЭО - ТаблицаЗначений - описание:
// 		** ЭлементОтчета - СправочникСсылка.ЭлементыФинансовыхОтчетов, Строка - элемент или его адрес во временном хранилище.
// 		** КлючЭлементаОформления - УникальныйИдентификатор -
// 		** ИмяПоляОтбора - Строка -
// 		** ИмяРесурса - Строка -
// * ОформляемыеКолонки - ТаблицаЗначений - описание:
// 		** ЭлементОтчета - СправочникСсылка.ЭлементыФинансовыхОтчетов, Строка - элемент или его адрес во временном хранилище.
// 		** КлючЭлементаОформления - УникальныйИдентификатор -
// * ОформляемыеСтроки - ТаблицаЗначений - описание:
// 		** ЭлементОтчета - СправочникСсылка.ЭлементыФинансовыхОтчетов, Строка - элемент или его адрес во временном хранилище.
// 		** КлючЭлементаОформления - УникальныйИдентификатор -
// * ЭлементыОформления - ТаблицаЗначений - описание:
// 		** Оформление - ХранилищеЗначения -
// 		** Условие - ХранилищеЗначения -
// 		** ТипОформляемойОбласти - ПеречислениеСсылка.ТипыОформляемыхОбластейБюджетныхОтчетов -
// 		** КлючЭлементаОформления - УникальныйИдентификатор -
// * ДополнительныеПоля - ТаблицаЗначений - описание:
// 		** Реквизит - Строка -
// 		** Наименование - Строка -
// 		** ВыводитьЗаголовок - Булево -
// 		** ВОтдельнойКолонке - Булево -
// * ЭлементыТаблицы - ТаблицаЗначений -:
// 		** Строка - СправочникСсылка.ЭлементыФинансовыхОтчетов, Строка - элемент или его адрес во временном хранилище.
// 		** Колонка - СправочникСсылка.ЭлементыФинансовыхОтчетов, Строка - элемент или его адрес во временном хранилище.
// 		** Элемент - СправочникСсылка.ЭлементыФинансовыхОтчетов, Строка - элемент или его адрес во временном хранилище.
// * ОперандыФормулы - ТаблицаЗначений - описание:
// 		** Идентификатор - Строка -
// 		** Операнд - СправочникСсылка.ЭлементыФинансовыхОтчетов, Строка - элемент или его адрес во временном хранилище.
// * РеквизитыВидаЭлемента - ТаблицаЗначений - описание:
// 		** Реквизит - ПланВидовХарактеристикСсылка.РеквизитыЭлементовФинансовыхОтчетов -
// 		** Значение - Характеристика.РеквизитыЭлементовФинансовыхОтчетов -
// * СвязанныйЭлемент - СправочникСсылка.ЭлементыФинансовыхОтчетов, Строка - элемент или его адрес во временном хранилище.
// * ЗначениеАналитики -Характеристика.АналитикиСтатейБюджетов -
// * ЕстьНастройки - Булево -
// * ДополнительныйОтбор - ХранилищеЗначения -
// * Комментарий - Строка -
// * ОбратныйЗнак - Булево -
// * НаименованиеДляПечати - Строка -
// * ВидЭлемента - ПеречислениеСсылка.ВидыЭлементовФинансовогоОтчета -
// * Код - Число -
// * Наименование - Строка -
// * Владелец - СправочникСсылка.ВидыФинансовыхОтчетов, СправочникСсылка.ВидыБюджетов -
// * Ссылка - СправочникСсылка.ЭлементыФинансовыхОтчетов, Строка - элемент или его адрес во временном хранилище.
Функция ДанныеЭлементаОтчета(ЭлементОтчета, ЗначенияРеквизитов = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ФинансоваяОтчетностьВызовСервера.ДанныеЭлементаОтчета(ЭлементОтчета, ЗначенияРеквизитов);
```
</details>

## УстановитьЗначениеДополнительногоРеквизита
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает значение дополнительного реквизита элемента финансового отчета.
//
// Параметры:
//  Источник - Произвольный - объект или адрес структуры элемента в хранилище
//  Реквизит - Строка, ПланВидовХарактеристикСсылка.РеквизитыЭлементовФинансовыхОтчетов - имя реквизита
//  Значение - Произвольный - значение реквизита.
//
Процедура УстановитьЗначениеДополнительногоРеквизита(Источник, Знач Реквизит, Значение) Экспорт
```

Пример вызова
```bsl
ФинансоваяОтчетностьВызовСервера.УстановитьЗначениеДополнительногоРеквизита(Источник, Реквизит, Значение) 
```
</details>

## УстановитьЗначенияДополнительныхРеквизитов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает значение дополнительного реквизита элемента финансового отчета.
//
// Параметры:
//  Источник - Произвольный - объект или адрес структуры элемента в хранилище
//  Реквизиты - Структура - реквизиты для установки.
//
Процедура УстановитьЗначенияДополнительныхРеквизитов(Источник, Реквизиты) Экспорт
```

Пример вызова
```bsl
ФинансоваяОтчетностьВызовСервера.УстановитьЗначенияДополнительныхРеквизитов(Источник, Реквизиты) 
```
</details>

## УстановитьЗначениеРеквизита
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура устанавливает значение реквизита элемента финансового отчета в хранилище.
//
// Параметры:
//  АдресХранилища - Строка - адрес структуры элемента
//  СтруктураЗначений - Структура - реквизиты для установки.
//
Процедура УстановитьЗначениеРеквизита(АдресХранилища, СтруктураЗначений) Экспорт
```

Пример вызова
```bsl
ФинансоваяОтчетностьВызовСервера.УстановитьЗначениеРеквизита(АдресХранилища, СтруктураЗначений) 
```
</details>

## ЗначенияДополнительныхРеквизитов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает значения дополнительных реквизитов элемента финансового отчета.
//
// Параметры:
//  СсылкаНаЭлемент - СправочникОбъект.ЭлементыФинансовыхОтчетов, СправочникСсылка.ЭлементыФинансовыхОтчетов, Структура, Строка -
//                    объект или адрес структуры элемента в хранилище.
//  Реквизиты - Структура - реквизиты для получения.
//
// Возвращаемое значение:
//   Структура - значение дополнительного реквизита.
//
Функция ЗначенияДополнительныхРеквизитов(СсылкаНаЭлемент, Реквизиты) Экспорт
```

Пример вызова
```bsl
Результат = ФинансоваяОтчетностьВызовСервера.ЗначенияДополнительныхРеквизитов(СсылкаНаЭлемент, Реквизиты) 
```
</details>

## ЗначениеДополнительногоРеквизита
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает значение дополнительного реквизита элемента финансового отчета.
//
// Параметры:
//  СсылкаНаЭлемент - Произвольный - объект или адрес структуры элемента в хранилище
//  Реквизит - строка - реквизит для получения.
//
// Возвращаемое значение:
//   Произвольный   - значение дополнительного реквизита.
//
Функция ЗначениеДополнительногоРеквизита(СсылкаНаЭлемент, Реквизит) Экспорт
```

Пример вызова
```bsl
Результат = ФинансоваяОтчетностьВызовСервера.ЗначениеДополнительногоРеквизита(СсылкаНаЭлемент, Реквизит) 
```
</details>

## ПараметрыИспользованияФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция определяет имя формы элемента справочника для редактирования элемента финансового отчета.
//
// Параметры:
//  ВидЭлемента - ПеречислениеСсылка.ВидыЭлементовФинансовогоОтчета - вид элемента для которого необходимо определить форму
//  Элемент - Строка - адрес во временном хранилище по которому расположены все данные элемента
//  ДополнительныйРежим - ПеречислениеСсылка.ДополнительныеРежимыЭлементовОтчетов - признак дополнительного режима формы.
//  ОткрытиеФормыЭлементаБюджетногоОтчета - Булево - флаг открытия формы бюджетного отчета, заполняется только при отрытии формы.
//
// Возвращаемое значение:
//   Структура - Структура с параметрами:
//    *ИмяФормы - Строка - Имя формы справочника.
//    *Реквизиты - Структура - Структура реквизитов.
//
Функция ПараметрыИспользованияФормы(ВидЭлемента, Элемент, ДополнительныйРежим = Неопределено, ОткрытиеФормыЭлементаБюджетногоОтчета = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ФинансоваяОтчетностьВызовСервера.ПараметрыИспользованияФормы(ВидЭлемента, Элемент, ДополнительныйРежим, ОткрытиеФормыЭлементаБюджетногоОтчета);
```
</details>

## ПериодичностьСтрокой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает имя значения перечисления Периодичность
//
// Параметры:
// 	Периодичность - ПеречислениеСсылка.Периодичность - значение периодичности.
// 	              - Неопределено - если значение периодичности не задано.
//
// Возвращаемое значение:
// 	Строка - Имя перечисления перечисления периодичности,
// 	         пустая строка, если значение периодичности не задано.
//
Функция ПериодичностьСтрокой(Периодичность) Экспорт
```

Пример вызова
```bsl
Результат = ФинансоваяОтчетностьВызовСервера.ПериодичностьСтрокой(Периодичность) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
