---
title: Финансовая отчетность клиент сервер
slug: erp-uh/финансовая-отчетность-клиент-сервер
---


## ПеременныеФинансовыхОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру значений параметров для подстановки в текстовые поля, используемых в финансовых отчетах.
//
// Параметры:
//  ИсключаяСкобки - Булево - Если истина, то из имени и представления параметра будут исключены ограничивающие квадратные скобки.
//  		Значение по умолчанию Ложь.
//  КодЯзыка - Строка - Код языка. По умолчанию пустая строка - соответствует языку текущего пользователя.
//  		Задается при необходимости получения представления для конкретного языка, например, для основного языка конфигурации.
//
// Возвращаемое значение:
//  Структура - Структура параметров, используемых в финансовых отчетах:
//   * КомплектОтчетов - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     ** Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     ** Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   * ВидОтчета - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     ** Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     ** Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   * ТекущаяДатаИВремя - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     ** Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     ** Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   * ПериодОтчетности - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     ** Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     ** Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   * КонечнаяДатаПериодаОтчета - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     ** Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     ** Представление - Строка - Представление переменной, может заключаться в квадратные скобки.
//   * Организация - Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//     ** Имя - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//     ** Представление - Строка - Представление переменной, может заключаться в квадратные скобки./
//
Функция ПеременныеФинансовыхОтчетов(ИсключаяСкобки = Ложь, КодЯзыка = "") Экспорт
```

Пример вызова
```bsl
Результат = ФинансоваяОтчетностьКлиентСервер.ПеременныеФинансовыхОтчетов(ИсключаяСкобки, КодЯзыка);
```
</details>

## ОписаниеПеременной
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращаемое значение:
//  Структура - Структура, хранящая нелокализируемое хранимое в базе данных значение и локализируемое представление:
//  * Имя   - Строка - Идентификатор параметра. Не локализуется, хранится в базе данных. Например, "[ТекущаяДатаИВремя]".
//  * Представление - Строка - Представление параметра.
//
Функция ОписаниеПеременной(Имя = "", Представление = "") Экспорт
```

Пример вызова
```bsl
Результат = ФинансоваяОтчетностьКлиентСервер.ОписаниеПеременной(Имя, Представление);
```
</details>

## УпорядоченныеПеременныеФинансовыхОтчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает упорядоченный массив значений переменных для подстановки в текстовые поля, используемых в финансовых отчетах.
//
// Параметры:
//  КодЯзыка         - Строка       - Код языка. По умолчанию пустая строка - соответствует языку текущего пользователя.
//                                    Задается при необходимости получения представления для конкретного языка, например, для основного языка конфигурации.
//
// Возвращаемое значение:
//  Массив из см. НовыйСтруктураПеременнойФинансовыхОтчетов - Упорядоченный массив параметров,
//  используемых в финансовых отчетах для подстановки в текстовые поля.
//
Функция УпорядоченныеПеременныеФинансовыхОтчетов(КодЯзыка = "") Экспорт
```

Пример вызова
```bsl
Результат = ФинансоваяОтчетностьКлиентСервер.УпорядоченныеПеременныеФинансовыхОтчетов(КодЯзыка);
```
</details>

## СтрокиПериода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает строки периода по значению перечисления.
//
// Параметры:
// 	Период - ПеречислениеСсылка.Периодичность
// Возвращаемое значение:
// 	Структура - различные представления строка периода, содержит поля:
// 	 * Период - Строка - "Период" + период
// 	 * ВыражениеПериода - Строка - "ВыражениеПериода" + период
// 	 * ФлагПериод - Строка - "ФлагПериод" + период.
// 	 * ПериодОтчет - Строка - "Период" + период + "Отчет"
// 	 * ПериодСоединение - Строка - "Период" + период + "Соединение"
//
Функция СтрокиПериода(Период) Экспорт
```

Пример вызова
```bsl
Результат = ФинансоваяОтчетностьКлиентСервер.СтрокиПериода(Период) 
```
</details>

## ПериодичностьПоПериодуСтрокой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает периодичность по строковому выражению периода
//
// Параметры:
//  ПериодСтрока - строковое выражение периода ("ПериодДень", "ПериодНеделя", "ПериодМесяц" и др.)
//
// Возвращаемое значение:
//    Периодичность - значение перечисления Периодичность
//
Функция ПериодичностьПоПериодуСтрокой(ПериодСтрока) Экспорт
```

Пример вызова
```bsl
Результат = ФинансоваяОтчетностьКлиентСервер.ПериодичностьПоПериодуСтрокой(ПериодСтрока) 
```
</details>

## ИндексНовойСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//++ НЕ УТ

// Возвращает индекс новой строки с учетом наличия в коллекции элемента отчета "ИтогПоГруппе".
//
//	Параметры:
//		СтрокиДерева - ДанныеФормыКоллекцияЭлементовДерева - коллекция строк в которой необходимо определить индекс вставки новой строки.
//
//	Возвращаемое значение:
//		Число - индекс для вставки новой строки.
//
Функция ИндексНовойСтроки(СтрокиДерева) Экспорт
```

Пример вызова
```bsl
Результат = ФинансоваяОтчетностьКлиентСервер.ИндексНовойСтроки(СтрокиДерева) 
```
</details>

## ЗаполнитьСтрокуДерева
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет строку списка или дерева элементов отчета
// дополнительными реквизитами.
//
// Параметры:
//  Параметры - структура - поля структуры:
//		Источник - структура - источник заполнения
//		СтрокаПриемник - ДанныеФормыСтрокаДерева - строка, которую заполняем
//		АдресЭлементаВХранилище - строка - адрес хранилища элемента
//		Поле - ДанныеФормыКоллекция - для поиска строки, если приемник - идентификатор строки.
//
Процедура ЗаполнитьСтрокуДерева(Параметры) Экспорт
```

Пример вызова
```bsl
ФинансоваяОтчетностьКлиентСервер.ЗаполнитьСтрокуДерева(Параметры) 
```
</details>

## СтруктураЭлементаОтчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция возвращает структуру реквизитов для помещения во временное хранилище
//
// Возвращаемое значение:
// 	Структура - структура со свойствами:
// 	*ИсточникиЗначений - ТаблицаЗначений -:
// 	  **Источник - СправочникСсылка.ЭлементыФинансовыхОтчетов -
// 	  **ДобавляемыеЗначенияДокумента - Булево -
// 	*РасшифровкаПолейОтбораЭО - ТаблицаЗначений -:
// 	  **ЭлементОтчета - СправочникСсылка.ЭлементыФинансовыхОтчетов -
// 	  **КлючЭлементаОформления - УникальныйИдентификатор -
// 	  **ИмяПоляОтбора - Строка -
// 	  **ИмяРесурса - Строка -
// 	*ОформляемыеКолонки - ТаблицаЗначений -:
// 	  **ЭлементОтчета - СправочникСсылка.ЭлементыФинансовыхОтчетов -
// 	  **КлючЭлементаОформления - УникальныйИдентификатор -
// 	*ОформляемыеСтроки  - ТаблицаЗначений -:
// 	  **ЭлементОтчета - СправочникСсылка.ЭлементыФинансовыхОтчетов -
// 	  **КлючЭлементаОформления - УникальныйИдентификатор -
// 	*ЭлементыОформления - ТаблицаЗначений -:
// 	  **Оформление - ХранилищеЗначения -
// 	  **Условие - ХранилищеЗначения -
// 	  **ТипОформляемойОбласти - ПеречислениеСсылка.ТипыОформляемыхОбластейБюджетныхОтчетов -
// 	  **КлючЭлементаОформления - УникальныйИдентификатор -
// 	*ДополнительныеПоля - ТаблицаЗначений -:
// 	  **Реквизит - Строка -
// 	  **Наименование - Строка -
// 	  **ВыводитьЗаголовок - Булево -
// 	  **ВОтдельнойКолонке - Булево -
// 	*ЭлементыТаблицы - ТаблицаЗначений -:
// 	  **Строка - СправочникСсылка.ЭлементыФинансовыхОтчетов -
// 	  **Колонка - СправочникСсылка.ЭлементыФинансовыхОтчетов -
// 	  **Элемент - СправочникСсылка.ЭлементыФинансовыхОтчетов -
// 	*ОперандыФормулы - ТаблицаЗначений - таблица операндов формулы:
// 	  **Идентификатор - Строка -
// 	  **Операнд - СправочникСсылка.ЭлементыФинансовыхОтчетов -
// 	*РеквизитыВидаЭлемента - ТаблицаЗначений -:
// 	  **Реквизит - ПланВидовХарактеристикСсылка.РеквизитыЭлементовФинансовыхОтчетов -
// 	  **Значение - Характеристика.РеквизитыЭлементовФинансовыхОтчетов -
// 	*СвязанныйЭлемент - СправочникСсылка.ЭлементыФинансовыхОтчетов -
// 	*ЗначениеАналитики - Характеристика.АналитикиСтатейБюджетов -
// 	*ЕстьНастройки - Булево -
// 	*ДополнительныйОтбор - ХранилищеЗначения -
// 	*Комментарий - Строка -
// 	*ОбратныйЗнак - Булево -
// 	*НаименованиеДляПечати - Строка -
// 	*ВидЭлемента - ПеречислениеСсылка.ВидыЭлементовФинансовогоОтчета -
// 	*Код - Число -
// 	*Наименование - Неопределено -
// 	*Владелец - СправочникСсылка.ВидыБюджетов -
// 				- СправочникСсылка.ВидыФинансовыхОтчетов -
// 	*Ссылка - СправочникСсылка.ЭлементыФинансовыхОтчетов -
//  * Точность - Число -
//
Функция СтруктураЭлементаОтчета() Экспорт
```

Пример вызова
```bsl
Результат = ФинансоваяОтчетностьКлиентСервер.СтруктураЭлементаОтчета() 
```
</details>

## РодительСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//-- НЕ УТ

// Возвращает родителя переданной строки в зависимости от типа.
//
//	Параметры:
//		СтрокаДерева - ДанныеФормыЭлементДерева, СтрокаДереваЗначений - строка дерева элементов отчета.
//
//	Возвращаемое значение:
//		ДанныеФормыЭлементДерева - Родитель строки,
//		СтрокаДереваЗначений - Родитель строки.
//
Функция РодительСтроки(СтрокаДерева) Экспорт
```

Пример вызова
```bsl
Результат = ФинансоваяОтчетностьКлиентСервер.РодительСтроки(СтрокаДерева) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
