---
title: Финансовые инструменты
slug: erp-uh/финансовые-инструменты
---


## ЧИСТВНДОХ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вычисляет приблизительную годовую ставку IRR для графика платежей с произвольной периодичностью. Соответствует функции Excel ЧИСТВНДОХ.
// Вычисление производится методом Ньютона.
// IRR - внутренняя норма доходности, при которой инвестиции равны приведенной стоимости будущих поступлений, т.е. NPV = 0.
//
// Параметры:
//    Платежи - Массив из Число - Суммы платежей по графику. По крайней мере один платеж в графике должен быть положительный и один отрицательный.
//    Даты - Массив из Дата - Даты платежей. Индексы дат в массиве должны совпадать с соответствующими индексами сумм в массиве платежей.
//    Предположение - Число - Предполагаемая ставка (задается в виде числа: например, 0.25 соответствует 25%).
//                            Необязательный параметр, по умолчанию исходная ставка = 0.1.
//
// Возвращаемое значение:
//    Число, Неопределено - Ставка IRR. Если рассчитать ставку не удалось или входные данные некорректны, возвращается Неопределено.
//
Функция ЧИСТВНДОХ(Платежи, Даты, Предположение = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ФинансовыеИнструменты.ЧИСТВНДОХ(Платежи, Даты, Предположение);
```
</details>

## ЧПС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вычисляет значение NPV для графика платежей с одинаковой периодичностью. Соответствует функции Excel ЧПС.
// Платежи не должны включать первоначальную инвестицию, она вычитается из результата.
// Чистая приведенная стоимость (NPV) - сумма дисконтированных потоков платежей, приведенных к начальной дате.
//
// Параметры:
//    Ставка - Число - Ставка дисконтирования (задается в виде числа: например, 0.25 соответствует 25%).
//    Платежи - Массив из Число - Суммы платежей по графику.
//
// Возвращаемое значение:
//    Число - Значение NPV.
//
Функция ЧПС(Ставка, Платежи) Экспорт
```

Пример вызова
```bsl
Результат = ФинансовыеИнструменты.ЧПС(Ставка, Платежи) 
```
</details>

## ЧИСТНЗ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вычисляет значение NPV для графика платежей с произвольной периодичностью. Соответствует функции Excel ЧИСТНЗ.
// Платежи должны включать первоначальную инвестицию.
// Чистая приведенная стоимость (NPV) - сумма дисконтированных потоков платежей, приведенных к начальной дате.
//
// Параметры:
//    Ставка - Число - Ставка дисконтирования (задается в виде числа: например, 0.25 соответствует 25%).
//    Платежи - Массив из Число - Суммы платежей по графику.
//    Даты - Массив из Дата - Даты платежей. Индексы дат в массиве должны совпадать с соответствующими индексами сумм в массиве платежей.
//
// Возвращаемое значение:
//    Число - Значение NPV.
//
Функция ЧИСТНЗ(Ставка, Платежи, Даты) Экспорт
```

Пример вызова
```bsl
Результат = ФинансовыеИнструменты.ЧИСТНЗ(Ставка, Платежи, Даты) 
```
</details>

## ТекстЗапросаВтКоэффициентыПересчетаВалют
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует таблицу для пересчета сумму в валюты упр. и регл. учета.
//
// Параметры:
// 	ТекстыЗапроса - СписокЗначений -
// 	ИмяТаблицы - Строка -
// 	НесколькоОрганизаций - Булево - признак получения таблиц запросов для пересчета в валюту для нескольких организаций
//
Процедура ТекстЗапросаВтКоэффициентыПересчетаВалют( Экспорт
```

Пример вызова
```bsl
ФинансовыеИнструменты.ТекстЗапросаВтКоэффициентыПересчетаВалют();
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
