---
title: Финансовый учет по данным балансовых регистров
slug: erp-uh/финансовый-учет-по-данным-балансовых-регистров
---


## ПараметрыОтраженияДвиженийВФинансовомУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров отражения записей регистров накопления в финансовом учете.
// Если какой-либо параметр является выражением языка запросов, то описания полей в нем должны содержать
// псевдоним источника данных, переданный через параметр ПсевдонимИсточникаДанных. Если параметр является
// только именем поля, в том числе разыменованным через точку, его можно указывать без псевдонима источника данных.
//
// Параметры:
//  РегистрацияКОтражению - Булево - Признак получения параметров для регистрации к отражению в учете
//
// Возвращаемое значение:
// 	Структура - Описание:
//  * ИнверсияДвижений - Булево - Признак несоответствия движений регистра правилу Приход = Дебет, Расход = Кредит
//  * ПутьКДаннымОрганизация - Строка - Путь выборки значения организации из данных регистра
//  * ПутьКДаннымРегистратор - Строка - Путь выборки значения документа движения из данных регистра
//  * ПутьКДаннымИдентификаторФинЗаписи - Строка - Путь выборки значения идентификатора записи регистра
//  * ПутьКДаннымНастройкаХозОперации - Строка - Путь выборки значения настройки хозяйственной операции
//  * ПутьКДаннымНаправлениеДеятельности - Строка - Путь выборки значения направления деятельности из данных регистра
//  * ПутьКДаннымИдентификаторСтроки - Строка - Путь выборки значения идентификатора строки из данных регистра. Может быть переопределено в описании объектов бух.учета
//  * ПутьКДаннымВидДеятельностиНДС - Строка - Путь выборки значения вида деятельности по учету НДС из данных регистра
//  * ПутьКДаннымПодразделение - Строка - Путь выборки значения подразделения из данных регистра
//  * ПутьКДаннымВалюта - Строка - Путь выборки значения валюты из данных регистра, пустая строка если в регистре не ведется валютный учет
//  * ПутьКДаннымСторно - Строка - Путь выборки признака исправительной записи корректирующего документа
//  * ЭтоРегистрУчетаНДС - Булево - Признак учета входящего или исходящего НДС.
//  * РесурсыУпр - Массив из Строка - Массив строк с именами всех используемых ресурсов, хранящих сумму операции в валюте управленческого учета. Может быть переопределено в описании объектов бух.учета. Может быть пустым при отсутствии упр. учета в регистре
//  * РесурсыРегл - Массив из Строка - Массив строк с именами всех используемых ресурсов, хранящих сумму операции в валюте регламентированного учета. Может быть переопределено в описании объектов бух.учета. Может быть пустым при отсутствии регл. учета в регистре
//  * РесурсыВал - Массив из Строка - Массив строк с именами всех используемых ресурсов, хранящих валютную сумму операции, если в регистре ведется валютный учет. Может быть переопределено в описании объектов бух.учета. Может быть пустым при отсутствии вал. учета в регистре
//  * РесурсыКоличество - Массив из Строка - Массив строк с именами ресурсов, хранящих количество операции. Может быть пустым при отсутствии количественного учета в регистре
//  * УсловиеДебет - Строка - Условие на языке запросов для определения признака дебета движения в некоторых оборотных регистрах и остаточных регистрах со сложной логикой
//  * УсловиеКредит - Строка - Условие на языке запросов для определения признака кредита движения в некоторых оборотных регистрах и остаточных регистрах со сложной логикой
//  * ДополнительныйОтбор - Строка - Условие на языке запросов для дополнительного отбора данных регистра.
//  * ПсевдонимИсточникаДанных - Строка - псевдоним источника данных, используемый в параметрах, являющимися выражениями языка запросов.
//
Функция ПараметрыОтраженияДвиженийВФинансовомУчете(РегистрацияКОтражению = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ФинансовыйУчетПоДаннымБалансовыхРегистров.ПараметрыОтраженияДвиженийВФинансовомУчете(РегистрацияКОтражению);
```
</details>

## ЗаполнитьПараметрыОтраженияПоМетаданнымРегистра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет параметры отражения движений в фин.учете по метаданным регистра накопления
//
// Параметры:
//  ПараметрыОтражения - см. ПараметрыОтраженияДвиженийВФинансовомУчете
//  МетаданныеРегистра - ОбъектМетаданныхРегистрНакопления - Метаданные регистра накопления
//	НедоступныеПоля - Массив - Массив имен полей, которые не доступны в качестве источников заполнения субконто
//
Процедура ЗаполнитьПараметрыОтраженияПоМетаданнымРегистра(ПараметрыОтражения, МетаданныеРегистра, НедоступныеПоля = Неопределено) Экспорт
```

Пример вызова
```bsl
ФинансовыйУчетПоДаннымБалансовыхРегистров.ЗаполнитьПараметрыОтраженияПоМетаданнымРегистра(ПараметрыОтражения, МетаданныеРегистра, НедоступныеПоля);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
