---
title: Форматно логический контроль переопределяемый
slug: erp-uh/форматно-логический-контроль-переопределяемый
---


## ПровестиФорматноЛогическийКонтроль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция переопределяет типовой форматно-логический контроль чека.
// Параметры:
//   ОбщиеПараметры - Структура - структура, полученная ранее методом ОборудованиеЧекопечатающиеУстройстваКлиентСервер.ПараметрыОперацииФискализацииЧека,
//                    и заполненная данными чека.
//                    Содержит параметры для контроля:
//                      СпособФорматноЛогическогоКонтроля - ПеречислениеСсылка.СпособыФорматноЛогическогоКонтроля - если не заполнена, то контроль не выполняется,
//                      ДопустимоеРасхождениеФорматноЛогическогоКонтроля - Число - по умолчанию установленное 54-ФЗ отклонение - 0.01.
//   СтандартнаяОбработка - Булево - Если присваивается значение Ложь, то стандартный контроль выполняться не будет.
//   ПодключаемоеОборудование - СправочникСсылка.ПодключаемоеОборудование - Не обязательный.
//                              Если заполнено оборудование и не заполнен способ контроля в общих параметрах,
//                              то способ контроля и допустимое расхождение можно получать из подключаемого оборудования.
Процедура ПровестиФорматноЛогическийКонтроль(ОбщиеПараметры, СтандартнаяОбработка, ПодключаемоеОборудование = Неопределено) Экспорт
```

Пример вызова
```bsl
ФорматноЛогическийКонтрольПереопределяемый.ПровестиФорматноЛогическийКонтроль(ОбщиеПараметры, СтандартнаяОбработка, ПодключаемоеОборудование);
```
</details>

## РазделитьФискальнуюСтроку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция выполняет разделение фискальной строки.
//
// Параметры:
//  ТекущаяПозиция - Структура
//  НовыеПозицииЧека - Массив
//  РасчетнаяЦена - Число
//  РазницаСумм - Число
//  СтандартнаяОбработка - Булево - выполнять стандартное разделение фискальной строки
//
Процедура РазделитьФискальнуюСтроку(ТекущаяПозиция, НовыеПозицииЧека, РасчетнаяЦена, РазницаСумм, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ФорматноЛогическийКонтрольПереопределяемый.РазделитьФискальнуюСтроку(ТекущаяПозиция, НовыеПозицииЧека, РасчетнаяЦена, РазницаСумм, СтандартнаяОбработка) 
```
</details>

## НуженФорматноЛогическийКонтроль
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция выполняет проверку необходимости форматно-логического контроля.
//
// Параметры:
//  ОбщиеПараметры - Структура
//  СтандартнаяОбработка - Булево - выполнять стандартную обработку
//
// Возвращаемое значение:
//  Булево.
Функция НуженФорматноЛогическийКонтроль(ОбщиеПараметры, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
Результат = ФорматноЛогическийКонтрольПереопределяемый.НуженФорматноЛогическийКонтроль(ОбщиеПараметры, СтандартнаяОбработка) 
```
</details>

## ПолучитьСтруктуруДанныхФорматноЛогическогоКонтроля
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция получает структуру данных форматно-логического контроля.
//
// Параметры:
//  ПодключаемоеОборудование - СправочникСсылка.ПодключаемоеОборудование - Устройство, фискализирующее чек
//  СтруктураДанныхФорматноЛогическогоКонтроля - Структура - Структура данных форматно логического контроля:
//    * СпособФорматноЛогическогоКонтроля - Неопределено -
//    * ДопустимоеРасхождениеФорматноЛогическогоКонтроля - Число -
//    * ФорматФД - Строка -
//    * ФорматФД - Строка, Произвольный -
//  СтандартнаяОбработка - Булево - выполнять стандартную обработку
//
// Возвращаемое значение:
//  Булево.
Функция ПолучитьСтруктуруДанныхФорматноЛогическогоКонтроля(ПодключаемоеОборудование, СтруктураДанныхФорматноЛогическогоКонтроля, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
Результат = ФорматноЛогическийКонтрольПереопределяемый.ПолучитьСтруктуруДанныхФорматноЛогическогоКонтроля(ПодключаемоеОборудование, СтруктураДанныхФорматноЛогическогоКонтроля, СтандартнаяОбработка) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
