---
title: Ценообразование клиент сервер
slug: erp-uh/ценообразование-клиент-сервер
---


## РассчитатьСуммуНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает сумму НДС от суммы в зависимости от включения НДС в цену.
//
// Параметры:
//  Сумма           - Число - Сумма, от которой необходимо рассчитать сумму НДС.
//  СтавкаНДС       - СправочникСсылка.СтавкиНДС - Ставка НДС.
//  ЦенаВключаетНДС - Булево - Признак включения НДС в цену.
//  НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС - налогообложение документа
//
// Возвращаемое значение:
//  Число - Сумма НДС.
//
Функция РассчитатьСуммуНДС(Сумма, СтавкаНДС, ЦенаВключаетНДС = Истина, НалогообложениеНДС = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЦенообразованиеКлиентСервер.РассчитатьСуммуНДС(Сумма, СтавкаНДС, ЦенаВключаетНДС, НалогообложениеНДС);
```
</details>

## ПолучитьСтавкуНДСЧислом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает числовое значение ставки НДС
//
// Параметры:
//  СтавкаНДС - СправочникСсылка.СтавкиНДС - значение СтавкиНДС.
//
// Возвращаемое значение:
//  Число - Значение ставки НДС числом.
//
Функция ПолучитьСтавкуНДСЧислом(Знач СтавкаНДС) Экспорт
```

Пример вызова
```bsl
Результат = ЦенообразованиеКлиентСервер.ПолучитьСтавкуНДСЧислом(СтавкаНДС) 
```
</details>

## ПолучитьСуммуДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сумму документа с учетом НДС
//
// Параметры:
//  Товары          - ТабличнаяЧасть - табличная часть документа для подсчета суммы документа.
//  ЦенаВключаетНДС - Булево - признак включения НДС в цену документа.
//
// Возвращаемое значение:
//  Число - Сумма документа с учетом НДС/.
//
Функция ПолучитьСуммуДокумента(Товары, Знач ЦенаВключаетНДС) Экспорт
```

Пример вызова
```bsl
Результат = ЦенообразованиеКлиентСервер.ПолучитьСуммуДокумента(Товары, ЦенаВключаетНДС) 
```
</details>

## ОкруглитьЦену
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Округляет число по заданному порядку
//
// Параметры:
//  Число              - Число - исходное число.
//  ТочностьОкругления - Число - Число, определяет точность округления.
//  ВариантОкругления  - ПеречислениеСсылка.ВариантыОкругления - определяет способ округления.
//
// Возвращаемое значение:
//  Число - исходное число, округленное с заданной точностью.
//
Функция ОкруглитьЦену(Число, ТочностьОкругления, ВариантОкругления) Экспорт
```

Пример вызова
```bsl
Результат = ЦенообразованиеКлиентСервер.ОкруглитьЦену(Число, ТочностьОкругления, ВариантОкругления) 
```
</details>

## ПрименитьПсихологическоеОкругление
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Применяет "психологическое округление" к числу
//
// Параметры:
//  Число                     - Число - число, к которому применяется округление.
//  ПсихологическоеОкругление - Число - число, значение "психологического округления".
//
// Возвращаемое значение:
//  Число - Результат применения "психологического округления" к числу.
//
Функция ПрименитьПсихологическоеОкругление(Число, ПсихологическоеОкругление) Экспорт
```

Пример вызова
```bsl
Результат = ЦенообразованиеКлиентСервер.ПрименитьПсихологическоеОкругление(Число, ПсихологическоеОкругление) 
```
</details>

## ТекстЗапросаРегистрСведенийЦеныНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Текст запроса регистр сведений цены номенклатуры.
//
// Параметры:
//  ИсточникТоваров - Строка - название таблицы с товарами
//  ПараметрДата - Строка - название параметра Дата
//  УсловиеВидЦены - Неопределено, Структура - условие по виду цен
//  ИспользуетсяЦенообразование25 - Неопределено, Булево - Используется ценообразование 2.5
//
// Возвращаемое значение:
//  Строка - Текст запроса регистр сведений цены номенклатуры
Функция ТекстЗапросаРегистрСведенийЦеныНоменклатуры(ИсточникТоваров, Экспорт
```

Пример вызова
```bsl
Результат = ЦенообразованиеКлиентСервер.ТекстЗапросаРегистрСведенийЦеныНоменклатуры(ИсточникТоваров, );
```
</details>

## ТекстЗапросаРегистрСведенийЦеныНоменклатурыУсловиеСоединения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Текст запроса регистр сведений цены номенклатуры условие соединения.
//
// Параметры:
//  ИсточникТоваров - Строка - название таблицы с товарами
//  ИсточникЦен - Строка - название таблицы с ценами
//  ИсточникВидовЦен - Строка, Неопределено - значение, если необходимо в соединение соединять по виду цен
//  ИспользуетсяЦенообразование25 - Неопределено, Булево - Используется ценообразование 2.5
//
// Возвращаемое значение:
//  Строка - Текст запроса регистр сведений цены номенклатуры условие соединения
Функция ТекстЗапросаРегистрСведенийЦеныНоменклатурыУсловиеСоединения(ИсточникТоваров, Экспорт
```

Пример вызова
```bsl
Результат = ЦенообразованиеКлиентСервер.ТекстЗапросаРегистрСведенийЦеныНоменклатурыУсловиеСоединения(ИсточникТоваров, );
```
</details>

## ТекстЗапросаВременнойТаблицыСДополнениемДляЦенообразования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Текст запроса временной таблицы с дополнением для ценообразования.
//
// Параметры:
//  Настройки - см. НастройкиДляВременнойТаблицыСДополнениемДляЦенообразования
//  ИспользуетсяЦенообразование25 - Неопределено - Используется ценообразование 2.5
//
// Возвращаемое значение:
//  Строка - Текст запроса временной таблицы с дополнением для ценообразования
Функция ТекстЗапросаВременнойТаблицыСДополнениемДляЦенообразования(Настройки, Экспорт
```

Пример вызова
```bsl
Результат = ЦенообразованиеКлиентСервер.ТекстЗапросаВременнойТаблицыСДополнениемДляЦенообразования(Настройки, );
```
</details>

## ТекстПолейДляЦенообразования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Текст полей для ценообразования.
//
// Параметры:
//  Настройки - Структура - Настройки:
// * ИсточникТоваров - Строка -
// * ПриемникТоваров - Строка -
// * ПолеНоменклатура - Строка -
// * ПолеХарактеристика - Строка -
// * ПолеСерия - Строка -
// * ПолеУпаковка - Строка -
// * СписокПрочихПолей - Строка -
// ДляПолейГруппировки  - Булево - Истина, для полоей группировки, не присваивать синонимы
//  ИспользуетсяЦенообразование25 - Неопределено - Используется ценообразование 2.5
//
// Возвращаемое значение:
//  Строка - Текст полей для ценообразования
Функция ТекстПолейДляЦенообразования(Настройки, Экспорт
```

Пример вызова
```bsl
Результат = ЦенообразованиеКлиентСервер.ТекстПолейДляЦенообразования(Настройки, );
```
</details>

## НастройкиДляВременнойТаблицыСДополнениемДляЦенообразования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Настройки для временной таблицы с дополнением для ценообразования.
//
// Возвращаемое значение:
//  Структура - Настройки для временной таблицы с дополнением для ценообразования:
// * ИсточникТоваров - Строка - Наименования таблицы истоника товаров
// * ПриемникТоваров - Строка - Наименования таблицы приемника товаров
// * ПолеНоменклатура - Строка - Наименование поля номенклатуры. Если нет необходимо присвоить путую строку
// * ПолеХарактеристика - Строка - Наименование поля характеристики. Если нет необходимо присвоить путую строку
// * ПолеСерия - Строка - Наименование поля серии. Если нет необходимо присвоить путую строку
// * ПолеУпаковка - Строка - Наименование поля упаковки. Если нет необходимо присвоить путую строку
// * СписокПрочихПолей - Строка - все остальные поля источника товаров через запятую
//
Функция НастройкиДляВременнойТаблицыСДополнениемДляЦенообразования() Экспорт
```

Пример вызова
```bsl
Результат = ЦенообразованиеКлиентСервер.НастройкиДляВременнойТаблицыСДополнениемДляЦенообразования() 
```
</details>

## ТекстЗапросаРегистрСведенийЦеныНоменклатурыИндексирование
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Текст запроса регистр сведений цены номенклатуры индексирование.
//
// Параметры:
//  ИспользуетсяЦенообразование25 - Неопределено, Булево - Используется ценообразование 2.5
//
// Возвращаемое значение:
//  Строка - Текст запроса регистр сведений цены номенклатуры индексирование
Функция ТекстЗапросаРегистрСведенийЦеныНоменклатурыИндексирование(ИспользуетсяЦенообразование25 = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЦенообразованиеКлиентСервер.ТекстЗапросаРегистрСведенийЦеныНоменклатурыИндексирование(ИспользуетсяЦенообразование25);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
