---
title: Централизованные закупки клиент сервер УХ
slug: erp-uh/централизованные-закупки-клиент-сервер-ух
---


## ЗаполнитьКроссТаблицуИзТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Преобразование Таблицы в Кросс-таблицу с переносом значений реквизитов периода в колонки кросс-таблицы.
//
// Параметры:
//  КроссТаблица - ДанныеФормы.Коллекция - Кросс-таблица в форме
//  Таблица      - ДанныеФормы.Коллекция - Табличная часть объекта
//  Параметры    - Структура - Дополнительные настройки, передаваемые в процедуру:
//                            ТаблицаПериоды, Периодичность, СтруктураРеквизитовПериода, СтруктураРеквизитов,
//                            ПоляГруппировки
//
Процедура ЗаполнитьКроссТаблицуИзТаблицы(КроссТаблица, Таблица, Параметры) Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ЗаполнитьКроссТаблицуИзТаблицы(КроссТаблица, Таблица, Параметры) 
```
</details>

## ЗаполнитьТаблицуИзКроссТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполнить таблицу из кросс-таблицы с переносом значений из колонок
//  кросс-таблицы в реквизиты таблицы.
//
// Параметры:
//  КроссТаблица         - ДанныеФормы.Коллекция - Кросс-таблица в форме
//  Таблица              - ДанныеФормы.Коллекция - Табличная часть объекта
//  Параметры            - Структура - Дополнительные настройки, передаваемые в процедуру:
//                                     ТаблицаПериоды, СтруктураРеквизитовПериода, СтруктураРеквизитов
//  СтруктураДействий    - Структура - Структура действий, выполняемых со строками ТЧ.
//  ЗаменаИменРеквизитов - Структура, Соответствие - {Имя реквизита типового объекта:
//													  Имя реквизита в переданном объекте}.
//
Процедура ЗаполнитьТаблицуИзКроссТаблицы( Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ЗаполнитьТаблицуИзКроссТаблицы();
```
</details>

## ПодготовитьЗаполнитьТаблицуИзКроссТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Записать кросс-таблицу в переданную таблицу значений
// или табличную часть. Не учитывает НДС. Заполняет
// вертикальные колонки кросс-таблицы: Период, Количество и Сумма.
// Остальные беруться как аналитики строк.
//
// Параметры:
//  КроссТаблица - ТаблицаЗначений - таблица с колонками
//		Количество и Сумма по каждому периоду из ТаблицаПериодов.
//  ПлоскаяТаблица - ТабличнаяЧасть | ТаблицаЗначений - таблица
//		для заполнения. Перед заполнением очищается.
//  ТаблицаПериодов - ТаблицаЗначений - периоды кросс-таблицы.
//	ЦенаВключаетНДС - Булево - значение реквизита документа.
//
Процедура ПодготовитьЗаполнитьТаблицуИзКроссТаблицы( Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ПодготовитьЗаполнитьТаблицуИзКроссТаблицы();
```
</details>

## РассчитатьНомерСтрокиКроссТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура рассчитывает добавленное поле "Номер строки" для кросс-таблицы
//
// Параметры:
//  Форма                    - УправляемаяФорма - Форма в которой есть кросс-таблица
//  ИмяРеквизитаКроссТаблицы - Строка - Имя кросс-таблицы в форме
//
Процедура РассчитатьНомерСтрокиКроссТаблицы(Форма, Знач ИмяРеквизитаКроссТаблицы) Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.РассчитатьНомерСтрокиКроссТаблицы(Форма, ИмяРеквизитаКроссТаблицы) 
```
</details>

## ОбработатьСтрокуТЧ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработать строку кросс-таблицы номенклатуры по указанным действиям.
// Может делать серверный(е) вызов(ы).
//
// Параметры:
//  Объект - любой объект 1С с возможностью получать значения реквизитов
//				- объект в контексте которого производятся действия
//				  над строкой кросс-таблицы.
//  ТекущаяСтрока - ДанныеФормыЭлементКоллекции,
//					СтрокаТаблицыЗначений,
//					СтрокаТабличнойЧасти - строка кросс-таблицы номенклатуры.
//  ТаблицаПериодов - ДанныеФормыКоллекция,
//					  ТаблицаЗначений - таблица с описанием периодов кросс-таблицы.
//  СтруктураДействий - Структура - действия, которые необходимо выполнить
//				в контексте строки кросс-таблицы номенклатуры.
//  ЗаменаИменРеквизитов - Структура, Соответствие -
//				{Имя реквизита типового объекта:
//				 Имя реквизита в переданном объекте}.
//
Процедура ОбработатьСтрокуТЧ(Объект, Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ОбработатьСтрокуТЧ(Объект, );
```
</details>

## ЧтоПолучитьНаСервере
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет по набору действий со строкой кросс-таблицы номенклатуры
// какие данные нужно получить на сервере.
//
// Параметры:
//  Объект - Любой объект 1С с возможностью получать значения реквизитов
//				- объект в контексте которого производятся действия
//				  над строкой кросс-таблицы.
//  ТекущаяСтрока - ДанныеФормыЭлементКоллекции,
//					СтрокаТаблицыЗначений,
//					СтрокаТабличнойЧасти - строка кросс-таблицы номенклатуры.
//  СтруктураДействий - Структура - действия, которые необходимо выполнить
//				в контексте строки кросс-таблицы номенклатуры.
//  ЗаменаИменРеквизитов - Структура, Соответствие -
//				{Имя реквизита типового объекта:
//				 Имя реквизита в переданном объекте}.
//
// Возвращаемое значение:
//  Описание данных для получения функцией
//	ЦентрализованныеЗакупкиВызовСервераУХ.ПолучитьДанныеНаСервере().
//
Функция ЧтоПолучитьНаСервере(Объект, Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ЧтоПолучитьНаСервере(Объект, );
```
</details>

## ПолучитьДатуКурсаПланаЗакупок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьДатуКурсаПланаЗакупок(Объект, ЗаменаИменРеквизитов, ИмяРеквизитаДаты="ДатаОкончания") Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПолучитьДатуКурсаПланаЗакупок(Объект, ЗаменаИменРеквизитов, ИмяРеквизитаДаты);
```
</details>

## ПолучитьДатуСтавкиНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьДатуСтавкиНДС(Объект, ЗаменаИменРеквизитов, ИмяРеквизитаДаты="ДатаОкончания") Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПолучитьДатуСтавкиНДС(Объект, ЗаменаИменРеквизитов, ИмяРеквизитаДаты);
```
</details>

## ПолучитьЗначениеРеквизитаОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение реквизита объекта с учетом правил замены
// имен реквизитов.
//
Функция ПолучитьЗначениеРеквизитаОбъекта(Объект, Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПолучитьЗначениеРеквизитаОбъекта(Объект, );
```
</details>

## ПересчитатьИтоговыеПоказателиКроссТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пересчитывает итоговые поля (Количество, Сумма, Цена, СуммаНДС) строк кросс-таблицы
Процедура ПересчитатьИтоговыеПоказателиКроссТаблицы( Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ПересчитатьИтоговыеПоказателиКроссТаблицы();
```
</details>

## ОбнулитьКоличествоСтрокиКроссТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обнуляет значение количества для указанной строки кросс-таблицы.
//
Процедура ОбнулитьКоличествоСтрокиКроссТаблицы(ПериодыЗакупок, Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ОбнулитьКоличествоСтрокиКроссТаблицы(ПериодыЗакупок, );
```
</details>

## ОбработатьИзменениеЦеныКроссТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбработатьИзменениеЦеныКроссТаблицы(ЦенаВключаетНДС, Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ОбработатьИзменениеЦеныКроссТаблицы(ЦенаВключаетНДС, );
```
</details>

## ПриИзмененииКоличестваСуммыСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПриИзмененииКоличестваСуммыСтроки(ЦенаВключаетНДС, Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ПриИзмененииКоличестваСуммыСтроки(ЦенаВключаетНДС, );
```
</details>

## РассчитатьИтогКоличестваСуммыСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РассчитатьИтогКоличестваСуммыСтроки(ПериодыЗакупок, Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.РассчитатьИтогКоличестваСуммыСтроки(ПериодыЗакупок, );
```
</details>

## ЗаполнитьСуммуНДСТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет реквизит СуммаНДС и СуммаСНДС на основании
//  реквизита Сумма и СтавкаНДС.
//
// Параметры:
//  ТаблицаНоменклатуры	 - ТабличнаяЧасть | ТаблицаЗначений
//		- таблица для обновления сумм НДС.
//  ЦенаВключаетНДС - Булево - способ расчета НДС по полю Сумма.
//
Процедура ЗаполнитьСуммуНДСТаблицы(ТаблицаНоменклатуры, СуммаВключаетНДС) Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ЗаполнитьСуммуНДСТаблицы(ТаблицаНоменклатуры, СуммаВключаетНДС) 
```
</details>

## УстановитьЦенуПоПериодамСтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УстановитьЦенуПоПериодамСтроки(ПериодыЗакупок, СтрокаТаблицы, Цена) Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.УстановитьЦенуПоПериодамСтроки(ПериодыЗакупок, СтрокаТаблицы, Цена) 
```
</details>

## ПересчитатьСуммуСтрокиПоЦене
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПересчитатьСуммуСтрокиПоЦене(ПериодыЗакупок, Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ПересчитатьСуммуСтрокиПоЦене(ПериодыЗакупок, );
```
</details>

## ПересчитатьСуммуСтрокиКолонкиОтЦеныИКоличества
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПересчитатьСуммуСтрокиКолонкиОтЦеныИКоличества( Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ПересчитатьСуммуСтрокиКолонкиОтЦеныИКоличества();
```
</details>

## РасчитатьСуммыПоНДССтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет СуммуНДС, Сумму и если есть, СуммуСНДС
Процедура РасчитатьСуммыПоНДССтроки(СтрокаТаблицы, СуммаВключаетНДС, ЕстьСуммаСНДС) Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.РасчитатьСуммыПоНДССтроки(СтрокаТаблицы, СуммаВключаетНДС, ЕстьСуммаСНДС) 
```
</details>

## ОбновитьСуммуПоНДССтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет Сумму при изменении ставки НДС строки.
Процедура ОбновитьСуммуПоНДССтроки(СтрокаТаблицы, СуммаВключаетНДС) Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ОбновитьСуммуПоНДССтроки(СтрокаТаблицы, СуммаВключаетНДС) 
```
</details>

## ОбновитьСуммуСНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обновляет колонку "СуммаСНДС" таблицы.
//
Процедура ОбновитьСуммуСНДС(ЦенаВключаетНДС, ТаблицаНоменклатуры) Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ОбновитьСуммуСНДС(ЦенаВключаетНДС, ТаблицаНоменклатуры) 
```
</details>

## РасчитатьНДССтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РасчитатьНДССтроки(ЦенаВключаетНДС, СтрокаТаблицы) Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.РасчитатьНДССтроки(ЦенаВключаетНДС, СтрокаТаблицы) 
```
</details>

## ОбновитьСуммуСНДССтроки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьСуммуСНДССтроки(ЦенаВключаетНДС, СтрокаТаблицы) Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ОбновитьСуммуСНДССтроки(ЦенаВключаетНДС, СтрокаТаблицы) 
```
</details>

## ЕстьРеквизитТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЕстьРеквизитТаблицы(Таблица, ИмяРеквизита) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ЕстьРеквизитТаблицы(Таблица, ИмяРеквизита) 
```
</details>

## ПроверитьЗаполнитьГраницыПериодаКроссТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Если какой-либо из переданных периодов не заполнен,
// то в переданной таблице значений или табличной
// части ищет по колонке ИмяРеквизитаПериода
// периоды с минимальной и максимальной датой начала
// и устанавливает их как значение ПериодНачала,
// ПериодОкончания начала и конца (если соотвествующее
// значение не заполнено).
Процедура ПроверитьЗаполнитьГраницыПериодаКроссТаблицы( Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ПроверитьЗаполнитьГраницыПериодаКроссТаблицы();
```
</details>

## ПолучитьГраницыПериодаКроссТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру с двумя датами: Начало и Окончание.
// С минимальной и максимальной датой начала периода соответственно
// Периоды читаем из реквизита ИмяРеквизитаПериода таблицы.
//
Функция ПолучитьГраницыПериодаКроссТаблицы(ТаблицаСПериодами, Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПолучитьГраницыПериодаКроссТаблицы(ТаблицаСПериодами, );
```
</details>

## ПолучитьОписаниеКолонкиКроссТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция - Получить описание колонки кросс таблицы
//
// Параметры:
//  ИмяКолонки - Строка - имя колонки в формате ИмяПоля_УИДПериода,
//		где ИмяПоля - это Количество, Цена или Сумма с любым
//					  префиксом перед ними (например,
//					  "ПотребностиВНоменклатуреПоПериодамКоличество");
//			УИДПериода - это идентификатор периода кросс таблицы.
//
// Возвращаемое значение:
//  Структура{ВидРесурса, УИДПериода} - если удалось разложить имя
//		на составляющие. ВидРесурса может принимать значения:
//		Количество, Цена или Сумма.
//	Неопределено - если не удалось разделить строку или оперделить
//		имя ресурса.
//
Функция ПолучитьОписаниеКолонкиКроссТаблицы(ИмяКолонки) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПолучитьОписаниеКолонкиКроссТаблицы(ИмяКолонки) 
```
</details>

## ОпределитьИмяРесурсаВИмениПоля
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Пытается найти имена "Количество", "Цена", "Сумма"
// в конце имени поля.
//
// Параметры:
//  ИмяПоля - Строка - имя колонки кросс-таблицы без УИД периода.
//
// Возвращаемое значение:
//	Строка - нейденное имя ресурса.
//	Неопределено - не удалось найти имя ресурса.
//
Функция ОпределитьИмяРесурсаВИмениПоля(ИмяПоля) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ОпределитьИмяРесурсаВИмениПоля(ИмяПоля) 
```
</details>

## ЕстьИмяРесурсаВСтроке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция - Найти имя ресурса в конце строки.
//
// Параметры:
//  Стр	- Строка - в ее конце пытаемся найти имя ресурса.
//  ИмяРесурса - Строка - имя для поиска.
//
// Возвращаемое значение:
//   Булево - имя найдено или нет.
//
Функция ЕстьИмяРесурсаВСтроке(Стр, ИмяРесурса) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ЕстьИмяРесурсаВСтроке(Стр, ИмяРесурса) 
```
</details>

## ХарактеристикиЗаполненыКорректно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет заполнение характеристик, если они необходимы.
//
// Параметры:
//  ТаблицаПотребностей - ДанныеФормыКоллекция - кросс-таблица потребностей.
//  ИмяЭлементаФормыТаблицыПотребностей - Строка - имя элемента формы
//		представляющего кросс-таблицу. Необходим для формирования ошибки.
//  ИмяПоляХарактеристик - Строка - имя поля содержащего характеристику.
//  ИмяПоляИспользованияХарактеристик - Строка - имя поля с реквизитом типа
//		Булево для отслеживания необходимости заполнения характеристики.
//  ОшибкиПользователю - Структура - внешняя переменная, которая будет
//		содержать описания ошибок в виде пригодном для функции
//		ОбщегоНазначенияКлиентСервер.СообщитьОшибкиПользователю().
//
// Возвращаемое значение:
//   - Булево - Истина - все характеристики заполнены корректно.
//				Ложь - есть ошибки, ОшибкиПользователю
//				в этом случае содержат описание ошибок.
//
Функция ХарактеристикиЗаполненыКорректно(ТаблицаПотребностей, Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ХарактеристикиЗаполненыКорректно(ТаблицаПотребностей, );
```
</details>

## ПроверитьЗаполнениеПолейКроссТаблицы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет поля на заполненность, и формирует сообщения об ошибках.
//
// Параметры:
//  ТаблицаПотребностей - ДанныеФормыКоллекция - кросс-таблица потребностей.
//  СтруктураИменаПолей - Структура - имена полей для проверки, с их
//		представлением для формирования ошибки.
//  ОшибкиПользователю - Структура - внешняя переменная, которая будет
//		содержать описания ошибок в виде пригодном для функции
//		ОбщегоНазначенияКлиентСервер.СообщитьОшибкиПользователю().
//
Процедура ПроверитьЗаполнениеПолейКроссТаблицы(ТаблицаПотребностей, Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ПроверитьЗаполнениеПолейКроссТаблицы(ТаблицаПотребностей, );
```
</details>

## ОбновитьВерсиюДляЕИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьВерсиюДляЕИС(Ссылка, Форма) Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ОбновитьВерсиюДляЕИС(Ссылка, Форма) 
```
</details>

## ТребуетсяОбоснованиеНМЦДляТаблицыНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Проверить, что значение флага ТребуетсяОбоснованиеНМЦ установлено
// в любой строке таблицы Номенклатура документа СтрокаПланаЗакупок.
//  Вынесено для доступа из объекта и формы.
//
// Параметры:
//  ТаблицаНоменклатуры	- Объект с функцией НайтиСтроки(Структура) -
//		таблица номенклатуры с реквизитом "ТребуетсяОбоснованиеНМЦ".
//
// Возвращаемое значение:
//   -
//
Функция ТребуетсяОбоснованиеНМЦДляТаблицыНоменклатуры(ТаблицаНоменклатуры) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ТребуетсяОбоснованиеНМЦДляТаблицыНоменклатуры(ТаблицаНоменклатуры) 
```
</details>

## ПредставлениеПотребности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строковое представление потребности.
//
// Параметры:
//  СтруктураПотребности - Любой объект с [], для чтения
//			значений реквизитов потребности.
//  РазделительКлючЗначение - Строка - разделитель имени реквизита
//			и его значения.
//  РазделительРеквизитов - Строка - разделитель реквизитов.
//
// Возвращаемое значение:
//   - Строка - представление потребности в понятном для пользователя виде.
//
Функция ПредставлениеПотребности(СтруктураПотребности, Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПредставлениеПотребности(СтруктураПотребности, );
```
</details>

## НайтиЗначениеВКэше
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Найти в кэше значение. Если его нет, то возвращает Неопределено.
//
// Параметры:
//  Кэш		 - Соответствие	 - для быстрого получения значения по набору параметров.
//  Параметры	 - Массив	 - набор значений для последовательного поиска
//								во вложенных соответствиях.
//
// Возвращаемое значение:
//   - Неопределено - нет цены для указанных параметров.
//	 - значение - цена найдена.
//
Функция НайтиЗначениеВКэше(Кэш, Параметры) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.НайтиЗначениеВКэше(Кэш, Параметры) 
```
</details>

## ДобавитьЗначениеВКэш
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Помещает значение в рекурсивный кэш по переданным значениям.
//
// Параметры:
//  Кэш			 - Соответствие	 - для добавления значения.
//  Параметры	 - Массив	 - значения для поиска во вложенных соотвествиях.
//	Значение	 - Произвольный - значение для добавления в кэш.
//  Обновить	 - Булево	 - если Ложь и значение уже есть в кэше, то не обновляет.
//							   если Истина, то обновляет в любом случае.
//
Процедура ДобавитьЗначениеВКэш(Кэш, Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ДобавитьЗначениеВКэш(Кэш, );
```
</details>

## ПоместитьВМассив2
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает массив из двух значений.
//
Функция ПоместитьВМассив2(Значение1, Значение2) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПоместитьВМассив2(Значение1, Значение2) 
```
</details>

## ПоместитьВМассив3
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает массив из трех значений.
//
Функция ПоместитьВМассив3(Значение1, Значение2, Значение3) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПоместитьВМассив3(Значение1, Значение2, Значение3) 
```
</details>

## ЗакупкаБольшеГода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, что закупка от даты ДатаОфициальногоОбъявленияЗакупкиВход до даты
// ДатаИсполненияДоговораВход является многопериодной.
Функция ЗакупкаБольшеГода(ДатаОфициальногоОбъявленияЗакупкиВход, ДатаИсполненияДоговораВход) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ЗакупкаБольшеГода(ДатаОфициальногоОбъявленияЗакупкиВход, ДатаИсполненияДоговораВход) 
```
</details>

## ПолучитьСуммуКонтрактаПоТаблицеПотребности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает Сумму контракта документа Строка плана закупок по её таблице
// потребностей ТаблицаВход.
Функция ПолучитьСуммуКонтрактаПоТаблицеПотребности(ТаблицаВход) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПолучитьСуммуКонтрактаПоТаблицеПотребности(ТаблицаВход) 
```
</details>

## ПолучитьТаблицуНоменклатурыИзКонтекстаФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


Функция ПолучитьТаблицуНоменклатурыИзКонтекстаФормы(Форма) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПолучитьТаблицуНоменклатурыИзКонтекстаФормы(Форма) 
```
</details>

## ЗаполнитьТаблицу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьТаблицу(ТаблицаИсточник, ТаблицаПриемник) Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ЗаполнитьТаблицу(ТаблицаИсточник, ТаблицаПриемник));
```
</details>

## ПолучитьПустойРезультатРаботы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Возвращает пустую структуру с полями "Ошибки" и "Успехи" типа Массив.
Функция ПолучитьПустойРезультатРаботы() Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПолучитьПустойРезультатРаботы() 
```
</details>

## ДобавитьОшибку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавить в структуру описывающую результат работы сообщение об ошибке.
// Если РезультатРаботы - Неопределено, то создает новый.
// Аргументы см. функцию ОбщегоНазначенияКлиентСервер.ДобавитьОшибкуПользователю.
//
// Параметры:
//  РезультатРаботы - Структура - см. функцию ПолучитьПустойРезультатРаботы.
//  ПолеОшибки - Строка - значение, которое задается в свойстве Поле объекта СообщениеПользователю.
//           Для автоподстановки номера строки должна содержать "%1".
//           Например, "Объект.ИНН" или "Объект.Пользователи[%1].Пользователь".
//  ТекстДляОднойОшибки - Строка - текст ошибки для случая, когда ГруппаОшибок в коллекции только одна,
//           например НСтр("ru = 'Пользователь не выбран.'").
//  ГруппаОшибок - Произвольный - используется для выбора либо текста для одной ошибки,
//           либо текста для нескольких ошибок, например, имя "Объект.Пользователи".
//           Если значение не заполнено, тогда используется текст для одной ошибки.
//  НомерСтроки - Число - значение от 0 ... , определяющее номер строки, который нужно подставить
//           в строку ПолеОшибки и в ТекстДляНесколькихОшибок (подставляется НомерСтроки + 1).
//  ТекстДляНесколькихОшибок - Строка - текст ошибки для случая, когда добавлено несколько ошибок с одинаковым
//           свойством ГруппаОшибок, например, НСтр("ru = 'Пользователь в строке %1 не выбран.'").
//  ИндексСтроки - Неопределено - совпадает со значением параметра НомерСтроки.
//           Число - значение от 0 ... , определяющее номер строки, который нужно подставить
//           в строку ПолеОшибки.
//
Процедура ДобавитьОшибку(РезультатРаботы, Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ДобавитьОшибку(РезультатРаботы, );
```
</details>

## ДобавитьУспех
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавить в структуру описывающую результат работы сообщение об ошибке.
// Если РезультатРаботы - Неопределено, то создает новый.
//
Процедура ДобавитьУспех(РезультатРаботы, ОписаниеУспеха) Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ДобавитьУспех(РезультатРаботы, ОписаниеУспеха) 
```
</details>

## СообщитьПользователюИзМассива
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вывести сообщения пользователю об ошибках.
//
// Параметры:
//  мСообщений - Массив(Строка|СообщениеПользователю) - сообщения пользователю.
//		Каждая строка выводится отдельным сообщением пользователю.
//		Если в элемент массива - это сообщение пользователю, то оно может быть
//		привязано к элементам открытых пользователем форм.
//  ЗаголовокОповещения - Строка - если заполнено, то будет
//		будет выведено первым сообщением.
//
Процедура СообщитьПользователюИзМассива(мСообщений, Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.СообщитьПользователюИзМассива(мСообщений, );
```
</details>

## СообщитьОшибкиПользователю
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СообщитьОшибкиПользователю(РезультатРаботы, Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.СообщитьОшибкиПользователю(РезультатРаботы, );
```
</details>

## МассивСообщенийВСтроку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Преобразовать сообщения пользователю об ошибках в строку.
//
// Параметры:
//  мСообщений - Массив(Строка|СообщениеПользователю) - сообщения пользователю.
//		Каждая строка выводится отдельным сообщением пользователю.
//		Если в элемент массива - это сообщение пользователю, то оно может быть
//		привязано к элементам открытых пользователем форм.
//	РазделительСообщений - Строка - разделитель, вставляемый между сообщениями.
//		Если не указан, то Символы.ПС.
//  ЗаголовокОповещения - Строка - если заполнено, то будет
//		будет добавлено перед сообщениями.
//
// Возвращает:
//		Строка - заголовок и все сообщения в порядке их появления
//				 в исходном массиве.
//
Функция МассивСообщенийВСтроку(мСообщений, Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.МассивСообщенийВСтроку(мСообщений, );
```
</details>

## СообщитьПользователюОРезультатахРаботыФункции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сообщить пользователю результаты работы функции.
//
// Параметры:
//  РезультатРаботы	- Структура("Ошибки, Успехи") - содержит два массива
//		с сообщениями об ошибках и успехах, соответственно.
//  ЗаголовокОповещенияОбУспехе - Строка - Если заполнен, то перед всеми
//		сообщениями об успехах будет выведена эта строка.
//  ЗаголовокОповещенияОбОшибке - Строка - Если заполнен, то перед всеми
//		сообщениями об ошибках будет выведена эта строка.
//
Процедура СообщитьПользователюОРезультатахРаботыФункции( Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.СообщитьПользователюОРезультатахРаботыФункции();
```
</details>

## ПроверитьУспехФункции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает Истина, если нет ошибок, и есть хотя бы один успех.
Функция ПроверитьУспехФункции(РезультатРаботы) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПроверитьУспехФункции(РезультатРаботы) 
```
</details>

## ПолучитьПредставлениеОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Для объекта с реквизитами формирует текстовое представление вида:
// {Префикс}{ИмяРеквизита}{РазделительЗначений}{Значение реквизита}{РазделительРеквизитов}
// Для самого последнего значения реквизита
// РазделительРеквизитов не вставляется.
//
// Параметры:
//  Объект - Любой объект из которого можно читать значения
//		реквизитов квадратными скобками.
//	мИменаИзмерений - Массив[Строка] - массив имен
//  РазделительЗначений - Строка - текст вставляемый между именем
//		измерения и его значением.
//  РазделительСтрок - Строка - текст разделяющий измерения.
//		Если не указан, или Неопределено, то вставляет новую строку.
//
// Возвращаемое значение:
//   - Строка - представление объекта.
//
Функция ПолучитьПредставлениеОбъекта(Объект, Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПолучитьПредставлениеОбъекта(Объект, );
```
</details>

## ЭтоСостояниеУтвержденногоОбъекта
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


Функция ЭтоСостояниеУтвержденногоОбъекта(СтатусСогласования) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ЭтоСостояниеУтвержденногоОбъекта(СтатусСогласования) 
```
</details>

## ЭтоИмяСобытияСогласования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоИмяСобытияСогласования(ИмяСобытия) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ЭтоИмяСобытияСогласования(ИмяСобытия) 
```
</details>

## СостоянияСогласованияВСтатусыВыгружаемыхОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// По состоянию согласования СостояниеВход получает соответствующий
// ему статус выгружаемого объекта.
Функция СостоянияСогласованияВСтатусыВыгружаемыхОбъектов(СостояниеВход) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.СостоянияСогласованияВСтатусыВыгружаемыхОбъектов(СостояниеВход) 
```
</details>

## ПолучитьТолькоПросмотрПодчиненныхЭлементов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Получить соответствие имен подчиненных элементов
// значениям их реквизита ТолькоПросмотр.
//
// Параметры:
//  Владелец -  -
//  ТолькоПросмотр - Соответствие| Неопределено -
//		необязательный. Соответствие имен элементов
//		значениям реквизита "ТолькоПросмотр" для
//		добавления. Если передано Неопределено,
//		то создает новое соответствие
//
// Возвращаемое значение:
//   - Соответствие {Имя элемента: Булево - значение только просмотр}
//
Функция ПолучитьТолькоПросмотрПодчиненныхЭлементов( Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПолучитьТолькоПросмотрПодчиненныхЭлементов();
```
</details>

## ВосстановитьТолькоПросмотрЭлементов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ВосстановитьТолькоПросмотрЭлементов( Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.ВосстановитьТолькоПросмотрЭлементов();
```
</details>

## ПолучитьВалютуДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В зависимости от вида документа и конфигурации возвращает
//  разные имена реквизитов.
//
// Параметры:
//  Документ - ДокументОбъект | ДокументСсылка - документ валюту которого
//		нужно прочитать.
//
// Возвращаемое значение:
//   - СправочникСсылка.Валюты - валюта документа.
//	 - Неопределено - передано неверное значение документа или у документа
//			нет реквизитов "ВалютаДокумента", или "Валюта".
//
Функция ПолучитьВалютуДокумента(Документ) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПолучитьВалютуДокумента(Документ) 
```
</details>

## УстановитьСвойствоЭлементаФормы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливает значение свойства элемента формы, если находит элемент на форме
//
// Параметры
//  ЭлементыФормы - ВсеЭлементыФормы - элементы формы, среди которых содержится искомый элемент.
//  ИмяЭлемента   - Строка - имя искомого элемента.
//  ИмяСвойства   - Строка - имя свойства, для которого будет устанавливаться значение.
//  Значение      - Произвольный - значение, которое будет установлено
//  УстанавливатьДляПодчиненных - Булево - установить аналогичное свойство для подчиненных элементов искомого элемента.
//
Процедура УстановитьСвойствоЭлементаФормы(ЭлементыФормы, ИмяЭлемента, ИмяСвойства, Значение, УстанавливатьДляПодчиненных = Ложь) Экспорт
```

Пример вызова
```bsl
ЦентрализованныеЗакупкиКлиентСерверУХ.УстановитьСвойствоЭлементаФормы(ЭлементыФормы, ИмяЭлемента, ИмяСвойства, Значение, УстанавливатьДляПодчиненных);
```
</details>

## ИменаКлючевыхПолейПотребности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Имена измерений регистра накопления ПотребностиВНоменклатуре
//
Функция ИменаКлючевыхПолейПотребности() Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ИменаКлючевыхПолейПотребности() 
```
</details>

## ПолучитьМассивИменаКлючевыхПолейПотребности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьМассивИменаКлючевыхПолейПотребности() Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПолучитьМассивИменаКлючевыхПолейПотребности() 
```
</details>

## ПолучитьПредставлениеКлючевыхПолейПотребности
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить представление имег ключевых полей потребности.
//
// Возвращаемое значение:
//   - Структура:
//		- ключ - имя реквизита потребности;
//		- значение - представление реквизита для пользователя.
//
Функция ПолучитьПредставлениеКлючевыхПолейПотребности() Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПолучитьПредставлениеКлючевыхПолейПотребности() 
```
</details>

## ПолучитьМассивИменаКлючевыхПолейЗаказа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПолучитьМассивИменаКлючевыхПолейЗаказа() Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПолучитьМассивИменаКлючевыхПолейЗаказа() 
```
</details>

## ИменаКлючевыхПолейКроссТаблицыПотребностей
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Имена ключевых полей кросс-таблицы с потребностями.
// Из нее удалено поле периода потребности
//
Функция ИменаКлючевыхПолейКроссТаблицыПотребностей() Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ИменаКлючевыхПолейКроссТаблицыПотребностей() 
```
</details>

## ИменаКлючевыхПолейПоставокПоДоговорам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Имена измерений регистра накопления ПланПоставокПоДоговорам
//
Функция ИменаКлючевыхПолейПоставокПоДоговорам() Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ИменаКлючевыхПолейПоставокПоДоговорам() 
```
</details>

## ИменаКлючевыхПолейЗаказовПоставщикам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Имена измерений регистра накопления ЗаказыПоставщикамУХ
//
Функция ИменаКлючевыхПолейЗаказовПоставщикам() Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ИменаКлючевыхПолейЗаказовПоставщикам() 
```
</details>

## ИменаКлючевыхПолейПредложенияПоставщика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИменаКлючевыхПолейПредложенияПоставщика() Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ИменаКлючевыхПолейПредложенияПоставщика() 
```
</details>

## ИменаКлючевыхПолейВыбораПобедителяЛота
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИменаКлючевыхПолейВыбораПобедителяЛота() Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ИменаКлючевыхПолейВыбораПобедителяЛота() 
```
</details>

## ИменаКлючевыхПолейВерсииСоглашенияКоммерческийДоговор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ИменаКлючевыхПолейВерсииСоглашенияКоммерческийДоговор() Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ИменаКлючевыхПолейВерсииСоглашенияКоммерческийДоговор() 
```
</details>

## ПолучитьВидыДоговоровУХ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает массив видов договоров с контрагентом
//  по которым возможна работа в рамках централизованных
//  закупок.
//
// Возвращаемое значение:
//   ФиксированныйМассив(СправочникСсылка.ВидыДоговоровКонтрагентовУХ)
//		допустимые виды договоров.
//
Функция ПолучитьВидыДоговоровУХ() Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПолучитьВидыДоговоровУХ() 
```
</details>

## ЭтоДопустимыйВидДоговораУХ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет, что с видом договора с контрагентом
//  возможна работа в рамках централизованных закупок.
//
// Параметры:
//  ВидДоговораУХ - СправочникСсылка.ВидыДоговоровКонтрагентовУХ -
//		вид договора для проверки.
//
// Возвращаемое значение:
//   Булево - Истина - возможно использовать договор с данным
//		видом. Ложь - нельзя.
//
Функция ЭтоДопустимыйВидДоговораУХ(ВидДоговораУХ) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ЭтоДопустимыйВидДоговораУХ(ВидДоговораУХ) 
```
</details>

## ПричинаЕдинственноеПредложение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, что причина ПричинаВход является причиной по единственному предложению.
Функция ПричинаЕдинственноеПредложение(ПричинаВход) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПричинаЕдинственноеПредложение(ПричинаВход) 
```
</details>

## ЭтоСпособВЭлектроннойФорме
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, что способ выбора поставщика СпособВыбораВход относится только к
// электронным торгам.
Функция ЭтоСпособВЭлектроннойФорме(СпособВыбораВход) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ЭтоСпособВЭлектроннойФорме(СпособВыбораВход) 
```
</details>

## ПредставлениеСтрокиСДлинойНеБолее
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает строку длиной не более определенного количества символов.
// Если строка больше - она обрезается и в конец добавляется многоточие.
//
// Параметры:
//  ИсходнаяСтрока		 - Строка
//  МаксимальнаяДлина	 - Число
//
// Возвращаемое значение:
//  Строка
//
Функция ПредставлениеСтрокиСДлинойНеБолее(ИсходнаяСтрока, МаксимальнаяДлина) Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПредставлениеСтрокиСДлинойНеБолее(ИсходнаяСтрока, МаксимальнаяДлина) 
```
</details>

## ПолучитьРеквизитыДляУстановкиПоНастройкамОсобогоПорядкаЗакупки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Для объекта и структуры с настройками особого порядка закупки возвращает
//  имена полей и их значения, которые должны быть установлены по значениям
//  реквизитов особого порядка закупки номенклатуры.
//
// Параметры:
//  Объект - любой объект для анализа значений его реквизитов.
//  ЗначенияРеквизитовОсобогоПорядка - Структура - описывает значения
//		по которым нужно обновлять реквизиты объекта.
//  НастройкаСоотвествияИмен - Структура - ключ - имя реквизита в
//		структуре ЗначенияРеквизитовОсобогоПорядка; значение - имя
//		соответствующего реквизита объекта.
//
// Возвращаемое значение:
//	- Структура, где имена ее полей - это имена реквизитов объекта, которые
//		нужно изменить по значению настройки;
//		значения - это значения для установки.
//
Функция ПолучитьРеквизитыДляУстановкиПоНастройкамОсобогоПорядкаЗакупки( Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ПолучитьРеквизитыДляУстановкиПоНастройкамОсобогоПорядкаЗакупки();
```
</details>

## ЗарегистрироватьРеквизитДляИзмененияЗначения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


Функция ЗарегистрироватьРеквизитДляИзмененияЗначения(СтароеЗначение, Экспорт
```

Пример вызова
```bsl
Результат = ЦентрализованныеЗакупкиКлиентСерверУХ.ЗарегистрироватьРеквизитДляИзмененияЗначения(СтароеЗначение, );
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
