---
title: Цены предприятия заполнение сервер
slug: erp-uh/цены-предприятия-заполнение-сервер
---


## ЗаполнитьЦены
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет реквизит "Цена" в товарной табличной части.
//
// Параметры:
// 		ТабличнаяЧасть - ДанныеФормыКоллекция, ТабличнаяЧасть - Товарная табличная часть документа. Содержит в том числе:
// 			* НомерСтроки			- Число - Номер строки
// 			* Номенклатура			- СправочникСсылка.Номенклатура - Номенклатура
// 			* Характеристика		- СправочникСсылка.ХарактеристикиНоменклатуры - Характеристика номенклатуры
// 			* Количество			- Число - Количество
// 			* КоличествоУпаковок	- Число - Количество упаковок
// 	ВыделенныеСтроки - Массив, Неопределено - Массив выделенных строк,
// 												если Неопределено, то будут заполнены ВСЕ строки.
// 	ПараметрыЗаполнения - см. НовыйПараметрыЗаполненияЗаполнитьЦены
// 	СтруктураДействий - см. ОбработкаТабличнойЧастиСервер.ОбработатьСтрокуТЧ.СтруктураДействий
//
// Возвращаемое значение:
//   Булево - Истина, если цены успешно заполнены.
//
Функция ЗаполнитьЦены(ТабличнаяЧасть, Экспорт
```

Пример вызова
```bsl
Результат = ЦеныПредприятияЗаполнениеСервер.ЗаполнитьЦены(ТабличнаяЧасть, );
```
</details>

## УстановитьУсловноеОформлениеВидовЦен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление для вида цены.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - Содержит данную форму
//  ИмяПоляВводаВидаЦены - Строка - Наименование элемента формы, содержащего вид цены,
//                                  если оно отличается от "ТоварыВидЦены".
//  ПутьКПолюОтбора - Строка - Полный путь к реквизиту "ВидЦены",
//                             если он отличается от "Объект.Товары.ВидЦены".
//
Процедура УстановитьУсловноеОформлениеВидовЦен(Форма, Экспорт
```

Пример вызова
```bsl
ЦеныПредприятияЗаполнениеСервер.УстановитьУсловноеОформлениеВидовЦен(Форма, );
```
</details>

## УстановитьУсловноеОформлениеЦенаВключаетНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Устанавливаем условное оформление для поля сумма с НДС
//		в зависимости от флага "ЦенаВключаетНДС".
//
// Параметры:
//	Форма - ФормаКлиентскогоПриложения - Содержит данную форму
//	ИмяПоляВводаСуммыСНДС - Строка - Наименование элемента формы, содержащего сумму с НДС,
//                                   если оно отличается от "ТоварыСуммаСНДС".
//
Процедура УстановитьУсловноеОформлениеЦенаВключаетНДС( Экспорт
```

Пример вызова
```bsl
ЦеныПредприятияЗаполнениеСервер.УстановитьУсловноеОформлениеЦенаВключаетНДС();
```
</details>

## ПолучитьЦенуПоОтбору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает цену по переданному отбору.
//
// Параметры:
//		ПараметрыОтбора - см. НовыйПараметрыОтбораПолучитьЦенуПоОтбору
//
// Возвращаемое значение:
// 		Число - Цена
//
Функция ПолучитьЦенуПоОтбору(ПараметрыОтбора) Экспорт
```

Пример вызова
```bsl
Результат = ЦеныПредприятияЗаполнениеСервер.ПолучитьЦенуПоОтбору(ПараметрыОтбора) 
```
</details>

## ПолучитьТекстЗапросаПолученияЦенДляВставки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить текст запроса получения цен для вставки в прочие запросы.
//
// Параметры:
//  ИмяВременнойТаблицыТоваров - Строка - Имя временной таблицы товаров вышестоящего запроса (таблица товаров на входе)
//  ИмяВременнойТаблицыЦен - Строка - Имя временной таблицы цен на выходе
//  ИменаКолонок - см. ИменаКолонокВременнойТаблицыТоваров
//  ДатаЗапроса - Неопределено, Дата - Дата запроса, для получении информации какой вариант ценообразования применить
//
// Возвращаемое значение:
//  Строка - Получить текст запроса получения цен для вставки
Функция ПолучитьТекстЗапросаПолученияЦенДляВставки(ИмяВременнойТаблицыТоваров, Экспорт
```

Пример вызова
```bsl
Результат = ЦеныПредприятияЗаполнениеСервер.ПолучитьТекстЗапросаПолученияЦенДляВставки(ИмяВременнойТаблицыТоваров, );
```
</details>

## ДополнитьТекстЗапросаЗаполнитьЦенуПередачиПродукцииДавальцу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для получения цены передачи продукции давальцу.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - Структура
Процедура ДополнитьТекстЗапросаЗаполнитьЦенуПередачиПродукцииДавальцу(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ЦеныПредприятияЗаполнениеСервер.ДополнитьТекстЗапросаЗаполнитьЦенуПередачиПродукцииДавальцу(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаПроверитьЗаполнитьЦенуВыпуска
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для получения цены выпуска.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - Структура
Процедура ДополнитьТекстЗапросаПроверитьЗаполнитьЦенуВыпуска(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ЦеныПредприятияЗаполнениеСервер.ДополнитьТекстЗапросаПроверитьЗаполнитьЦенуВыпуска(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## ДополнитьТекстЗапросаЗаполнитьЦенуПродажи
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет запрос в пакет запросов для получения данных, необходимых для получения цены продажи.
//
// Параметры:
//  СтруктураДействий - см. ПакетнаяОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//  ОписаниеЗапроса - см. ПакетнаяОбработкаТабличнойЧастиСервер.ОписаниеЗапроса
//  КэшированныеЗначения - Структура
//
Процедура ДополнитьТекстЗапросаЗаполнитьЦенуПродажи(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ЦеныПредприятияЗаполнениеСервер.ДополнитьТекстЗапросаЗаполнитьЦенуПродажи(СтруктураДействий, ОписаниеЗапроса, КэшированныеЗначения) 
```
</details>

## НовыйПараметрыЗаполненияЗаполнитьЦены
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор параметров метода ЗаполнитьЦены.
//
// Возвращаемое значение:
// 	Структура - Структура параметров заполнения:
// 		Обязательные поля.
// 			* Дата - Дата - Дата документа
// 			* Валюта - СправочникСсылка.Валюты - Валюта документа
// 			* Соглашение - СправочникСсылка.СоглашенияСКлиентами -
// 							если ключ отсутствует, значит должен быть заполнен параметр "ВидЦены".
// 			* ВидЦены - СправочникСсылка.ВидыЦен -
// 							если параметр отсутствует, значит должен быть заполнен параметр "Соглашение".
// 		Необязательные поля.
// 			* ПоляЗаполнения - Строка - Строка с перечислением заполняемых полей в таблице;
// 					значение по умолчанию: "Цена"; дополнительные поля - "ВидЦены, СрокПоставки, СтавкаНДС".
// 			* КолонкиПоЗначению - см. ОбщегоНазначенияУТ.ВыгрузитьТаблицуЗначений.КолонкиПоЗначению
// 			* ДругиеИменаКолонок - см. ОбщегоНазначенияУТ.ВыгрузитьТаблицуЗначений.НовыеИменаКолонок
// 			* РассчитыватьНаборы - Булево
// 			* Организация - СправочникСсылка.Организации
// 			* НалогообложениеНДС - ПеречислениеСсылка.ТипыНалогообложенияНДС
// 			* ВозвращатьМногооборотнуюТару - Булево
//
Функция НовыйПараметрыЗаполненияЗаполнитьЦены() Экспорт
```

Пример вызова
```bsl
Результат = ЦеныПредприятияЗаполнениеСервер.НовыйПараметрыЗаполненияЗаполнитьЦены() 
```
</details>

## НовыйПараметрыОтбораПолучитьЦенуПоОтбору
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция-конструктор структуры отбора для получения цены, используется для получения атомарного значения цены.
// Используется как параметр метода ПолучитьЦенуПоОтбору().
//
// Возвращаемое значение:
//	Структура - Структура параметров заполнения поля отбора:
//		* Дата - Дата - дата, на которую необходимо получение цены.
//		* Валюта - СправочникСсылка.Валюты -
//		* Номенклатура - СправочникСсылка.Номенклатура -
//		* Характеристика - СправочникСсылка.ХарактеристикиНоменклатуры -
//		* Упаковка - СправочникСсылка.УпаковкиЕдиницыИзмерения -
//		* Серия - СправочникСсылка.СерииНоменклатуры -
//		* ВидЦены - СправочникСсылка.ВидыЦен - .
//
Функция НовыйПараметрыОтбораПолучитьЦенуПоОтбору() Экспорт
```

Пример вызова
```bsl
Результат = ЦеныПредприятияЗаполнениеСервер.НовыйПараметрыОтбораПолучитьЦенуПоОтбору() 
```
</details>

## ИменаКолонокВременнойТаблицыТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Имена колонок временной таблицы товаров.
//
// Возвращаемое значение:
//  Структура - Имена колонок временной таблицы товаров:
// * ИмяКолонкиНомерСтроки - Строка - По умолчанию "НомерСтроки"
// * ИмяКолонкиСерия - Строка - По умолчанию "Серия"
// * ИмяКолонкиУпаковка - Строка - По умолчанию "Упаковка"
// * ИмяКолонкиВидЦены - Строка - Если колонки в таблице нет, то используется параметр "ВидЦены"
// * ИмяКолонкиВалюта - Строка - Если колонки в таблице нет, то используется параметр "Валюта"
Функция ИменаКолонокВременнойТаблицыТоваров() Экспорт
```

Пример вызова
```bsl
Результат = ЦеныПредприятияЗаполнениеСервер.ИменаКолонокВременнойТаблицыТоваров() 
```
</details>

## НовыйПараметрыПроверкиВидаЦенДоговора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Конструктор параметров проверки вида цен договора для заполнения.
//
// Возвращаемое значение:
//	Структура - Структура параметров проверки вида цен договора:
// 	* ИмяТабличнойЧасти           - Строка - Имя табличной части документа
// 	* ПредставлениеТабличнойЧасти - Строка - Представление названия табличной части
// 	* ВидЦеныДоговора             - СправочникСсылка.ВидыЦен - Выбранный вид цен договора
// 	* ПолеВидаЦен                 - Строка - Название поля вида цен договора
// 	* ЦенаВключаетНДС             - Булево - признак включения НДС в цену для выбранного вида цен.
//
Функция НовыйПараметрыПроверкиВидаЦенДоговора() Экспорт
```

Пример вызова
```bsl
Результат = ЦеныПредприятияЗаполнениеСервер.НовыйПараметрыПроверкиВидаЦенДоговора() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
