---
title: Шаблоны фискальных документов
slug: erp-uh/шаблоны-фискальных-документов
---


## НовыйФормат
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает формат для строки шаблона.
//
// Параметры:
//  БазовыйФормат - см. НовыйФормат.
//
// Возвращаемое значение:
//   Структура:
//     * Тип - Строка - тип строки шаблона: Строка, Разделитель, Штрихкод, XML.
//     * Выравнивание - ГоризонтальноеПоложение.
//     * ВыравниваниеЗаголовка - Булево - Истина - выравнивать заголовок вместе с текстом, иначе Ложь.
//     * ОбтеканиеСлева - Булево - Истина - выполнять обтекание слева.
//     * ОбтеканиеСправа - Булево - Истина - выполнять обтекание справа.
//     * Ширина - Строка - ширина колонки в символах или процентах:
//                "10" - 10 символов;
//                "40%" - 40% от строки;
//                "*" - автоматически попытаться полностью поместить в колонку;
//                "0", "" - распределить поровну оставшееся место в строке.
//     * Заполнитель - Строка - символ заполнитель строки между заголовком и полем, по умолчанию " ".
//     * ВыводитьЗаголовок - Булево - принудительно выводить заголовок даже если значение не установлено.
//     * ПодавлятьПробелы - Булево - удалять пробелы в строке.
//     * ШтрихкодТип - Строка - тип штрихкода: "EAN13", "QR".
//     * ШтрихкодВысота - Число - высота штрихкода в строках.
//     * ЭлементXML - Структура.
//     * ИмяАтрибутаXML - Строка.
//
Функция НовыйФормат(БазовыйФормат = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.НовыйФормат(БазовыйФормат);
```
</details>

## ФорматРазделитель
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает формат для строки разделителя.
//
// Возвращаемое значение:
//   Структура - см. НовыйФормат.
//
Функция ФорматРазделитель() Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ФорматРазделитель() 
```
</details>

## ФорматШтрихкод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает формат для штрихкода.
//
// Параметры:
//   Выравнивание - ГоризонтальноеПоложение.
//   ШтрихкодТип - Строка.
//   ШтрихкодВысота - Число.
//   ИспользоватьBase64 - Булево.
//
// Возвращаемое значение:
//   Структура - см. НовыйФормат.
Функция ФорматШтрихкод(Выравнивание = Неопределено, ШтрихкодТип = "EAN13", ШтрихкодВысота = 0, ИспользоватьBase64 = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ФорматШтрихкод(Выравнивание, ШтрихкодТип, ШтрихкодВысота, ИспользоватьBase64);
```
</details>

## ФорматШтрихкодШирина
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает формат для штрихкода.
//
// Параметры:
//   Ширина - Строка - ширина штрихкода
//   Выравнивание - ГоризонтальноеПоложение
//   ШтрихкодТип - Строка
//   ШтрихкодВысота - Число - высота штрихкода
//   ИспользоватьBase64 - Булево.
//
// Возвращаемое значение:
//   Структура - см. НовыйФормат
Функция ФорматШтрихкодШирина(Ширина, Выравнивание = Неопределено, ШтрихкодТип = "EAN13", ШтрихкодВысота = 0, ИспользоватьBase64 = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ФорматШтрихкодШирина(Ширина, Выравнивание, ШтрихкодТип, ШтрихкодВысота, ИспользоватьBase64);
```
</details>

## ФорматСтрока
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает формат для строки.
//
// Параметры:
//   Выравнивание - ГоризонтальноеПоложение.
//   ВыравниваниеЗаголовка - Булево - Истина - выравнивать заголовок вместе с текстом, иначе Ложь.
//   Обтекание - Булево - использовать обтекание
//
// Возвращаемое значение:
//   Структура - см. НовыйФормат
Функция ФорматСтрока(Выравнивание = Неопределено, ВыравниваниеЗаголовка = Ложь, Обтекание = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ФорматСтрока(Выравнивание, ВыравниваниеЗаголовка, Обтекание);
```
</details>

## ФорматСтрокаШирина
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает формат для строки.
//
// Параметры:
//   Ширина - Строка - ширина штрихкода
//   Выравнивание - ГоризонтальноеПоложение
//   ВыравниваниеЗаголовка - Булево - Истина - выравнивать заголовок вместе с текстом, иначе Ложь.
//   Обтекание - Булево - использовать обтекание
//
// Возвращаемое значение:
//   Структура - см. НовыйФормат
//
Функция ФорматСтрокаШирина(Ширина, Выравнивание = Неопределено, ВыравниваниеЗаголовка = Ложь, Обтекание = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ФорматСтрокаШирина(Ширина, Выравнивание, ВыравниваниеЗаголовка, Обтекание);
```
</details>

## ФорматXML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает формат для элемента XML.
//
// Параметры:
//   ЭлементXML - Структура
//   ИмяАтрибутаXML - Строка
//   БазовыйФормат - см. НовыйФормат
//
// Возвращаемое значение:
//   Структура - см. НовыйФормат
//
Функция ФорматXML(ЭлементXML, ИмяАтрибутаXML, БазовыйФормат = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ФорматXML(ЭлементXML, ИмяАтрибутаXML, БазовыйФормат);
```
</details>

## НовыйШаблон
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает объект шаблона.
//
// Параметры:
//  ШиринаСтроки - Число - ширина строки для расчета шаблона
//
// Возвращаемое значение:
//  Структура:
//   * ШиринаСтроки - Число
//   * Отладка - Булево
//   * СтрокиОшибок - Массив из Строка
//   * XML - Булево
//   * КореньXML - Структура
//   * ЭлементыXML - см. НовыйСоответствиеЭлементыXML
//   * Элементы - Массив из Структура
//   * Результат - Массив из структура
 //
Функция НовыйШаблон(ШиринаСтроки = 48) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.НовыйШаблон(ШиринаСтроки);
```
</details>

## НовыйЭлементXML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет элемент XML в шаблон.
//
// Параметры:
//   Шаблон - см. НовыйШаблон
//   ИмяЭлемента - Строка
//   Родитель - см. НовыйЭлементXML
//
// Возвращаемое значение:
//  Структура:
//   * Имя - Строка
//   * Дочерние - Массив из см. НовыйЭлементXML
//   * ВыводитьПоСтрокам - Булево
//   * ЭлементXML - см. НовыйЭлементXML
//   * АтрибутыXML - Соответствие из Структура
//
Функция НовыйЭлементXML(Шаблон, ИмяЭлемента, Родитель = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.НовыйЭлементXML(Шаблон, ИмяЭлемента, Родитель);
```
</details>

## ДобавитьСтроку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавить строку в шаблон, перегруженная процедура:
// * ШаблонНоваяСтрока(Шаблон, Заголовок, Значение, Формат)
// * ШаблонНоваяСтрока(Шаблон, Заголовок, Значение)
// * ШаблонНоваяСтрока(Шаблон, Значение, Формат)
// * ШаблонНоваяСтрока(Шаблон, Значение)
//
// Параметры:
//   Шаблон - см. НовыйШаблон
//   Параметр1 - Строка, Произвольный - Заголовок, Значение которое будет добавлено в шаблон
//   Параметр2 - Структура, Произвольный - Значение или формат которое будет добавлено в шаблон
//   Параметр3 - Структура - Формат см. НовыйФормат
Процедура ДобавитьСтроку(Шаблон, Параметр1 = Неопределено, Параметр2 = Неопределено, Параметр3 = Неопределено) Экспорт
```

Пример вызова
```bsl
ШаблоныФискальныхДокументов.ДобавитьСтроку(Шаблон, Параметр1, Параметр2, Параметр3);
```
</details>

## ДобавитьКолонку
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавить колонку в шаблон, перегруженная процедура:
// * ШаблонНоваяСтрока(Шаблон, Заголовок, Значение, Формат)
// * ШаблонНоваяСтрока(Шаблон, Заголовок, Значение)
// * ШаблонНоваяСтрока(Шаблон, Значение, Формат)
// * ШаблонНоваяСтрока(Шаблон, Значение)
//
// Параметры:
//   Шаблон - см. НовыйШаблон
//   Параметр1 - Строка, Произвольный - Заголовок, Значение которое будет добавлено в шаблон
//   Параметр2 - Структура, Произвольный - Значение или формат которое будет добавлено в шаблон
//   Параметр3 - см. НовыйФормат
Процедура ДобавитьКолонку(Шаблон, Параметр1 = Неопределено, Параметр2 = Неопределено, Параметр3 = Неопределено) Экспорт
```

Пример вызова
```bsl
ШаблоныФискальныхДокументов.ДобавитьКолонку(Шаблон, Параметр1, Параметр2, Параметр3);
```
</details>

## СформироватьДокументПоШаблону
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует документ по заданному шаблону.
//
// Параметры:
//   Шаблон - см. НовыйШаблон
//
Процедура СформироватьДокументПоШаблону(Шаблон) Экспорт
```

Пример вызова
```bsl
ШаблоныФискальныхДокументов.СформироватьДокументПоШаблону(Шаблон) 
```
</details>

## ВывестиКакТекст
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит сформированный документ как текстовая строка.
//
// Параметры:
//  Шаблон - см. НовыйШаблон
//
// Возвращаемое значение:
//  Строка
//
Функция ВывестиКакТекст(Шаблон, ЗамещатьШтрихкоды = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ВывестиКакТекст(Шаблон, ЗамещатьШтрихкоды);
```
</details>

## ВывестиКакТабличныйДокумент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит сформированный документ как табличный документ.
//
// Параметры:
//  Шаблон - см. НовыйШаблон
//
// Возвращаемое значение:
//  ТабличныйДокумент
//
Функция ВывестиКакТабличныйДокумент(Шаблон) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ВывестиКакТабличныйДокумент(Шаблон) 
```
</details>

## ВывестиКакPDF
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выводит сформированный документ как документ PDF.
//
// Параметры:
//  Шаблон - см. НовыйШаблон
//
// Возвращаемое значение:
//  ДокументPDF
//
Функция ВывестиКакPDF(Шаблон) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ВывестиКакPDF(Шаблон) 
```
</details>

## ПараметрыШаблонаФискальногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров для формирования шаблона фискального документа.
//
// Возвращаемое значение:
//  Структура:
//   * ВерсияФФД - Строка - версия формата фискальных документов
//   * Заголовок - Строка
//   * Подпись - Булево - формировать ли поле подписи в документе
//   * ДополнительныйТекст - Строка - дополнительный текст для вывода внизу документа
//
Функция ПараметрыШаблонаФискальногоДокумента() Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ПараметрыШаблонаФискальногоДокумента() 
```
</details>

## ШаблонКассовыйЧек
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Генерирует шаблон кассового чека, по данным операции фискализации чека.
//
// Параметры:
//   ШиринаСтроки - Число
//   Данные - см. ОборудованиеЧекопечатающиеУстройстваКлиентСервер.ПараметрыОперацииФискализацииЧека
//   ФискальнаяОперация - Структура
//   Параметры - см. ПараметрыШаблонаФискальногоДокумента
//
// Возвращаемое значение:
//  см. НовыйШаблон
//
Функция ШаблонКассовыйЧек(ШиринаСтроки, Данные, ФискальнаяОперация = Неопределено, Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ШаблонКассовыйЧек(ШиринаСтроки, Данные, ФискальнаяОперация, Параметры);
```
</details>

## ШаблонОтчетОбОткрытииСмены
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Генерирует шаблон отчета об открытии смены.
//
// Параметры:
//   ШиринаСтроки - Число
//   Данные - см. ОборудованиеЧекопечатающиеУстройстваКлиентСервер.ПараметрыОткрытияЗакрытияСмены
//   Параметры - см. ПараметрыШаблонаФискальногоДокумента
//
// Возвращаемое значение:
//  см. НовыйШаблон
//
Функция ШаблонОтчетОбОткрытииСмены(ШиринаСтроки, Данные, Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ШаблонОтчетОбОткрытииСмены(ШиринаСтроки, Данные, Параметры);
```
</details>

## ШаблонОтчетОЗакрытииСмены
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Генерирует шаблон отчета о закрытии смены.
//
// Параметры:
//   ШиринаСтроки - Число
//   Данные - см. ОборудованиеЧекопечатающиеУстройстваКлиентСервер.ПараметрыОткрытияЗакрытияСмены
//   Параметры - см. ПараметрыШаблонаФискальногоДокумента
//
// Возвращаемое значение:
//  см. НовыйШаблон
//
Функция ШаблонОтчетОЗакрытииСмены(ШиринаСтроки, Данные, Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ШаблонОтчетОЗакрытииСмены(ШиринаСтроки, Данные, Параметры);
```
</details>

## ШаблонОтчетОТекущемСостоянии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Генерирует шаблон отчета о текущем состоянии.
//
// Параметры:
//   ШиринаСтроки - Число
//   Данные - см. ОборудованиеЧекопечатающиеУстройстваКлиентСервер.ПараметрыВыполненияОперации
//   Параметры - см. ПараметрыШаблонаФискальногоДокумента
//
// Возвращаемое значение:
//  см. НовыйШаблон
//
Функция ШаблонОтчетОТекущемСостоянии(ШиринаСтроки, Данные, Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ШаблонОтчетОТекущемСостоянии(ШиринаСтроки, Данные, Параметры);
```
</details>

## ШаблонСнятиеНаличных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Генерирует шаблон отчета о снятии наличных.
//
// Параметры:
//   ШиринаСтроки - Число
//   Данные - см. ОборудованиеЧекопечатающиеУстройстваКлиентСервер.ПараметрыИнкассации
//   Параметры - см. ПараметрыШаблонаФискальногоДокумента
//
// Возвращаемое значение:
//  см. НовыйШаблон
//
Функция ШаблонСнятиеНаличных(ШиринаСтроки, Данные, Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ШаблонСнятиеНаличных(ШиринаСтроки, Данные, Параметры);
```
</details>

## ШаблонВнесениеНаличных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Генерирует шаблон отчета о внесении наличных.
//
// Параметры:
//   ШиринаСтроки - Число
//   Данные - см. ОборудованиеЧекопечатающиеУстройстваКлиентСервер.ПараметрыИнкассации
//   Параметры - см. ПараметрыШаблонаФискальногоДокумента
//
// Возвращаемое значение:
//  см. НовыйШаблон
//
Функция ШаблонВнесениеНаличных(ШиринаСтроки, Данные, Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ШаблонВнесениеНаличных(ШиринаСтроки, Данные, Параметры);
```
</details>

## ШаблонИнфоКвитанция
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Генерирует шаблон отчета о инфо квитанции.
//
// Параметры:
//   ШиринаСтроки - Число
//   Данные - см. ОборудованиеЧекопечатающиеУстройстваКлиентСервер.ПараметрыВыполненияОперации
//   Параметры - см. ПараметрыШаблонаФискальногоДокумента
//
// Возвращаемое значение:
//  см. НовыйШаблон
//
Функция ШаблонИнфоКвитанция(ШиринаСтроки, Данные, Параметры = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШаблоныФискальныхДокументов.ШаблонИнфоКвитанция(ШиринаСтроки, Данные, Параметры);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
