---
title: Штрихкодирование ИС
slug: erp-uh/штрихкодирование-ис
---


## ДанныеШтрихкодовУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует данные штрихкодов упаковок.
//
// Параметры:
//  СтрокиТаблицы - Массив Из СтрокаТаблицыЗначений - Массив из строк таблицы значний типа
//  См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализацияТаблицыДанныхКодовМаркировки
//  ТипыУпаковок - Массив из ПеречислениеСсылка.ТипыУпаковок - Коллекция типов упаковок, по которым будет
//       установлено условие для формирования запроса.
//  ПроверкаНаGS1 - Булево - Добавляет в поиск значение штрихкода без скобок, только для упаковок GS1.
//
// Возвращаемое значение:
//  ТаблицаЗначений - Данные штрихкодов упаковок:
//   * Штрихкод - Строка - Значение штрихкода.
//   * ШтрихкодУпаковки - СправочникСсылка.ШтрихкодыУпаковокТоваров.
//   * ДатаУпаковки - Дата - Дата формирования упаковки.
//   * ТипУпаковки - ПеречислениеСсылка.ТипыУпаковок - Тип упаковки.
//   * Номенклатура - ОпределяемыйТип.Номенклатура - Номенклатура.
//   * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - Характеристика.
//   * Серия - ОпределяемыйТип.СерияНоменклатуры - Серия.
//   * Количество - Число - Количество единиц товара соответствующее штрихкоду
//   * МаркируемаяПродукция - Булево - Истина, если продкция подлежит маркированию.
//   * ТребуетВзвешивания - Булево - Истина, если потребительские упаковки номенклатуры требуют взвешивания
//   * ПроизвольнаяЕдиницаУчета - Булево - Истина, если учетная единица номенклатуры отличается от индивидуального КМ
//   * ВидПродукции - ПеречислениеСсылка.ВидыПродукцииИС - Вид продукции номенклатуры.
Функция ДанныеШтрихкодовУпаковок(СтрокиТаблицы, ТипыУпаковок = Неопределено, ПроверкаНаGS1 = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИС.ДанныеШтрихкодовУпаковок(СтрокиТаблицы, ТипыУпаковок, ПроверкаНаGS1);
```
</details>

## ЗначенияНедопустимыхШтрихкодовИзДереваМаркируемойПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Производит анализ дерева упаковок на продукцию с недопустимым статусом кодов маркировки
//
// Параметры:
//  ДеревоМаркируемойПродукции - ДеревоЗначений - Иерархия хранения маркируемой продукции с упаковками.
//  ЗначенияШтрихкодов - Соответствие Из Строка - Соответствие, которое будет дополнен штрихкодами, имеющими недопустимый статус.
// Возвращаемое значение:
//  Соответствие Из Строка - Штрихкоды, которые имеют недопустимый статус и содержатся в дереве упаковок.
Функция ЗначенияНедопустимыхШтрихкодовИзДереваМаркируемойПродукции(ДеревоМаркируемойПродукции, ЗначенияШтрихкодов = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИС.ЗначенияНедопустимыхШтрихкодовИзДереваМаркируемойПродукции(ДеревоМаркируемойПродукции, ЗначенияШтрихкодов);
```
</details>

## ОбработатьШтрихкодыУпаковокПоДаннымБазы
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбработатьШтрихкодыУпаковокПоДаннымБазы(ПараметрыСканирования, ДанныеПоШтрихкодам, ШтрихкодыМаркируемойПродукции, ТипыУпаковок, ЗаполнитьПоСсылкам) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеИС.ОбработатьШтрихкодыУпаковокПоДаннымБазы(ПараметрыСканирования, ДанныеПоШтрихкодам, ШтрихкодыМаркируемойПродукции, ТипыУпаковок, ЗаполнитьПоСсылкам) 
```
</details>

## ВложенныеШтрихкодыУпаковокПоДокументу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует коллекции: «ДеревоУпаковок» и «МаркированныеТовары» по ссылке на документ.
// Данные собираются на основании информации справочника «ШтрихкодыУпаковок».
// Так же возможно получение информации из сервиса Государственных Информационных Систем,
// если данное взаимодействие и получение информации предусмотрено.
//
// Параметры:
//  ДокументСсылка - ДокументСсылка - Ссылка на документ.
//  ВидПродукции - Неопределено, ПеречислениеСсылка.ВидыПродукцииИС - Вид продукции, по которому необходимо осуществить
//  отбор формирования вложенных штрихкодов.
//  Детализация - Неопределено, ПеречислениеСсылка.ДетализацияСтруктурыХраненияИС - Детализация,
//  с которой необходимо сформировать вложенные штрихкоды.
//  ОтключитьИспользованиеСервиса - Булево - Истина, если не требуется образение в сервис.
// Возвращаемое значение:
//  Структура - Описание:
//   * ШтрихкодыПродукцииДляСопоставления - Массив Из Строка - Массив штрихкодов, которые необходимо сопоставить с номенклатурой,
//   * ВидыПродукции - Массив из ПеречислениеСсылка.ВидыПродукцииИС - Массив видов продукции,
//   * МаркированныеТовары - ТаблицаЗначений - Таблица, содержащая товары, подлежащие маркировке,
//   * ДеревоУпаковок - ДеревоЗначений - Дерево упаковок, построенное в соответствие с хранением в справочнике ШтрихкодыУпаковок.
Функция ВложенныеШтрихкодыУпаковокПоДокументу(ДокументСсылка, ВидПродукции = Неопределено, Детализация = Неопределено, ОтключитьИспользованиеСервиса = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИС.ВложенныеШтрихкодыУпаковокПоДокументу(ДокументСсылка, ВидПродукции, Детализация, ОтключитьИспользованиеСервиса);
```
</details>

## ВложенныеШтрихкодыИзвестныхУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует структуру Вложенные штрихкоды для упаковок на основании существующих данных в ИБ.
//
// Параметры:
//  МассивУпаковок - Массив из СправочникСсылка.ШтрихкодыУпаковокТоваров - Коллекция элементов справочника Штрихкоды упаковок.
//  ПараметрыСканирования - См. ПараметрыСканирования
// Возвращаемое значение:
//  См. ИнициализацияВложенныхШтрихкодов
Функция ВложенныеШтрихкодыИзвестныхУпаковок(МассивУпаковок, ПараметрыСканирования = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИС.ВложенныеШтрихкодыИзвестныхУпаковок(МассивУпаковок, ПараметрыСканирования);
```
</details>

## ЗначенияШтрихкодовИзДереваМаркируемойПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Производит анализ дерева упаковок на продукцию.
//
// Параметры:
//  ДеревоМаркируемойПродукции - ДеревоЗначений - Иерархия хранения маркируемой продукции с упаковками.
//  ЗначенияШтрихкодов - Неопределено, Массив Из СтрокаДереваЗначений - Массив, который будет дополнен штрихкодами, которые в наличии.
//  НаличиеКолонок - Структура, Неопределено - служебная структура для проверки по колонке "НедопустимыйКодМаркировки"
// Возвращаемое значение:
//  Массив Из СтрокаДереваЗначений - Штрихкоды, которые имеют статус "В Наличии" и содержатся в дереве упаковок.
Функция ЗначенияШтрихкодовИзДереваМаркируемойПродукции(ДеревоМаркируемойПродукции, ЗначенияШтрихкодов = Неопределено, НаличиеКолонок = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИС.ЗначенияШтрихкодовИзДереваМаркируемойПродукции(ДеревоМаркируемойПродукции, ЗначенияШтрихкодов, НаличиеКолонок);
```
</details>

## ЗаполнитьДанныеRFID
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьДанныеRFID(ДанныеПоШтрихкодам, ПараметрыСканирования) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеИС.ЗаполнитьДанныеRFID(ДанныеПоШтрихкодам, ПараметрыСканирования) 
```
</details>

## ОбщиеКолонкиКоллекцийВложенныхШтрихкодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает состав колонок, который является общим для дерева упаковок и таблицы значений маркированные товары.
//
// Возвращаемое значение:
//  Структура - Описание:
//   * ТипШтрихкода - Неопределено, ПеречислениеСсылка.ТипыШтрихкодов - Тип штрихкода кода маркировки.
//   * УпаковкаВерхнегоУровня - Неопределено -
//   * ВидПродукции - Неопределено, ПеречислениеСсылка.ВидыПродукцииИС - Вид продукции кода маркировки.
//   * Серия - Неопределено, ОпределяемыйТип.СерияНоменклатуры - Серия номенклатуры.
//   * Характеристика - Неопределено, ОпределяемыйТип.ХарактеристикаНоменклатуры - Характеристика.
//   * Номенклатура - Неопределено, ОпределяемыйТип.Номенклатура - Номенклатура.
//   * Штрихкод - Неопределено, Строка - Штрихкод.
//   * ШтрихкодУпаковки - Неопределено, СправочникСсылка.ШтрихкодыУпаковокТоваров - ссылка на элемент справочника.
//   * ИдентификаторСтроки - Неопределено, Строка - Идентификатор
//   * Упаковка - Неопределено, СправочникСсылка.ШтрихкодыУпаковокТоваров -
//   * ЭтоКодВводаОстатков - Булево -
//   * Количество - Число -
//   * МаркируемаяПродукция - Булево -
//   * ТребуетВзвешивания - Булево -
//   * ПроизвольнаяЕдиницаУчета - Булево -
//   * КоличествоПотребительскихУпаковокПоДаннымИБ - Число
//   * КоличествоПоДаннымИБ - Число -
//   * ВидУпаковки - Неопределено, ПеречислениеСсылка.ВидыУпаковокИС -
//   * СоставКодаМаркировки - Неопределено -
//   * ДанныеРазбора - Неопределено -
//   * ПараметрыОшибки - Неопределено, Структура из КлючИЗначение -
//   * РазрешительныйРежимИдентификаторЗапросаГИСМТ - ОпределяемыйТип.УникальныйИдентификаторИС
//   * РазрешительныйРежимДатаЗапросаГИСМТ - Строка - дата получения идентификатора ГИС МТ в формате timestamp
Функция ОбщиеКолонкиКоллекцийВложенныхШтрихкодов() Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИС.ОбщиеКолонкиКоллекцийВложенныхШтрихкодов());
```
</details>

## ВложенныеШтрихкодыУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует коллекции: «ДеревоУпаковок» и «МаркированныеТовары».
// Данные собираются на основании информации справочника «ШтрихкодыУпаковок».
// Так же возможно получение информации из сервиса Государственных Информационных Систем,
// если данное взаимодействие и получение информации предусмотрено.
//
// Параметры:
//  Упаковки              - Массив из СправочникСсылка.ШтрихкодыУпаковокТоваров - Массив упаковок, по которому формируются вложенные штрихкоды.
//                        - Массив из см. ШтрихкодированиеИС.НовыйЭлементКоллекцииУпаковокДляРаспределенияПоТоварам -
//	                         Штрикходы упаковок документа, с дополнительным данными частичного выбытия.
//  ПараметрыСканирования - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования).
//  ЗаполнитьСведенияПоШтрихкодамEAN - Булево - Заполнять данные по штрихкодам EAN.
//  СортироватьДанные - Булево - Выполнить сортировку данных
// Возвращаемое значение:
//  Структура - Описание:
//   * ШтрихкодыПродукцииДляСопоставления - Массив Из Строка - Массив штрихкодов, которые необходимо сопоставить с номенклатурой.
//   * ВидыПродукции - Массив из ПеречислениеСсылка.ВидыПродукцииИС - Массив видов продукции.
//   * МаркированныеТовары - ТаблицаЗначений - Таблица, содержащая товары, подлежащие маркировке:
//   * ДеревоУпаковок - ДеревоЗначений - Дерево упаковок, построенное в соответствие с хранением в справочнике ШтрихкодыУпаковок.
//   * ЕстьОшибки - Булево - если были ошибки при получении данных из сервиса.
//   * ТребуетсяОбновлениеКлючаСессии - Булево - если были ошибки при получении данных из сервиса.
//   * ТекстОшибки - Строка - ошибка при получении данных из сервиса.
Функция ВложенныеШтрихкодыУпаковок(Упаковки, ПараметрыСканирования = Неопределено, ЗаполнитьСведенияПоШтрихкодамEAN = Ложь, СортироватьДанные = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИС.ВложенныеШтрихкодыУпаковок(Упаковки, ПараметрыСканирования, ЗаполнитьСведенияПоШтрихкодамEAN, СортироватьДанные);
```
</details>

## ЗаполнитьКоэффициентыВложенностиУпаковокПоШтрихкодамEAN
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет информацию по коэффициентам вложенности упаковок. Информация помещается в таблицу ДанныеПоШтрихкодам.ДанныеКодовМаркировки.
//
// Параметры:
//  ДанныеПоШтрихкодам    - См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализацияДанныхПоШтрихкодам
//  ПараметрыСканирования - См. ПараметрыСканирования
//  ДанныеКодовМаркировки - см. ШтрихкодированиеОбщегоНазначенияИС.ИнициализацияТаблицыДанныхКодовМаркировки
Процедура ЗаполнитьКоэффициентыВложенностиУпаковокПоШтрихкодамEAN(ДанныеПоШтрихкодам, ПараметрыСканирования, ДанныеКодовМаркировки = Неопределено) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеИС.ЗаполнитьКоэффициентыВложенностиУпаковокПоШтрихкодамEAN(ДанныеПоШтрихкодам, ПараметрыСканирования, ДанныеКодовМаркировки);
```
</details>

## ЗаполнитьДанныеВложенныхШтрихкодовДереваУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьДанныеВложенныхШтрихкодовДереваУпаковок(ПараметрыСканирования, ДанныеПоШтрихкодам) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеИС.ЗаполнитьДанныеВложенныхШтрихкодовДереваУпаковок(ПараметрыСканирования, ДанныеПоШтрихкодам) 
```
</details>

## ОбработатьСохраненныйВыборДанныхПоМаркируемойПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбработатьСохраненныйВыборДанныхПоМаркируемойПродукции(ПараметрыСканирования, Форма, ДанныеШтрихкода) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеИС.ОбработатьСохраненныйВыборДанныхПоМаркируемойПродукции(ПараметрыСканирования, Форма, ДанныеШтрихкода) 
```
</details>

## ЗаполнитьСведенияПоШтриходамДаннымПулаGTIN
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьСведенияПоШтриходамДаннымПулаGTIN(ДанныеПоШтрихкодам, ПараметрыСканирования, ДанныеКодовМаркировки = Неопределено) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеИС.ЗаполнитьСведенияПоШтриходамДаннымПулаGTIN(ДанныеПоШтрихкодам, ПараметрыСканирования, ДанныеКодовМаркировки);
```
</details>

## КодGS1ДляКомпонентыПечати
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает штрихкод GS1 в формате со скобками к передаче в компоненту печати штрихкодов.
//
// Параметры:
//  ЗначениеШтрихкода - Строка - Штрихкод
//  ТипКода - Число - Тип кода (см. документацию по компоненте печати штрихкодов)
//  ТипВходныхДанных - Число - Тип входных данных [Входящий / Исходящий]
// Возвращаемое значение:
//  Строка - Штрихкод для передачи в компоненту печати
Функция КодGS1ДляКомпонентыПечати(ЗначениеШтрихкода, ТипКода, ТипВходныхДанных = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИС.КодGS1ДляКомпонентыПечати(ЗначениеШтрихкода, ТипКода, ТипВходныхДанных);
```
</details>

## ПолучитьСтруктуруРеквизитовДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные реквизитов шапки документа.
//  Имена реквизитов собираются по метаданным документа.
//
// Параметры:
//  ВходноеЗначение - ДокументСсылка, ДокументОбъект, ДанныеФормыСтруктура - Ссылка на документ.
// Возвращаемое значение:
//  Структура - содержит имена (ключи) и значения реквизитов переданного документа, включая ссылку на документ,
//	см. ОбщегоНазначения.ЗначенияРеквизитовОбъекта
Функция ПолучитьСтруктуруРеквизитовДокумента(ВходноеЗначение) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИС.ПолучитьСтруктуруРеквизитовДокумента(ВходноеЗначение) 
```
</details>

## ВыполнитьДействие
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет действие после уточнения информации у пользователя
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма, для которой необходимо обработать штрихкоды.
//  Действие - Строка - Идентификатор необходимого действия.
//  Параметры - См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализироватьПараметрыОбработкиВыбора.
// Возвращаемое значение:
//  Структура, Неопределено - Результат выполнения действия.
Функция ВыполнитьДействие(Форма, Действие, Параметры) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИС.ВыполнитьДействие(Форма, Действие, Параметры) 
```
</details>

## УчитываемыеВидыМаркируемойПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// см. ИнтеграцияИС.УчитываемыеВидыМаркируемойПродукции
Функция УчитываемыеВидыМаркируемойПродукции() Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИС.УчитываемыеВидыМаркируемойПродукции() 
```
</details>

## НовыйЭлементКоллекцииУпаковокДляРаспределенияПоТоварам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает и возвращает новый элемент коллекции упаковок для распределения по товарам.
//
// Возвращаемое значение:
//  Структура - Новый элемент коллекции упаковок для распределения по товарам:
// * ШтрихкодУпаковки                 - СправочникСсылка.ШтрихкодыУпаковокТоваров, Неопределено           - штрихкод упаковки товара.
// * ЧастичноеВыбытиеКоличество       - Число, Неопределено                                               - часть упаковки, с которой производится операция (числитель).
// * ЧастичноеВыбытиеВариантУчета     - ПеречислениеСсылка.ВариантыУчетаЧастичногоВыбытияИС, Неопределено - вариант учета частичного выбытия.
// * ЧастичноеВыбытиеНоменклатура     - ОпределяемыйТип.Номенклатура, Неопределено                        - номенклатура частичного выбытия, если отличается от основной.
// * ЧастичноеВыбытиеХарактеристика   - ОпределяемыйТип.ХарактеристикаНоменклатуры, Неопределено          - характеристика частичного выбытия, если отличается от основной.
// * РазрешительныйРежимИдентификаторЗапросаГИСМТ - ОпределяемыйТип.УникальныйИдентификаторИС, Неопределено - идентификатор запроса ГИС МТ
// * РазрешительныйРежимДатаЗапросаГИСМТ          - Строка, Неопределено                                    - дата получения идентификатора ГИС МТ в формате
// * ВыбытиеБутылки                               - Булево, Неопределено                                    - признак выбытия бутылки ЕГАИС
Функция НовыйЭлементКоллекцииУпаковокДляРаспределенияПоТоварам() Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИС.НовыйЭлементКоллекцииУпаковокДляРаспределенияПоТоварам() 
```
</details>

## ДобавитьИзменитьКодМаркировкиВскрытойПотребительскойУпаковки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Используется для автоматического заполнения кодов маркировки по вскрытым потребительским упаковкам.
// Возвращает штрихкод упаковки с данными частичного выбытия, которые сохраняются в документе розничной продажи.
//
// Параметры:
//  ПараметрыСканирования - см. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования
// 	Товары - ТаблицаЗначений, ТабличнаяЧасть, ДанныеФормыКоллекция, Массив из СтрокаТабличнойЧасти - Таблица товаров для заполнения по всем строкам одновременно
// 	 	   - СтрокаТаблицыЗначений, СтрокаТабличнойЧасти, ДанныеФормыЭлементКоллекции - Строка товаров, если необходимо заполнить код маркировки в строке товаров
// 	       Таблица/элемент коллекции определяется полями:
// 	        * Номенклатура   - ОпределяемыйТип.Номенклатура               - Номенклатура таблицы товаров
// 	        * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - Характеристика таблицы товаров (опционально)
// 	        * Серия          - ОпределяемыйТип.СерияНоменклатуры          - Серия таблицы товаров (опционально)
// 	        * Количество     - Число                                      - Количество единиц товаров
//  ШтрихкодыУпаковок - Неопределено - Код маркировки размещается в таблице товаров
//                    - ТаблицаЗначений, ТабличнаяЧасть, ДанныеФормыКоллекция, Массив из см. РаспределениеШтрихкодовУпаковокПоТоварам -
//                      Коллекция штрихкодов упаковок из документа с данными частичного выбытия.
// Возвращаемое значение:
//  Структура - Добавить изменить код маркировки кега на оборудовании розлива:
// * ЕстьИзменения - Булево - Признак наличия изменений: Добавлен или изменен код маркировки с данными частичного выбытия
// * КодыМаркировки - Соответствие из КлючИЗначение:
//                    * Ключ - СтрокаТаблицыЗначений, СтрокаТабличнойЧасти, ДанныеФормыЭлементКоллекции - Исходная строка Товаров
//                    * Значение - Массив из см. НовыйЭлементКоллекцииУпаковокДляРаспределенияПоТоварам
// * УдалитьКодыМакрировки - Массив из ОпределяемыйТип.ШтрихкодУпаковкиИС
// * УстановленныеСерии - Соответствие из КлючИЗначение:
//                             * Ключ - СтрокаТаблицыЗначений, СтрокаТабличнойЧасти, ДанныеФормыЭлементКоллекции - Исходная строка Товаров
//                             * Значение - ОпределяемыйТип.СерияНоменклатуры - значение серии кода маркировки, в случае если в исходной строке товаров серия не былы указана
Функция ДобавитьИзменитьКодМаркировкиВскрытойПотребительскойУпаковки(ПараметрыСканирования, Товары, ШтрихкодыУпаковок = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИС.ДобавитьИзменитьКодМаркировкиВскрытойПотребительскойУпаковки(ПараметрыСканирования, Товары, ШтрихкодыУпаковок);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
