---
title: Штрихкодирование ИС вызов сервера
slug: erp-uh/штрихкодирование-ис-вызов-сервера
---


## ОбработатьДанныеRFID
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет обработку штрихкода и возвращает результат этой обработки.
//
// Параметры:
//  ДанныеRFID - Структура - Данные RFID-меток.
//  ПараметрыСканирования - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования).
//  КэшированныеЗначения - Структура - Содержит поля кэшируемых значений.
//  УникальныйИдентификатор - УникальныйИдентификатор - Идентификатор, по которому будут помещены данные по обработанным
//                                                      штрихкодам в хранилище.
// Возвращаемое значение:
//  Структура - (См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализироватьРезультатОбработкиШтрихкода).
Функция ОбработатьДанныеRFID(ДанныеRFID, ПараметрыСканирования, КэшированныеЗначения, УникальныйИдентификатор) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИСВызовСервера.ОбработатьДанныеRFID(ДанныеRFID, ПараметрыСканирования, КэшированныеЗначения, УникальныйИдентификатор) 
```
</details>

## ДанныеRFID
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет обработку штрихкода и возвращает результат этой обработки.
//
// Параметры:
//  СырыеДанные - Массив Из Структура - Сырые данные со считывателя RFID-меток.
//
// Возвращаемое значение:
//  Структура:
//   * ДанныеRFID - См. ШтрихкодированиеИСКлиентСервер.ИнициализироватьДанныеRFID
//   * ТекстОшибки - Строка - Текст ошибки
Функция ДанныеRFID(СырыеДанные) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИСВызовСервера.ДанныеRFID(СырыеДанные) 
```
</details>

## ОбработатьДанныеШтрихкодаПослеВыбораСерии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет серию в элемент справочника "ШтрихкодыУпаковок".
//
// Параметры:
//  РезультатОбработки - См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализироватьРезультатОбработкиШтрихкода.
//  РезультатВыбора - См. ШтрихкодированиеИСКлиент.ИнициализацияСтруктурыДанныхСохраненногоВыбора.
// Возвращаемое значение:
// (См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализироватьДанныеШтрихкода).
Функция ОбработатьДанныеШтрихкодаПослеВыбораСерии(РезультатОбработки, РезультатВыбора) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИСВызовСервера.ОбработатьДанныеШтрихкодаПослеВыбораСерии(РезультатОбработки, РезультатВыбора) 
```
</details>

## ВидПродукцииПоGTIN
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает вид продукции по коду GTIN.
//
// Параметры:
//  GTIN - Строка - Код формата GTIN.
// Возвращаемое значение:
//  ПеречислениеСсылка.ВидыПродукцииИС - Вид продукции ИС.
Функция ВидПродукцииПоGTIN(GTIN) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИСВызовСервера.ВидПродукцииПоGTIN(GTIN) 
```
</details>

## ОчиститьОтложенныеКодыМаркировки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Очищает отложенные коды маркировки в кеше маркируемой продукции
//
// Параметры:
//  АдресКэшаМаркируемойПродукции - Строка - Адрес временного хранилища кеша маркируемой продукции
Процедура ОчиститьОтложенныеКодыМаркировки(АдресКэшаМаркируемойПродукции) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеИСВызовСервера.ОчиститьОтложенныеКодыМаркировки(АдресКэшаМаркируемойПродукции) 
```
</details>

## ОчиститьКэшМаркируемойПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Очищает кеш маркируемой продукции
//
// Параметры:
//  АдресКэшаМаркируемойПродукции - Строка - Адрес временного хранилища кеша маркируемой продукции
Процедура ОчиститьКэшМаркируемойПродукции(АдресКэшаМаркируемойПродукции) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеИСВызовСервера.ОчиститьКэшМаркируемойПродукции(АдресКэшаМаркируемойПродукции) 
```
</details>

## ДанныеДляУточненияСведенийПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные для уточнения сведений у пользователя из кэша по адресу.
//
// Параметры:
//  АдресВременногоХранилища - Строка - Адрес кэша обработки кодов маркировки.
// Возвращаемое значение:
//  Неопределено - Структура -
Функция ДанныеДляУточненияСведенийПользователя(АдресВременногоХранилища) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеИСВызовСервера.ДанныеДляУточненияСведенийПользователя(АдресВременногоХранилища) 
```
</details>

## ОбработатьУточнениеДанныхДляФормыПроверкиИПодбора
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбработатьУточнениеДанныхДляФормыПроверкиИПодбора(РезультатВыбора, РезультатОбработки, ПараметрыСканирования, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеИСВызовСервера.ОбработатьУточнениеДанныхДляФормыПроверкиИПодбора(РезультатВыбора, РезультатОбработки, ПараметрыСканирования, КэшированныеЗначения) 
```
</details>

## ОбработатьГрупповоеУточнениеДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбработатьГрупповоеУточнениеДанных(СохраненныйВыбор, ОбновляемыеШтрихкодыУпаковок, ПараметрыСканирования) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеИСВызовСервера.ОбработатьГрупповоеУточнениеДанных(СохраненныйВыбор, ОбновляемыеШтрихкодыУпаковок, ПараметрыСканирования) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
