---
title: Штрихкодирование МОТП
slug: erp-uh/штрихкодирование-мотп
---


## ОбработатьУточнениеДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет поля данных штрихкода, используемые подсистемой МОТП, после уточнения данных:
//  * Выбор вида и типа упаковки (пачка/блок), если ранее он не распознан, по коэффициенту вложенности (количеству пачек)
//  * По виду упаковки и коэффициенту указание количества пачек и блоков.
//
// Параметры:
//  ДанныеШтрихкода - Структура - текущие данные штрихкода
//  ДанныеВыбора    - Структура - данные уточнения номенклатуры
//  ПараметрыСканирования - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования).
//  РезультатОбработки    - Структура - Результат обработки штрихкода.
Процедура ОбработатьУточнениеДанных(ДанныеШтрихкода, ДанныеВыбора, ПараметрыСканирования, РезультатОбработки) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.ОбработатьУточнениеДанных(ДанныеШтрихкода, ДанныеВыбора, ПараметрыСканирования, РезультатОбработки) 
```
</details>

## ВложенныеШтрихкодыУпаковокПоДокументу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует структуру вложенных штрихкодов по ссылке на документ.
//
// Параметры:
//  ДокументСсылка - ДокументСсылка - Ссылка на документ.
//  Детализация - ПеречислениеСсылка.ДетализацияСтруктурыХраненияИС - Детализация, с которой
//                           требуется сформировать вложенные штрихкоды.
//  ПараметрыСканирования - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования).
//  СортироватьДанные - Булево - Необходимость сортировки данных дерева.
// Возвращаемое значение:
//  (См. ИнициализацияВложенныхШтрихкодов).
Функция ВложенныеШтрихкодыУпаковокПоДокументу(ДокументСсылка, ПараметрыСканирования, СортироватьДанные = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеМОТП.ВложенныеШтрихкодыУпаковокПоДокументу(ДокументСсылка, ПараметрыСканирования, СортироватьДанные);
```
</details>

## ВложенныеШтрихкодыУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует структуру вложенных штрихкодов по ссылке на документ.
//
// Параметры:
//  ШтрихкодыУпаковок - Массив из Структура - Описание:
// * ШтрихкодУпаковки - СправочникСсылка.ШтрихкодыУпаковокТоваров - Ссылка на элемент справочника.
// * Штрихкод - Строка - Код маркировки.
//  Детализация - ПеречислениеСсылка.ДетализацияСтруктурыХраненияИС - Детализация, с которой
//                           требуется сформировать вложенные штрихкоды.
//  ПараметрыСканирования - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования).
//  СортироватьДанные - Булево - Необходимость сортировки данных дерева.
// Возвращаемое значение:
//  (См. ИнициализацияВложенныхШтрихкодов).
Функция ВложенныеШтрихкодыУпаковок(ШтрихкодыУпаковок, ПараметрыСканирования, СортироватьДанные = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеМОТП.ВложенныеШтрихкодыУпаковок(ШтрихкодыУпаковок, ПараметрыСканирования, СортироватьДанные);
```
</details>

## ШтрихкодыУпаковокИзДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ШтрихкодыУпаковокИзДокумента(Знач ДокументСсылка, Знач ПараметрыСканирования) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеМОТП.ШтрихкодыУпаковокИзДокумента(ДокументСсылка, ПараметрыСканирования) 
```
</details>

## ЗаполнитьДанныеНеизвестнойМаркируемойПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует данные по неизвестным кодам табачных пачек и заполняет данные по штрихкодам.
//
// Параметры:
//  ДанныеПоШтрихкодам - (См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализацияДанныхПоШтрихкодам).
//  ПараметрыСканирования - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования).
Процедура ЗаполнитьДанныеНеизвестнойМаркируемойПродукции(ДанныеПоШтрихкодам, ПараметрыСканирования) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.ЗаполнитьДанныеНеизвестнойМаркируемойПродукции(ДанныеПоШтрихкодам, ПараметрыСканирования) 
```
</details>

## ОбработатьВыбор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет обработку выбора пользователем уточняющей информации.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - Форма, для которой требуется обработка штрихкодов.
//  ИмяЭлементаВыбора - Строка - Идентификатор операции.
//  РезультатВыбора - Структура - Результат выбора данных пользователем.
//  РезультатОбработкиШтрихкода - (См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализироватьРезультатОбработкиШтрихкода).
//  КэшированныеЗначения - Структура - закэшированные данные формы.
// Возвращаемое значение:
//  (См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализироватьРезультатОбработкиШтрихкода).
Функция ОбработатьВыбор(Форма, ИмяЭлементаВыбора, РезультатВыбора, РезультатОбработкиШтрихкода, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеМОТП.ОбработатьВыбор(Форма, ИмяЭлементаВыбора, РезультатВыбора, РезультатОбработкиШтрихкода, КэшированныеЗначения) 
```
</details>

## ПривестиВложенныеШтрихкодыКТребуемомуВидуДетализации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Приводит дерево упаковок и таблицу маркированные товары к детализации, которая указана в параметрах сканирования.
//
// Параметры:
//  ВложенныеШтрихкоды - Структура - Включает в себя таблицу значений "Маркированные товары" и "Дерево упаковок".
//  ПараметрыСканирования - См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования.
//  ДанныеКодовМаркировки - Неопределено, ТаблицаЗначений - связанные данные кодов маркировки.
Процедура ПривестиВложенныеШтрихкодыКТребуемомуВидуДетализации(ВложенныеШтрихкоды, ПараметрыСканирования, ДанныеКодовМаркировки = Неопределено) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.ПривестиВложенныеШтрихкодыКТребуемомуВидуДетализации(ВложенныеШтрихкоды, ПараметрыСканирования, ДанныеКодовМаркировки);
```
</details>

## ДополнитьДанныеПоШтрихкодамСпецификой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополнение полученных данных штрихкодов данными, которые актуальны для табачной продукции.
//
// Параметры:
//  ДанныеПоШтрихкодам    - (См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализацияДанныхПоШтрихкодам).
//  ПараметрыСканирования - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования).
//  ПараметрыДополнения   - Неопределено - Поддержка обратной совместимости.
//                        - см. ШтрихкодированиеОбщегоНазначенияИС.ПараметрыДополненияВложенныхШтрихкодовУпаковок.
Процедура ДополнитьДанныеПоШтрихкодамСпецификой(ДанныеПоШтрихкодам, ПараметрыСканирования, ПараметрыДополнения = Неопределено) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.ДополнитьДанныеПоШтрихкодамСпецификой(ДанныеПоШтрихкодам, ПараметрыСканирования, ПараметрыДополнения);
```
</details>

## РасширеннаяПроверкаНаОшибкиПоПравилам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РасширеннаяПроверкаНаОшибкиПоПравилам(ДанныеПоШтрихкодам, ПравилаПроверкиНаОшибки, ПараметрыСканирования, ЕстьОшибки) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.РасширеннаяПроверкаНаОшибкиПоПравилам(ДанныеПоШтрихкодам, ПравилаПроверкиНаОшибки, ПараметрыСканирования, ЕстьОшибки) 
```
</details>

## РасширенныеПроверкиПоСтрокеДанныхМОТП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РасширенныеПроверкиПоСтрокеДанныхМОТП(СтрокаДанных, ПравилаПроверкиНаОшибки, ПараметрыСканирования, ЕстьОшибки) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.РасширенныеПроверкиПоСтрокеДанныхМОТП(СтрокаДанных, ПравилаПроверкиНаОшибки, ПараметрыСканирования, ЕстьОшибки) 
```
</details>

## ЗаполнитьПредставленияДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет представления статусов, владельцев и прочую дополнительную информацию
//
// Параметры:
//  ДанныеПоШтрихкодам - (См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализацияДанныхПоШтрихкодам).
//  ПараметрыСканирования - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования).
Процедура ЗаполнитьПредставленияДанных(ДанныеПоШтрихкодам, ПараметрыСканирования) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.ЗаполнитьПредставленияДанных(ДанныеПоШтрихкодам, ПараметрыСканирования) 
```
</details>

## ВыполнитьДействие
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Реализует обработку действий пользователя. Возвращает результат обработки.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - Форма
//  Действие - Строка - Идентификатор действия.
//  Параметры - (См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализироватьПараметрыОбработкиВыбора).
// Возвращаемое значение:
//  (См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализироватьРезультатОбработкиШтрихкода).
Функция ВыполнитьДействие(Форма, Действие, Параметры) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеМОТП.ВыполнитьДействие(Форма, Действие, Параметры) 
```
</details>

## ВложенныеШтрихкоды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру "ВложенныеШтрихкоды" по коллекции кодов марок. Для марок табачных пачек так же формируется дерево
// упаковок. Неизвестные марки будут созданы в базе.
//
// Параметры:
//  ДанныеШтрихкодовСписок - Массив из Структура:
//   * Штрихкод - Строка - Штрихкод
//   * Количество - Число - Количество
//  ПараметрыСканирования - См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования
//  ДляУпаковокТребоватьПодключениеМОТП - Булево - Требовать подключение МОТП для упаковок, если ранее не было проверено
//                                                 наличие данных для построения структуры без обращения к сервису.
//  СортироватьДанные - Булево - Необходимость сортировки данных дерева
// Возвращаемое значение:
//  См. ИнициализацияРезультатаФормированияВложенныхШтрихкодов
Функция ВложенныеШтрихкоды(ДанныеШтрихкодовСписок, ПараметрыСканирования, ДляУпаковокТребоватьПодключениеМОТП = Истина, СортироватьДанные = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеМОТП.ВложенныеШтрихкоды(ДанныеШтрихкодовСписок, ПараметрыСканирования, ДляУпаковокТребоватьПодключениеМОТП, СортироватьДанные);
```
</details>

## ДеревоУпаковокПоДаннымМОТП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет запрос в МОТП, на основании которого формирует "ВложенныеШтрихкоды".
//
// Параметры:
//  МассивСтрокТаблицы - Массив из См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализацияТаблицыДанныхКодовМаркировки.
//  ПараметрыСканирования - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования).
//  ТребуемаяДетализация - ПеречислениеСсылка.ДетализацияСтруктурыХраненияИС - Требуемая детализация
// Возвращаемое значение:
//  Структура - Описание:
// * ТекстОшибки - Строка - Текст ошибки получения данных из МОТП.
// * ЕстьОшибки - Булево - Истина, если возникла ошибка при попытке получения данных из МОТП.
// * ВложенныеШтрихкоды - Неопределено, Структура - Включает в себя дерево упаковок и маркированные товары.
Функция ДеревоУпаковокПоДаннымМОТП(МассивСтрокТаблицы, ПараметрыСканирования, ТребуемаяДетализация = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеМОТП.ДеревоУпаковокПоДаннымМОТП(МассивСтрокТаблицы, ПараметрыСканирования, ТребуемаяДетализация);
```
</details>

## ЗаполнитьДанныеНеизвестныхУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные из государтсвенных информационных систем и заполняет данные для упаковок, о которых нет никакой
// информации в справочнике Штрихкоды упаковок.
//
// Параметры:
//  ДанныеПоШтрихкодам - (См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализацияДанныхПоШтрихкодам).
//  ПараметрыСканирования - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования).
Процедура ЗаполнитьДанныеНеизвестныхУпаковок(ДанныеПоШтрихкодам, ПараметрыСканирования) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.ЗаполнитьДанныеНеизвестныхУпаковок(ДанныеПоШтрихкодам, ПараметрыСканирования) 
```
</details>

## ПроверитьПотребительскиеУпаковкиНаВхождениеВСеруюЗону
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПроверитьПотребительскиеУпаковкиНаВхождениеВСеруюЗону(ЭлементыДанных, ПараметрыСканирования) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеМОТП.ПроверитьПотребительскиеУпаковкиНаВхождениеВСеруюЗону(ЭлементыДанных, ПараметрыСканирования));
```
</details>

## ПроверитьЛогистическиеИГрупповыеУпаковкиНаСодержаниеСерыхКодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПроверитьЛогистическиеИГрупповыеУпаковкиНаСодержаниеСерыхКодов(Результат, ДанныеКодовМаркировки, ПараметрыСканирования) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеМОТП.ПроверитьЛогистическиеИГрупповыеУпаковкиНаСодержаниеСерыхКодов(Результат, ДанныеКодовМаркировки, ПараметрыСканирования));
```
</details>

## ПрименитьИзменениеКСтрокамВышестоящегоУровня
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ПрименитьИзменениеКСтрокамВышестоящегоУровня(СтрокаДерева, ИзменениеКоличествоПотребительскихУпаковок, ОчиститьГрупповыеУпаковки, КандидатыВСеруюЗону) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.ПрименитьИзменениеКСтрокамВышестоящегоУровня(СтрокаДерева, ИзменениеКоличествоПотребительскихУпаковок, ОчиститьГрупповыеУпаковки, КандидатыВСеруюЗону));
```
</details>

## УдалитьСтрокиПоСсылкамНаСтрокиДереваРекурсивно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УдалитьСтрокиПоСсылкамНаСтрокиДереваРекурсивно(СтрокаДерева, ДанныеКодовМаркировки) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.УдалитьСтрокиПоСсылкамНаСтрокиДереваРекурсивно(СтрокаДерева, ДанныеКодовМаркировки) 
```
</details>

## НайтиУпаковкиДляПроверкиНаВхождениеВСеруюЗону
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура НайтиУпаковкиДляПроверкиНаВхождениеВСеруюЗону(СтрокаДерева, КандидатыВСеруюЗону, СтандартнаяВложенностьУпаковок, ПараметрыСканирования) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.НайтиУпаковкиДляПроверкиНаВхождениеВСеруюЗону(СтрокаДерева, КандидатыВСеруюЗону, СтандартнаяВложенностьУпаковок, ПараметрыСканирования));
```
</details>

## КоэффициентУпаковки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция КоэффициентУпаковки(СтрокаДерева, СтандартнаяВложенностьУпаковок) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеМОТП.КоэффициентУпаковки(СтрокаДерева, СтандартнаяВложенностьУпаковок));
```
</details>

## GTINВложеннойГрупповойУпаковки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция GTINВложеннойГрупповойУпаковки(СтрокаДерева) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеМОТП.GTINВложеннойГрупповойУпаковки(СтрокаДерева));
```
</details>

## ВложенныеШтрихкодыПоДаннымМОТП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует вложенные штрихкоды по данным, полученным в системе МОТП.
//
// Параметры:
//  ДанныеШтрихкодовСписок - Массив из Структура - Описание:
// * Штрихкод - Строка - Код маркировки.
// * Количество - Число - Количество.
//  ПараметрыСканирования - Структура - Описание:
// Возвращаемое значение:
//  Структура - (См. ИнициализацияФормированияПолученияВложенныхШтрихкодов).
Функция ВложенныеШтрихкодыПоДаннымМОТП(ДанныеШтрихкодовСписок, ПараметрыСканирования) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеМОТП.ВложенныеШтрихкодыПоДаннымМОТП(ДанныеШтрихкодовСписок, ПараметрыСканирования));
```
</details>

## ИнициализацияРезультатаФормированияВложенныхШтрихкодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует результат формирования вложенных штрихкодов по кодам маркировки МОТП.
//
// Возвращаемое значение:
//  Структура - Описание:
// * ВложенныеШтрихкоды - Структура - Описание:
// * ЕстьОшибки - Булево - Истина, если есть ошибки.
// * ТекстОшибки - Строка - Описание ошибки.
// * ТребуетсяОбновлениеКлючаСессии - Булево - Истина, если требуется авторизация.
Функция ИнициализацияРезультатаФормированияВложенныхШтрихкодов() Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеМОТП.ИнициализацияРезультатаФормированияВложенныхШтрихкодов());
```
</details>

## ЗаполнитьДанныеНеизвестныхТабачныхПачекБезЗапросаСведенийМОТП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет данные по штрихкодам информацией по табачным пачкам без запроса сведений из МОТП.
//
// Параметры:
//  ДанныеПоШтрихкодам - (См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализацияДанныхПоШтрихкодам).
//  ПараметрыСканирования - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования).
Процедура ЗаполнитьДанныеНеизвестныхТабачныхПачекБезЗапросаСведенийМОТП(ДанныеПоШтрихкодам, ПараметрыСканирования) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.ЗаполнитьДанныеНеизвестныхТабачныхПачекБезЗапросаСведенийМОТП(ДанныеПоШтрихкодам, ПараметрыСканирования));
```
</details>

## ЗаполнитьДанныеНеизвестныхТабачныхПачекСЗапросомСведенийМОТП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запрашивает сведения из МОТП по кодам марировки табачных пачек. Дополняет данные по штрихкодам полученными сведениями.
//
// Параметры:
//  ДанныеПоШтрихкодам - (См. ШтрихкодированиеОбщегоНазначенияИС.ИнициализацияДанныхПоШтрихкодам).
//  ПараметрыСканирования - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования).
Процедура ЗаполнитьДанныеНеизвестныхТабачныхПачекСЗапросомСведенийМОТП(ДанныеПоШтрихкодам, ПараметрыСканирования) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.ЗаполнитьДанныеНеизвестныхТабачныхПачекСЗапросомСведенийМОТП(ДанныеПоШтрихкодам, ПараметрыСканирования));
```
</details>

## РасчетМРЦПоСтрокамДерева
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Расчитывает МРЦ по строкам дерева по групповой упаковке в родительской строке.
//
// Параметры:
// 	ВычисляемыеСтроки - Массив из СтрокаДереваЗначений - данные для расчета МРЦ по строкам.
Процедура РасчетМРЦПоСтрокамДерева(ВычисляемыеСтроки) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.РасчетМРЦПоСтрокамДерева(ВычисляемыеСтроки) 
```
</details>

## НормализованныйШтрихкод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция НормализованныйШтрихкод(Штрихкод, ВидПродукции, КэшДанныхРазбора = Неопределено, ПользовательскиеПараметрыРазбора = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеМОТП.НормализованныйШтрихкод(Штрихкод, ВидПродукции, КэшДанныхРазбора, ПользовательскиеПараметрыРазбора);
```
</details>

## РасчетКоэффициентовПоСтатистике
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура РасчетКоэффициентовПоСтатистике(ДеревоУпаковок, УточнениеКоэффициентовУпаковок, ПараметрыСканирования) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.РасчетКоэффициентовПоСтатистике(ДеревоУпаковок, УточнениеКоэффициентовУпаковок, ПараметрыСканирования) 
```
</details>

## ДобавитьРасширенныеКолонкиТаблицыДанныхКодовМаркировки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДобавитьРасширенныеКолонкиТаблицыДанныхКодовМаркировки(ПараметрыСканирования, ОбязательныеКолонки) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.ДобавитьРасширенныеКолонкиТаблицыДанныхКодовМаркировки(ПараметрыСканирования, ОбязательныеКолонки) 
```
</details>

## ДополнитьРасширенныеКолонкиДереваУпаковокИСМП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДополнитьРасширенныеКолонкиДереваУпаковокИСМП(КоллекцияДополнительныхКолонок) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеМОТП.ДополнитьРасширенныеКолонкиДереваУпаковокИСМП(КоллекцияДополнительныхКолонок) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
