---
title: Штрихкодирование номенклатуры ЕГАИС клиент переопределяемый
slug: erp-uh/штрихкодирование-номенклатуры-егаис-клиент-переопределяемый
---


## ОчиститьКэшированныеШтрихкоды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре нужно реализовать очистку кэшированных штрихкодов для исключения повторной обработки.
//
// Параметры:
//  ДанныеШтрихкодов - Массив - полученные штрихкоды,
//  КэшированныеЗначения - Структура - используется механизмом обработки изменения реквизитов ТЧ.
Процедура ОчиститьКэшированныеШтрихкоды(ДанныеШтрихкодов, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеНоменклатурыЕГАИСКлиентПереопределяемый.ОчиститьКэшированныеШтрихкоды(ДанныеШтрихкодов, КэшированныеЗначения) 
```
</details>

## ПодготовитьДанныеДляОбработкиТаблицыТоваровПолученнойИзТСД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В функции нужно реализовать подготовку данных для дальнейшей обработки штрихкодов, полученных из ТСД.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа, в которой происходит обработка,
//  ТаблицаТоваров - Массив - полученные данные из ТСД,
//  КэшированныеЗначения - Структура - используется механизмом обработки изменения реквизитов ТЧ,
//  ПараметрыЗаполнения - Структура - параметры заполнения (см. ИнтеграцияЕГАИСКлиентСервер.ПараметрыЗаполненияТабличнойЧасти()).
//  СтруктураДействий - Структура - подготовленные данные.
Процедура ПодготовитьДанныеДляОбработкиТаблицыТоваровПолученнойИзТСД( Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеНоменклатурыЕГАИСКлиентПереопределяемый.ПодготовитьДанныеДляОбработкиТаблицыТоваровПолученнойИзТСД();
```
</details>

## ПослеОбработкиТаблицыТоваровПолученнойИзТСД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается после загрузки данных из ТСД. В процедуре нужно проанализировать полученные штрихкоды на предмет сканирования акцизной марки, а также
// обработать штрихкоды, не привязанные к номенклатуре.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа, в которой были обработаны штрихкоды,
//  ОбработанныеДанные - Структура - подготовленные ранее данные штрихкодов,
//  КэшированныеЗначения - Структура - используется механизмом обработки изменения реквизитов ТЧ.
Процедура ПослеОбработкиТаблицыТоваровПолученнойИзТСД(Форма, ОбработанныеДанные, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеНоменклатурыЕГАИСКлиентПереопределяемый.ПослеОбработкиТаблицыТоваровПолученнойИзТСД(Форма, ОбработанныеДанные, КэшированныеЗначения) 
```
</details>

## ОткрытьФормуРегистрацииШтрихкодовНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре нужно открыть форму регистрации новых штрихкодов номенклатуры.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма, откуда производится вызов процедуры,
//  ДанныеШтрихкодов - Массив - элемент массива - структура с ключами:
//   * Штрихкод - Строка - штрихкод номенклатуры,
//   * Количество - Число - количество алкогольной продукции.
Процедура ОткрытьФормуРегистрацииШтрихкодовНоменклатуры(Форма, ДанныеШтрихкодов) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеНоменклатурыЕГАИСКлиентПереопределяемый.ОткрытьФормуРегистрацииШтрихкодовНоменклатуры(Форма, ДанныеШтрихкодов) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
