---
title: Штрихкодирование номенклатуры ЕГАИС переопределяемый
slug: erp-uh/штрихкодирование-номенклатуры-егаис-переопределяемый
---


## ОбработатьШтрихкоды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре требуется реализовать алгоритм обработки полученных штрихкодов.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа, в которой происходит обработка,
//  ДанныеДляОбработки - Структура - подготовленные ранее данные для обработки,
//  КэшированныеЗначения - Структура - используется механизмом обработки изменения реквизитов ТЧ.
Процедура ОбработатьШтрихкоды(Форма, ДанныеДляОбработки, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеНоменклатурыЕГАИСПереопределяемый.ОбработатьШтрихкоды(Форма, ДанныеДляОбработки, КэшированныеЗначения) 
```
</details>

## ОбработатьДанныеИзТСД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре требуется реализовать алгоритм обработки полученных штрихкодов из ТСД.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма документа, в которой происходит обработка,
//  ДанныеДляОбработки - Структура - подготовленные ранее данные для обработки,
//  КэшированныеЗначения - Структура - используется механизмом обработки изменения реквизитов ТЧ.
Процедура ОбработатьДанныеИзТСД(Форма, ДанныеДляОбработки, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеНоменклатурыЕГАИСПереопределяемый.ОбработатьДанныеИзТСД(Форма, ДанныеДляОбработки, КэшированныеЗначения) 
```
</details>

## ПриПолученииШтрихкодовНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре требуется реализовать алгоритм заполнения массива штрихкодов по переданному отбору.
//
// Параметры:
//   МассивШтрихкодов - Массив    - результат получения штрихкодов
//   Отбор            - Структура - переданные ключи отбора:
//    * Номенклатура   - ОпределяемыйТип.Номенклатура - ссылка на номенклатуру,
//    * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - ссылка на характеристику номенклатуры,
//    * Упаковка       - ОпределяемыйТип.Упаковка - ссылка на упаковку.
//
// Возвращаемое значение:
//  Массив Из Строка - массив штрихкодов.
Процедура ПриПолученииШтрихкодовНоменклатуры(МассивШтрихкодов, Отбор) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеНоменклатурыЕГАИСПереопределяемый.ПриПолученииШтрихкодовНоменклатуры(МассивШтрихкодов, Отбор) 
```
</details>

## НайтиПоШтрихкоду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получить данные о номенклатуре по штрихкоду. Заполняемое значение - Структура со свойствами:
//   * НоменклатураЕГАИС - СправочникСсылка.КлассификаторАлкогольнойПродукцииЕГАИС - ссылка на алкогольную продукцию,
//   * Номенклатура - ОпределяемыйТип.Номенклатура - ссылка на номенклатуру,
//   * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - ссылка на характеристику номенклатуры.
//   * Упаковка - ОпределяемыйТип.Упаковка - ссылка на упаковку номенклатуры.
//   или Неопределено если не найдено
//
// Параметры:
//   ДанныеСопоставления - Структура, Неопределено - результат поиска
//   Штрихкод            - Строка                  - считанный штрихкод.
Процедура НайтиПоШтрихкоду(ДанныеСопоставления, Штрихкод) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеНоменклатурыЕГАИСПереопределяемый.НайтиПоШтрихкоду(ДанныеСопоставления, Штрихкод) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
