---
title: Штрихкодирование номенклатуры клиент
slug: erp-uh/штрихкодирование-номенклатуры-клиент
---


## ОбработатьНеизвестныеШтрихкоды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура выполняет обработку неизвестных штрихкодов. В зависимости от наличия прав пользователя, выдает сообщение
// о неизвестных штрихкодах или открывает форму регистрации новых штрихкодов номенклатуры.
//
// Параметры:
//  СтруктураПараметровДействия - Структура
//  КэшированныеЗначения        - Структура
//  ФормаВладелец               - Форма.
//
Процедура ОбработатьНеизвестныеШтрихкоды(СтруктураПараметровДействия, КэшированныеЗначения, ФормаВладелец) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеНоменклатурыКлиент.ОбработатьНеизвестныеШтрихкоды(СтруктураПараметровДействия, КэшированныеЗначения, ФормаВладелец) 
```
</details>

## ПоказатьВводШтрихкода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура показывает ввод штрихкода и оповещает в случае успешного ввода
//
// Параметры:
//  ОповещениеУспешногоВвода - ОписаниеОповещения - описание оповещения успешного ввода штрихкода
//  Количество - Число
//  Заголовок                - Строка             - переопределяемый заголовок.
Процедура ПоказатьВводШтрихкода(ОповещениеУспешногоВвода, Количество = Неопределено, Заголовок = "") Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеНоменклатурыКлиент.ПоказатьВводШтрихкода(ОповещениеУспешногоВвода, Количество, Заголовок);
```
</details>

## ПараметрыОбработкиШтрихкодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру параметров обработки штрихкодов.
//
// Возвращаемое значение:
//  Структура - Параметры обработки штрихкодов.
//
Функция ПараметрыОбработкиШтрихкодов() Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеНоменклатурыКлиент.ПараметрыОбработкиШтрихкодов() 
```
</details>

## НужноОткрытьФормуУказанияСерийПослеОбработкиШтрихкодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет необходимость открытия формы указания серий после обработки штрихкодов.
// Форму нужно открывать, если был отсканирован один штрихкод товара, по которому ведется учет серий.
//
// Параметры:
//  ПараметрыОбработкиШтрихкодов - см. ШтрихкодированиеНоменклатурыКлиент.ПараметрыОбработкиШтрихкодов.
//
// Возвращаемое значение:
//  Булево - Истина, если нужно открыть форму.
//
Функция НужноОткрытьФормуУказанияСерийПослеОбработкиШтрихкодов(ПараметрыОбработкиШтрихкодов) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеНоменклатурыКлиент.НужноОткрытьФормуУказанияСерийПослеОбработкиШтрихкодов(ПараметрыОбработкиШтрихкодов) 
```
</details>

## НужноОткрытьФормуУказанияАкцизныхМарокПослеОбработкиШтрихкодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет необходимость открытия формы указания акцизных марок после обработки штрихкодов.
// Форму нужно открывать, если был отсканирован один штрихкод маркируемой алкогольной продукции.
//
// Параметры:
//  ПараметрыОбработкиШтрихкодов - см. ШтрихкодированиеНоменклатурыКлиент.ПараметрыОбработкиШтрихкодов.
//
// Возвращаемое значение:
//  Булево - Истина, если нужно открыть форму.
//
Функция НужноОткрытьФормуУказанияАкцизныхМарокПослеОбработкиШтрихкодов(ПараметрыОбработкиШтрихкодов) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеНоменклатурыКлиент.НужноОткрытьФормуУказанияАкцизныхМарокПослеОбработкиШтрихкодов(ПараметрыОбработкиШтрихкодов) 
```
</details>

## СтруктураДанныхШтрихкода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру, которая затем обрабатывается процедурами заполнения ТЧ.
//
// Параметры:
//  Штрихкод - Строка - штрихкод, который необходимо обработать.
//  Количество - Число - количество товаров с указанным штрихкодом.
//
// Возвращаемое значение:
//  Структура - Структура со свойствами:
//   * Штрихкод - Строка - Штрихкод.
//   * Количество - Число - Количество.
//
Функция СтруктураДанныхШтрихкода(Штрихкод, Количество) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеНоменклатурыКлиент.СтруктураДанныхШтрихкода(Штрихкод, Количество) 
```
</details>

## ШтрихкодыВалидны
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Определяет валидны или нет переданные штрихкоды.
// Если в штрихкодах есть недопустимые символы код признан не валидным.
//
// Параметры:
//  Штрихкоды - Массив, Структура - Данные по штрихкодам.
//  ВыводитьОповещение - Булево - Истина, выводить оповещение пользователю.
//
// Возвращаемое значение:
//  Булево - Истина, если штрихкоды валидны.
//
Функция ШтрихкодыВалидны(Штрихкоды, ВыводитьОповещение = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеНоменклатурыКлиент.ШтрихкодыВалидны(Штрихкоды, ВыводитьОповещение);
```
</details>

## ДляОбработкиRFIDНуженСерверныйВызов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция - Для обработки RFIDНужен серверный вызов
//
// Параметры:
//  ДанныеМеток	 - Массив - данные меток
//  Форма		 - ФормаКлиентскогоПриложения - форма, из которой вызывается функция.
//
// Возвращаемое значение:
// Булево - Истина, если нужен серверный вызов.
//
Функция ДляОбработкиRFIDНуженСерверныйВызов(ДанныеМеток, Форма) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеНоменклатурыКлиент.ДляОбработкиRFIDНуженСерверныйВызов(ДанныеМеток, Форма) 
```
</details>

## ОткрытьСессиюСчитывателяRFID
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура - Открыть сессию считывателя RFID
//
// Параметры:
//  Форма				 - ФормаКлиентскогоПриложения - форма, из которой вызывается процедура
//  СледующееДействие	 - ОписаниеОповещения - описание следующего действия.
//
Процедура ОткрытьСессиюСчитывателяRFID(Форма, СледующееДействие = Неопределено) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеНоменклатурыКлиент.ОткрытьСессиюСчитывателяRFID(Форма, СледующееДействие);
```
</details>

## ОтработатьТаймаутОжиданияСчитыванияRFID
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура - Отработать таймаут ожидания считывания метки
//
// Параметры:
//  Форма	 - ФормаКлиентскогоПриложения - форма, из которой вызывается процедура.
//
Процедура ОтработатьТаймаутОжиданияСчитыванияRFID(Форма) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеНоменклатурыКлиент.ОтработатьТаймаутОжиданияСчитыванияRFID(Форма) 
```
</details>

## ЗаписатьДанныеВRFID
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура - Записать данные ВRFID
//
// Параметры:
//  Результат	 - Неопределено - служебный параметр описания оповещения (не используется)
//  Параметры	 - Структура - параметры с данными серий для записи.
//
Процедура ЗаписатьДанныеВRFID(Результат, Параметры) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеНоменклатурыКлиент.ЗаписатьДанныеВRFID(Результат, Параметры) 
```
</details>

## ЗаписатьДанныеВRFIDЗавершение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl


// Процедура - Записать данные ВRFIDЗавершение
//
// Параметры:
//  Результат	 - Структура - со свойствами:
//  	*Результат - Булево - признак успешного выполнения предыдущей операции
//  Параметры	 - Структура - со свойствами:
//  	*ДанныеСерии - Структура - с данными серии в свойствах.
//
Процедура ЗаписатьДанныеВRFIDЗавершение(Результат, Параметры) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеНоменклатурыКлиент.ЗаписатьДанныеВRFIDЗавершение(Результат, Параметры) 
```
</details>

## ОтключитьОборудование
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура - Отключить оборудование
//
// Параметры:
//  Результат	 - Неопределено - не используется (служебный параметр)
//  Параметры	 - Структура - содержит свойства:
//		*Форма - ФормаКлиентскогоПриложения - форма, откуда было инициировано отключение оборудования.
//
Процедура ОтключитьОборудование(Результат, Параметры) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеНоменклатурыКлиент.ОтключитьОборудование(Результат, Параметры) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
