---
title: Штрихкодирование номенклатуры сервер
slug: erp-uh/штрихкодирование-номенклатуры-сервер
---


## ОбработатьШтрихкоды
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура обрабатывает введенные штрихкоды:
// - добавляет введенные штрихкоды в табличную часть документа;
// - вызывает помощник создания штрихкода, если он не был найден.
// Параметры:
//   Форма - ФормаКлиентскогоПриложения - форма для которой будут обработаны введенные штрихкоды.
//   Объект - ДанныеФормыСтруктура - объект формы.
//   СтруктураПараметров - см. ШтрихкодированиеНоменклатурыКлиентСервер.ПараметрыОбработкиШтрихкодов
//   КэшированныеЗначения - см. ОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
Процедура ОбработатьШтрихкоды(Форма, Объект, СтруктураПараметров, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеНоменклатурыСервер.ОбработатьШтрихкоды(Форма, Объект, СтруктураПараметров, КэшированныеЗначения) 
```
</details>

## ПравоРегистрацииШтрихкодовНоменклатурыДоступно
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция - Право регистрации штрихкодов номенклатуры доступно
//
// Возвращаемое значение:
// Булево - Истина, если доступно.
//
Функция ПравоРегистрацииШтрихкодовНоменклатурыДоступно() Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеНоменклатурыСервер.ПравоРегистрацииШтрихкодовНоменклатурыДоступно() 
```
</details>

## НоменклатураПоШтрихкоду
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает ссылку на номенклатуру, соответствующую переданному штрихкоду или Неопределено, если штрихкод не зарегистрирован.
//
// Параметры:
//  ПараметрыОбработки - см. ШтрихкодированиеНоменклатурыКлиентСервер.ПараметрыОбработкиШтрихкодов
//  КэшированныеЗначения - см. ОбработкаТабличнойЧастиКлиентСервер.ПолучитьСтруктуруКэшируемыеЗначения
//
// Возвращаемое значение:
//  СправочникСсылка.Номенклатура, Неопределено - Результат поиска номенклатуры по штрихкоду.
//
Функция НоменклатураПоШтрихкоду(ПараметрыОбработки, КэшированныеЗначения) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеНоменклатурыСервер.НоменклатураПоШтрихкоду(ПараметрыОбработки, КэшированныеЗначения) 
```
</details>

## СтруктураПоТипамШтрихкодов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Раскладывает переданный массив считанных штрихкодов по типам штрихкодов.
//
// Параметры:
//	Штрихкоды - Массив Из см. ШтрихкодированиеНоменклатурыКлиент.СтруктураДанныхШтрихкода - коллекция описания состава штрихкода.
//
// Возвращаемое значение:
//	Структура - коллекция описания типов штрихкодов, содержащая следующие свойства:
//		* БезТипа - Массив из см. ШтрихкодированиеНоменклатурыКлиент.СтруктураДанныхШтрихкода.
//
Функция СтруктураПоТипамШтрихкодов(Штрихкоды) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеНоменклатурыСервер.СтруктураПоТипамШтрихкодов(Штрихкоды) 
```
</details>

## ОбработатьСчитываниеRFID
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняется обработка считанных RFID-меток.
//
// Параметры:
//	ДанныеМеток					- Массив из Структура	- данные меток.
//	ПараметрыОбработки			- см. ПараметрыОбработкиСчитанныхRFID.
//	ТЧСерии						- ТабличнаяЧасть		- табличная часть Серии.
//	ИдентификаторТекущейСтроки	- Число					- идентификатор.
//
// Возвращаемое значение:
//	Структура - содержит свойства:
//		* ЗакрытьФорму - Булево - признак необходимости закрыть форму
//		* ИдентификаторТекущейСтроки - Число, Неопределено - идентификатор
//		* ДанныеСерии - СтрокаТабличнойЧасти, Неопределено - строка с серией.
//
Функция ОбработатьСчитываниеRFID(ДанныеМеток, ПараметрыОбработки, ТЧСерии = Неопределено, ИдентификаторТекущейСтроки = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеНоменклатурыСервер.ОбработатьСчитываниеRFID(ДанныеМеток, ПараметрыОбработки, ТЧСерии, ИдентификаторТекущейСтроки);
```
</details>

## ПараметрыОбработкиСчитанныхRFID
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Функция - Параметры обработки считанных RFID и КиЗ
//
// Возвращаемое значение:
//	Структура - параметры обработки:
//	* СчитывательRFID - СправочникСсылка.ПодключаемоеОборудование - ссылка на считыватель RFID.
//	* УникальныйИдентификатор - УникальныйИдентификатор, Неопределено - уникальный идентификатор формы.
//	* НастройкиИспользованияСерий - см. Справочники.ВидыНоменклатуры.НастройкиИспользованияСерий.
//	* ПараметрыУказанияСерий - см. НоменклатураКлиентСервер.ПараметрыУказанияСерий.
//	* ЗначенияПолейСвязи - Структура - коллекция связи полей между ТЧ Товары и ТЧ Серии из ПараметрыУказанияСерий.ПоляСвязи:
//		** Ключ - Строка - имя реквизита без суффикса, например "Номенклатура".
//		** Значение - Строка - имя реквизита с суффиксом, например "НоменклатураОприходование".
//
Функция ПараметрыОбработкиСчитанныхRFID() Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеНоменклатурыСервер.ПараметрыОбработкиСчитанныхRFID() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
