---
title: Штрихкодирование общего назначения ИС
slug: erp-uh/штрихкодирование-общего-назначения-ис
---


## ПараметрыСканирования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет инициализацию и заполнение параметров сканирования по переданному контексту.
// Параметры сканирования необходимы для анализа и обработки штрихкодов маркируемой продукции.
//
// Параметры:
//  Контекст - Неопределено, Структура, ВыборкаИзРезультатаЗапроса, ФормаКлиентскогоПриложения - Источник данных для формирования параметров сканирования.
//  ФормаВыбора - ФормаКлиентскогоПриложения - Форма выбора.
//  ВидПродукции - ПеречислениеСсылка.ВидыПродукцииИС - Вид продукции, по которому будут инициализированы параметры сканирования.
//  ПараметрыРежимаИсправленияОшибок - Структура - Параметры режима исправления ошибок.
//
// Возвращаемое значение:
//  См. ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.БазовыеПараметрыСканирования
Функция ПараметрыСканирования(Контекст = Неопределено, ФормаВыбора = Неопределено, ВидПродукции = Неопределено, ПараметрыРежимаИсправленияОшибок = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИС.ПараметрыСканирования(Контекст, ФормаВыбора, ВидПродукции, ПараметрыРежимаИсправленияОшибок);
```
</details>

## ТекстЗапросаСвойстваМаркируемойПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет текст запроса получения признаков номенклатуры:
//   * МаркируемаяПродукция,
//   * ВидПродукции.
// Помещает признаки во временную таблицу "СвойстваМаркируемойПродукции".
//
// Параметры:
//  ТаблицаИсточник - Строка - имя временной таблицы запроса-источника данных.
// Возвращаемое значение:
//  Строка - Текст формирования временной таблицы запроса.
//
Функция ТекстЗапросаСвойстваМаркируемойПродукции(ТаблицаИсточник = "ДанныеШтрихкодовУпаковок") Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИС.ТекстЗапросаСвойстваМаркируемойПродукции(ТаблицаИсточник);
```
</details>

## ОбработатьВводШтрихкода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет обработку штрихкода и возвращает результат этой обработки.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения - форма, для которой необходимо выполнить обработку штрихкода.
//  ВходящиеДанные - Структура - Исходные данные, включающие только значение штрихкода и количество,
//                               либо уже полноценные заполненные данные штрихкода, которые нуждаются в обработке.
//  КэшированныеЗначения - Структура - Содержит поля кэшируемых значений
//  ПараметрыСканирования - См. ПараметрыСканирования
// Возвращаемое значение:
//  См. ИнициализироватьРезультатОбработкиШтрихкода
Функция ОбработатьВводШтрихкода(Форма, ВходящиеДанные, КэшированныеЗначения, ПараметрыСканирования = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИС.ОбработатьВводШтрихкода(Форма, ВходящиеДанные, КэшированныеЗначения, ПараметрыСканирования);
```
</details>

## ПодготовитьДанныеКодовМаркировкиДляОбработки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет таблицу "ДанныеКодовМаркировки" данными разбора кода и сведениями по номенклатуре на основании штрихкода EAN,
// входящего в состав кода маркировки.
//
// Параметры:
//  ДанныеПоШтрихкодам    - См. ИнициализацияДанныхПоШтрихкодам.
//  СписокДанныхШтрихкода - Массив Из Структура.
//  ПараметрыСканирования - См. ПараметрыСканирования
//  КешДанныхРазбора - Неопределено, Соответствие из КлючИЗначение - Известный кешированный результат разбора кодов маркировки
Процедура ПодготовитьДанныеКодовМаркировкиДляОбработки(ДанныеПоШтрихкодам, СписокДанныхШтрихкода, ПараметрыСканирования, КешДанныхРазбора = Неопределено) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеОбщегоНазначенияИС.ПодготовитьДанныеКодовМаркировкиДляОбработки(ДанныеПоШтрихкодам, СписокДанныхШтрихкода, ПараметрыСканирования, КешДанныхРазбора);
```
</details>

## ЗаполнитьВидыПродукцииДанныхКодовМаркировки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗаполнитьВидыПродукцииДанныхКодовМаркировки(ДанныеПоШтрихкодам, ПараметрыСканирования, ДанныеКодовМаркировки = Неопределено) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеОбщегоНазначенияИС.ЗаполнитьВидыПродукцииДанныхКодовМаркировки(ДанныеПоШтрихкодам, ПараметрыСканирования, ДанныеКодовМаркировки);
```
</details>

## УточнитьДанныеРазбораПоВидуПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура УточнитьДанныеРазбораПоВидуПродукции(СтрокаДанных, ВидПродукции, ПараметрыСканирования, ОбщиеМодули = Неопределено) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеОбщегоНазначенияИС.УточнитьДанныеРазбораПоВидуПродукции(СтрокаДанных, ВидПродукции, ПараметрыСканирования, ОбщиеМодули);
```
</details>

## ЗаполнитьСведенияПоШтрихкодамEANСУчетомВерсии
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет информацию по EAN кодов маркировки по данным ИБ. Информация помещается в таблицу ДанныеПоШтрихкодам.ДанныеКодовМаркировки.
//
// Параметры:
//  ДанныеПоШтрихкодам    - См. ИнициализацияДанныхПоШтрихкодам.
//  ПараметрыСканирования - См. ПараметрыСканирования.
//  ДанныеКодовМаркировки - см. ИнициализацияТаблицыДанныхКодовМаркировки
Процедура ЗаполнитьСведенияПоШтрихкодамEANСУчетомВерсии(ДанныеПоШтрихкодам, ПараметрыСканирования, ДанныеКодовМаркировки = Неопределено) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеОбщегоНазначенияИС.ЗаполнитьСведенияПоШтрихкодамEANСУчетомВерсии(ДанныеПоШтрихкодам, ПараметрыСканирования, ДанныеКодовМаркировки);
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
