---
title: Штрихкодирование общего назначения ИС клиент
slug: erp-uh/штрихкодирование-общего-назначения-ис-клиент
---


## ПараметрыСканирования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет инициализацию и заполнение параметров сканирования по переданному контексту.
// Параметры сканирования необходимы для анализа и обработки штрихкодов маркируемой продукции.
//
// Параметры:
//  Контекст - Неопределено, ДокументСсылка, ФормаКлиентскогоПриложения - Источник данных для формирования параметров сканирования.
//  ФормаВыбора - ФормаКлиентскогоПриложения - Форма
//  ВидПродукции - ПеречислениеСсылка.ВидыПродукцииИС - Вид продукции
//  ПараметрыРежимаИсправленияОшибок - Структура - Параметры режима исправления ошибок
//
// Возвращаемое значение:
//  См. ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.БазовыеПараметрыСканирования
Функция ПараметрыСканирования(Контекст = Неопределено, ФормаВыбора = Неопределено, ВидПродукции = Неопределено, ПараметрыРежимаИсправленияОшибок = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования(Контекст, ФормаВыбора, ВидПродукции, ПараметрыРежимаИсправленияОшибок);
```
</details>

## ПроверитьНаНаличиеОшибокУточнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПроверитьНаНаличиеОшибокУточнения(ПараметрыСканирования, РезультатВыбораДанныеШтрихкода, ДанныеУточнения) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиент.ПроверитьНаНаличиеОшибокУточнения(ПараметрыСканирования, РезультатВыбораДанныеШтрихкода, ДанныеУточнения) 
```
</details>

## ОбработатьДанныеШтрихкода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет обработку штрихкода. Вызывается из формы проверки и подбора маркируемой продукции.
//
// Параметры:
//  ЗавершениеОбработки - Строка - Имя описания оповещения - обработчика формы, которое произойдет при завершении обработки.
//  Форма - ФормаКлиентскогоПриложения - форма, в которой отсканирован штрихкод.
//  ДанныеШтрихкода - Структура - структура с ключами:
//   * Штрихкод - Строка - считанный штрихкод,
//   * Количество - Число - количество упаковок.
//  ПараметрыСканирования - См. ПараметрыСканирования
//  ДанныеРазбора - см. РазборКодаМаркировкиИССлужебныйКлиентСервер.НовыйРезультатРазбораКодаМаркировки
//  ДополнительныеПараметры - Структура
Процедура ОбработатьДанныеШтрихкода(ЗавершениеОбработки, Форма, ДанныеШтрихкода, ПараметрыСканирования = Неопределено, ДанныеРазбора = Неопределено, ДополнительныеПараметры = Неопределено) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеОбщегоНазначенияИСКлиент.ОбработатьДанныеШтрихкода(ЗавершениеОбработки, Форма, ДанныеШтрихкода, ПараметрыСканирования, ДанныеРазбора, ДополнительныеПараметры);
```
</details>

## Подключаемый_ОбработатьУточнениеКодаМаркировки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция Подключаемый_ОбработатьУточнениеКодаМаркировки(Форма) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиент.Подключаемый_ОбработатьУточнениеКодаМаркировки(Форма) 
```
</details>

## ПрисутствуетАлкогольнаяПродукция
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку в переданном массиве "ВидыПродукции" наличие элемента алкогольной продукции.
//
// Параметры:
//  ВидыПродукции - Массив из ПеречислениеСсылка.ВидыПродукцииИС - Вид продукции ИС.
//  ПараметрыСканирования - (см. ПараметрыСканирования)
// Возвращаемое значение:
//  Булево - Истина, если в переданном массиве найден элемент перечисления алкогольная продукция.
Функция ПрисутствуетАлкогольнаяПродукция(ВидыПродукции, ПараметрыСканирования) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиент.ПрисутствуетАлкогольнаяПродукция(ВидыПродукции, ПараметрыСканирования) 
```
</details>

## ПрисутствуетТабачнаяПродукция
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку в переданном массиве "ВидыПродукции" наличие элемента табачной продукции.
//
// Параметры:
//  ВидыПродукции - Массив из ПеречислениеСсылка.ВидыПродукцииИС - Вид продукции ИС.
// Возвращаемое значение:
//  Булево - Истина, если в переданном массиве найден элемент перечисления табачная продукция.
Функция ПрисутствуетТабачнаяПродукция(ВидыПродукции) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиент.ПрисутствуетТабачнаяПродукция(ВидыПродукции) 
```
</details>

## ПрисутствуетПродукцияИСМП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку в переданном массиве "ВидыПродукции" наличие элемента продукции ИСМП.
//
// Параметры:
//  ВидыПродукции - Массив из ПеречислениеСсылка.ВидыПродукцииИС - Вид продукции ИС.
//  ВключатьТабачнуюПродукцию - Булево - Признак включения табачной продукции
//  ВключатьМолочнуюПродукцию - Булево - Признак вкючения молочной продукции
// Возвращаемое значение:
//  Булево - Истина, если в переданном массиве найден элемент перечисления обувная продукция.
Функция ПрисутствуетПродукцияИСМП(ВидыПродукции, ВключатьТабачнуюПродукцию = Ложь, ВключатьМолочнуюПродукцию = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиент.ПрисутствуетПродукцияИСМП(ВидыПродукции, ВключатьТабачнуюПродукцию, ВключатьМолочнуюПродукцию);
```
</details>

## ПрисутствуетПрочаяПродукция
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет проверку в переданном массиве "ВидыПродукции" наличие элемента с пустым видом продукции.
//
// Параметры:
//  ВидыПродукции - Массив из ПеречислениеСсылка.ВидыПродукцииИС - Вид продукции ИС.
// Возвращаемое значение:
//  Булево - Истина, если в переданном массиве найден элемент перечисления пустая ссылка.
Функция ПрисутствуетПрочаяПродукция(ВидыПродукции) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиент.ПрисутствуетПрочаяПродукция(ВидыПродукции) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
