---
title: Штрихкодирование общего назначения ИС клиент сервер
slug: erp-uh/штрихкодирование-общего-назначения-ис-клиент-сервер
---


## БазовыеПараметрыСканирования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Инициализирует и возвращает общие параметры сканирования для всех видов продукции.
//
// Возвращаемое значение:
//  Структура - Описание:
// * ИдентификаторФормы - УникальныйИдентификатор - Уникальный идентификатор формы
// * СсылкаНаОбъект - ЛюбаяСсылка, Неопределено - Ссылка на объект из которого выполняется сканирование кодов маркировки
// * ИмяКолонкиШтрихкодУпаковки - Строка - Имя колонки хранения штрихкода упаковки в табличной части ИмяТабличнойЧастиШтрихкодыУпаковок
// * ИмяТабличнойЧастиШтрихкодыУпаковок - Строка - Наименование табличной части, где хранятся элементы штрихкодов упаковок
// * Склад - Неопределено - Место хранения
// * Организация - ОпределяемыйТип.Организация - Организация
// * Владелец - ОпределяемыйТип.ОрганизацияКонтрагентГосИС - Организация или контргент (используется в механизме контроля кодов маркировки)
// * ДопустимыйСпособВводаВОборот - Неопределено - Допустимый способ ввода в оборот (используется в механизме контроля кодов маркировки)
// * ПараметрыУказанияСерий - Структура, Неопределено - Произвольные параметры указания серий (может использоваться в конфигурации-потребителе)
// * ОперацияКонтроляАкцизныхМарок - Строка - Доступные типы: "Продажа", "Возврат". "Продажа" - для документов, которые
//                                            отражает расход по складу, "Возврат" - для документов, отражающих приход.
// * ПроверятьДублиКодовМаркировки - Строка - Вариант проверки дублей кодов маркировки
// * КонтрольУникальностиКодовМаркировки - Булево - Признак необходимости контроля дублей кодов маркировки
// * ДополнительныеПараметры - Структура - Параметры необходимые для переопределения обработки прикладных объектов
// * ИспользуютсяДанныеВыбораПоМаркируемойПродукции - Булево - Истина, если данные выбора по маркируемой продукции используются
// * ДанныеВыбораПоМаркируемойПродукции - Структура, Неопределено - последние данные выбора, которые требовалось запомнить для последующего сканирования
// * ИспользуетсяСоответствиеШтрихкодовСтрокДерева - Булево - Признак наличия в форме дерева упаковок (только формы проверки и подбора)
// * АдресДанныхДокументаОснования - Строка, Неопределено - адрес во временном хранилище, где хранятся данные документа основания
// * КонтрольРасхожденийСДокументомОснованием - Булево - Истина, если необходимо выполнять контроль и сообщать
//                                                       об ошибках в случае несоответствия документу-основанию.
// * КэшированныеЗначения - Произвольный - Произвольная структура данных для кэширования значений
// * ТолькоМаркируемаяПродукция - Булево - Истина, если документ поддерживает работу только с маркируемой продукцией
// * ВозможнаЗагрузкаТСД - Булево - Истина, если контекст поддерживает работу с ТСД
// * ДокументОснование - ДокументСсылка, Неопределено - Ссылка на документ-основание
// * СоздаватьШтрихкодУпаковки - Булево - Если флаг установлен, то в момент сканирования кода маркировки создается запись в справочнике ШтрихкодыУпаковокТоваров
// * АдресСоответствияАкцизныхМарок - Строка, Неопределено - адрес во временном хранилище, где хранятся обработанные данные по штрихкодам
// * ДопустимыеВидыПродукции - Массив Из ПеречислениеСсылка.ВидыПродукцииИС - Допустимые виды продукции, которые поддерживает контекст
// * ОтборПоВидуПродукции - Булево - Признак необходимости отбора кодов маркировки по виду продукции.
//                                   Используется при открытии форм проверки из документов конфигурации-потребителя
//                                   или при получении списка кодов маркировки из документов конфигурации-потребителя.
//                                   В документе конфигурации-потребителя может содержаться множество разных видов продукции.
// * КэшМаркируемойПродукции - Соответствие из КлючИЗначение, Неопределено - Используется для защиты от повторного сканирования кодов маркировки
// * РазрешенаОбработкаБезУказанияМарки - Булево - Признак возможности работы с товарами без указания кодов маркировки.
//                                                 Используется в формах сканирования кодов маркировки.
//                                                 Если флаг не установлен, то команда "Добавить без кода маркировки" скрывается.
// * РазрешенаОбработкаКодовСПустойНоменклатурой - Булево - Признак возможности обработки кодов маркировки без указания номенклатуры
// * РазрешеноЗапрашиватьКодМаркировки - Булево - Признак необходимости открытия формы сканирования кода маркировки после сканирования GTIN.
// * СопоставлятьНоменклатуру - Булево - Признак возможности сопоставления номенклатуры после сканирования кода маркировки.
// * ДоступнаПечатьЭтикеток - Булево - Признак доступности печати этикеток после сканирования EAN (Потоковая печать)
// * ДополнительныеВариантыСопоставленияНоменклатуры - Соответствие Из КлючИЗначение:
//    ** Ключ - Строка - Штрихкод EAN
//    ** Значение - Массив Из Структура:
//        *** Номенклатура - ОпределяемыйТип.Номенклатура - Номенклатура
//        *** Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - Характеристика номенклатуры
//        *** Серия - ОпределяемыйТип.СерияНоменклатуры - Серия номенклатуры
// * ДанныеТаблицыТовары - Неопределено - Данные таблицы товары
// * РазрешенаОбработкаНеНайденныхЛогистическихУпаковок - Булево - Параметр используется в формах проверки и подбора в случае если документ
//                                                                 поддерживает операции агрегации.
// * ПоддерживаютсяОперацииАгрегации - Булево - Параметр работает в паре с параметром РазрешенаОбработкаНеНайденныхЛогистическихУпаковок.
//                                              Если для документ поддерживает операции агрегации, то в форме проверки разрешено работать
//                                              с пустыми упаковками.
// * КонтрольПустыхУпаковок - Булево - Признак необходимости контроля пустых упаковок при операциях сканирования.
//                                     Контроль выполняется для групповых и логистических упаковок.
// * ВыводитьСообщенияОбОшибках - Булево - Ложь, если вывод сообщений об ошибках запрещен
// * ПроверятьАлфавитКодовМаркировки - Булево - Признак необходимости проверки алфавита кодов маркировки
// * КонтролироватьСтандартнуюВложенность - Булево - Признак необходимости контроля стандартной вложенности
// * ПропускатьСтрокиСОшибкамиПриЗагрузкеИзТСД - Булево - Истина, если необходимо пропускать коды маркировки с ошибками при работе с ТСД
// * ДетализацияСтруктурыХранения - Неопределено - Детализация данных сканирования.
// * ВосстанавливатьСтруктуруКодаМаркировки - Булево - Истина, если можно восстанавливать структуру полных кодов маркировки.
// * КонтролироватьСоставАгрегатов - Булево -
// * ПроверятьСтруктуруКодовМаркировки - Булево - Признак проверки кода маркировки на полный состав
// * ПодсистемаИСМПСуществует - Булево - Признак включения в сборку подсистемы ИС МП
// * ЗапрашиватьКоличествоМерногоТовара - Булево -  Параметр работы с весовыми маркируемыми товарами:
//   Ложь - не запрашивать количество,
//   Истина - запрашивать количество.
// * СозданиеНаборов - Булево - Признак возможности создания наборов
// * РасширеннаяВерсияГосИС - Булево - Устанавливается при варианте сборки Расширенная
// * РежимБРМК - Булево - Режим работы штрихкодирования без открытия дополнительных форм
// * ЭтоМаркировкаТоваровИСМП - Булево - признак, что документ является документом Маркировка товаров ИС МП
Функция БазовыеПараметрыСканирования() Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.БазовыеПараметрыСканирования() 
```
</details>

## ЗаполнитьБазовыеПараметрыСканирования
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет заполнение базовых параметров сканирования на основании данных контекста.
//  * Заполнение данных выбора (есть реквизит на форме, не выполняется групповая обработка)
//  * Заполнение кеша маркируемой продукции
//  * Заполнение параметров указания серий.
//
// Параметры:
//  ПараметрыСканирования - См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования
//  Контекст - ФормаКлиентскогоПриложения, ЛюбаяСсылка - контекст, данные которого будут использованы для заполнения параметров сканирования.
Процедура ЗаполнитьБазовыеПараметрыСканирования(ПараметрыСканирования, Контекст) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.ЗаполнитьБазовыеПараметрыСканирования(ПараметрыСканирования, Контекст) 
```
</details>

## GTINПоШтрихкодуEAN
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет штрихкод EAN лидирующими нулями.
//
// Параметры:
//  ШтрихкодEAN - Строка - Значение штрихкода EAN.
// Возвращаемое значение:
//  Строка - GTIN.
Функция GTINПоШтрихкодуEAN(Знач ШтрихкодEAN) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.GTINПоШтрихкодуEAN(ШтрихкодEAN) 
```
</details>

## ЗакодироватьШтрихкодДанныхBase64
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ЗакодироватьШтрихкодДанныхBase64(ДанныеШтрихкода) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.ЗакодироватьШтрихкодДанныхBase64(ДанныеШтрихкода) 
```
</details>

## ДекодироватьШтрихкодДанныхBase64
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ДекодироватьШтрихкодДанныхBase64(ДанныеШтрихкода, СохранитьШтрихкодBase64 = Ложь) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.ДекодироватьШтрихкодДанныхBase64(ДанныеШтрихкода, СохранитьШтрихкодBase64);
```
</details>

## Base64ВШтрихкод
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Декодирует штрихкод по алгоритму Base64 в строковый формат.
//
// Параметры:
//  ШтрихкодВBase64 - Строка - закодированный штрихкод.
// Возвращаемое значение:
//  Строка - Декодированный штрихкод.
Функция Base64ВШтрихкод(Знач ШтрихкодВBase64) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.Base64ВШтрихкод(ШтрихкодВBase64) 
```
</details>

## ШтрихкодВBase64
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Кодирует значение штрихкода по алгоритму Base64.
//
// Параметры:
//  Штрихкод - Строка - Значение штрихкода.
// Возвращаемое значение:
//  Строка - штрихкод закодированный по алгоритму Base64.
Функция ШтрихкодВBase64(Знач Штрихкод) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.ШтрихкодВBase64(Штрихкод) 
```
</details>

## ДопустимВидПродукции
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет допустимость обработки вида продукции по параметрам сканирования.
//
// Параметры:
//  ПараметрыСканирования - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования)
//  ВидПродукцииИС - ПеречислениеСсылка.ВидыПродукцииИС - Вид продукции
// Возвращаемое значение:
//  Булево - Истина, если вид продукции допустим.
Функция ДопустимВидПродукции(ПараметрыСканирования, ВидПродукцииИС) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.ДопустимВидПродукции(ПараметрыСканирования, ВидПродукцииИС) 
```
</details>

## ТипШтрихкодаПоСтроке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает значение перечисления типа штрихкода по строке
//
// Параметры:
// 	ТипШтрихкодаСтрокой - Строка - тип штрихкода (например, Code128Формат1, GS1128, GS1DataBarExpandedStacked)
// Возвращаемое значение:
//  ПеречислениеСсылка.ТипыШтрихкодов - тип шаблона
Функция ТипШтрихкодаПоСтроке(ТипШтрихкодаСтрокой) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.ТипШтрихкодаПоСтроке(ТипШтрихкодаСтрокой) 
```
</details>

## ЭтоСтрокаДанныхЧастичногоВыбытия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ЭтоСтрокаДанныхЧастичногоВыбытия(СтрокаДанных, ПараметрыСканирования, ВидПродукции = Неопределено, ПроверятьФлагВыбытия = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.ЭтоСтрокаДанныхЧастичногоВыбытия(СтрокаДанных, ПараметрыСканирования, ВидПродукции, ПроверятьФлагВыбытия);
```
</details>

## ОперацияИС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ОперацияИС(ПараметрыСканирования, ВидПродукции) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.ОперацияИС(ПараметрыСканирования, ВидПродукции) 
```
</details>

## ПредставлениеШтрихкода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сокращенное представление штрихкода маркируемой продукции
//
// Параметры:
//  Штрихкод - Строка - Штрихкод
// Возвращаемое значение:
//  Строка - Краткое представление штрихкода маркируемой продукции
Функция ПредставлениеШтрихкода(Штрихкод) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.ПредставлениеШтрихкода(Штрихкод) 
```
</details>

## ОбновитьНеобходимостьУточненияДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОбновитьНеобходимостьУточненияДанных(ДанныеШтрихкода) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.ОбновитьНеобходимостьУточненияДанных(ДанныеШтрихкода) 
```
</details>

## ВозможнаГрупповаяУпаковкаИлиНабор
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Если код маркировки соответствует формату GS1 и может принадлежать альтернативной табачной продукции,
// то вид упаковки в некототорых случаях может быть пустым и принадлежать как потребительской, так и групповой упаковкам.
//
// Параметры:
//   ВидУпаковки - ПеречислениеСсылка.ВидыУпаковокИС - Вид упаковки
//   ДанныеРазбора - См. РазборКодаМаркировкиИССлужебныйКлиентСервер.НовыйРезультатРазбораКодаМаркировки
// Возвращаемое значение:
//   Булево - Истина, если Вид упаковки - групповая или если групповая упаковка возможна по данным разбора
Функция ВозможнаГрупповаяУпаковкаИлиНабор(ВидУпаковки, ДанныеРазбора) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.ВозможнаГрупповаяУпаковкаИлиНабор(ВидУпаковки, ДанныеРазбора) 
```
</details>

## ПараметрыОткрытияФормыУточненияДанных
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает параметры открытия формы уточнения данных у пользователя, таких как "Номенклатура", "Характеристика", "Серия".
//
// Возвращаемое значение:
//  Структура - Описание:
// * ПараметрыСканирования - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыСканирования).
// * ПараметрыУказанияСерий - Структура - данные для расчета серий.
// * ШтрихкодEAN - Строка - Штрихкода формата EAN.
// * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - Элемент Характеристика.
// * Номенклатура - ОпределяемыйТип.Номенклатура - Элемент Номенклатура.
// * ТипШтрихкода - ПеречислениеСсылка.ТипыШтрихкодов - Тип штрихкода кода маркировки.
// * КодМаркировки - Строка - Код маркировки.
// * ХешСуммаКодаМаркировки - Строка - Хэш кода маркировки.
Функция ПараметрыОткрытияФормыУточненияДанных() Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСКлиентСервер.ПараметрыОткрытияФормыУточненияДанных() 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
