---
title: Штрихкодирование общего назначения ИСМП клиент
slug: erp-uh/штрихкодирование-общего-назначения-исмп-клиент
---


## НачатьПроверкуКодовМаркировкиСредствамиККТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Запускает проверку кодов маркировки средствами ККТ. По завершении проверки будет вызвано оповещение, переданное в параметрах.
//
// Параметры:
//  ПараметрыНачалаПроверки - см. ПараметрыНачалаПроверкиКодовМаркировкиСредствамиККТ.
Процедура НачатьПроверкуКодовМаркировкиСредствамиККТ(ПараметрыНачалаПроверки) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеОбщегоНазначенияИСМПКлиент.НачатьПроверкуКодовМаркировкиСредствамиККТ(ПараметрыНачалаПроверки) 
```
</details>

## ПараметрыНачалаПроверкиКодовМаркировкиСредствамиККТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры начала проверки кодов маркировки средствами ККТ.
// Параметры используюся дла начала проверки методом (см. НачатьПроверкуКодовМаркировкиСредствамиККТ).
//
// Возвращаемое значение:
//  Структура:
// * ОповещениеОЗавершении   - ОписаниеОповещения - Оповещение, которое будет вызвано по окончании проверки,
//                             в качестве результат будет передано значения типа (см. НовыйРезультатПроверкиСредствамиККТ).
// * ДанныеДляПроверки       - см. ШтрихкодированиеОбщегоНазначенияИСМПКлиентСервер.НовыйЭлементДанныхПроверкиСредствамиККТ
// * ДанныеДляПроверки       - Массив из см. ШтрихкодированиеОбщегоНазначенияИСМПКлиентСервер.НовыйЭлементДанныхПроверкиСредствамиККТ
// * ПараметрыСканирования   - см. ШтрихкодированиеОбщегоНазначенияИС.ПараметрыСканирования
// * ФормаОсновногоОбъекта   - ФормаКлиентскогоПриложения               - Форма, связанная с основным объектов проверки, например, форма РТиУ.
// * ФормаВспомогательная    - ФормаКлиентскогоПриложения, неопределено - Форма, отображаемая пользоваетелю в текущий момент, например, форма предпросмотра чека.
// * ЗаголовокКнопкиИгнорировать - Строка, Неопределено - Заголовок кнопки для игнорирования ошибки проверки на ККТ.
//                                                        Результат проверки на ККТ может быть отрицательным, описание ошибки
//                                                        отображается в соответствующей форме.
//                                                        После подтверждения покупателем отрицательного результата проверки
//                                                        ошибка может быть проигнорирована и операция продолжена.
//                                                        Если это операция пробития чека то в этом свойстве может быть задано, например:
//                                                        "Прибить чек", "Покупатель согласен", "Оформить передачу". По-умолчанию "Игнорировать ошибку".
// * ЭтоДокументОплаты       - Булево - Взвести флаг, если вызов происходит по отдельному документу оплаты, без привязки к форме документа с кодами маркировки, Например ПКО по РТиУ.
// * ЭтоСканирование         - Булево - Внутренний. Признак вызова проверки при сканировании.
// * ПроверятьЗапросыГИСМТ   - Булево - Признак проверки идентификаторов запросов ГИС МТ при розничной продаже
Функция ПараметрыНачалаПроверкиКодовМаркировкиСредствамиККТ() Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСМПКлиент.ПараметрыНачалаПроверкиКодовМаркировкиСредствамиККТ() 
```
</details>

## ПроверкаКодаМаркировкиСредствамиККТПоДаннымШтрихкода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверка кода маркировки средствами ККТ по данным штрихкода.
//
// Параметры:
//  ПараметрыСканирования - см. ШтрихкодированиеОбщегоНазначенияИС.ПараметрыСканирования
//  РезультатОбработкиШтрихкода - см. ШтрихкодированиеОбщегоНазначенияИСМП.РезультатОбработкиКодаМаркировки
//  ФормаВладелец - ФормаКлиентскогоПриложения - Владелец
//  ОписаниеОповещения - ОписаниеОповещения -
//  ИсходныйРезультатВыбора - Неопределено - Исходный результат выбора
Процедура ПроверкаКодаМаркировкиСредствамиККТПоДаннымШтрихкода(ПараметрыСканирования, РезультатОбработкиШтрихкода, ФормаВладелец, ОписаниеОповещения, ИсходныйРезультатВыбора = Неопределено) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеОбщегоНазначенияИСМПКлиент.ПроверкаКодаМаркировкиСредствамиККТПоДаннымШтрихкода(ПараметрыСканирования, РезультатОбработкиШтрихкода, ФормаВладелец, ОписаниеОповещения, ИсходныйРезультатВыбора);
```
</details>

## ОбработкаОповещенияПриПроверкеСредствамиККТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработка оповещения при проверке средствами ККТ.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения
//  ИмяСобытия - Строка
//  Параметры - Произвольный -
//  Источник - Произвольный -
Процедура ОбработкаОповещенияПриПроверкеСредствамиККТ(Форма, ИмяСобытия, Параметры, Источник) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеОбщегоНазначенияИСМПКлиент.ОбработкаОповещенияПриПроверкеСредствамиККТ(Форма, ИмяСобытия, Параметры, Источник) 
```
</details>

## ИмяСобытияОповещенияИзменилосьСостояниеПроверкиСредствамиККТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Имя события оповещения изменилось состояние проверки средствами ККТ.
//
// Возвращаемое значение:
//  Строка - Имя события оповещения изменилось состояние проверки средствами ККТ
Функция ИмяСобытияОповещенияИзменилосьСостояниеПроверкиСредствамиККТ() Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСМПКлиент.ИмяСобытияОповещенияИзменилосьСостояниеПроверкиСредствамиККТ() 
```
</details>

## ИмяСобытияОповещенияСледующегоШагаПроверкиСредствамиККТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Имя события оповещения следующего шага проверки средствами ККТ.
//
// Возвращаемое значение:
//  Строка - Имя события оповещения следующего шага проверки средствами ККТ
Функция ИмяСобытияОповещенияСледующегоШагаПроверкиСредствамиККТ() Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСМПКлиент.ИмяСобытияОповещенияСледующегоШагаПроверкиСредствамиККТ() 
```
</details>

## ИмяСобытияОповещенияЕстьОшибкиПроверкиСредствамиККТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Имя события оповещения есть ошибки проверки средствами ККТ.
//
// Возвращаемое значение:
//  Строка - Имя события оповещения есть ошибки проверки средствами ККТ
Функция ИмяСобытияОповещенияЕстьОшибкиПроверкиСредствамиККТ() Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСМПКлиент.ИмяСобытияОповещенияЕстьОшибкиПроверкиСредствамиККТ() 
```
</details>

## ИмяСобытияОповещенияПрогрессПолученияИдентификаторовЗапросаГИСМТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Имя события оповещения прогресс получения идентификаторов запроса ГИС МТ.
//
// Возвращаемое значение:
//  Строка - Имя события оповещения прогресс получения идентификаторов запроса ГИС МТ
Функция ИмяСобытияОповещенияПрогрессПолученияИдентификаторовЗапросаГИСМТ() Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСМПКлиент.ИмяСобытияОповещенияПрогрессПолученияИдентификаторовЗапросаГИСМТ() 
```
</details>

## ВыполнениеШагаПроверкиСредствамиККТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполнение шага проверки средствами ККТ.
//
// Параметры:
//  Форма - ФормаКлиентскогоПриложения -
//  ПараметрыПроверки - см. НовыеПараметрыПроверкиНаККТ
Процедура ВыполнениеШагаПроверкиСредствамиККТ(Форма, ПараметрыПроверки) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеОбщегоНазначенияИСМПКлиент.ВыполнениеШагаПроверкиСредствамиККТ(Форма, ПараметрыПроверки) 
```
</details>

## ТекущийЭлементПроверкиСредствамиККТ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает текущий элемент коллекции для проверки средствами ККТ.
//
// Параметры:
//  ПараметрыПроверки - см. НовыеПараметрыПроверкиНаККТ
//
// Возвращаемое значение:
//  см. ШтрихкодированиеОбщегоНазначенияИСМПКлиентСервер.НовыйЭлементДанныхПроверкиСредствамиККТ
Функция ТекущийЭлементПроверкиСредствамиККТ(ПараметрыПроверки) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСМПКлиент.ТекущийЭлементПроверкиСредствамиККТ(ПараметрыПроверки) 
```
</details>

## ТребуетсяУточнениеДанныхУПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет результат обработки штрихкода на необходимость интерактивного уточнения данных у пользователя.
//
// Параметры:
//  РезультатОбработки - Структура - (См. ШтрихкодированиеОбщегоНазначенияИСМП.ИнициализироватьРезультатОбработкиШтрихкода).
// Возвращаемое значение:
//  Булево - Истина, если необходимо уточнить данные у пользователя.
Функция ТребуетсяУточнениеДанныхУПользователя(РезультатОбработки) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСМПКлиент.ТребуетсяУточнениеДанныхУПользователя(РезультатОбработки) 
```
</details>

## ЗавершитьОбработкуВводаШтрихкода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет анализ результат обработки штрихкода, на основании которого выполняет необходимые действия.
//
// Параметры:
//  ПараметрыЗавершенияВводаШтрихкода - Структура - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыЗавершенияОбработкиШтрихкода).
//  ВыполнятьОбработчикОповещения     - Булево    - Выполнять обработчик оповещения.
//
// Возвращаемое значение:
//  Булево - Завершить обработку ввода штрихкода.
Функция ЗавершитьОбработкуВводаШтрихкода(ПараметрыЗавершенияВводаШтрихкода, ВыполнятьОбработчикОповещения = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодированиеОбщегоНазначенияИСМПКлиент.ЗавершитьОбработкуВводаШтрихкода(ПараметрыЗавершенияВводаШтрихкода, ВыполнятьОбработчикОповещения);
```
</details>

## АвторизацияПользователяЗавершение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет повторно вызов клиентских функий обработки штрихкодов в случае успешного прохождения авторизации.
//
// Параметры:
// 	Результат - Соответствие - содержит информация о необходимости авторизации по организации.
// 	ПараметрыЗавершенияОбработкиШтрихкода - (См. ШтрихкодированиеОбщегоНазначенияИСКлиент.ПараметрыЗавершенияОбработкиШтрихкода).
Процедура АвторизацияПользователяЗавершение(Результат, ПараметрыЗавершенияОбработкиШтрихкода) Экспорт
```

Пример вызова
```bsl
ШтрихкодированиеОбщегоНазначенияИСМПКлиент.АвторизацияПользователяЗавершение(Результат, ПараметрыЗавершенияОбработкиШтрихкода) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
