---
title: Штрихкоды упаковок клиент сервер
slug: erp-uh/штрихкоды-упаковок-клиент-сервер
---


## КодМаркировкиБезСкобок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Убирает разделители идентификаторов "(", ")" из кода маркировки.
//
// Параметры:
//  КодМаркировки - Строка - Код маркировки.
//  УстанавливатьИдентификаторПримененияSSCC - Булево -
// Возвращаемое значение:
//  Строка - Код маркировки без разделителей.
Функция КодМаркировкиБезСкобок(КодМаркировки, УстанавливатьИдентификаторПримененияSSCC = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодыУпаковокКлиентСервер.КодМаркировкиБезСкобок(КодМаркировки, УстанавливатьИдентификаторПримененияSSCC);
```
</details>

## ТипЗначенияПараметра
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает уточненное описание типов значения идентификатора применения по базовому типу
// и значению дополнительного параметра.
//
// Параметры:
// 	КлючИдентификатора - Строка - Код (ключ) идентификатора применения
// 	ДополнительныйПараметрЗначение - Число - Значение дополнительного параметра
//
// Возвращаемое значение:
// 	ОписаниеТипов - уточненное описание типов для значения идентификатора применения
//
Функция ТипЗначенияПараметра(КлючИдентификатора, ДополнительныйПараметрЗначение = 0) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодыУпаковокКлиентСервер.ТипЗначенияПараметра(КлючИдентификатора, ДополнительныйПараметрЗначение);
```
</details>

## СимволОкончанияСтрокиПеременнойДлины
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает значение спецсимвола окончания параметра переменной длины.
// Например, идентификатор СерийныйНомер может иметь переменную длину до 20 символов в штрихкоде.
// Если ключи идентификаторов не ограничиваются скобками, тогда в конце полей
// переменной длины должен стоять спецсимвол. Не сериализуется.
//
// Возвращаемое значение:
// 	Строка - значение не сериализуемого спецсимвола
//
Функция СимволОкончанияСтрокиПеременнойДлины() Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодыУпаковокКлиентСервер.СимволОкончанияСтрокиПеременнойДлины() 
```
</details>

## ШтрихкодSSCC
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сгенерированный штрихкод SSCC по переданным параметрам.
//
// Параметры:
//  ПараметрыШтрихкода  - Структура - Структура входящих параметров штрихкода.
// 	 * ЦифраРасширения    - Число - Цифра расширения SSCC.
// 	 * ПрефиксКомпанииGS1 - Число - префикс компании GS1.
// 	 * СерийныйНомерSSCC  - Число - серийный номер SSCC.
// 	УстанавливатьСкобки                  - Булево - Если истина, то идентификатор SSCC 00 будет помещен в скобки.
// 	УстанавливатьИдентификаторПрименения - Булево - Если истина, то будет установлен индентификатор применения.
//
// Возвращаемое значение:
// 	Строка - Сгенерированный штрихкод.
//
Функция ШтрихкодSSCC(ПараметрыШтрихкода, УстанавливатьСкобки = Истина, УстанавливатьИдентификаторПрименения = Истина) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодыУпаковокКлиентСервер.ШтрихкодSSCC(ПараметрыШтрихкода, УстанавливатьСкобки, УстанавливатьИдентификаторПрименения);
```
</details>

## ШтрихкодCode128
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сгенерированный штрихкод Code128 по переданным параметрам
//
// Параметры:
// 	ПараметрыШтрихкода  - Структура - Структура входящих параметров штрихкода
// 	 * НомерФорматаCode128 - Число - Не 0, номер формата Code-128. (Подробнее см. метод ФорматШтрихкодаCode128)
// 	 * Список остальных параметров различен для каждого формата (см. в описании методов:
// 	                    ШтрихкодCode128Формат1, ШтрихкодCode128Формат2, ШтрихкодCode128Формат3)
//
// Возвращаемое значение:
// 	Строка - Сгенерированный штрихкод
//
Функция ШтрихкодCode128(ПараметрыШтрихкода) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодыУпаковокКлиентСервер.ШтрихкодCode128(ПараметрыШтрихкода) 
```
</details>

## ШтрихкодGS1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает сгенерированный штрихкод в формате GS1
//
// Параметры:
// 	ИспользуемыеИдентификаторы - Массив структур используемых идентификаторов применения GS1. Свойства структур:
// 	   *ИмяИдентификатора          - Строка, имя идентификатора в верхнем регистре, например, "МАССАНЕТТОВКГ"
// 	   *КлючИдентификатора         - Строка, ключ идентификатора без значения дополнительного параметра.
// 	                                  Например, для МассаНеттоВКг указывается 310 вместо 3102.
// 	   *Значение                   - Значение идентификатора. Строка, дата, число.
// 	   *ДополнительныйПараметр     - Число. Например, для МассаНеттоВКг последняя цифра 2 в идентификаторе (3102) - количество
// 	                                      знаков после запятой.
// 	УстанавливатьСкобки - Булево    - Если истина, то коды идентификаторов (вместе с дополнительными параметрами идентификаторов,
// 	                                  при их наличии) будут помещены внутрь скобок ().
// 	СимволFNC1          - Строка    - Символ завершения параметра переменной длины.
// 	                                  Может принимать значения: "", Символ(29), [NFC1].
// 	                                  Штрихкод с символом Символ(29) не может передаваться с клиента на сервер.
//
// Возвращаемое значение:
// 	Строка - сгенерированный штрихкод. При не заполненных параметрах штрихкод сгенерирован не будет.
//
Функция ШтрихкодGS1(ИспользуемыеИдентификаторы, УстанавливатьСкобки = Истина, СимволFNC1 = "") Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодыУпаковокКлиентСервер.ШтрихкодGS1(ИспользуемыеИдентификаторы, УстанавливатьСкобки, СимволFNC1);
```
</details>

## ПараметрыШтрихкодаSSCC
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Читает штрихкод формата SSCC и возвращает параметры штрихкода
//
// Параметры:
// 	Штрихкод - Строка - Штрихкод в формате SSCC
//
// Возвращаемое значение:
// 	Структура - структура параметров:
// 	 * Результат - Неопределено - Чтение штрихкода завершилось неудачей
// 	             - Структура - Параметры штрихкода, если штрихкод прочитан успешно:
// 	                ** ЦифраРасширения - Число - цифра расширения SSCC
// 	                ** ПрефиксКомпанииGS1 - Число - префикс компании GS1
// 	                ** СерийныйНомерSSCC  - Число - серийный номер SSCC
// 	                ** КонтрольноеЧисло   - Число - контрольная цифра штрихкода
// 	 * ТекстОшибки - Строка - Текст ошибки при чтении, если ошибки не было - то пустая строка.
//
Функция ПараметрыШтрихкодаSSCC(Знач Штрихкод) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодыУпаковокКлиентСервер.ПараметрыШтрихкодаSSCC(Штрихкод) 
```
</details>

## ПараметрыШтрихкодаCode128
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Читает штрихкод формата Code128 и возвращает параметры штрихкода
//
// Параметры:
// 	Штрихкод - Строка - Штрихкод в формате 1 типа Code128 (устаревший формат)
//
// Возвращаемое значение:
// 	Структура из КлючИЗначение - структура параметров:
// 	 * Результат - Неопределено - Чтение штрихкода завершилось неудачей
// 	             - Структура - Параметры штрихкода, если штрихкод прочитан успешно:
// 	                ** НомерФорматаCode128 - Число - Не 0, номер формата Code-128 (подробнее см. метод ФорматШтрихкодаCode128)
// 	                ** Список прочих параметров определяется номером формата и подробнее описан в методах:
// 	                     ПараметрыШтрихкодаCode128Формат1, ПараметрыШтрихкодаCode128Формат2, ПараметрыШтрихкодаCode128Формат3
// 	 * ТекстОшибки - Строка - Текст ошибки при чтении, если ошибки не было - то пустая строка.
//
Функция ПараметрыШтрихкодаCode128(Знач Штрихкод) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодыУпаковокКлиентСервер.ПараметрыШтрихкодаCode128(Штрихкод) 
```
</details>

## ПараметрыШтрихкодаGS1
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Читает штрихкод и возвращает параметры. Ключи идентификаторов применения не заключены в скобки,
// но после параметров переменной длины следует символ окончания параметра переменной длины.
//
// Параметры:
// 	Штрихкод     - Строка - Штрихкод, считанный со сканера.
// 	ПараметрыШтрихкода - Неопределено
// 	                   - Структура    - накопленные считанные параметры штрихкода.
//
// Возвращаемое значение:
// 	Структура из КлючИЗначение:
// 	 * Результат - Неопределено - Если в процессе чтения возникла ошибка.
// 	             - Массив из см. ПараметрЗначенияИдентификатораПрименения
// 	 * ТекстОшибки - Строка     - Содержит текст ошибки считывания, при ее наличии.
//
Функция ПараметрыШтрихкодаGS1(Знач Штрихкод, ПараметрыШтрихкода = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодыУпаковокКлиентСервер.ПараметрыШтрихкодаGS1(Штрихкод, ПараметрыШтрихкода);
```
</details>

## ПараметрыШтрихкодаGS1СоСкобками
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Читает штрихкод и возвращает параметры. Ключи идентификаторов применения заключены в скобки,
// но после параметров переменной длины1 не следует символ окончания параметра переменной длины.
// В данном формате штрихкод храниться в поле ИБ.
// См. описание функции ПараметрыШтрихкодаGS1.
//
// Параметры:
//  Штрихкод - Строка - Штрихкод
//  ПараметрыШтрихкода - Неопределено
//  ПараметрыШтрихкода - см. ПараметрыШтрихкодаCode128 -
//
// Возвращаемое значение:
// - Неопределено
// - см. ПараметрыШтрихкодаGS1
Функция ПараметрыШтрихкодаGS1СоСкобками(Знач Штрихкод, ПараметрыШтрихкода = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодыУпаковокКлиентСервер.ПараметрыШтрихкодаGS1СоСкобками(Штрихкод, ПараметрыШтрихкода);
```
</details>

## ПараметрыШтрихкода
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Читает штрихкод неизвестного типа штрихкода и возвращает параметры.
// Для каждого типа штрихкода возвращаются соответствующие параметры.
//
// Параметры:
//  Штрихкод - Строка - Штрихкод
//
// Возвращаемое значение:
// - Неопределено
// - см. ПараметрыШтрихкодаSSCC
// - см. ПараметрыШтрихкодаCode128
// - см. ПараметрыШтрихкодаGS1
//
Функция ПараметрыШтрихкода(Знач Штрихкод) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодыУпаковокКлиентСервер.ПараметрыШтрихкода(Штрихкод) 
```
</details>

## ФорматШтрихкодаCode128
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает номер формата Code-128 по переданному штрихкоду.
//
// Параметры:
// 	Штрихкод - Строка - Штрихкод товара.
//
// Возвращаемое значение:
// 	Число - Номер формата Code-128. Если значение 0, то формат не определен.
//
Функция ФорматШтрихкодаCode128(Штрихкод) Экспорт
```

Пример вызова
```bsl
Результат = ШтрихкодыУпаковокКлиентСервер.ФорматШтрихкодаCode128(Штрихкод) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
