---
title: Электронное взаимодействие ИСМП
slug: erp-uh/электронное-взаимодействие-исмп
---


## ДанныеДокументаСоответствуютДаннымУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Проверяет совпадение табличной части "Штрихкоды упаковок" и табличной части ("Товары")
//   в отношении маркируемой продукции перед формированием документа ЭДО.
//   Проверка не выполняется если по документу уже оформлена отгрузка товаров ИСМП (прямой обмен).
//   Допущение: в документе по одной номенклатуре нет отновременно строк с указанием серий и строк без серий.
//
// Параметры:
//   ПроверяемыйДокумент - ДокументСсылка - проверяемый документ
//   АвтоматическиФормироватьОСУ - Булево - коды ОСУ по документу могут формироваться автоматически
// Возвращаемое значение:
//   Булево - номенклатура и количество по маркируемой продукции совпадают
Функция ДанныеДокументаСоответствуютДаннымУпаковок(ПроверяемыйДокумент, АвтоматическиФормироватьОСУ = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействиеИСМП.ДанныеДокументаСоответствуютДаннымУпаковок(ПроверяемыйДокумент, АвтоматическиФормироватьОСУ);
```
</details>

## ДокументСвязанСЭлектронным
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Проверяет что по текущему прикладному документу есть электронный документ (входящий или исходящий).
//   Вариант: по текущему прикладному документу есть электронный документ с данными о маркируемых товарах.
//
// Параметры:
//   Ссылка - ДокументСсылка - проверяемый документ
//   СодержащимДанныеОМаркируемыхТоварах - Булево - отбор документа ЭДО с данными о маркируемых товарах
//
// Возвращаемое значение:
//   Булево - с текущим документом связан электронный документ.
//
Функция ДокументСвязанСЭлектронным(Ссылка, СодержащимДанныеОМаркируемыхТоварах = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействиеИСМП.ДокументСвязанСЭлектронным(Ссылка, СодержащимДанныеОМаркируемыхТоварах);
```
</details>

## КодМаркировкиДляПередачиУПД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Код маркировки для передачи УПД.
//
// Параметры:
//  ЗначениеШтрихкода - Строка - Значение кода маркировки
//  ВидПродукции      - ПеречислениеСсылка.ВидыПродукцииИС - Вид продукции
//  РезультатРазбора  - см. ШтрихкодированиеОбщегоНазначенияИС.НоваяСтруктураОбработкиШтрихкода - Результат разбора,
//                    - Неопределено - разбор не производился.
//
// Возвращаемое значение:
//  Строка - Код маркировки для передачи УПД.
Функция КодМаркировкиДляПередачиУПД(ЗначениеШтрихкода, ВидПродукции, РезультатРазбора = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействиеИСМП.КодМаркировкиДляПередачиУПД(ЗначениеШтрихкода, ВидПродукции, РезультатРазбора);
```
</details>

## ЧастичноеСодержимое
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Разворачивает таблицу транспортных и индивидуальных штрихкодов до номенклатуры, характеристики, серии
//   для дальнейшего сопоставления информации об упаковках с товарной частью.
// Для транспортных мультитоварных упаковок номенклатура (характеристика, серия)- это различная номенклатура
//   (характеристика, серия) каждого вложенного (на любом уровне) индивидуального штрихкода, для монотоварных упаковок и
//   кодов маркировки - содержимое.
//
// Параметры:
// 	ТаблицаУпаковок - ТаблицаЗначений - исходная таблица упаковок:
// 	 * Ссылка   - Произвольный - объект-владелец штрихкода
// 	 * Штрихкод - СправочникСсылка.ШтрихкодыУпаковокТоваров - Штрихкод
// Возвращаемое значение:
// ТаблицаЗначений - таблица упаковок с товарными данными:
// 	 * Ссылка             - Произвольный - объект-владелец штрихкода - исходная колонка
// 	 * Штрихкод           - СправочникСсылка.ШтрихкодыУпаковокТоваров - ссылка на индивидуальный штрихкод содержимого или мультитоварную упаковку
// 	 * Номенклатура       - ОпределяемыйТип.Номенклатура - содержимое
// 	 * Характеристика     - ОпределяемыйТип.ХарактеристикаНоменклатуры - содержимое
// 	 * Серия              - ОпределяемыйТип.СерияНоменклатуры - содержимое
// 	 * ТребуетВзвешивания - Булево - признак продукции требующей взвешивания потребительских кодов
// 	 * ЗначениеШтрихкода  - Строка - текстовое представление исходного штрихкода для передачи в ЭДО
// 	 * Мультитоварная     - Булево - признак мультитоварной упаковки
// 	 * ВидПродукции       - Перечислениессылка.ВидыПродукцииИС - вид продукции номенклатуры для кодировки значения штрихкода
// 	 * ВидУпаковки        - ПеречислениеСсылка.ВидыУпаковокИС - вид упаковки номенклатуры для кодировки значения штрихкода
// 	 * Обработан          - Булево - признак сопоставления строки товарной части документа
// 	 * Количество         - Число  - количество маркируемой продукции по коду маркировки
// 	 * КоличествоПотребительскихУпаковок - Число  - количество потребительских упаковок маркируемой продукции по коду маркировки
//   * ТекстОшибкиИС      - Строка - Текст ошибки по строке при наличии
//   * КоличествоВПотребительскойУпаковке - Число - количество в 1 потребительской упаковке (в т.ч. средний вес) для автоматического кода ОСУ
Функция ЧастичноеСодержимое(ТаблицаУпаковок) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействиеИСМП.ЧастичноеСодержимое(ТаблицаУпаковок) 
```
</details>

## ЧастичноеСодержимоеИКодыОСУ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Разворачивает таблицу транспортных и индивидуальных штрихкодов до номенклатуры, характеристики, серии
//   для дальнейшего сопоставления информации об упаковках с товарной частью.
// Добавляет в таблицу коды ОСУ для строк, по которым коды маркировки не указывались. Считаем что таблица товаров
//   уже соответствует таблице штрихкодов упаковок (с учетом невнесенных ОСУ).
//
// Параметры:
// 	ТаблицаУпаковок - ТаблицаЗначений - исходная таблица упаковок:
// 	 * Ссылка   - Произвольный - объект-владелец штрихкода
// 	 * Штрихкод - СправочникСсылка.ШтрихкодыУпаковокТоваров - Штрихкод
//  ТаблицаТоваров	 - ТаблицаЗначений - исходная таблица товаров:
// 	 * Ссылка         - Произвольный - объект-владелец штрихкода
// 	 * Номенклатура   - ОпределяемыйТип.Номенклатура - номенклатура
// 	 * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - характеристика
// 	 * Количество     - Число - количество
//  ПараметрыСканирования - См. ШтрихкодированиеОбщегоНазначенияИС.ПараметрыСканирования
// Возвращаемое значение:
//  ТаблицаЗначений - См. ЧастичноеСодержимое
//
Функция ЧастичноеСодержимоеИКодыОСУ(ТаблицаУпаковок, ТаблицаТоваров, ПараметрыСканирования) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействиеИСМП.ЧастичноеСодержимоеИКодыОСУ(ТаблицаУпаковок, ТаблицаТоваров, ПараметрыСканирования) 
```
</details>

## Содержимое
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Разворачивает таблицу транспортных и индивидуальных штрихкодов до номенклатуры, характеристики, серии
// для дальнейшего сравнения информации об упаковках с товарной частью.
//
// Параметры:
//   ШтрихкодыУпаковок - Массив Из СправочникСсылка.ШтрихкодыУпаковокТоваров                                       - Исходные штрихкоды упаковок без частичного выбытия.
//                     - Массив Из см. ШтрихкодированиеИС.НовыйЭлементКоллекцииУпаковокДляРаспределенияПоТоварам - Исходные штрихкоды упаковок, используя частичное выбытие.
//   ВидыПродукцииИС   - ПеречислениеСсылка.ВидыПродукцииИС, Массив Из ПеречислениеСсылка.ВидыПродукцииИС, Неопределено -
//      ограничение содержимого штрихкодов упаковок по виду/видам маркируемой продукции.
//   ДоКомплектующих - Булево - Разворачивать наборы до комплектующих
//   ВключатьШтрихкодУпаковки - Булево - Сворачивает полученную таблицу содержимого до штрихкода упаковки
// Возвращаемое значение:
// ТаблицаЗначений - таблица состава упаковок:
//   * ШтрихкодУпаковки   - СправочникСсылка.ШтрихкодыУпаковокТоваров  - Штрихкод упаковки.
//   * Номенклатура       - ОпределяемыйТип.Номенклатура               - содержимое
//   * Характеристика     - ОпределяемыйТип.ХарактеристикаНоменклатуры - содержимое
//   * Серия              - ОпределяемыйТип.СерияНоменклатуры          - содержимое
//   * Количество         - Число                                      - количество единиц содержимого
//   * ЧастичноеВыбытиеВариантУчета - ПеречислениеСсылка.ВариантыУчетаЧастичногоВыбытияИС - Вариант частичного выбытия.
Функция Содержимое(Знач ШтрихкодыУпаковок, Знач ВидыПродукцииИС = Неопределено, ДоКомплектующих = Ложь, ВключатьШтрихкодУпаковки = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействиеИСМП.Содержимое(ШтрихкодыУпаковок, ВидыПродукцииИС, ДоКомплектующих, ВключатьШтрихкодУпаковки);
```
</details>

## СодержимоеИКодыОСУ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Разворачивает таблицу транспортных и индивидуальных штрихкодов до номенклатуры, характеристики, серии
// для дальнейшего сравнения информации об упаковках с товарной частью.
//
// Параметры:
//  Упаковки - Массив Из см. ШтрихкодированиеИС.НовыйЭлементКоллекцииУпаковокДляРаспределенияПоТоварам - штрихкоды упаковок, используя частичное выбытие.
//                  - ТаблицаЗначений - исходная таблица упаковок:
// 	 * Штрихкод                       - СправочникСсылка.ШтрихкодыУпаковокТоваров - Штрихкод
//  ТаблицаТоваров	 - ТаблицаЗначений - исходная таблица товаров:
// 	 * Ссылка         - Произвольный - объект-владелец штрихкода
// 	 * Номенклатура   - ОпределяемыйТип.Номенклатура - номенклатура
// 	 * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - характеристика
// 	 * Количество     - Число - количество
//  ПараметрыСканирования - См. ШтрихкодированиеОбщегоНазначенияИС.ПараметрыСканирования
// Возвращаемое значение:
//  ТаблицаЗначений - см. Содержимое
Функция СодержимоеИКодыОСУ(Упаковки, ТаблицаТоваров, ПараметрыСканирования) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействиеИСМП.СодержимоеИКодыОСУ(Упаковки, ТаблицаТоваров, ПараметрыСканирования) 
```
</details>

## ЧастичноеСодержимоеТОРГ2
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Дополняет таблицу транспортных и индивидуальных штрихкодов видом продукции, видом упаковок
// для дальнейшего заполнения данных о кодах маркировки при формировании ТОРГ-2.
//
// Параметры:
// 	ТаблицаУпаковок - ТаблицаЗначений - исходная таблица упаковок:
// 	 * Ссылка   - Произвольный - объект-владелец штрихкода
// 	 * Штрихкод - СправочникСсылка.ШтрихкодыУпаковокТоваров - Штрихкод
// 	 * Номенклатура       - ОпределяемыйТип.Номенклатура - содержимое
// 	 * Характеристика     - ОпределяемыйТип.ХарактеристикаНоменклатуры - содержимое
//   ПолеТипРасхождения - Строка - путь к данным тип расхождения, необязательный параметр.
//
// Возвращаемое значение:
// ТаблицаЗначений - таблица упаковок с товарными данными:
// 	 * Ссылка             - Произвольный - объект-владелец штрихкода - исходная колонка
// 	 * Номенклатура       - ОпределяемыйТип.Номенклатура - содержимое
// 	 * Характеристика     - ОпределяемыйТип.ХарактеристикаНоменклатуры - содержимое
// 	 * ЗначениеШтрихкода  - Строка - текстовое представление исходного штрихкода для передачи в ЭДО
// 	 * ВидПродукции       - Перечислениессылка.ВидыПродукцииИС - вид продукции номенклатуры для кодировки значения штрихкода
// 	 * ВидУпаковки        - ПеречислениеСсылка.ВидыУпаковокИС - вид упаковки номенклатуры для кодировки значения штрихкода
// 	 * Обработан          - Булево - признак сопоставления строки товарной части документа
//   * ТипРасхождения     - ОпределяемыйТип.ТипРасхожденияИСМП - тип расхождения.
Функция ЧастичноеСодержимоеТОРГ2(ТаблицаУпаковок, ПолеТипРасхождения = Неопределено) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействиеИСМП.ЧастичноеСодержимоеТОРГ2(ТаблицаУпаковок, ПолеТипРасхождения);
```
</details>

## НормализоватьШтрихкодыУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура НормализоватьШтрихкодыУпаковок(Товары, ШтрихкодыУпаковок) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.НормализоватьШтрихкодыУпаковок(Товары, ШтрихкодыУпаковок) 
```
</details>

## НормализоватьШтрихкодыУпаковокУКД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Нормализация кодов, полученных в переданной таблице, заполненной по данным ЭДО.
// Входящая таблица штрихкоды должна содержать данные о номенклатуре, используемой для определения вида продукции при разборе кодов.
//
// Параметры:
//  ШтрихкодыУпаковок - ТаблицаЗначений - таблица, содержащая колонки:
//  * ЗначениеШтрихкода - Строка - Значение штрихкода.
//  * Номенклатура - ОпределяемыйТип.Номенклатура - Номенклатура.
//  * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - Характеристика.
Процедура НормализоватьШтрихкодыУпаковокУКД(ШтрихкодыУпаковок) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.НормализоватьШтрихкодыУпаковокУКД(ШтрихкодыУпаковок) 
```
</details>

## ЗаполнитьРасхожденияКодовМаркировкиУКД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обрабатывает таблицы кодов маркировки для заполнения УКД только расхождениями (сокращенный формат).
//
// Параметры:
//  ШтрихкодыУпаковокДо - ТаблицаЗначений - См. ЧастичноеСодержимое. Таблица кодов документа-основания. Будет перезаполнена кодами, которые отсутствуют в корректируемом документе.
//  ШтрихкодыУпаковок   - ТаблицаЗначений - См. ЧастичноеСодержимое. Таблица кодов документа корректировки. Будет перезаполнена кодами, которые отсутствуют в документе основании.
Процедура ЗаполнитьРасхожденияКодовМаркировкиУКД(ШтрихкодыУпаковокДо, ШтрихкодыУпаковок) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ЗаполнитьРасхожденияКодовМаркировкиУКД(ШтрихкодыУпаковокДо, ШтрихкодыУпаковок) 
```
</details>

## ЗаполнитьСведенияОМаркировке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет в приемнике сведения по маркировке если они есть во входящих данных.
//
// Параметры:
//  Приемник - СтрокаТаблицыЗначений - для заполнения колонки СведенияОМаркировке.
//  Источник - СтрокаТаблицыЗначений - строка документа, содержащая колонки:
//   * Ссылка         - ДокументСсылка - ссылка на документ, для которого заполняются данные,
//   * Номенклатура   - ОпределяемыйТип.Номенклатура - номенклатура в строке документа,
//   * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - характеристика в строке,
//   * Серия          - ОпределяемыйТип.СерияНоменклатуры - серия в строке,
//   * Количество     - Число - количество в строке (ограничивает привязанные строки маркировки).
//  ДанныеШтрихкодовУпаковок - См. ЧастичноеСодержимое
//  ОбъектыСОграничениемДлины - Массив Из ДокументСсылка - документы в которых сработало ограничение на длину строки
//
Процедура ЗаполнитьСведенияОМаркировке(Приемник, Источник, ДанныеШтрихкодовУпаковок, ОбъектыСОграничениемДлины) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ЗаполнитьСведенияОМаркировке(Приемник, Источник, ДанныеШтрихкодовУпаковок, ОбъектыСОграничениемДлины) 
```
</details>

## ПроверитьСведенияОМаркировке
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет распределение штрихкодов по строкам товаров. Требуется использование в формате ЭДО с ограничением
// количества символов кодов маркировки для строки маркируемой продукции (после применения ограничения могут быть
// распределены не все коды).
//
// Параметры:
//   ДанныеШтрихкодовУпаковок  - См. ЧастичноеСодержимое
//   ОбъектыСОграничениемДлины - Массив Из ДокументСсылка - ссылки на документы, где требуется проверка
//   Отказ                     - Булево - признак что не все коды распределены
//
Процедура ПроверитьСведенияОМаркировке(ДанныеШтрихкодовУпаковок, ОбъектыСОграничениемДлины, Отказ) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ПроверитьСведенияОМаркировке(ДанныеШтрихкодовУпаковок, ОбъектыСОграничениемДлины, Отказ) 
```
</details>

## ПроверитьСведенияОМаркировке_2019
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет распределение штрихкодов по строкам товаров. Требуется использование в формате ЭДО с объемно-сортовыми
// кодами маркировки: для каждого такого кода нужна своя строка документа (после применения ограничения могут быть
// распределены не все коды).
//
// Параметры:
//   ДанныеШтрихкодовУпаковок  - См. ЧастичноеСодержимое
//   Отказ                     - Булево - признак что не все коды распределены
//
Процедура ПроверитьСведенияОМаркировке_2019(ДанныеШтрихкодовУпаковок, Отказ) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ПроверитьСведенияОМаркировке_2019(ДанныеШтрихкодовУпаковок, Отказ) 
```
</details>

## ПроверитьСведенияОМаркировке_5_02
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет распределение штрихкодов по строкам товаров. Требуется использование в формате ЭДО с объемно-сортовыми
// кодами маркировки: для каждого такого кода нужна своя строка документа (после применения ограничения могут быть
// распределены не все коды).
//
// Параметры:
//   ДанныеШтрихкодовУпаковок  - См. ЧастичноеСодержимое
//   Отказ                     - Булево - признак что не все коды распределены
//
Процедура ПроверитьСведенияОМаркировке_5_02(ДанныеШтрихкодовУпаковок, Отказ) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ПроверитьСведенияОМаркировке_5_02(ДанныеШтрихкодовУпаковок, Отказ) 
```
</details>

## ЗаполнитьСведенияОМаркировке_2019
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет в приемнике сведения по маркировке если они есть во входящих данных.
//
// Параметры:
//  Приемник - СтрокаТаблицыЗначений - для заполнения колонки СведенияОМаркировке.
//  Источник - СтрокаТаблицыЗначений - строка документа, содержащая колонки:
//   * Ссылка         - ДокументСсылка - ссылка на документ, для которого заполняются данные,
//   * Номенклатура   - ОпределяемыйТип.Номенклатура - номенклатура в строке документа,
//   * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - характеристика в строке,
//   * Серия          - ОпределяемыйТип.СерияНоменклатуры - серия в строке,
//   * Количество     - Число - количество в строке (ограничивает привязанные строки маркировки).
//  ДанныеШтрихкодовУпаковок - Неопределено, ТаблицаЗначений - содержит сведения об упаковках (См. ЧастичноеСодержимое)
Процедура ЗаполнитьСведенияОМаркировке_2019(Приемник, Источник, ДанныеШтрихкодовУпаковок) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ЗаполнитьСведенияОМаркировке_2019(Приемник, Источник, ДанныеШтрихкодовУпаковок) 
```
</details>

## ЗаполнитьСведенияОМаркировке_5_02
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет в приемнике сведения по маркировке если они есть во входящих данных.
//
// Параметры:
//  Приемник - СтрокаТаблицыЗначений - для заполнения колонки СведенияОМаркировке.
//  Источник - СтрокаТаблицыЗначений - строка документа, содержащая колонки:
//   * Ссылка         - ДокументСсылка - ссылка на документ, для которого заполняются данные,
//   * Номенклатура   - ОпределяемыйТип.Номенклатура - номенклатура в строке документа,
//   * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - характеристика в строке,
//   * Серия          - ОпределяемыйТип.СерияНоменклатуры - серия в строке,
//   * Количество     - Число - количество в строке (ограничивает привязанные строки маркировки).
//  ДанныеШтрихкодовУпаковок - Неопределено, ТаблицаЗначений - содержит сведения об упаковках (См. ЧастичноеСодержимое)
Процедура ЗаполнитьСведенияОМаркировке_5_02(Приемник, Источник, ДанныеШтрихкодовУпаковок) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ЗаполнитьСведенияОМаркировке_5_02(Приемник, Источник, ДанныеШтрихкодовУпаковок) 
```
</details>

## ЗаполнениеПоказателейМаркировкиВДереве_5_02
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполнение признаков наличия определенных маркируемых товаров в дереве: ЕстьАлкогольнаяПродукция, ЕстьТабачнаяПродукция.
//
// Параметры:
//  ДеревоДанных - ДеревоЗначений - дерево электронного документа.
//  ДанныеШтрихкодовУпаковок - Неопределено, ТаблицаЗначений - содержит сведения об упаковках (См. ЧастичноеСодержимое)
Процедура ЗаполнениеПоказателейМаркировкиВДереве_5_02(ДеревоДанных, ДанныеШтрихкодовУпаковок) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ЗаполнениеПоказателейМаркировкиВДереве_5_02(ДеревоДанных, ДанныеШтрихкодовУпаковок) 
```
</details>

## ЗаполнитьСведенияОМаркировкеАктОРасхождениях_2019
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет в приемнике сведения по маркировке если они есть во входящих данных.
//
// Параметры:
//  Приемник - СтрокаТаблицыЗначений - для заполнения колонки Маркировка.
//  Источник - СтрокаТаблицыЗначений - строка документа, содержащая колонки:
//   * Ссылка         - ДокументСсылка - ссылка на документ, для которого заполняются данные,
//   * Номенклатура   - ОпределяемыйТип.Номенклатура - номенклатура в строке документа,
//   * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - характеристика в строке,
//   * Серия          - ОпределяемыйТип.СерияНоменклатуры - серия в строке,
//   * Количество     - Число - количество в строке (ограничивает привязанные строки маркировки). Имя колонки определяется в 4м параметре.
//  ДанныеШтрихкодовУпаковок - Неопределено, ТаблицаЗначений - содержит сведения об упаковках (См. ЧастичноеСодержимоеТОРГ2)
//  ПолеКоличество - Строка - имя поля количество строки источника
//  ОтборПоТипуРасхождений - Булево - истина, если требуется отбирать коды маркировки с учетом типа расхождения
//  ТипРасхождения - ОпределяемыйТип.ТипРасхожденияИСМП - тип расхождения.
Процедура ЗаполнитьСведенияОМаркировкеАктОРасхождениях_2019(Приемник, Источник, ДанныеШтрихкодовУпаковок, Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ЗаполнитьСведенияОМаркировкеАктОРасхождениях_2019(Приемник, Источник, ДанныеШтрихкодовУпаковок, );
```
</details>

## ЗаполнитьСведенияОМаркировкеУКД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет в приемнике сведения по маркировке если они есть во входящих данных.
//
// Параметры:
//  Приемник - СтрокаТаблицыЗначений - для заполнения колонки СведенияОМаркировке.
//  Источник - СтрокаТаблицыЗначений - строка документа, содержащая колонки:
//   * Ссылка         - ДокументСсылка - ссылка на документ, для которого заполняются данные,
//   * Номенклатура   - ОпределяемыйТип.Номенклатура - номенклатура в строке документа,
//   * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - характеристика в строке,
//   * Серия          - ОпределяемыйТип.СерияНоменклатуры - серия в строке,
//   * КоличествоДо   - Число - количество в строке до корректировки (ограничивает привязанные строки маркировки),
//   * Количество     - Число - количество в строке после корректировки (ограничивает привязанные строки маркировки).
//  ДанныеШтрихкодовУпаковокДо - ТаблицаЗначений - содержит сведения об упаковках (См. ЧастичноеСодержимое)
//  ДанныеШтрихкодовУпаковокПосле  - ТаблицаЗначений - содержит сведения об упаковках (См. ЧастичноеСодержимое)
Процедура ЗаполнитьСведенияОМаркировкеУКД(Приемник, Источник, ДанныеШтрихкодовУпаковокДо, ДанныеШтрихкодовУпаковокПосле) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ЗаполнитьСведенияОМаркировкеУКД(Приемник, Источник, ДанныеШтрихкодовУпаковокДо, ДанныеШтрихкодовУпаковокПосле) 
```
</details>

## ЗаполнитьСведенияОМаркировкеУКД2020
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет в приемнике сведения по маркировке если они есть во входящих данных.
//
// Параметры:
//  Приемник - СтрокаТаблицыЗначений - для заполнения колонки СведенияОМаркировке.
//  Источник - СтрокаТаблицыЗначений - строка документа, содержащая колонки:
//   * Ссылка         - ДокументСсылка - ссылка на документ, для которого заполняются данные,
//   * Номенклатура   - ОпределяемыйТип.Номенклатура - номенклатура в строке документа,
//   * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - характеристика в строке,
//   * Серия          - ОпределяемыйТип.СерияНоменклатуры - серия в строке,
//   * КоличествоДо   - Число - количество в строке до корректировки (ограничивает привязанные строки маркировки),
//   * Количество     - Число - количество в строке после корректировки (ограничивает привязанные строки маркировки).
//  ДанныеШтрихкодовУпаковокДо - ТаблицаЗначений - содержит сведения об упаковках (См. ЧастичноеСодержимое)
//  ДанныеШтрихкодовУпаковокПосле  - ТаблицаЗначений - содержит сведения об упаковках (См. ЧастичноеСодержимое)
Процедура ЗаполнитьСведенияОМаркировкеУКД2020(Приемник, Источник, ДанныеШтрихкодовУпаковокДо, ДанныеШтрихкодовУпаковокПосле) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ЗаполнитьСведенияОМаркировкеУКД2020(Приемник, Источник, ДанныеШтрихкодовУпаковокДо, ДанныеШтрихкодовУпаковокПосле) 
```
</details>

## ПолучитьКоличествоОформитьРасхожденияКакБрак
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Рассчитывает по таблице расхождений количество бракованных кодов
//
// Параметры:
//  ВыборкаТовары - ВыборкаИзРезультатаЗапроса - данные выборки по строке товара.
//  ТаблицаУпаковкиРасхождения - См. ЧастичноеСодержимоеТОРГ2.
//
// Возвращаемое значение:
//  Число - количество, доступное к оформлению как брак по расхождениям.
//
Функция ПолучитьКоличествоОформитьРасхожденияКакБрак(ВыборкаТовары, ТаблицаУпаковкиРасхождения) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействиеИСМП.ПолучитьКоличествоОформитьРасхожденияКакБрак(ВыборкаТовары, ТаблицаУпаковкиРасхождения) 
```
</details>

## ШтрихкодыУпаковокИзСтрокиДереваЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает коды маркировки для строки товара из дерева электронного документа ЭДО.
//
// Параметры:
//	СведенияОТоваре - СтрокаДереваЗначений - строка товаров дерева электронного документа ЭДО.
//
// Пример использования:
//	СведенияОТоварах = ДеревоДанных.Строки.Найти("СведенияОТоварах", "ПолныйПуть");
//	Для Каждого СведенияОТоваре Из СведенияОТоварах.Строки Цикл
//		ШтрихкодыУпаковок = ЭлектронноеВзаимодействиеИСМП.ШтрихкодыУпаковокИзСтрокиДереваЭДО(СведенияОТоваре);
//	КонецЦикла;.
//
Функция ШтрихкодыУпаковокИзСтрокиДереваЭДО(СведенияОТоваре) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействиеИСМП.ШтрихкодыУпаковокИзСтрокиДереваЭДО(СведенияОТоваре));
```
</details>

## ШтрихкодыУпаковокИзСтрокиДереваЭДО_2019
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает коды маркировки для строки товара из дерева электронного документа ЭДО.
//
// Параметры:
//	СведенияОТоваре - СтрокаДереваЗначений - строка товаров дерева электронного документа ЭДО.
//
// Пример использования:
//	СведенияОТоварах = ДеревоДанных.Строки.Найти("СведенияОТоварах", "ПолныйПуть");
//	Для Каждого СведенияОТоваре Из СведенияОТоварах.Строки Цикл
//		ШтрихкодыУпаковок = ЭлектронноеВзаимодействиеИСМП.ШтрихкодыУпаковокИзСтрокиДереваЭДО(СведенияОТоваре);
//	КонецЦикла;.
//
// Возвращаемое значение:
//  Массив из Строка - массив штрихкодов упаковок
Функция ШтрихкодыУпаковокИзСтрокиДереваЭДО_2019(СведенияОТоваре) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействиеИСМП.ШтрихкодыУпаковокИзСтрокиДереваЭДО_2019(СведенияОТоваре));
```
</details>

## ШтрихкодыУпаковокИзСтрокиДереваЭДО_5_02
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает коды маркировки для строки товара из дерева электронного документа ЭДО.
//
// Параметры:
//	СведенияОТоваре - СтрокаДереваЗначений - строка товаров дерева электронного документа ЭДО.
//
// Пример использования:
//	СведенияОТоварах = ДеревоДанных.Строки.Найти("СведенияОТоварах", "ПолныйПуть");
//	Для Каждого СведенияОТоваре Из СведенияОТоварах.Строки Цикл
//		ШтрихкодыУпаковок = ЭлектронноеВзаимодействиеИСМП.ШтрихкодыУпаковокИзСтрокиДереваЭДО(СведенияОТоваре);
//	КонецЦикла;.
//
// Возвращаемое значение:
//  Массив из Строка - массив штрихкодов упаковок
Функция ШтрихкодыУпаковокИзСтрокиДереваЭДО_5_02(СведенияОТоваре) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействиеИСМП.ШтрихкодыУпаковокИзСтрокиДереваЭДО_5_02(СведенияОТоваре) 
```
</details>

## ШтрихкодыУпаковокИзСтрокиДереваЭДО_УКД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает коды маркировки для строки товара из дерева электронного документа ЭДО.
//
// Параметры:
//	СведенияОТоваре - СтрокаДереваЗначений - строка товаров дерева электронного документа ЭДО.
//	Постфикс - Строка - потсфикс имени реквизита строки ЭДО, хранящего сведения о маркировке ("До", "После")
// Пример использования:
//	СведенияОТоварах = ДеревоДанных.Строки.Найти("СведенияОТоварах", "ПолныйПуть");
//	Для Каждого СведенияОТоваре Из СведенияОТоварах.Строки Цикл
//		ШтрихкодыУпаковок = ЭлектронноеВзаимодействиеИСМП.ШтрихкодыУпаковокИзСтрокиДереваЭДО(СведенияОТоваре);
//	КонецЦикла;.
//
Функция ШтрихкодыУпаковокИзСтрокиДереваЭДО_УКД(СведенияОТоваре, Постфикс = "После") Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействиеИСМП.ШтрихкодыУпаковокИзСтрокиДереваЭДО_УКД(СведенияОТоваре, Постфикс);
```
</details>

## НоваяТаблицаШтрихкодыУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает новую таблицу значений для штрихкодов упаковок.
// В прикладных документах должна существовать табличная часть с аналогичным набором колонок.
//
// Параметры:
// 	ДобавитьНоменклатуру - Булево - признак необходимости дополнить возвращаемую таблицу колонками номенклатуры.
//
// Возвращаемое значение:
// 	ТаблицаЗначений - Таблица значений штрихкодов упаковок:
// * ШтрихкодУпаковки - СправочникСсылка.ШтрихкодыУпаковокТоваров - Штрихкод упаковки
// * ЗначениеШтрихкода - Строка - Значение штрихкода
// * Номенклатура - ОпределяемыйТип.Номенклатура - Номенклатура
// * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - Характеристика
Функция НоваяТаблицаШтрихкодыУпаковок(ДобавитьНоменклатуру = Ложь) Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействиеИСМП.НоваяТаблицаШтрихкодыУпаковок(ДобавитьНоменклатуру);
```
</details>

## ТаблицаШтрихкодыУпаковокНоменклатура
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает таблицу значений для штрихкодов упаковок, полученных в ТОРГ-2
// В прикладных документах должна существовать табличная часть с аналогичным набором колонок.
//
// Возвращаемое значение:
// 	ТаблицаЗначений - Таблица значений штрихкодов упаковок:
// * ШтрихкодУпаковки - СправочникСсылка.ШтрихкодыУпаковокТоваров - Штрихкод упаковки
// * ЗначениеШтрихкода - Строка - Значение штрихкода
// * Номенклатура - ОпределяемыйТип.Номенклатура - Номенклатура
// * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - Характеристика
// * ТипРасхождения - ОпределяемыйТип.ТипРасхожденияИСМП - тип расхождения.
// * Количество - Число - количество единиц.
//
Функция ТаблицаШтрихкодыУпаковокНоменклатура() Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействиеИСМП.ТаблицаШтрихкодыУпаковокНоменклатура() 
```
</details>

## ДобавитьШтрихкодыТаблицуШтрихкодовУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет коды маркировки из сведений о товаре документа ЭДО в общую таблицу штрихкодов упаковок.
//
// Параметры:
// 	ШтрихкодыУпаковок - ТаблицаЗначений - Таблица штрихкодов (См. НоваяТаблицаШтрихкодыУпаковок).
// 	СведенияОТоваре - СтрокаДереваЗначений - Строка сведений о товаре из документа ЭДО.
Процедура ДобавитьШтрихкодыТаблицуШтрихкодовУпаковок(ШтрихкодыУпаковок, СведенияОТоваре) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ДобавитьШтрихкодыТаблицуШтрихкодовУпаковок(ШтрихкодыУпаковок, СведенияОТоваре) 
```
</details>

## ДобавитьШтрихкодыТаблицуШтрихкодовУпаковок_2019
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет коды маркировки из сведений о товаре документа ЭДО в общую таблицу штрихкодов упаковок.
//
// Параметры:
// 	ШтрихкодыУпаковок - ТаблицаЗначений - Таблица штрихкодов (См. НоваяТаблицаШтрихкодыУпаковок).
// 	СведенияОТоваре - СтрокаДереваЗначений - Строка сведений о товаре из документа ЭДО.
Процедура ДобавитьШтрихкодыТаблицуШтрихкодовУпаковок_2019(ШтрихкодыУпаковок, СведенияОТоваре) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ДобавитьШтрихкодыТаблицуШтрихкодовУпаковок_2019(ШтрихкодыУпаковок, СведенияОТоваре) 
```
</details>

## ДобавитьШтрихкодыТаблицуШтрихкодовУпаковок_5_02
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет коды маркировки из сведений о товаре документа ЭДО в общую таблицу штрихкодов упаковок.
//
// Параметры:
// 	ШтрихкодыУпаковок - ТаблицаЗначений - Таблица штрихкодов (См. НоваяТаблицаШтрихкодыУпаковок).
// 	СведенияОТоваре - СтрокаДереваЗначений - Строка сведений о товаре из документа ЭДО.
Процедура ДобавитьШтрихкодыТаблицуШтрихкодовУпаковок_5_02(ШтрихкодыУпаковок, СведенияОТоваре) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ДобавитьШтрихкодыТаблицуШтрихкодовУпаковок_5_02(ШтрихкодыУпаковок, СведенияОТоваре) 
```
</details>

## ДобавитьШтрихкодыТаблицуШтрихкодовУпаковок_УКД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет коды маркировки из сведений о товаре документа ЭДО в общую таблицу штрихкодов упаковок.
// Используется для УКД, заполненного кодами маркировки полным форматом (все коды До/После).
//
// Параметры:
// 	ШтрихкодыУпаковок - ТаблицаЗначений - Таблица штрихкодов (См. НоваяТаблицаШтрихкодыУпаковок).
// 	СведенияОТоваре - СтрокаДереваЗначений - Строка сведений о товаре из документа ЭДО.
Процедура ДобавитьШтрихкодыТаблицуШтрихкодовУпаковок_УКД(ШтрихкодыУпаковок, СведенияОТоваре) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ДобавитьШтрихкодыТаблицуШтрихкодовУпаковок_УКД(ШтрихкодыУпаковок, СведенияОТоваре) 
```
</details>

## ДобавитьШтрихкодыТаблицуШтрихкодовУпаковок_УКД2020
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет коды маркировки из сведений о товаре документа ЭДО в общую таблицу штрихкодов упаковок.
// Используется для УКД, заполненного кодами маркировки по упрощенному формату (только расхождения До/После).
//
// Параметры:
// 	ШтрихкодыУпаковок - ТаблицаЗначений - Таблица штрихкодов для заполнения данными из ЭДО (См. НоваяТаблицаШтрихкодыУпаковок).
// 	СведенияОТоваре - СтрокаДереваЗначений - Строка сведений о товаре из документа ЭДО.
//  ШтрихкодыУпаковокОснования - ТаблицаЗначений - таблица, содержащая колонки:
//  * ЗначениеШтрихкода - Строка - Значение штрихкода.
//  * Номенклатура - ОпределяемыйТип.Номенклатура - Номенклатура.
//  * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - Характеристика.
// 	СтрокаТовары - СтрокаТаблицыЗначений - строка документа, содержащая колонки:
//   * Номенклатура   - ОпределяемыйТип.Номенклатура - номенклатура в строке документа,
//   * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - характеристика в строке.
Процедура ДобавитьШтрихкодыТаблицуШтрихкодовУпаковок_УКД2020(ШтрихкодыУпаковок, СведенияОТоваре, ШтрихкодыУпаковокОснования, СтрокаТовары) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ДобавитьШтрихкодыТаблицуШтрихкодовУпаковок_УКД2020(ШтрихкодыУпаковок, СведенияОТоваре, ШтрихкодыУпаковокОснования, СтрокаТовары) 
```
</details>

## ДобавитьШтрихкодыПоДокументуОснованию_УКД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Дополняет таблицу штрихкоды упаковок при заполнении УКД данными кодов документа-основания с отобором по номенклатуре строки.
//
// Параметры:
// 	ШтрихкодыУпаковок - ТаблицаЗначений - Таблица штрихкодов (См. НоваяТаблицаШтрихкодыУпаковок).
//  ШтрихкодыУпаковокОснования - ТаблицаЗначений - таблица, содержащая колонки:
//  * ЗначениеШтрихкода - Строка - Значение штрихкода
//  * Номенклатура - ОпределяемыйТип.Номенклатура - Номенклатура
//  * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - Характеристика
//  СтрокаТовары - СтрокаТаблицыЗначений - строка документа, содержащая колонки:
//   * Номенклатура   - ОпределяемыйТип.Номенклатура - номенклатура в строке документа,
//   * Характеристика - ОпределяемыйТип.ХарактеристикаНоменклатуры - характеристика в строке.
Процедура ДобавитьШтрихкодыПоДокументуОснованию_УКД(ШтрихкодыУпаковок, ШтрихкодыУпаковокОснования, СтрокаТовары) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ДобавитьШтрихкодыПоДокументуОснованию_УКД(ШтрихкодыУпаковок, ШтрихкодыУпаковокОснования, СтрокаТовары) 
```
</details>

## ДобавитьШтрихкодыТаблицыШтрихкодовАктОРасхождениях
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Добавляет коды маркировки из сведений о товаре документа ЭДО в таблицы штрихкодов упаковок (факт и расхождения).
//
// Параметры:
//  ШтрихкодыУпаковок - ТаблицаЗначений - Таблица штрихкодов для заполнения данными раздела Факт (См. ТаблицаШтрихкодыУпаковокНоменклатура).
//  ШтрихкодыУпаковокРасхождения - ТаблицаЗначений - Таблица штрихкодов для заполнения данными по расхождениям (См. ТаблицаШтрихкодыУпаковокНоменклатура).
//  СведенияОТоваре - СтрокаДереваЗначений - Строка сведений о товаре из документа ЭДО.
Процедура ДобавитьШтрихкодыТаблицыШтрихкодовАктОРасхождениях(ШтрихкодыУпаковок, ШтрихкодыУпаковокРасхождения, Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ДобавитьШтрихкодыТаблицыШтрихкодовАктОРасхождениях(ШтрихкодыУпаковок, ШтрихкодыУпаковокРасхождения, );
```
</details>

## ПараметрыЗаполненияТаблицыШтрихкодовАктОРасхождениях
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Функция ПараметрыЗаполненияТаблицыШтрихкодовАктОРасхождениях() Экспорт
```

Пример вызова
```bsl
Результат = ЭлектронноеВзаимодействиеИСМП.ПараметрыЗаполненияТаблицыШтрихкодовАктОРасхождениях());
```
</details>

## СвернутьТаблицуШтрихкодовУпаковок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сворачивает таблицу штрихкодов упаковок.
//
// Параметры:
// 	ШтрихкодыУпаковок - ТаблицаЗначений - Таблица штрихкодов упаковок.
Процедура СвернутьТаблицуШтрихкодовУпаковок(ШтрихкодыУпаковок) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.СвернутьТаблицуШтрихкодовУпаковок(ШтрихкодыУпаковок) 
```
</details>

## СвернутьТаблицуШтрихкодовУпаковокАкт
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура СвернутьТаблицуШтрихкодовУпаковокАкт(ШтрихкодыУпаковок) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.СвернутьТаблицуШтрихкодовУпаковокАкт(ШтрихкодыУпаковок) 
```
</details>

## ОчиститьРезультатыПроверкиДокументаПриЗагрузкеДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

Процедура ОчиститьРезультатыПроверкиДокументаПриЗагрузкеДокумента(Документ) Экспорт
```

Пример вызова
```bsl
ЭлектронноеВзаимодействиеИСМП.ОчиститьРезультатыПроверкиДокументаПриЗагрузкеДокумента(Документ) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
