---
title: Этапы оплаты сервер
slug: erp-uh/этапы-оплаты-сервер
---


## ПараметрыЗаполненияЭтаповОплатыПоЗаказам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру с параметрами заполнения этапов оплаты по заказам.
//
// Возвращаемое значение:
//  Структура - Параметры заполнения этапов оплаты:
// * ДатаЗаказа                     - Дата - Дата заказа, если есть.
// * ДатаСогласования               - Дата - Дата заказа, если есть.
// * ДатаОтгрузки                   - Дата, ТаблицаЗначений -
// * СрокПереходаПраваСобственности - Число - Срок перехода права собственности из соглашения.
// * Соглашение                     - СправочникСсылка.СоглашенияСКлиентами, СправочникСсылка.СоглашенияСПоставщиками - Соглашение, если есть
// * СуммаОплаты                    - Число - Общая сумма к оплате, без учета залога.
// * СуммаЗалога                    - Число - Сумма залога за тару.
//
Функция ПараметрыЗаполненияЭтаповОплатыПоЗаказам() Экспорт
```

Пример вызова
```bsl
Результат = ЭтапыОплатыСервер.ПараметрыЗаполненияЭтаповОплатыПоЗаказам() 
```
</details>

## ЗаполнитьЭтапыОплатыДокументаПоЗаказам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет ТЧ ЭтапыГрафикаОплаты по переданной структуре параметров.
//
// Параметры:
//  ЭтапыГрафикаОплаты - ТаблицаЗначений - Таблица этапов для заполнения.
//  Параметры - см. ПараметрыЗаполненияЭтаповОплатыПоЗаказам
//
Процедура ЗаполнитьЭтапыОплатыДокументаПоЗаказам(ЭтапыГрафикаОплаты, Параметры) Экспорт
```

Пример вызова
```bsl
ЭтапыОплатыСервер.ЗаполнитьЭтапыОплатыДокументаПоЗаказам(ЭтапыГрафикаОплаты, Параметры) 
```
</details>

## РаспределитьСуммыЭтаповОплатыДокументаПоЗаказам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Распределяет суммы документа по процентам графика
//
// Параметры:
//  ЭтапыГрафикаОплаты -ТаблицаЗначений - Этапы графика оплаты.
//  Параметры - см. ПараметрыЗаполненияЭтаповОплатыПоЗаказам
//
Процедура РаспределитьСуммыЭтаповОплатыДокументаПоЗаказам(ЭтапыГрафикаОплаты, Параметры) Экспорт
```

Пример вызова
```bsl
ЭтапыОплатыСервер.РаспределитьСуммыЭтаповОплатыДокументаПоЗаказам(ЭтапыГрафикаОплаты, Параметры) 
```
</details>

## ПараметрыЗаполненияЭтаповОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру с параметрами заполнения этапов оплаты по соглашению, графику оплаты или по умолчанию.
//
// Возвращаемое значение:
//  Структура - Параметры заполнения этапов оплаты:
// * ДатаЗаказа                     - Дата - Дата заказа, если есть.
// * ДатаСогласования               - Дата - Дата заказа, если есть.
// * ДатаОтгрузки                   - Дата, ТаблицаЗначений - Общая дата отгрузки или таблица значений с колонками "ДатаОтгрузки","СуммаПлатежа" и "СуммаЗалогаЗаТару".
// * СрокПереходаПраваСобственности - Число - Срок перехода права собственности из соглашения.
// * Соглашение                     - СправочникСсылка.СоглашенияСКлиентами, СправочникСсылка.СоглашенияСПоставщиками - Соглашение, если есть
// * СуммаОплаты                    - Число - Общая сумма к оплате, без учета залога.
// * СуммаЗалога                    - Число - Сумма залога за тару.
//
Функция ПараметрыЗаполненияЭтаповОплаты() Экспорт
```

Пример вызова
```bsl
Результат = ЭтапыОплатыСервер.ПараметрыЗаполненияЭтаповОплаты() 
```
</details>

## ЗаполнитьЭтапыОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет этапы графика оплаты или распределяет уже заполненную сумму в документах продажи.
//
// Параметры:
// 		ЭтапыГрафикаОплаты - ТаблицаЗначений - таблица этапов оплаты.
// 		ПараметрыЗаполнения - см. ПараметрыЗаполненияЭтаповОплаты
//
Процедура ЗаполнитьЭтапыОплаты(ЭтапыГрафикаОплаты, ПараметрыЗаполнения) Экспорт
```

Пример вызова
```bsl
ЭтапыОплатыСервер.ЗаполнитьЭтапыОплаты(ЭтапыГрафикаОплаты, ПараметрыЗаполнения) 
```
</details>

## ЗаполнитьЭтапыОплатыПоГрафикуИсполнения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет этапы графика оплаты в документе по графику исполнения договора.
//
// Параметры:
// 		ЭтапыГрафикаОплаты - ТаблицаЗначений - таблица этапов оплаты.
// 		ПараметрыЗаполнения - см. ПараметрыЗаполненияЭтаповОплаты
//
Процедура ЗаполнитьЭтапыОплатыПоГрафикуИсполнения(ЭтапыГрафикаОплаты, ПараметрыЗаполнения) Экспорт
```

Пример вызова
```bsl
ЭтапыОплатыСервер.ЗаполнитьЭтапыОплатыПоГрафикуИсполнения(ЭтапыГрафикаОплаты, ПараметрыЗаполнения) 
```
</details>

## ЗаполнитьЭтапыОплатыПоСоглашению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет этапы графика оплаты в документе по графику указанном в соглашении.
//
// Параметры:
// 		ЭтапыГрафикаОплаты - ТаблицаЗначений - таблица этапов оплаты.
// 		ПараметрыЗаполнения - см. ПараметрыЗаполненияЭтаповОплаты
//
Процедура ЗаполнитьЭтапыОплатыПоСоглашению(ЭтапыГрафикаОплаты, ПараметрыЗаполнения) Экспорт
```

Пример вызова
```bsl
ЭтапыОплатыСервер.ЗаполнитьЭтапыОплатыПоСоглашению(ЭтапыГрафикаОплаты, ПараметрыЗаполнения) 
```
</details>

## ЗаполнитьЭтапыОплатыПоГрафикуОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет этапы графика оплаты в документе по графику оплаты указанном в соглашении.
//
// Параметры:
// 		ЭтапыГрафикаОплаты - ТаблицаЗначений - таблица этапов оплаты.
// 		ПараметрыЗаполнения - см. ПараметрыЗаполненияЭтаповОплаты
//
Процедура ЗаполнитьЭтапыОплатыПоГрафикуОплаты(ЭтапыГрафикаОплаты, ПараметрыЗаполнения) Экспорт
```

Пример вызова
```bsl
ЭтапыОплатыСервер.ЗаполнитьЭтапыОплатыПоГрафикуОплаты(ЭтапыГрафикаОплаты, ПараметрыЗаполнения) 
```
</details>

## ЗаполнитьЭтапыОплатыДокументаПоШаблону
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет этапы графика оплаты в документе по переданному шаблону.
//
// Параметры:
// 		ЭтапыГрафикаОплаты - ТаблицаЗначений - таблица этапов оплаты.
// 		ПараметрыЗаполнения - см. ПараметрыЗаполненияЭтаповОплаты
//
Процедура ЗаполнитьЭтапыОплатыДокументаПоШаблону(ЭтапыГрафикаОплаты, ПараметрыЗаполнения) Экспорт
```

Пример вызова
```bsl
ЭтапыОплатыСервер.ЗаполнитьЭтапыОплатыДокументаПоШаблону(ЭтапыГрафикаОплаты, ПараметрыЗаполнения) 
```
</details>

## ПараметрыПроверкиКорректностиЗаполненияЭтапов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Параметры проверки корректности заполнения этапов.
//
// Возвращаемое значение:
//  Структура - Параметры проверки корректности заполнения этапов:
// * ДатаОтгрузки                     - Дата, ТаблицаЗначений - Единая дата отгрузки или таблица с колонками "ДатаОтгрузки", "СуммаПлатежа" и "СуммаЗалогаЗаТару".
// * Дата                             - Дата - Дата документа.
// * Валюта                           - СправочникСсылка.Валюты - Валюта оплаты.
// * ЭтоЗаказ                         - Булево - Это заказ.
// * НакладнаяИсточникГрафика         - Булево - Это накладная на основании заказа.
// * НадписьЭтапыОплаты               - Строка - Путь к реквизиту формы "НадписьЭтапыОплаты", если есть.
// * СуммаОплатыПоДокументу           - Число - сумма документа, в котором необходимо осуществить проверку
// * СуммаЗалогаПоДокументу           - Число - сумма залога по документу, в котором необходимо осуществить проверку
// * ИмяКолонкиДатаОтгрузки           - Строка - Имя колонки, содержащей даты отгрузки в ТЧ, если параметр ДатаОтгрузки содержит ТЧ.
//
Функция ПараметрыПроверкиКорректностиЗаполненияЭтапов() Экспорт
```

Пример вызова
```bsl
Результат = ЭтапыОплатыСервер.ПараметрыПроверкиКорректностиЗаполненияЭтапов() 
```
</details>

## ПроверитьКорректностьЭтаповГрафикаОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Проверяет корректность заполнения этапов графика оплаты в документе
//
// Параметры:
// ЭтапыГрафикаОплаты               - ТаблицаЗначений - Таблица этапов оплаты для проверки.
// Отказ                            - Булево - Флаг отказа от записи документа
// СтруктураПараметров              - см. ПараметрыПроверкиКорректностиЗаполненияЭтапов
// УпрощенныйРежимДиалога           - Булево - флаг, указывающий на использование простого диалога ввода этапов оплаты.
// ПривязыватьСообщенияКГиперссылке - Булево - флаг, говорящий о том что проверка происходит на форме и сообщения надо привязывать к надписи графика этапов оплаты.
//
Процедура ПроверитьКорректностьЭтаповГрафикаОплаты(Знач ЭтапыГрафикаОплаты, Экспорт
```

Пример вызова
```bsl
ЭтапыОплатыСервер.ПроверитьКорректностьЭтаповГрафикаОплаты(ЭтапыГрафикаОплаты, );
```
</details>

## ПолучитьПоследнююДатуПоГрафику
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает дату последнего этапа по графику.
//
// Параметры:
// 	ДатаОтгрузки                   - Дата - дата отгрузки.
// 	Соглашение                     - СправочникСсылка.СоглашенияСПоставщиками, СправочникСсылка.СоглашенияСКлиентами - Соглашение.
// 	ГрафикОплаты                   - СправочникСсылка.ГрафикиОплаты - График оплаты, если есть.
// 	ДатаЗаказа                     - Дата - дата заказа.
// 	ДатаСогласования               - Дата - дата согласования заказа.
// 	ДатаПереходаПраваСобственности - Дата - дата перехода права собственности
//
// Возвращаемое значение:
// 	Дата - Последняя дата по графику с учетом календаря.
//
Функция ПолучитьПоследнююДатуПоГрафику(ДатаОтгрузки, Экспорт
```

Пример вызова
```bsl
Результат = ЭтапыОплатыСервер.ПолучитьПоследнююДатуПоГрафику(ДатаОтгрузки, );
```
</details>

## ПараметрыВыбораРеквизитовОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает структуру с параметрами выбора реквизитов оплаты для передачи во внешние формы.
//
// Параметры:
// 		ОбъектМетаданных - ОбъектМетаданных - объект метаданных, по которому нужно определить параметры.
//
// Возвращаемое значение:
// 		Структура:
// 			* Ключ - Строка - Имя реквизита оплаты.
// 			* Значение - ФиксированныйМассив из Структура - Параметры выбора, где:
// 				** ФормаОплаты - ФиксированныйМассив из ПараметрВыбора.
// 				** Касса - ФиксированныйМассив из ПараметрВыбора.
// 				** БанковскийСчет - ФиксированныйМассив из ПараметрВыбора.
// 				** ГрафикОплаты - ФиксированныйМассив из ПараметрВыбора.
//
Функция ПараметрыВыбораРеквизитовОплаты(ОбъектМетаданных) Экспорт
```

Пример вызова
```bsl
Результат = ЭтапыОплатыСервер.ПараметрыВыбораРеквизитовОплаты(ОбъектМетаданных) 
```
</details>

## ДатаПервогоНеоплаченногоЭтапаГрафика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

//Возращает минимальную дату неоплаченного этапа графика исполнения договора.
//
// Параметры:
//
// 		ГрафикИсполненияДоговора - ДокументСсылка.ГрафикИсполненияДоговора - график договора.
// 		Дата - Дата - дата документа.
// 		ТипРасчетов - ПеречислениеСсылка.ТипыРасчетовСПартнерами - определяет в каком регистре искать дату неоплаченного этапа.
//
// Возвращаемое значение:
// 		Дата - Минимальная дата неоплаченного этапа графика, если все оплачены - пустая дата.
Функция ДатаПервогоНеоплаченногоЭтапаГрафика(ГрафикИсполненияДоговора, Дата, ТипРасчетов) Экспорт
```

Пример вызова
```bsl
Результат = ЭтапыОплатыСервер.ДатаПервогоНеоплаченногоЭтапаГрафика(ГрафикИсполненияДоговора, Дата, ТипРасчетов) 
```
</details>

## ПроверитьЗаполнениеКорректностьДатыПлатежа
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура проверяет заполнение и корректность даты платежа в документе.
//
// Параметры:
//		ДатаПлатежа - Дата - дата платежа проверяемого документа
//		ДатаДокумента - Дата - дата проверяемого документа
//		Отказ - Булево - Признак отказа от продолжения работы.
//
Процедура ПроверитьЗаполнениеКорректностьДатыПлатежа(ДатаПлатежа, ДатаДокумента, Отказ) Экспорт
```

Пример вызова
```bsl
ЭтапыОплатыСервер.ПроверитьЗаполнениеКорректностьДатыПлатежа(ДатаПлатежа, ДатаДокумента, Отказ) 
```
</details>

## ЗаполнитьПроцентыПоСуммам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет проценты по уже рассчитанным суммам в таблице этапов графиков оплаты.
//
// Параметры:
// 	ЭтапыГрафикаОплаты - ТаблицаЗначений,ДанныеФормыКоллекция - этапы, в которых надо заполнить проценты.
//
Процедура ЗаполнитьПроцентыПоСуммам(ЭтапыГрафикаОплаты) Экспорт
```

Пример вызова
```bsl
ЭтапыОплатыСервер.ЗаполнитьПроцентыПоСуммам(ЭтапыГрафикаОплаты) 
```
</details>

## РаспределитьСуммуОтклоненияПоЭтапамГрафикаОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура распределяет сумму отклонения мерных товаров по этапам графика оплаты.
Процедура РаспределитьСуммуОтклоненияПоЭтапамГрафикаОплаты(ЭтапыГрафикаОплаты, Знач СуммаОтклоненияКРаспределению) Экспорт
```

Пример вызова
```bsl
ЭтапыОплатыСервер.РаспределитьСуммуОтклоненияПоЭтапамГрафикаОплаты(ЭтапыГрафикаОплаты, СуммаОтклоненияКРаспределению) 
```
</details>

## ПересчитатьДатыПлатежаЭтаповОплаты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Двигает даты платежа этапов оплаты  в соответствии с изменениями исходных дат
//
// Параметры:
//  Объект - ДокументОбъект, СправочникОбъект, ФормаКлиентскогоПриложения - Обрабатываемый объект
//  СтруктураПараметров - см. ВзаиморасчетыСервер.ПараметрыМеханизма - параметры механизма
//  МассивИспользуемыхРеквизитов- Массив из Строка - имена реквизитов
//
// Возвращаемое значение:
//  Булево - Истина, если есть изменения в Этапах оплаты
Функция ПересчитатьДатыПлатежаЭтаповОплаты(Объект, СтруктураПараметров, МассивИспользуемыхРеквизитов) Экспорт
```

Пример вызова
```bsl
Результат = ЭтапыОплатыСервер.ПересчитатьДатыПлатежаЭтаповОплаты(Объект, СтруктураПараметров, МассивИспользуемыхРеквизитов) 
```
</details>

## ПослеЗаполненияОбеспечения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура по возможности пересчитает этапы оплаты заказа клиента после заполнения обеспечения.
//
// Параметры:
//  Объект - ДокументОбъект.ЗаказКлиента, ДокументОбъект.ЗаказДавальца2_5 - Заказ, в котором изменились даты отгрузки
Процедура ПослеЗаполненияОбеспечения(Объект) Экспорт
```

Пример вызова
```bsl
ЭтапыОплатыСервер.ПослеЗаполненияОбеспечения(Объект) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
