---
title: Обмен с контрагентами переопределяемый
slug: erp-uh/обмен-с-контрагентами-переопределяемый
---


## ПриОпределенииИспользуемыхТиповЭлектронныхДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при определении типов электронных документов, которые можно формировать или отражать в учете в конфигурации.
// Для добавления типа электронного документа в коллекцию необходимо использовать процедуру см. ОбменСКонтрагентами.ДобавитьИспользуемыйТипДокумента.
//
// Параметры:
//  ИспользуемыеТипы - Соответствие - типы актуальных электронных документов.
//
Процедура ПриОпределенииИспользуемыхТиповЭлектронныхДокументов(ИспользуемыеТипы) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОпределенииИспользуемыхТиповЭлектронныхДокументов(ИспользуемыеТипы) 
```
</details>

## ПодготовитьСтруктуруОбъектовКомандЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для распределения объектов, к которым подключаются команды ЭДО, по группам.
//
// Параметры:
//  СоставКомандЭДО - Структура - структура состава команд ЭДО. Для каждого из ключей указывается массив полных имен
//                    объектов метаданных, к которым подключаются команды ЭДО:
//    * Исходящие    - Массив Из Строка - объекты для команд работы с исходящими документами.
//    * Входящие     - Массив Из Строка - объекты для команд работы со входящими документами.
//    * БезПодписи   - Массив Из Строка - объекты для команд выполнения ЭДО без подписи.
//    * Внутренние   - Массив Из Строка - объекты для команд внутреннего ЭДО.
//    * Интеркампани - Массив Из Строка - объекты для команд обмена между организациями в рамках одной базы.
//    * Контрагенты  - Массив Из Строка - объекты для команд работы с контрагентами.
//    * Организации  - Массив Из Строка - объекты для команд работы с организациями.
//    * Договоры     - Массив Из Строка - объекты для команд работы с договорами.
//
// Пример:
//  СоставКомандЭДО.Исходящие.Добавить("Документ.РеализацияТоваровУслуг");
//	СоставКомандЭДО.Исходящие.Добавить("Документ.СчетФактураВыданный");
//
//	СоставКомандЭДО.Входящие.Добавить("Документ.ПоступлениеТоваровУслуг");
//	СоставКомандЭДО.Входящие.Добавить("Документ.СчетФактураПолученный");
//
//	СоставКомандЭДО.БезПодписи.Добавить("Документ.ЗаказПокупателя");
//	СоставКомандЭДО.БезПодписи.Добавить("Документ.ЗаказПоставщику");
//
//	СоставКомандЭДО.Интеркампани.Добавить(Документ.ПередачаТоваровМеждуОрганизациями);
//
//	СоставКомандЭДО.Контрагенты.Добавить("Справочник.Контрагенты");
//	СоставКомандЭДО.Организации.Добавить("Справочник.Организации");
//	СоставКомандЭДО.Договоры.Добавить("Справочник.ДоговорыКонтрагентов");
//
Процедура ПодготовитьСтруктуруОбъектовКомандЭДО(СоставКомандЭДО) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПодготовитьСтруктуруОбъектовКомандЭДО(СоставКомандЭДО) 
```
</details>

## ДополнительнаяАналитикаКонтрагентовСправочникПартнеры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура возвращает признак использования справочника Партнеров в качестве
// дополнительной аналитики к справочнику Контрагенты.
//
// Параметры:
//  ИспользуетсяСправочникПартнеры - Булево - флаг использования в библиотеке справочника Партнеры.
//
Процедура ДополнительнаяАналитикаКонтрагентовСправочникПартнеры(ИспользуетсяСправочникПартнеры) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ДополнительнаяАналитикаКонтрагентовСправочникПартнеры(ИспользуетсяСправочникПартнеры) 
```
</details>

## ИспользоватьОбменЭДМеждуОрганизациями
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет разрешение использовать механизм прямого обмена между организациями.
//
// Параметры:
//  Отказ - Булево - Истина, если использование обмена между организациями запрещено;
//    Ложь - в противном случае;
//    Значение по умолчанию - Ложь;
//
// Пример:
//	Если <Выражение> Тогда
//		Отказ = Истина;
//	КонецЕсли;
//
Процедура ИспользоватьОбменЭДМеждуОрганизациями(Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ИспользоватьОбменЭДМеждуОрганизациями(Отказ) 
```
</details>

## ИспользоватьПрямойОбмен
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет возможность использования прямого обмена в конфигурации.
//
// Параметры:
//  Использовать - Булево - признак использования прямого обмена в конфигурации.
//                          Значение по умолчанию - Ложь.
//
Процедура ИспользоватьПрямойОбмен(Использовать) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ИспользоватьПрямойОбмен(Использовать) 
```
</details>

## РазрешеноИспользоватьВнутреннийЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет состояние использования конфигурацией внутренних электронных документов.
//
// Параметры:
//  Использовать - Булево - признак использования внутреннего ЭДО в конфигурации.
//                          Значение по умолчанию - Истина.
//
Процедура РазрешеноИспользоватьВнутреннийЭДО(Использовать) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.РазрешеноИспользоватьВнутреннийЭДО(Использовать) 
```
</details>

## ВключатьФункциональнуюОпциюИспользоватьВнутренниеДокументыЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, включать ли функциональную опцию "Использовать внутренние документы" при обновлении.
//
// Параметры:
//   Включать - Булево - если Истина, функциональная опция будет включена.
//
// Пример:
//  Включать = Истина;
//
Процедура ВключатьФункциональнуюОпциюИспользоватьВнутренниеДокументыЭДО(Включать) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ВключатьФункциональнуюОпциюИспользоватьВнутренниеДокументыЭДО(Включать) 
```
</details>

## ПриОпределенииОбъектовМетаданныхСПоддержкойДиагностикиОшибок
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет список объектов метаданных конфигурации (являющихся основаниями электронных документов),
// в модулях форм которых в обработчике события
// ПослеЗаписи размещен вызов процедуры ОбменСКонтрагентамиКлиент.ПослеЗаписи_ФормаДокумента или
// ОбменСКонтрагентамиКлиент.ПослеЗаписи_ФормаСправочника, показывающей список накопленных в процессе записи ошибок в
// форме, которая предоставляет инструменты их исправления.
// Если в модуле формы объекта метаданных в обработчике события ПослеЗаписи не размещен вызов процедуры
// ОбменСКонтрагентамиКлиент.ПослеЗаписи_ФормаДокумента или ОбменСКонтрагентамиКлиент.ПослеЗаписи_ФормаСправочника,
// ошибки будут выведены пользователю стандартным способом.
//
// Параметры:
//   СписокЭлементов - Массив Из ОбъектМетаданных - объекты метаданных, в модуле форм которых в обработчике
//      события ПослеЗаписи размещен вызов см. ОбменСКонтрагентамиКлиент.ПослеЗаписи_ФормаДокумента
//                                     или см. ОбменСКонтрагентамиКлиент.ПослеЗаписи_ФормаСправочника.
//
// Пример:
//  СписокЭлементов.Добавить(Метаданные.Документы.ЗаказПокупателя);
//  СписокЭлементов.Добавить(Метаданные.Справочники.ДоговорыКонтрагентов);
//
Процедура ПриОпределенииОбъектовМетаданныхСПоддержкойДиагностикиОшибок(СписокЭлементов) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОпределенииОбъектовМетаданныхСПоддержкойДиагностикиОшибок(СписокЭлементов) 
```
</details>

## ПриОпределенииПечатныхФормЗапрещенныхДляФормированияДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет список идентификаторов печатных форм документов,
// исключаемых из списка доступных для формирования документов из печатных форм.
//
// Параметры:
//   СписокИдентификаторов - Массив Из Строка - идентификаторы печатных форм.
//
Процедура ПриОпределенииПечатныхФормЗапрещенныхДляФормированияДокумента(СписокИдентификаторов) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОпределенииПечатныхФормЗапрещенныхДляФормированияДокумента(СписокИдентификаторов) 
```
</details>

## ПриПроверкеИспользованияУведомлений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, включать ли прием информационной базой уведомлений от сервиса ЭДО.
// В случае, если использование включено, необходимо обеспечить доступность HTTP-сервиса /hs/events/newdocs.
// В частности, при публикации прикладного решения в модели сервиса необходимо опубликовать HTTP-сервис "ЭДО" с basic-авторизацией.
// Логин и пароль пользователя указаны в методе ОбменСКонтрагентами.СоздатьСлужебногоПользователяОповещенийЭДО.
//
// Параметры:
//  Используется - Булево - признак использования уведомлений в прикладном решении
//
Процедура ПриПроверкеИспользованияУведомлений(Используется) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриПроверкеИспользованияУведомлений(Используется) 
```
</details>

## ИспользованиеНастройкиФормированияУниверсальныхДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет необходимость вывода в интерфейсах настроек отправки электронных документов опций формирования первичных /
// корректировочных документов и счетов-фактур в составе единого документа (т.е. использования УПД / УКД).
//
// Параметры:
// 	Использовать - Булево - Выходной параметр. Необходимо присвоить Истина, в случае, если прикладное решение
// 	                        самостоятельно определяет для каждого экземпляра учетного документа необходимость формирования
// 	                        универсальных документов (УПД / УКД) - см. ЗаполнитьПараметрыЭДПоИсточнику, либо не использует их.
//
Процедура ИспользованиеНастройкиФормированияУниверсальныхДокументов(Использовать = Истина) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ИспользованиеНастройкиФормированияУниверсальныхДокументов(Использовать);
```
</details>

## ПолучитьСоответствиеПеречислений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает значение перечисления по имени объектов метаданных.
//
// Параметры:
//  СоответствиеПеречислений - Соответствие Из КлючИЗначение:
//   * Ключ - Строка - имя библиотечного перечисления
//   * Значение - Строка - имя прикладного перечисления
//    - Рекомендуется определить соответствие для следующих перечислений подсистемы:
//                                ЮрФизЛицо
//                                ВариантыОплатыКлиентом
//                                ВариантыОплатыПоставщику
//
Процедура ПолучитьСоответствиеПеречислений(СоответствиеПеречислений) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПолучитьСоответствиеПеречислений(СоответствиеПеречислений) 
```
</details>

## ПолучитьЗначениеПеречисления
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает значение перечисления по имени перечисления и представлению в библиотеке.
//
// Параметры:
//  ИмяПеречисления - Строка - имя прикладного перечисления, заданное в см. ПолучитьСоответствиеПеречислений.
//  ПредставлениеПеречисления - Строка - идентификатор значения перечисления в библиотеке. Возможные значения по видам перечислений:
//     ЮрФизЛицо - "ЮрЛицо", "ФизЛицо"
//     ВариантыОплатыКлиентом - "Аванс (до обеспечения)", "Предоплата (до отгрузки)", "Кредит (после отгрузки)", ""
//     ВариантыОплатыПоставщику - "Аванс (до подтверждения)", "Предоплата (до поступления)", "Кредит (после поступления)"
//  НайденноеЗначение - ПеречислениеСсылка - в параметр необходимо поместить найденное значение прикладного перечисления.
//                                           Выходной параметр.
//
Процедура ПолучитьЗначениеПеречисления(ИмяПеречисления, ПредставлениеПеречисления, НайденноеЗначение) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПолучитьЗначениеПеречисления(ИмяПеречисления, ПредставлениеПеречисления, НайденноеЗначение) 
```
</details>

## ЗаполнитьСоответствиеСтавокНДС
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре указывается соответствие строковых представлений ставок НДС (используемых в подсистеме)
// с прикладными значениями этих ставок.
//
// Параметры:
//   Соответствие - Соответствие Из КлючИЗначение:
//    * Ключ - Строка - строковое представление ставки НДС
//    * Значение - ПеречислениеСсылка.СтавкиНДС, Строка - прикладное значение ставки НДС
//     - заполняемое соответствие ставок НДС. Возможные значения ставок в подсистеме:
//                                    "0"
//                                    "10"
//                                    "18"
//                                    "10/110"
//                                    "18/118"
//                                    "20"
//                                    "20/120"
//                                    "без НДС"
//                                    "НДС исчисляется налоговым агентом"
//
// Пример:
//   Соответствие.Вставить("0",                                  Перечисления.СтавкиНДС.НДС0);
//   Соответствие.Вставить("10",                                 Перечисления.СтавкиНДС.НДС10);
//   Соответствие.Вставить("18",                                 Перечисления.СтавкиНДС.НДС18);
//   Соответствие.Вставить("10/110",                             Перечисления.СтавкиНДС.НДС10_110);
//   Соответствие.Вставить("18/118",                             Перечисления.СтавкиНДС.НДС18_118);
//   Соответствие.Вставить("20",                                 Перечисления.СтавкиНДС.НДС20);
//   Соответствие.Вставить("20/120",                             Перечисления.СтавкиНДС.НДС20_120);
//   Соответствие.Вставить("без НДС",                            Перечисления.СтавкиНДС.БезНДС);
//   Соответствие.Вставить("НДС исчисляется налоговым агентом", "НДС исчисляется налоговым агентом"");
//
Процедура ЗаполнитьСоответствиеСтавокНДС(Соответствие) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьСоответствиеСтавокНДС(Соответствие) 
```
</details>

## ЗаполнитьСоответствиеВидовДоговоровКонтрагентов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре указывается соответствие строковых представлений видов договоров контрагентов (используемых в подсистеме)
// с прикладными значениями этих значений.
//
// Параметры:
//   Соответствие - Соответствие Из КлючИЗначение:
//   * Ключ - Строка - имя вида договора;
//   * Значение - ПеречислениеСсылка.ВидыДоговоровКонтрагентов - значение переменной.
//
// Пример:
//	Соответствие.Вставить("С поставщиком", Перечисления.ВидыДоговоровКонтрагентов.СПоставщиком);
//	Соответствие.Вставить("С покупателем", Перечисления.ВидыДоговоровКонтрагентов.СПокупателем);
//	Соответствие.Вставить("С комитентом (принципалом) на продажу", Перечисления.ВидыДоговоровКонтрагентов.СКомитентом);
//	Соответствие.Вставить("С комиссионером (агентом) на продажу",
//		Перечисления.ВидыДоговоровКонтрагентов.СКомиссионером);
//	Соответствие.Вставить("С комитентом (принципалом) на закупку",
//		Перечисления.ВидыДоговоровКонтрагентов.СКомитентомНаЗакупку);
//	Соответствие.Вставить("С комиссионером (агентом) на закупку",
//		Перечисления.ВидыДоговоровКонтрагентов.СКомиссионеромНаЗакупку);
//	Соответствие.Вставить("Прочее", Перечисления.ВидыДоговоровКонтрагентов.Прочее);
//
Процедура ЗаполнитьСоответствиеВидовДоговоровКонтрагентов(Соответствие) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьСоответствиеВидовДоговоровКонтрагентов(Соответствие) 
```
</details>

## ЗаполнитьСоответствиеВидовДоговоровПротивоположноеЗначениюКонтрагентов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// В процедуре указывается соответствие строковых представлений видов договоров контрагентов (используемых в подсистеме)
// с прикладными значениями этих значений с противоположным смыслом. Так если контрагент имеет договор с видом:
// "С поставщиком", то противоположное значение будет: "С покупателем".
//
// Параметры:
//   Соответствие - Соответствие Из КлючИЗначение:
//   * Ключ - Строка - имя вида договора;
//   * Значение - ПеречислениеСсылка.ВидыДоговоровКонтрагентов - значение переменной.
//
// Пример:
//	Соответствие.Вставить("С покупателем", Перечисления.ВидыДоговоровКонтрагентов.СПоставщиком);
//	Соответствие.Вставить("С поставщиком", Перечисления.ВидыДоговоровКонтрагентов.СПокупателем);
//	Соответствие.Вставить("С комиссионером (агентом) на продажу", Перечисления.ВидыДоговоровКонтрагентов.СКомитентом);
//	Соответствие.Вставить("С комитентом (принципалом) на продажу",
//		Перечисления.ВидыДоговоровКонтрагентов.СКомиссионером);
//	Соответствие.Вставить("С комиссионером (агентом) на закупку",
//		Перечисления.ВидыДоговоровКонтрагентов.СКомитентомНаЗакупку);
//	Соответствие.Вставить("С комитентом (принципалом) на закупку",
//		Перечисления.ВидыДоговоровКонтрагентов.СКомиссионеромНаЗакупку);
//	Соответствие.Вставить("Прочее", Перечисления.ВидыДоговоровКонтрагентов.Прочее);
//
Процедура ЗаполнитьСоответствиеВидовДоговоровПротивоположноеЗначениюКонтрагентов(Соответствие) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьСоответствиеВидовДоговоровПротивоположноеЗначениюКонтрагентов(Соответствие) 
```
</details>

## СоответствиеИсходящихТиповЭлектронныхДокументовДокументамИБ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет соответствие исходящих типов электронных документов и представлений документов информационной базы,
// на основании которых они формируются.
//
// Параметры:
//  СоответствиеТиповЭлектронныхДокументовДокументамИБ - Соответствие - перечень типов электронных документов.
//    - Соответствие - с свойствами:
//    * Ключ             - см. ОбменСКонтрагентами.ТипыДокументов - тип электронного документа.
//    * Значение         - Строка - представление документа информационной базы (хозяйственной операции).
//
Процедура СоответствиеИсходящихТиповЭлектронныхДокументовДокументамИБ(СоответствиеТиповЭлектронныхДокументовДокументамИБ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.СоответствиеИсходящихТиповЭлектронныхДокументовДокументамИБ(СоответствиеТиповЭлектронныхДокументовДокументамИБ) 
```
</details>

## СписокТиповДокументовПоТипуЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Задает соответствие типов и представлений объектов учета по типу электронного документа.
//
// Параметры:
//  ТипДокумента          - см. ОбменСКонтрагентами.ТипыДокументов   - тип электронного документа.
//  ОписанияОбъектовУчета - СписокЗначений - список ссылок на объекты учета. В качестве ключа задается пустая ссылка
//                          объекта, в качестве представления представление объекта учета, которое может быть показано пользователю.
//
Процедура СписокТиповДокументовПоТипуЭлектронногоДокумента(ТипДокумента, ОписанияОбъектовУчета) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.СписокТиповДокументовПоТипуЭлектронногоДокумента(ТипДокумента, ОписанияОбъектовУчета) 
```
</details>

## СвязанныеКонтрагенты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет получение соответствия ссылки на контрагента по связанному объекту.
// Используется для получения контрагента в случае если его функцию может выполнять другой объект конфигурации.
// Например при использовании опции прикладного решения ИспользоватьПартнеровКакКонтрагентов
//
// Параметры:
//  СсылкиНаОбъекты - Массив Из ЛюбаяСсылка - ссылки на объекты.
//  СоответствиеКонтрагентов - Соответствие из КлючИЗначение:
//   * Ключ - ЛюбаяСсылка - ссылка на объект.
//   * Значение - ОпределяемыйТип.КонтрагентБЭД - ссылка на контрагента.
//
Процедура СвязанныеКонтрагенты(СсылкиНаОбъекты, СоответствиеКонтрагентов) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.СвязанныеКонтрагенты(СсылкиНаОбъекты, СоответствиеКонтрагентов) 
```
</details>

## ЗаполнитьПараметрыЭДПоИсточнику
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для получения параметров ЭДО по ссылке на объект учета.
// По одному источнику может быть несколько параметров, для каждого нужно добавить строку в таблицу значений.
//
// Параметры:
//  Источник                       - Объект, ЛюбаяСсылка - документ или справочник источника.
//  ПараметрыЭлектронногоДокумента - ТаблицаЗначений - параметры источника, необходимые для определения настроек обмена электронными документами:
//    * Тип                - Произвольный - значение элемента структуры возвращаемой
//                           см. ОбменСКонтрагентами.ТипыДокументов. Используются все ключи, кроме УПД, УКД. Обязательный.
//                           Необходимость формирования УПД, УКД определяется на основании нескольких критериев
//                           (указанный тип, вариант формирования универсальных документов, настройки отправки
//                           электронных документов).
//    * ФормированиеУниверсальногоДокумента - Произвольный - значение элемента структуры, возвращаемой
//                           см. ОбменСКонтрагентами.ВариантыФормированияУниверсальныхДокументов. Обязательный при указании типов:
//                            - ТоварнаяНакладная
//                            - АктВыполненныхРабот
//                            - АктНаПередачуПрав
//                            - СоглашениеОбИзмененииСтоимости
//                            - СчетФактура
//                            - КорректировочныйСчетФактура
//    * Направление        - Произвольный - значение элемента структуры возвращаемой
//                           см. ОбменСКонтрагентами.НаправленияДокументов(). Обязательный.
//    * Организация        - ОпределяемыйТип.Организация - организация документа.
//    * Контрагент         - ОпределяемыйТип.КонтрагентБЭД - контрагент документа.
//    * ДоговорКонтрагента - ОпределяемыйТип.ДоговорСКонтрагентомЭДО - договор контрагента.
//
Процедура ЗаполнитьПараметрыЭДПоИсточнику(Источник, ПараметрыЭлектронногоДокумента) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьПараметрыЭДПоИсточнику(Источник, ПараметрыЭлектронногоДокумента) 
```
</details>

## ПриОпределенииВариантовЗаполненияПолейЭлектронныхДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняется при выводе формы настроек регламента ЭДО. Используется для получения возможных вариантов
// заполнения некоторых полей формализованных форматов.
//
// Параметры:
//  ВариантыЗаполненияПолей	 - Структура - описание полей и вариантов их заполнения. В качестве ключа задается идентификатор поля,
//     а в качестве значения - список значений возможных вариантов заполнения.
//     Возможные идентификаторы:
//       * УПД_ТоварКод - на входе содержит список значений: {"Код", "Внутренний код"}; {"Штрихкод", "Штрихкод"}
//       * ПередачаТоваров_ТоварКод - на входе содержит список значений: {"Код", "Внутренний код"}; {"Штрихкод", "Штрихкод"}
//
Процедура ПриОпределенииВариантовЗаполненияПолейЭлектронныхДокументов(ВариантыЗаполненияПолей) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОпределенииВариантовЗаполненияПолейЭлектронныхДокументов(ВариантыЗаполненияПолей) 
```
</details>

## ПолучитьЗапросКонструктораДополнительныхПолейШапки
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает запросы, описывающие документы-источники данных для формирования электронного документа указанного типа.
// Запросы используются для указания пользователем формулы заполнения значений доп. полей по данным источника.
// Запрос должен включать в себя отбор по параметру Ссылка.
//
// Параметры:
//  Параметры - Структура - параметры электронного документа, для которого производится настройка.
//     * ТипДокумента - см. ОбменСКонтрагентами.ТипыДокументов - тип электронного документа. Могут передаваться
//                                  следующие типы документов:
//                                  АктВыполненныхРабот, ТоварнаяНакладная, СчетФактура, КорректировочныйСчетФактура,
//                                  СоглашениеОбИзмененииСтоимости, АктНаПередачуПрав, УПД, УКД.
//  ТекстЗапроса - Строка - текст запроса, который должен быть использован в конструкторе доп. полей шапки.
//
Процедура ПолучитьЗапросКонструктораДополнительныхПолейШапки(Параметры, ТекстЗапроса) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПолучитьЗапросКонструктораДополнительныхПолейШапки(Параметры, ТекстЗапроса) 
```
</details>

## ЗаполнитьДанныеУКД2020_ИнформацияПродавца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа УКД (информация продавца) по приказу ФНС № ММВ-7-15/???@.
//
// Параметры:
//  Основание - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  Настройки - ФиксированнаяСтруктура - настройки заполнения данных:
//   * ТипДокумента - Произвольный - тип документа, который нужно сформировать. Возможные значения представлены следующими
//                                   свойствами результата функции см. ОбменСКонтрагентами.ТипыДокументов:
//                                    - СоглашениеОбИзмененииСтоимости,
//                                    - КорректировочныйСчетФактура,
//                                    - УКД,
//                                    - КорректировкаСведенийОРеализацииКомиссионером,
//                                    - КорректировкаСведенийОЗакупкеКомиссионером.
//   * Отправитель - ОпределяемыйТип.Организация - отправитель электронного документа.
//   * Получатель - ОпределяемыйТип.КонтрагентБЭД - получатель электронного документа.
//   * Договор - ОпределяемыйТип.ДоговорСКонтрагентомЭДО - договор с получателем электронного документа.
//   * ВариантыЗаполненияПолей - Структура - пользовательские настройки для заполнения полей:
//    ** ТоварКод - Строка - значение из списка, заданного см. ПриОпределенииВариантовЗаполненияПолейЭлектронныхДокументов
//                           для идентификатора "УКД_ТоварКод".
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.УКД_ИнформацияПродавца_2020. Выходной параметр.
//  Описание - Структура - дополнительная информация о документе. Выходной параметр.
//   * Основания - Массив из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылки на дополнительные объекты-основания
//                 электронного документа помимо указанного в параметре "Основание".
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеУКД2020_ИнформацияПродавца(Знач Основание, Знач Настройки, Данные, Описание, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеУКД2020_ИнформацияПродавца(Основание, Настройки, Данные, Описание, Отказ) 
```
</details>

## ЗаполнитьДанныеУКД2020_ИнформацияПокупателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа УКД (информация покупателя) по приказу ФНС № ММВ-7-15/???@.
//
// Параметры:
//  Основания - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основания электронного документа.
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.УКД_ИнформацияПродавца_УКД_ИнформацияПокупателя_2020.
//                            Выходной параметр.
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеУКД2020_ИнформацияПокупателя(Знач Основания, Данные, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеУКД2020_ИнформацияПокупателя(Основания, Данные, Отказ) 
```
</details>

## НайтиСоздатьУКД_2020
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Поиск и создание учетных документов при отражении в учете документа УКД (информация продавца). Вызывается для УКД всех
// возможных функций (КСЧФ, КСЧФДИС, ДИС). Приказ по формату в стадии согласования.
//
// Параметры:
//  ДеревоДанных		 - ДеревоЗначений - данные электронного документа в виде заполненного макета
//                         см. Обработка.ОбменСКонтрагентами.Макет.УКД_ИнформацияПродавца_2020
//  СсылкиНаВладельцев	 - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылки на документы учета, если они уже
//                         прикреплены к электронному документу.
//  СпособОбработки		 - Структура - способы сохранения данных в информационной базе, выбранные пользователем.
//     * ПервичныйДокумент - Строка - способ сохранения первичного документа.
//     * СчетФактура       - Строка - способ сохранения счета-фактуры.
//  ОписаниеОшибки       - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//
Процедура НайтиСоздатьУКД_2020(ДеревоДанных, СсылкиНаВладельцев = Неопределено, СпособОбработки  = Неопределено, ОписаниеОшибки = "") Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.НайтиСоздатьУКД_2020(ДеревоДанных, СсылкиНаВладельцев, СпособОбработки, ОписаниеОшибки);
```
</details>

## ЗаполнитьДанныеУПД_5_02_ИнформацияПродавца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа УПД (информация продавца) по приказу ФНС № ЕД-7-26/970@.
//
// Параметры:
//  Основание - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  Настройки - ФиксированнаяСтруктура - настройки заполнения данных:
//   * ТипДокумента - Произвольный - тип документа, который нужно сформировать. Возможные значения представлены следующими
//                                   свойствами результата функции см. ОбменСКонтрагентами.ТипыДокументов:
//                                    - АктВыполненныхРабот,
//                                    - АктНаПередачуПрав,
//                                    - ТоварнаяНакладная,
//                                    - СчетФактура,
//                                    - УПД,
//                                    - СведенияОРеализацииКомиссионером,
//                                    - СведенияОЗакупкеКомиссионером.
//   * Отправитель - ОпределяемыйТип.Организация - отправитель электронного документа.
//   * Получатель - ОпределяемыйТип.КонтрагентБЭД - получатель электронного документа.
//   * Договор - ОпределяемыйТип.ДоговорСКонтрагентомЭДО - договор с получателем электронного документа.
//   * ВариантыЗаполненияПолей - Структура - пользовательские настройки для заполнения полей:
//    ** ТоварКод - Строка - значение из списка, заданного в ПриОпределенииВариантовЗаполненияПолейЭлектронныхДокументов
//                           для идентификатора "УПД_ТоварКод".
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.УПД_ИнформацияПродавца_2019. Выходной параметр.
//  Описание - Структура - дополнительная информация о документе. Выходной параметр.
//   * Основания - Массив из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылки на дополнительные объекты-основания
//                 электронного документа помимо указанного в параметре "Основание".
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеУПД_5_02_ИнформацияПродавца(Знач Основание, Знач Настройки, Данные, Описание, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеУПД_5_02_ИнформацияПродавца(Основание, Настройки, Данные, Описание, Отказ) 
```
</details>

## ЗаполнитьДанныеУПД_5_02_ИнформацияПокупателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа УПД (информация покупателя) по приказу ФНС № ЕД-7-26/970@.
//
// Параметры:
//  Основания - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основания электронного документа.
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.УПД_ИнформацияПокупателя_2019. Выходной параметр.
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеУПД_5_02_ИнформацияПокупателя(Знач Основания, Данные, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеУПД_5_02_ИнформацияПокупателя(Основания, Данные, Отказ) 
```
</details>

## НайтиСоздатьУниверсальныйПередаточныйДокумент_5_02
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Поиск и создание учетных документов при отражении в учете документа УПД (информация продавца). Вызывается для УПД всех
// возможных функций (СЧФ, СЧФДОП, ДОП). Формат по приказу ЕД-7-26/970@.
//
// Параметры:
//  ДеревоДанных		 - ДеревоЗначений - данные электронного документа в виде заполненного макета
//                         см. Обработка.ОбменСКонтрагентами.Макет.УПД_ИнформацияПродавца_2019
//  СсылкиНаВладельцев	 - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылки на документы учета, если они уже
//                         прикреплены к электронному документу.
//  СпособОбработки		 - Структура - способы сохранения данных в информационной базе, выбранные пользователем.
//     * ПервичныйДокумент - Строка - способ сохранения первичного документа.
//     * СчетФактура       - Строка - способ сохранения счета-фактуры.
//  ОписаниеОшибки       - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//
Процедура НайтиСоздатьУниверсальныйПередаточныйДокумент_5_02(ДеревоДанных, СсылкиНаВладельцев = Неопределено, СпособОбработки = Неопределено, ОписаниеОшибки = "") Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.НайтиСоздатьУниверсальныйПередаточныйДокумент_5_02(ДеревоДанных, СсылкиНаВладельцев, СпособОбработки, ОписаниеОшибки);
```
</details>

## ЗаполнитьДанныеУПД2019_ИнформацияПродавца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа УПД (информация продавца) по приказу ФНС № ММВ-7-15/820@.
//
// Параметры:
//  Основание - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  Настройки - ФиксированнаяСтруктура - настройки заполнения данных:
//   * ТипДокумента - Произвольный - тип документа, который нужно сформировать. Возможные значения представлены следующими
//                                   свойствами результата функции см. ОбменСКонтрагентами.ТипыДокументов:
//                                    - АктВыполненныхРабот,
//                                    - АктНаПередачуПрав,
//                                    - ТоварнаяНакладная,
//                                    - СчетФактура,
//                                    - УПД,
//                                    - СведенияОРеализацииКомиссионером,
//                                    - СведенияОЗакупкеКомиссионером.
//   * Отправитель - ОпределяемыйТип.Организация - отправитель электронного документа.
//   * Получатель - ОпределяемыйТип.КонтрагентБЭД - получатель электронного документа.
//   * Договор - ОпределяемыйТип.ДоговорСКонтрагентомЭДО - договор с получателем электронного документа.
//   * ВариантыЗаполненияПолей - Структура - пользовательские настройки для заполнения полей:
//    ** ТоварКод - Строка - значение из списка, заданного в ПриОпределенииВариантовЗаполненияПолейЭлектронныхДокументов
//                           для идентификатора "УПД_ТоварКод".
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.УПД_ИнформацияПродавца_2019. Выходной параметр.
//  Описание - Структура - дополнительная информация о документе. Выходной параметр.
//   * Основания - Массив из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылки на дополнительные объекты-основания
//                 электронного документа помимо указанного в параметре "Основание".
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеУПД2019_ИнформацияПродавца(Знач Основание, Знач Настройки, Данные, Описание, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеУПД2019_ИнформацияПродавца(Основание, Настройки, Данные, Описание, Отказ) 
```
</details>

## ЗаполнитьДанныеУПД2019_ИнформацияПокупателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа УПД (информация покупателя) по приказу ФНС № ММВ-7-15/820@.
//
// Параметры:
//  Основания - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основания электронного документа.
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.УПД_ИнформацияПокупателя_2019. Выходной параметр.
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеУПД2019_ИнформацияПокупателя(Знач Основания, Данные, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеУПД2019_ИнформацияПокупателя(Основания, Данные, Отказ) 
```
</details>

## НайтиСоздатьУниверсальныйПередаточныйДокумент_2019
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Поиск и создание учетных документов при отражении в учете документа УПД (информация продавца). Вызывается для УПД всех
// возможных функций (СЧФ, СЧФДОП, ДОП). Формат по приказу ММВ-7-15/820@.
//
// Параметры:
//  ДеревоДанных		 - ДеревоЗначений - данные электронного документа в виде заполненного макета
//                         см. Обработка.ОбменСКонтрагентами.Макет.УПД_ИнформацияПродавца_2019
//  СсылкиНаВладельцев	 - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылки на документы учета, если они уже
//                         прикреплены к электронному документу.
//  СпособОбработки		 - Структура - способы сохранения данных в информационной базе, выбранные пользователем.
//     * ПервичныйДокумент - Строка - способ сохранения первичного документа.
//     * СчетФактура       - Строка - способ сохранения счета-фактуры.
//  ОписаниеОшибки       - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//
Процедура НайтиСоздатьУниверсальныйПередаточныйДокумент_2019(ДеревоДанных, СсылкиНаВладельцев = Неопределено, СпособОбработки = Неопределено, ОписаниеОшибки = "") Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.НайтиСоздатьУниверсальныйПередаточныйДокумент_2019(ДеревоДанных, СсылкиНаВладельцев, СпособОбработки, ОписаниеОшибки);
```
</details>

## ЗаполнитьДанныеУПД_ИнформацияПокупателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl
// Подготавливает данные для электронного документа УПД (информация покупателя) по приказу ФНС № ММВ-7-15/155@.
//
// Параметры:
//  Основания - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основания электронного документа.
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.УПД_ИнформацияПокупателя_2019. Выходной параметр.
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеУПД_ИнформацияПокупателя(Знач Основания, Данные, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеУПД_ИнформацияПокупателя(Основания, Данные, Отказ) 
```
</details>

## НайтиСоздатьУниверсальныйПередаточныйДокумент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Поиск и создание учетных документов при отражении в учете документа УПД (информация продавца). Вызывается для УПД всех
// возможных функций (СЧФ, СЧФДОП, ДОП). Формат по приказу ММВ-7-15/155@.
//
// Параметры:
//  ДеревоДанных		 - ДеревоЗначений - данные электронного документа в виде заполненного макета
//                         см. Обработка.ОбменСКонтрагентами.Макет.УПД_ИнформацияПродавца_5_01
//  СсылкиНаВладельцев	 - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылки на документы учета, если они уже
//                         прикреплены к электронному документу.
//  СпособОбработки		 - Структура - способы сохранения данных в информационной базе, выбранные пользователем.
//     * ПервичныйДокумент - Строка - способ сохранения первичного документа.
//     * СчетФактура       - Строка - способ сохранения счета-фактуры.
//  ОписаниеОшибки       - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//
Процедура НайтиСоздатьУниверсальныйПередаточныйДокумент(ДеревоДанных, СсылкиНаВладельцев = Неопределено, Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.НайтиСоздатьУниверсальныйПередаточныйДокумент(ДеревоДанных, СсылкиНаВладельцев, );
```
</details>

## ЗаполнитьДанныеУКД_ИнформацияПродавца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа УКД (информация продавца) по приказу ФНС № ММВ-7-15/189@.
//
// Параметры:
//  Основание - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  Настройки - ФиксированнаяСтруктура - настройки заполнения данных:
//   * ТипДокумента - Произвольный - тип документа, который нужно сформировать. Возможные значения представлены следующими
//                                   свойствами результата функции см. ОбменСКонтрагентами.ТипыДокументов:
//                                   - СоглашениеОбИзмененииСтоимости
//                                   - УКД.
//   * ВариантыЗаполненияПолей - Структура - пользовательские настройки для заполнения полей:
//    ** ТоварКод - Строка - значение из списка, заданного в ПриОпределенииВариантовЗаполненияПолейЭлектронныхДокументов
//                           для идентификатора "УКД_ТоварКод".
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.УКД_ИнформацияПродавца. Выходной параметр.
//  Описание - Структура - дополнительная информация о документе. Выходной параметр.
//   * ТипДокумента - Произвольный - позволяет переопределить тип, который будет присвоен электронному документу.
//                                   Для получения допустимых значений следует использовать следующие свойства
//                                   результата функции ОбменСКонтрагентами.ТипыДокументов:
//                                   - СоглашениеОбИзмененииСтоимости
//                                   - УКД.
//   * Основания - Массив из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылки на дополнительные объекты-основания
//                 электронного документа помимо указанного в параметре "Основание".
//   * Контрагент - ОпределяемыйТип.КонтрагентБЭД - ссылка на контрагента учетного документа.
//   * Организация - ОпределяемыйТип.Организация - ссылка на организацию учетного документа.
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеУКД_ИнформацияПродавца(Знач Основание, Знач Настройки, Данные, Описание, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеУКД_ИнформацияПродавца(Основание, Настройки, Данные, Описание, Отказ) 
```
</details>

## ЗаполнитьДанныеУКД_ИнформацияПокупателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа УКД (информация покупателя) по приказу ФНС № ММВ-7-15/189@.
//
// Параметры:
//  Основания - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основания для электронного документа.
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.УКД_ИнформацияПокупателя. Выходной параметр.
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеУКД_ИнформацияПокупателя(Знач Основания, Данные, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеУКД_ИнформацияПокупателя(Основания, Данные, Отказ) 
```
</details>

## НайтиСоздатьУниверсальныйКорректировочныйДокумент
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Поиск и создание учетных документов при отражении в учете документа УКД (информация продавца). Вызывается для УКД всех
// возможных функций (КСЧФ, КСЧФДИС, ДИС). Формат по приказу ММВ-7-15/189@.
//
// Параметры:
//  ДеревоДанных		 - ДеревоЗначений - данные электронного документа в виде заполненного макета
//                         см. Обработка.ОбменСКонтрагентами.Макет.УКД_ИнформацияПродавца
//  СсылкиНаВладельцев	 - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылки на документы учета, если они уже
//                         прикреплены к электронному документу.
//  СпособОбработки		 - Структура - способы сохранения данных в информационной базе, выбранные пользователем.
//     * ПервичныйДокумент - Строка - способ сохранения первичного документа.
//     * СчетФактура       - Строка - способ сохранения счета-фактуры.
//  ОписаниеОшибки       - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//
Процедура НайтиСоздатьУниверсальныйКорректировочныйДокумент(ДеревоДанных, СсылкиНаВладельцев = Неопределено, Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.НайтиСоздатьУниверсальныйКорректировочныйДокумент(ДеревоДанных, СсылкиНаВладельцев, );
```
</details>

## ЗаполнитьДанныеПередачаТоваров_ИнформацияПродавца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа Передача товаров (информация продавца). Формат по приказу ММВ-7-10/551@.
//
// Параметры:
//  Основание - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  Настройки - ФиксированнаяСтруктура - настройки заполнения данных:
//   * ТипДокумента - Произвольный - ожидаемый тип документа. Доступные значения представлены следующими свойствами
//                                   результата функции см. ОбменСКонтрагентами.ТипыДокументов:
//                                   - ТоварнаяНакладная.
//   * ВариантыЗаполненияПолей - Структура - пользовательские настройки для заполнения полей:
//    ** ТоварКод - Строка - значение из списка, заданного в ПриОпределенииВариантовЗаполненияПолейЭлектронныхДокументов
//                           для идентификатора "ПередачаТоваров_ТоварКод".
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.ТОРГ12_Продавец. Выходной параметр.
//  Описание - Структура - дополнительная информация о документе. Выходной параметр.
//   * Основания - Массив из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылки на дополнительные объекты-основания
//                 электронного документа помимо указанного в параметре "Основание".
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеПередачаТоваров_ИнформацияПродавца(Знач Основание, Знач Настройки, Данные, Описание, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПередачаТоваров_ИнформацияПродавца(Основание, Настройки, Данные, Описание, Отказ) 
```
</details>

## ЗаполнитьДанныеПередачаТоваров_ИнформацияПокупателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа Передача товаров (информация покупателя). Формат по приказу ММВ-7-10/551@.
//
// Параметры:
//  Основания - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основания электронного документа.
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.ТОРГ12_Покупатель. Выходной параметр.
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеПередачаТоваров_ИнформацияПокупателя(Знач Основания, Данные, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПередачаТоваров_ИнформацияПокупателя(Основания, Данные, Отказ) 
```
</details>

## НайтиСоздатьДокументПередачаТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Поиск и создание учетного документа при отражении в учете документа Передача товаров (информация продавца).
// Формат по приказу ММВ-7-10/551@.
//
// Параметры:
//  ДеревоДанных		 - ДеревоЗначений - данные электронного документа в виде заполненного макета
//                         см. Обработка.ОбменСКонтрагентами.Макет.ТОРГ12_Продавец.
//  СсылкаНаВладельца	 - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылка на документ учета, если он уже
//                         прикреплен к электронному документу.
//  СпособОбработки		 - Строка - способ сохранения данных в информационной базе, выбранный пользователем. Передается
//                         значение элемента списка значений.
//  ОписаниеОшибки       - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//
Процедура НайтиСоздатьДокументПередачаТоваров(ДеревоДанных, СсылкаНаВладельца, СпособОбработки = "", ОписаниеОшибки = "") Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.НайтиСоздатьДокументПередачаТоваров(ДеревоДанных, СсылкаНаВладельца, СпособОбработки, ОписаниеОшибки);
```
</details>

## ЗаполнитьДанныеПередачаУслуг_ИнформацияПродавца
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа Передачи результатов работ (информация продавца) по приказу ФНС № ММВ-7-10/552@.
//
// Параметры:
//  Основание - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  Настройки - ФиксированнаяСтруктура - настройки заполнения данных:
//   * ТипДокумента - Произвольный - ожидаемый тип документа. Доступные значения представлены следующими свойствами
//                                   результата функции см. ОбменСКонтрагентами.ТипыДокументов:
//                                    - АктВыполненныхРабот.
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.Акт501_Исполнитель. Выходной параметр.
//  Описание - Структура - дополнительная информация о документе. Выходной параметр.
//   * Основания - Массив из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылки на дополнительные объекты-основания
//                 электронного документа помимо указанного в параметре "Основание".
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеПередачаУслуг_ИнформацияПродавца(Знач Основание, Знач Настройки, Данные, Описание, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПередачаУслуг_ИнформацияПродавца(Основание, Настройки, Данные, Описание, Отказ) 
```
</details>

## ЗаполнитьДанныеПередачаУслуг_ИнформацияПокупателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа Передачи услуг (информация покупателя) по приказу ФНС № ММВ-7-10/552@.
//
// Параметры:
//  Основания - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основания электронного документа.
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.Акт501_Заказчик. Выходной параметр.
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеПередачаУслуг_ИнформацияПокупателя(Знач Основания, Данные, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПередачаУслуг_ИнформацияПокупателя(Основания, Данные, Отказ) 
```
</details>

## НайтиСоздатьДокументПередачаРезультатовРабот
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Поиск и создание учетного документа при отражении в учете документа Передача результатов работ (информация продавца).
// Формат по приказу ММВ-7-10/552@.
//
// Параметры:
//  ДеревоДанных		 - ДеревоЗначений - данные электронного документа в виде заполненного макета
//                         см. Обработка.ОбменСКонтрагентами.Макет.Акт501_Исполнитель.
//  СсылкаНаВладельца	 - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылка на документ учета, если он уже
//                         прикреплен к электронному документу.
//  СпособОбработки		 - Строка - способ сохранения данных в информационной базе, выбранный пользователем.
//  ОписаниеОшибки       - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//
Процедура НайтиСоздатьДокументПередачаРезультатовРабот(ДеревоДанных, СсылкаНаВладельца, СпособОбработки = "", ОписаниеОшибки = "") Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.НайтиСоздатьДокументПередачаРезультатовРабот(ДеревоДанных, СсылкаНаВладельца, СпособОбработки, ОписаниеОшибки);
```
</details>

## ЗаполнитьДанныеАктОРасхождениях_ИнформацияПокупателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа вида "Акт о расхождениях".
//
// Параметры:
//  Основание - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  Настройки - ФиксированнаяСтруктура - настройки заполнения данных:
//   * ТипДокумента - Произвольный - ожидаемый вид документа. Доступные значения представлены следующими свойствами
//                                   результата функции см. ОбменСКонтрагентами.ТипыДокументов:
//                                    - АктОРасхождениях.
//   * ВариантыЗаполненияПолей - Структура - пользовательские настройки для заполнения полей:
//    ** ТоварКод - Строка - значение из списка, заданного в ПриОпределенииВариантовЗаполненияПолейЭлектронныхДокументов
//                           для идентификатора "АктОРасхождениях_ТоварКод".
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.АктОРасхождениях_2019. Выходной параметр.
//  Описание - Структура - дополнительная информация о документе. Выходной параметр.
//   * Основания - Массив из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылки на дополнительные объекты-основания
//                 электронного документа помимо указанного в параметре "Основание".
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеАктОРасхождениях_ИнформацияПокупателя(Знач Основание, Знач Настройки, Данные, Описание, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеАктОРасхождениях_ИнформацияПокупателя(Основание, Настройки, Данные, Описание, Отказ) 
```
</details>

## НайтиСоздатьАктОРасхождениях_ФНС_2019
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Поиск и создание учетного документа при отражении в учете документа Акт о расхождениях (информация покупателя).
// Формат по приказу ММВ-7-15/423@.
//
// Параметры:
//  ДеревоДанных		 - ДеревоЗначений - данные электронного документа в виде заполненного макета
//                         см. Обработка.ОбменСКонтрагентами.Макет.АктОРасхождениях_2019.
//  ДокументУчета	     - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылка на документ учета, если он уже
//                         прикреплен к электронному документу.
//  СпособОбработки		 - Строка - способ сохранения данных в информационной базе, выбранный пользователем.
//  ОписаниеОшибки       - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//
Процедура НайтиСоздатьАктОРасхождениях_ФНС_2019(ДеревоДанных, ДокументУчета = Неопределено, СпособОбработки = "", ОписаниеОшибки = "") Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.НайтиСоздатьАктОРасхождениях_ФНС_2019(ДеревоДанных, ДокументУчета, СпособОбработки, ОписаниеОшибки);
```
</details>

## ЗаполнитьДанныеАктОРасхождениях_ДополнительныеСведения
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для дополнительных сведений по результатам приемки электронного документа вида "Акт о расхождениях".
//
// Параметры:
//  Основание - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.АктОРасхождениях_2019. Выходной параметр.
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеАктОРасхождениях_ДополнительныеСведения(Знач Основание, Данные, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеАктОРасхождениях_ДополнительныеСведения(Основание, Данные, Отказ) 
```
</details>

## ЗаполнитьАктОРасхожденияхПоДополнительнымСведениям
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет заполнение электронных документов вида "Акт о расхождениях" данными дополнительных сведений о результатах приемки.
//
// Параметры:
//  ДанныеДокумента - см. ОбменСКонтрагентами.ДанныеЭлектронногоДокументаПоФайлу.
//  ОбъектыУчета - Массив из ОпределяемыеТипы.ОснованияЭлектронныхДокументовЭДО.
//
Процедура ЗаполнитьАктОРасхожденияхПоДополнительнымСведениям(ДанныеДокумента, ОбъектыУчета = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьАктОРасхожденияхПоДополнительнымСведениям(ДанныеДокумента, ОбъектыУчета);
```
</details>

## ЗаполнитьДанныеАктОПриемкеВыполненныхРаботВСтроительстве_ИнформацияПодрядчика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа вида "Акт о приемке строительных работ услуг".
//
// Параметры:
//  СсылкаНаОбъект - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО
//  КонструкторЭД - ОбработкаОбъект.ФорматАктПриемкиСтроительныхРаботИнформацияПодрядчикаЭДО
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеАктОПриемкеВыполненныхРаботВСтроительстве_ИнформацияПодрядчика(СсылкаНаОбъект, КонструкторЭД, Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеАктОПриемкеВыполненныхРаботВСтроительстве_ИнформацияПодрядчика(СсылкаНаОбъект, КонструкторЭД, );
```
</details>

## ЗаполнитьДанныеАктОПриемкеВыполненныхРаботВСтроительстве_ИнформацияЗаказчика
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа вида "Акт о приемке строительных работ услуг".
//
// Параметры:
//  СсылкаНаОбъект - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО
//  КонструкторЭД - ОбработкаОбъект.ФорматАктПриемкиСтроительныхРаботИнформацияЗаказчикаЭДО
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеАктОПриемкеВыполненныхРаботВСтроительстве_ИнформацияЗаказчика(СсылкаНаОбъект, КонструкторЭД, Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеАктОПриемкеВыполненныхРаботВСтроительстве_ИнформацияЗаказчика(СсылкаНаОбъект, КонструкторЭД, );
```
</details>

## НайтиСоздатьАктОПриемкеСтроительныхРаботУслуг
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Поиск и создание учетного документа при отражении входящего электронного документа.
//
// Параметры:
//  КонструкторЭД - ОбработкаОбъект.ФорматАктПриемкиСтроительныхРаботИнформацияПодрядчикаЭДО
//  ДокументУчета - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылка на документ учета, если он уже
//                  прикреплен к электронному документу.
//  СпособОбработки - Строка - способ сохранения данных в информационной базе, выбранный пользователем.
//  ОписаниеОшибки - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//
Процедура НайтиСоздатьАктОПриемкеСтроительныхРаботУслуг(КонструкторЭД, ДокументУчета = Неопределено, Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.НайтиСоздатьАктОПриемкеСтроительныхРаботУслуг(КонструкторЭД, ДокументУчета, );
```
</details>

## ПриОпределенииТаблицАктаОПриемкиСтроительныхРаботУслугКСопоставленияНоменклатуры
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определение таблицы акта о приемки строительных работ/услуг, участвующих в сопоставлении номенклатуры.
//
// Параметры:
//  ТаблицыКСопоставлению - Массив Из Строка - Список таблиц, из которых будет собираться данные
//                                             к сопоставлению с номенклатурой ИБ
//  ДоступныеТаблицы - см. ОбработкаМенеджер.ФорматАктПриемкиСтроительныхРаботИнформацияПодрядчикаЭДО.ДоступныеКСопоставлениюТаблицы
//
Процедура ПриОпределенииТаблицАктаОПриемкиСтроительныхРаботУслугКСопоставленияНоменклатуры(ТаблицыКСопоставлению, Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОпределенииТаблицАктаОПриемкиСтроительныхРаботУслугКСопоставленияНоменклатуры(ТаблицыКСопоставлению, );
```
</details>

## ЗаполнитьДанныеАктСверкиВзаиморасчетов_ИнформацияОтправителя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа вида "Акт сверки расчетов с контрагентом".
//
// Параметры:
//  Основание - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  Настройки - ФиксированнаяСтруктура - настройки заполнения данных:
//   * ТипДокумента - Произвольный - ожидаемый вид документа. Доступные значения представлены следующими свойствами
//                                   результата функции см. ОбменСКонтрагентами.ТипыДокументов:
//                                    - АктСверкиВзаиморасчетов.
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.АктСверкиВзаиморасчетов_ИнформацияОтправителя. Выходной параметр.
//  Описание - Структура - дополнительная информация о документе. Выходной параметр.
//   * Основания - Массив из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылки на дополнительные объекты-основания
//                 электронного документа помимо указанного в параметре "Основание".
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеАктСверкиВзаиморасчетов_ИнформацияОтправителя(Знач Основание, Знач Настройки, Данные, Описание, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеАктСверкиВзаиморасчетов_ИнформацияОтправителя(Основание, Настройки, Данные, Описание, Отказ) 
```
</details>

## ЗаполнитьДанныеАктСверкиВзаиморасчетов_ИнформацияПолучателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа вида "Акт сверки расчетов с контрагентом".
//
// Параметры:
//  Основание - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  Настройки - ФиксированнаяСтруктура - настройки заполнения данных:
//   * ТипДокумента - Произвольный - ожидаемый вид документа. Доступные значения представлены следующими свойствами
//                                   результата функции см. ОбменСКонтрагентами.ТипыДокументов:
//                                    - АктСверкиВзаиморасчетов.
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.АктСверкиВзаиморасчетов_ИнформацияПолучателя. Выходной параметр.
//  Описание - Структура - дополнительная информация о документе. Выходной параметр.
//   * Основания - Массив из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылки на дополнительные объекты-основания
//                 электронного документа помимо указанного в параметре "Основание".
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеАктСверкиВзаиморасчетов_ИнформацияПолучателя(Знач Основание, Знач Настройки, Данные, Описание, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеАктСверкиВзаиморасчетов_ИнформацияПолучателя(Основание, Настройки, Данные, Описание, Отказ) 
```
</details>

## НайтиСоздатьАктСверкиВзаиморасчетов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Поиск и создание учетного документа при отражении в учете документа Акт сверки взаиморасчетов (информация отправителя).
// Формат по приказу ЕД-7-26/405@.
//
// Параметры:
//  ДеревоДанных		 - ДеревоЗначений - данные электронного документа в виде заполненного макета
//                         см. Обработка.ОбменСКонтрагентами.Макет.АктСверкиВзаиморасчетов_ИнформацияОтправителя.
//  ДокументУчета	     - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылка на документ учета, если он уже
//                         прикреплен к электронному документу.
//  СпособОбработки		 - Строка - способ сохранения данных в информационной базе, выбранный пользователем.
//  ОписаниеОшибки       - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//
Процедура НайтиСоздатьАктСверкиВзаиморасчетов(ДеревоДанных, ДокументУчета = Неопределено, СпособОбработки = "", ОписаниеОшибки = "") Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.НайтиСоздатьАктСверкиВзаиморасчетов(ДеревоДанных, ДокументУчета, СпособОбработки, ОписаниеОшибки);
```
</details>

## ЗаполнитьАктСверкиВзаиморасчетовПоДаннымПолучателя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняет заполнение электронных документов вида "Акт сверки расчетов с контрагентом"
// данными, поступившими от их получателя.
//
// Параметры:
//  ДанныеДокумента - Структура - см. ФорматыЭДО.ДанныеЭлектронногоДокумента.
//  ОбъектыУчета - Массив - ОпределяемыеТипы.ОснованияЭлектронныхДокументовЭДО.
Процедура ЗаполнитьАктСверкиВзаиморасчетовПоДаннымПолучателя(ДанныеДокумента, ОбъектыУчета = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьАктСверкиВзаиморасчетовПоДаннымПолучателя(ДанныеДокумента, ОбъектыУчета);
```
</details>

## ЗаполнитьДанныеПоСчетуНаОплату101
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа вида "Счет на оплату"
//
// Параметры:
//  Основание - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  Настройки - ФиксированнаяСтруктура - настройки заполнения данных:
//   * ТипДокумента - Произвольный - ожидаемый вид документа. Доступные значения представлены следующими свойствами
//                                   результата функции см. ОбменСКонтрагентами.ТипыДокументов:
//                                    - СчетНаОплату.
//  Данные - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                            см. Обработка.ОбменСКонтрагентами.Макет.СчетНаОплату101. Выходной параметр.
//  Описание - Структура - дополнительная информация о документе. Выходной параметр.
//   * Основания - Массив из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылки на дополнительные объекты-основания
//                 электронного документа помимо указанного в параметре "Основание".
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеПоСчетуНаОплату101(Знач Основание, Знач Настройки, Данные, Описание, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПоСчетуНаОплату101(Основание, Настройки, Данные, Описание, Отказ) 
```
</details>

## НайтиСоздатьСчетНаОплату101
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Поиск и создание учетного документа при отражении в учете документа Счет на оплату.
// Тестовый формат ФНС.
//
// Параметры:
//  ДеревоДанных		 - ДеревоЗначений - данные электронного документа в виде заполненного макета
//                         см. Обработка.ОбменСКонтрагентами.Макет.СчетНаОплату_1_01.
//  ДокументУчета	     - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылка на документ учета, если он уже
//                         прикреплен к электронному документу.
//  СпособОбработки		 - Строка - способ сохранения данных в информационной базе, выбранный пользователем.
//  ОписаниеОшибки       - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//
Процедура НайтиСоздатьСчетНаОплату101(ДеревоДанных, ДокументУчета = Неопределено, СпособОбработки = "", ОписаниеОшибки = "") Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.НайтиСоздатьСчетНаОплату101(ДеревоДанных, ДокументУчета, СпособОбработки, ОписаниеОшибки);
```
</details>

## ЗаполнитьДанныеПоДоговорномуДокументу101
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа вида "Договорный документ".
//
// Параметры:
//  СсылкаНаОбъект - ЛюбаяСсылка
//  КонструкторЭД - ОбработкаОбъект.ФорматДоговорныйДокумент101
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеПоДоговорномуДокументу101(СсылкаНаОбъект, КонструкторЭД, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПоДоговорномуДокументу101(СсылкаНаОбъект, КонструкторЭД, Отказ) 
```
</details>

## НайтиСоздатьДоговорнойДокумент101
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Поиск и создание учетного документа при отражении в учете договорного документа формата PDF/A3.
// Формат по приказу
//
// Параметры:
//  КонструкторЭД - ОбработкаОбъект.ФорматДоговорныйДокумент101
//  ДокументУчета - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылка на документ учета, если он уже
//                  прикреплен к электронному документу.
//  СпособОбработки - Строка - способ сохранения данных в информационной базе, выбранный пользователем.
//  ОписаниеОшибки - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//
Процедура НайтиСоздатьДоговорнойДокумент101(КонструкторЭД, ДокументУчета = Неопределено, Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.НайтиСоздатьДоговорнойДокумент101(КонструкторЭД, ДокументУчета, );
```
</details>

## НайтиСоздатьДоговорныйДокументXML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Поиск и создание учетного документа при отражении в учете договорного документа формата XML.
// Формат по приказу ЕД-7-26/115@
//
// Параметры:
//  ДанныеФайлаЭД - ОбъектXDTO
//  ДокументУчета - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылка на документ учета, если он уже
//                  прикреплен к электронному документу.
//  СпособОбработки - Строка - способ сохранения данных в информационной базе, выбранный пользователем.
//  ОписаниеОшибки - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//
Процедура НайтиСоздатьДоговорныйДокументXML(ДанныеФайлаЭД, ДокументУчета = Неопределено, Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.НайтиСоздатьДоговорныйДокументXML(ДанныеФайлаЭД, ДокументУчета, );
```
</details>

## УстановитьПризнакИспользованияФорматаДоговорногоДокументаXML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Вызывается при определении использования формата договорных документов формата XML (ЕД-7-26/115@) в конфигурации.
// Требуется для того, чтобы при автоматическом обновлении информации о форматах, данные об использовании договорных
// документов xml сохранялись актуальными.
//
// Если происходит включение использования формата, то, дополнительно, следует воспользоваться методом
// см. ОбменСКонтрагентами.ПодключитьИспользованиеФорматаДоговорныхДокументовXML. Его нужно вызвать
// отдельно, чтобы в текущих настройках форматов было включено использование нового формата.
//
// Параметры:
//  Используется - Булево - Истина, если поддержка реализована, Ложь - если нет.
//
Процедура УстановитьПризнакИспользованияФорматаДоговорногоДокументаXML(Используется = Ложь) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.УстановитьПризнакИспользованияФорматаДоговорногоДокументаXML(Используется);
```
</details>

## ЗаполнитьДанныеРеквизитыОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа типа Реквизиты организации формата CML 2.
//
// Параметры:
//  СсылкаНаОбъект - ОпределяемыйТип.Организация - ссылка на организацию, реквизиты которой нужно сформировать.
//  Данные         - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                                    см. Обработка.ОбменСКонтрагентами.Макет.РеквизитыОрганизации. Выходной параметр.
//  Отказ          - Булево - если нужно отказаться от создания электронного документа, необходимо установить значение в Истина.
//                            После этого дальнейшие действия по формированию документа производиться не будут, поэтому
//                            нужно сформировать сообщения пользователю при необходимости самостоятельно.
//
Процедура ЗаполнитьДанныеРеквизитыОрганизации(СсылкаНаОбъект, Данные, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеРеквизитыОрганизации(СсылкаНаОбъект, Данные, Отказ) 
```
</details>

## ЗаполнитьДанныеПоКаталогуТоваровCML
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа типа КаталогТоваров формата CML 2.
//
// Параметры:
//  Организация    - ОпределяемыйТип.Организация - ссылка на организацию
//  ТоварыКаталога - Произвольный - список товаров в виде, возвращенном после выполнения метода
//                                  см. ОбменСКонтрагентамиКлиентПереопределяемый.ОткрытьФормуПодбораТоваров.
//  ДеревоДанных   - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                                    см. Обработка.ОбменСКонтрагентами.Макет.КаталогТоваров. Выходной параметр.
//  Отказ          - Булево - если нужно отказаться от создания электронного документа, необходимо установить значение в Истина.
//                   После этого дальнейшие действия по формированию документа производиться не будут, поэтому
//                   нужно сформировать сообщения пользователю при необходимости самостоятельно.
//
Процедура ЗаполнитьДанныеПоКаталогуТоваровCML(Организация, ТоварыКаталога, ДеревоДанных, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПоКаталогуТоваровCML(Организация, ТоварыКаталога, ДеревоДанных, Отказ) 
```
</details>

## ЗаполнитьДанныеПоПрайсЛисту
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа типа ПрайсЛист формата CML 2.
//
// Параметры:
//  СсылкаНаОбъект  - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  ДеревоДокумента - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                                     см. Обработка.ОбменСКонтрагентами.Макет.ПрайсЛист. Выходной параметр.
//  Отказ           - Булево - если нужно отказаться от создания электронного документа, необходимо установить значение в Истина.
//                   После этого дальнейшие действия по формированию документа производиться не будут, поэтому
//                   нужно сформировать сообщения пользователю при необходимости самостоятельно.
//
Процедура ЗаполнитьДанныеПоПрайсЛисту(СсылкаНаОбъект, ДеревоДокумента, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПоПрайсЛисту(СсылкаНаОбъект, ДеревоДокумента, Отказ) 
```
</details>

## ЗаполнитьДанныеПоСчету
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа типа Счет формата CML 2.
//
// Параметры:
//  СсылкаНаОбъект  - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  ДеревоДокумента - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                                     см. Обработка.ОбменСКонтрагентами.Макет.СчетНаОплату. Выходной параметр.
//  Отказ           - Булево - если нужно отказаться от создания электронного документа, необходимо установить значение в Истина.
//                   После этого дальнейшие действия по формированию документа производиться не будут, поэтому
//                   нужно сформировать сообщения пользователю при необходимости самостоятельно.
//
Процедура ЗаполнитьДанныеПоСчету(СсылкаНаОбъект, ДеревоДокумента, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПоСчету(СсылкаНаОбъект, ДеревоДокумента, Отказ) 
```
</details>

## ЗаполнитьДанныеПоЗаказуТоваров
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа типа ЗаказТоваров формата CML 2.
//
// Параметры:
//  СсылкаНаОбъект  - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  ДеревоДокумента - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                                     см. Обработка.ОбменСКонтрагентами.Макет.ЗаказТовара. Выходной параметр.
//  Отказ           - Булево - если нужно отказаться от создания электронного документа, необходимо установить значение в Истина.
//                   После этого дальнейшие действия по формированию документа производиться не будут, поэтому
//                   нужно сформировать сообщения пользователю при необходимости самостоятельно.
//
Процедура ЗаполнитьДанныеПоЗаказуТоваров(СсылкаНаОбъект, ДеревоДокумента, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПоЗаказуТоваров(СсылкаНаОбъект, ДеревоДокумента, Отказ) 
```
</details>

## ЗаполнитьДанныеПоОтветуНаЗаказ
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа типа ОтветНаЗаказ формата CML 2.
//
// Параметры:
//  СсылкаНаОбъект  - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  ДеревоДокумента - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                                     см. Обработка.ОбменСКонтрагентами.Макет.ОтветНаЗаказ. Выходной параметр.
//  Отказ           - Булево - если нужно отказаться от создания электронного документа, необходимо установить значение в Истина.
//                   После этого дальнейшие действия по формированию документа производиться не будут, поэтому
//                   нужно сформировать сообщения пользователю при необходимости самостоятельно.
//
Процедура ЗаполнитьДанныеПоОтветуНаЗаказ(СсылкаНаОбъект, ДеревоДокумента, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПоОтветуНаЗаказ(СсылкаНаОбъект, ДеревоДокумента, Отказ) 
```
</details>

## ЗаполнитьДанныеПоОтчетуОПродажахКомиссионногоТовара
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа типа ОтчетКомитенту формата CML 2.
//
// Параметры:
//  СсылкаНаОбъект  - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  ДеревоДокумента - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                                     см. Обработка.ОбменСКонтрагентами.Макет.ОтчетКомиссионераОПродажах. Выходной параметр.
//  Отказ           - Булево - если нужно отказаться от создания электронного документа, необходимо установить значение в Истина.
//                   После этого дальнейшие действия по формированию документа производиться не будут, поэтому
//                   нужно сформировать сообщения пользователю при необходимости самостоятельно.
//
Процедура ЗаполнитьДанныеПоОтчетуОПродажахКомиссионногоТовара(СсылкаНаОбъект, ДеревоДокумента, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПоОтчетуОПродажахКомиссионногоТовара(СсылкаНаОбъект, ДеревоДокумента, Отказ) 
```
</details>

## ЗаполнитьДанныеПоОтчетуОСписанииКомиссионногоТовара
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа типа ОтчетКомитентуОСписании формата CML 2.
//
// Параметры:
//  СсылкаНаОбъект  - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  ДеревоДокумента - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                                     см. Обработка.ОбменСКонтрагентами.Макет.ОтчетКомиссионераОСписании. Выходной параметр.
//  Отказ           - Булево - если нужно отказаться от создания электронного документа, необходимо установить значение в Истина.
//                   После этого дальнейшие действия по формированию документа производиться не будут, поэтому
//                   нужно сформировать сообщения пользователю при необходимости самостоятельно.
//
Процедура ЗаполнитьДанныеПоОтчетуОСписанииКомиссионногоТовара(СсылкаНаОбъект, ДеревоДокумента, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПоОтчетуОСписанииКомиссионногоТовара(СсылкаНаОбъект, ДеревоДокумента, Отказ) 
```
</details>

## СохранитьДанныеОбъектаВБД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Сохраняет данные из электронного документа в объект учета.
//
// Параметры:
//  СтрокаДляЗагрузки - СтрокаДереваЗначений - строка дерева, описывающая данные электронного документа. Реквизиты
//                                             документа содержатся в подчиненных строках. Сама строка обладает следующими свойствами:
//    * ВидЭД - см. ОбменСКонтрагентами.ТипыДокументов - используется для определения типа пришедшего документа.
//  ДеревоРазбора     - ДеревоЗначений - дерево с найденными ссылками на учетные сущности.
//  ПараметрыОбработки - Структура - дополнительные параметры для обработки объекта:
//    * СсылкаНаВладельца - Неопределено,ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - владелец электронного документа (передается
//    	                                                                     при перезаполнении уже существующего документа учета).
//    * Записывать        - Булево - если Истина, то объект должен быть записан. По умолчанию Истина.
//    * СпособОбработки   - Строка - способ сохранения данных в информационной базе.
//      См. ОбменСКонтрагентамиПереопределяемый.ПриОпределенииСпособовОбработкиПрикладногоТипаЭлектронногоДокумента.
//	ДополнительныеДанные - Структура - Дополнительные данные для отражения в учете. Могут передаваться другими подсистемами
//	                                   из состава библиотеки. Состав данных должен быть описан в документации соответствующей подсистемы.
//  НайденныйОбъект - Произвольный - созданный объект.
//  ОписаниеОшибки - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//
Процедура СохранитьДанныеОбъектаВБД(СтрокаДляЗагрузки, ДеревоРазбора, ПараметрыОбработки = Неопределено, Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.СохранитьДанныеОбъектаВБД(СтрокаДляЗагрузки, ДеревоРазбора, ПараметрыОбработки, );
```
</details>

## СоздатьОбъектВБД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает элементы справочников по дереву параметров.
//
// Параметры:
//  СтрокаОбъекта - СтрокаДереваЗначений - строка дерева, описывающая данные объекта электронного документа. Реквизиты
//                                         документа содержатся в подчиненных строках. Состав реквизитов зависит от типа
//                                         объекта. См. возможные варианты в описаниях деревьев документов CML в макетах обработки
//                                         см. Обработка.ОбменСКонтрагентами. Также строка содержит обязательные свойства:
//    * ОписаниеТипа - Строка - имя типа объекта
//  ДеревоРазбора     - ДеревоЗначений - дерево с найденными ссылками на учетные сущности.
//  НовыйЭлемент - СправочникСсылка - в этот параметр необходимо вернуть ссылку на созданный элемент справочника.
//
Процедура СоздатьОбъектВБД(СтрокаОбъекта, ДеревоРазбора, НовыйЭлемент) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.СоздатьОбъектВБД(СтрокаОбъекта, ДеревоРазбора, НовыйЭлемент) 
```
</details>

## ЗаполнитьТаблицуПорядкаСозданияТиповОбъектов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет таблицу порядка создания типов объектов при загрузке электронных документов формата CML.
// Позволяет переопределить порядок создания типов объектов в дереве. Это может быть необходимо, когда одни типы
// зависимы от других, например, номенклатура поставщика, как правило, зависима от номенклатуры. Используется при
// заполнении в дереве электронного документа ссылок на объекты информационной базы.
//
// Параметры:
//  Таблица	 - ТаблицаЗначений - содержит колонки:
//    * ТипОбъекта - Строка - строковый идентификатор библиотечного типа. Возможные значения: БанковскиеСчетаКонтрагентов, НоменклатураКонтрагентов.
//    * Порядок - Число - порядок создания типа в дереве (нумеруется с 1).
//
Процедура ЗаполнитьТаблицуПорядкаСозданияТиповОбъектов(Таблица) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьТаблицуПорядкаСозданияТиповОбъектов(Таблица) 
```
</details>

## ПодготовитьДанныеПоПередачеТоваровМеждуОрганизациями
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа типа ПередачаТоваровМеждуОрганизациями.
//
// Параметры:
//  СсылкаНаОбъект - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  ДеревоЭД - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                              см. Обработка.ОбменСКонтрагентами.Макет.ПередачаВозвратТоваровМеждуОрганизациями. Выходной параметр.
//  Отказ - Булево - если нужно отказаться от создания электронного документа, необходимо установить значение в Истина.
//                   После этого дальнейшие действия по формированию документа производиться не будут, поэтому
//                   нужно сформировать сообщения пользователю при необходимости самостоятельно.
//
Процедура ПодготовитьДанныеПоПередачеТоваровМеждуОрганизациями(СсылкаНаОбъект, ДеревоЭД, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПодготовитьДанныеПоПередачеТоваровМеждуОрганизациями(СсылкаНаОбъект, ДеревоЭД, Отказ) 
```
</details>

## ПодготовитьДанныеПоВозвратуТоваровМеждуОрганизациями
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа типа ВозвратТоваровМеждуОрганизациями.
//
// Параметры:
//  СсылкаНаОбъект - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание для электронного документа.
//  ДеревоЭД - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                              см. Обработка.ОбменСКонтрагентами.Макет.ПередачаВозвратТоваровМеждуОрганизациями. Выходной параметр.
//  Отказ - Булево - если нужно отказаться от создания электронного документа, необходимо установить значение в Истина.
//                   После этого дальнейшие действия по формированию документа производиться не будут, поэтому
//                   нужно сформировать сообщения пользователю при необходимости самостоятельно.
//
Процедура ПодготовитьДанныеПоВозвратуТоваровМеждуОрганизациями(СсылкаНаОбъект, ДеревоЭД, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПодготовитьДанныеПоВозвратуТоваровМеждуОрганизациями(СсылкаНаОбъект, ДеревоЭД, Отказ) 
```
</details>

## ЗаполнитьДанныеПоЗапросуКоммерческихПредложений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для формирования исходящего электронного документа по Запросу коммерческих предложений.
//
// Параметры:
//  СсылкаНаОбъект  - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание электронного документа.
//  ДеревоДанных    - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                                     см. Обработка.ОбменСКонтрагентами.Макет.ЗапросКоммерческихПредложений.
//                                     Если используется подсистема
//                                     ЭлектронноеВзаимодействие.КоммерческиеПредложения, то обработчик не вызывается
//                                     (см. КоммерческиеПредложенияПереопределяемый.ЗаполнитьДанныеПоЗапросуКоммерческихПредложений).
//                                     Выходной параметр.
//  Отказ           - Булево         - Если нужно отказаться от создания электронного документа, необходимо установить
//                                     значение в Истина. После этого дальнейшие действия по формированию документа
//                                     производиться не будут, поэтому нужно сформировать сообщения пользователю при
//                                     необходимости самостоятельно.
//
Процедура ЗаполнитьДанныеПоЗапросуКоммерческихПредложений(Знач СсылкаНаОбъект, ДеревоДанных, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПоЗапросуКоммерческихПредложений(СсылкаНаОбъект, ДеревоДанных, Отказ) 
```
</details>

## НайтиСоздатьЗапросКоммерческихПредложений
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создание нового или перезаполнение существующего прикладного документа Запрос коммерческих предложений от клиента
// по данным входящего электронного документа.
// Если существует подсистема КоммерческиеПредложенияДокументы.ЗапросКоммерческогоПредложенияОтКлиента, обработчик
// не вызывается.
//
// Параметры:
//  ДанныеВходящегоДокумента - ДеревоЗначений - данные электронного документа, см. Обработка.ОбменСКонтрагентами.Макет.ЗапросКоммерческихПредложений.
//  УчетныйДокумент          - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылка на учетный документ Запрос коммерческих предложений от клиента.
//  СпособОбработки          - Строка - Способ сохранения данных в информационной базе.
//    См. ОбменСКонтрагентамиПереопределяемый.ПриОпределенииСпособовОбработкиПрикладногоТипаЭлектронногоДокумента.
//  ОписаниеОшибки - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//
Процедура НайтиСоздатьЗапросКоммерческихПредложений(Знач ДанныеВходящегоДокумента, УчетныйДокумент, СпособОбработки, ОписаниеОшибки) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.НайтиСоздатьЗапросКоммерческихПредложений(ДанныеВходящегоДокумента, УчетныйДокумент, СпособОбработки, ОписаниеОшибки) 
```
</details>

## ЗаполнитьДанныеПоКоммерческомуПредложению
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для формирования исходящего электронного документа по Коммерческому предложению.
//
// Параметры:
//  СсылкаНаОбъект  - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - основание электронного документа.
//  ДеревоДанных    - ДеревоЗначений - данные для заполнения электронного документа. Строится по макету
//                                     см. Обработка.ОбменСКонтрагентами.Макет.КоммерческоеПредложение.
//                                     Если используется подсистема
//                                     ЭлектронноеВзаимодействие.КоммерческиеПредложения, то обработчик не вызывается
//                                     (см. КоммерческиеПредложенияПереопределяемый.ЗаполнитьДанныеПоКоммерческомуПредложению).
//                                     Выходной параметр.
//  Отказ           - Булево         - Если нужно отказаться от создания электронного документа, необходимо установить
//                                     значение в Истина. После этого дальнейшие действия по формированию документа
//                                     производиться не будут, поэтому нужно сформировать сообщения пользователю при
//                                     необходимости самостоятельно.
//
Процедура ЗаполнитьДанныеПоКоммерческомуПредложению(Знач СсылкаНаОбъект, ДеревоДанных, Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПоКоммерческомуПредложению(СсылкаНаОбъект, ДеревоДанных, );
```
</details>

## НайтиСоздатьКоммерческоеПредложение
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создание нового или перезаполнение существующего прикладного документа Коммерческое предложение поставщика
// по данным входящего электронного документа.
// Если существует подсистема КоммерческиеПредложенияДокументы.КоммерческоеПредложениеПоставщика, обработчик
// не вызывается.
//
// Параметры:
//  ДанныеВходящегоДокумента - ДеревоЗначений - данные электронного документа, см. Обработка.ОбменСКонтрагентами.Макет.КоммерческоеПредложение.
//  УчетныйДокумент          - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - Ссылка на учетный документ Коммерческое предложение поставщика.
//  СпособОбработки          - Строка - Способ сохранения данных в информационной базе.
//    См. ОбменСКонтрагентамиПереопределяемый.ПриОпределенииСпособовОбработкиПрикладногоТипаЭлектронногоДокумента.
//  ОписаниеОшибки - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//
Процедура НайтиСоздатьКоммерческоеПредложение(Знач ДанныеВходящегоДокумента, УчетныйДокумент, СпособОбработки, ОписаниеОшибки) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.НайтиСоздатьКоммерческоеПредложение(ДанныеВходящегоДокумента, УчетныйДокумент, СпособОбработки, ОписаниеОшибки) 
```
</details>

## ЗаполнитьДанныеПоДокументуПредприятия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Подготавливает данные для электронного документа вида "Документ предприятия".
//
// Параметры:
//  СсылкаНаОбъект - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО
//  КонструкторЭД - ОбработкаОбъект.ФорматДокументПредприятия
//  Отказ - Булево - признак отказа от дальнейшего формирования электронного документа.
//                   Информационное сообщение пользователю необходимо формировать самостоятельно.
//
Процедура ЗаполнитьДанныеПоДокументуПредприятия(СсылкаНаОбъект, КонструкторЭД, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьДанныеПоДокументуПредприятия(СсылкаНаОбъект, КонструкторЭД, Отказ) 
```
</details>

## НайтиСоздатьДокументПредприятия
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Поиск и создание учетного документа при отражении в учете документа предприятия.
//
// Параметры:
//  СсылкаНаОбъектУчета - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - найденный или созданный объект учета.
//  КонструкторЭД - ОбработкаОбъект.ФорматДокументПредприятия
//  ПараметрыОбработки - Структура - дополнительные параметры для обработки объекта:
//    * СпособОбработки   - Строка - способ сохранения данных в информационной базе.
//          См. ОбменСКонтрагентамиПереопределяемый.ПриОпределенииСпособовОбработкиПрикладногоТипаЭлектронногоДокумента
//  ОписаниеОшибки - Строка - описание ошибки создания учетного документа. Может быть выведена пользователю.
//  ДополнительныеДанные - Структура - дополнительные данные для отражения в учете. Могут передаваться другими подсистемами
//                                     из состава библиотеки. Состав данных должен быть описан в документации соответствующей подсистемы.
//
Процедура НайтиСоздатьДокументПредприятия(СсылкаНаОбъектУчета, КонструкторЭД, ПараметрыОбработки, ОписаниеОшибки, ДополнительныеДанные = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.НайтиСоздатьДокументПредприятия(СсылкаНаОбъектУчета, КонструкторЭД, ПараметрыОбработки, ОписаниеОшибки, ДополнительныеДанные);
```
</details>

## СпособыОтраженияВУчетеТипаЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает идентификаторы способов отражения в учете, доступных при загрузке электронного документа.
//
// Параметры:
//  ТипДокумента   - см. ОбменСКонтрагентами.ТипыДокументов   - тип электронного документа.
//  СпособыОтраженияВУчете - СписокЗначений - список способов отражения в учете. В качестве значения задается строковый
//                           идентификатор, который будет передан в переопределяемый методы создания учетных документов
//                           по данным электронных. В качестве представления - представление способа отражения, которое
//                           может быть отображено пользователю.
//                           Выходной параметр.
//
Процедура СпособыОтраженияВУчетеТипаЭлектронногоДокумента(ТипДокумента, СпособыОтраженияВУчете) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.СпособыОтраженияВУчетеТипаЭлектронногоДокумента(ТипДокумента, СпособыОтраженияВУчете) 
```
</details>

## СписокВидовИсходящихДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает список видов учетных документов для подбора в исходящих документах.
//
// Параметры:
//  ТипДокумента - ПеречислениеСсылка.ТипыДокументовЭДО - тип электронного документа.
//  СписокСпособовОбработки - СписокЗначений из Строка - список видов учетных документов. В качестве значения задается строковый
//                           идентификатор. В качестве представления - представление вида документа, которое
//                           может быть отображено пользователю.
//                           Выходной параметр.
//
Процедура СписокВидовИсходящихДокументов(ТипДокумента, СписокСпособовОбработки) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.СписокВидовИсходящихДокументов(ТипДокумента, СписокСпособовОбработки) 
```
</details>

## ИмяОбъектаМетаданныхПоСпособуОтраженияВУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет имя объекта метаданных для способа обработки входящего электронного документа, в случае, если оно не
// совпадает с именем способа обработки.
//
// Параметры:
//  СпособОтраженияВУчете - Строка - один из способов отражения в учете входящего документа, заданный в переопределении.
//                          см. СпособыОтраженияВУчетеТипаЭлектронногоДокумента.
//  ИмяДокумента - Строка - в параметр необходимо поместить имя объекта метаданных, соответствующее переданному способу обработки.
//                          Выходной параметр.
//
Процедура ИмяОбъектаМетаданныхПоСпособуОтраженияВУчете(СпособОтраженияВУчете, ИмяДокумента) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ИмяОбъектаМетаданныхПоСпособуОтраженияВУчете(СпособОтраженияВУчете, ИмяДокумента) 
```
</details>

## ТаблицаПредопределенногоПрофиля
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Переопределяет заполнение таблицы настройки отражения в учете по имени профиля.
//
// Параметры:
//  ТаблицаПрофиля - ТаблицаЗначений - таблица соответствия способов отражения в учете и электронных документов:
//   * ТипДокумента - см. ОбменСКонтрагентами.ТипыДокументов() - тип электронного документа.
//   * ПрикладнойТипДокумента - ОпределяемыйТип.ПрикладныеТипыЭлектронныхДокументовЭДО - прикладной тип документа.
//                              Указывается при встраивании в конфигурацию собственных типов электронных документов.
//   * СпособОбработки - Строка - идентификатор способа отражения в учете, заданный в см. СпособыОтраженияВУчетеТипаЭлектронногоДокумента.
//  Профиль		   - Строка - имя профиля настроек. Возможные значения:
//   - Автоматически
//   - Вручную
//   - Поставщик
//   - Покупатель
//   - ПервоначальноеЗаполнение
//
Процедура ТаблицаПредопределенногоПрофиля(ТаблицаПрофиля, Профиль) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ТаблицаПредопределенногоПрофиля(ТаблицаПрофиля, Профиль) 
```
</details>

## ПриПроверкеВозможностиСозданияУчетногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняется при проверке возможности создания учетного документа по электронному документу.
//
// Параметры:
//  Параметры - Структура - параметры электронного документа, отражаемого в учете.
//   * ЭтоСводныйУПД - Булево - электронный документ имеет формат УПД и содержит несколько продавцов, покупателей и т.п.
//  Отказ - Булево - признак отказа от отражения в учете. Если установить Истина, то документ не отражается в учете
//                   (для изменения). По умолчанию Ложь.
//  Описание - Строка - описание причины отказа от отражения в учете.
//
Процедура ПриПроверкеВозможностиСозданияУчетногоДокумента(Знач Параметры, Отказ, Описание) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриПроверкеВозможностиСозданияУчетногоДокумента(Параметры, Отказ, Описание) 
```
</details>

## ПриПроверкеФормированияДокументовЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие возникает при формировании электронных документов. Данные электронных документов сформированы, но не записаны.
// На данном этапе можно отказаться от записи электронных документов.
// Событие может выполняться в фоновом задании, в связи с этим не следует помещать данные во временное хранилище.
//
// Параметры:
//  ДанныеДляПроверки - ТаблицаЗначений - сформированные данные электронных документов.
//    * Ключ - Число - ключ связи с данными для проверки. Используется для отказа от записи электронного документа
//                     при произвольной обработке результатов проверок.
//    * ТипДокумента - см. ОбменСКонтрагентами.ТипыДокументов()
//    * ОписаниеФайла - Структура:
//      ** ДвоичныеДанные - ДвоичныеДанные - данные xml.
//      ** ИмяФайла - Строка - имя файла с расширением.
//      ** Формат - см. ОбменСКонтрагентами.ФорматыДокументов()
//    * ОбъектыУчета - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументов
//    * Отказ - Булево - признак отказа от записи электронного документа при обработке результата по умолчанию.
//    * ПричинаОтказа - Строка - описание причины отказа для отображения пользователю при обработке результата по умолчанию.
//  СтандартнаяОбработка - Булево - признак обработки результата проверки по умолчанию.
//  РезультатыПроверок - Структура - результаты проверок для произвольной обработки.
//     Используется при нестандартной обработке (см. ПриОбработкеРезультатовПроверокФормированияДокументовЭДО).
//
//@skip-warning
Процедура ПриПроверкеФормированияДокументовЭДО(ДанныеДляПроверки, СтандартнаяОбработка, РезультатыПроверок) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриПроверкеФормированияДокументовЭДО(ДанныеДляПроверки, СтандартнаяОбработка, РезультатыПроверок) 
```
</details>

## ПриОбработкеРезультатовПроверокФормированияДокументовЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие возникает при нестандартной обработке результатов проверок данных электронных документов при формировании.
// Т.е. в процедуре см. ПриПроверкеФормированияДокументовЭДО флаг СтандартнаяОбработка установлен в Ложь.
//
// Параметры:
//  РезультатыПроверок - Структура - результаты проверок для произвольной обработки.
//  ПараметрыОбработкиНаКлиенте - Структура - параметры для передачи на клиент. Значения свойств должны сериализоваться.
//      См. ОбменСКонтрагентамиКлиентПереопределяемый.ПриОбработкеРезультатовПроверокФормированияДокументовЭДО
//
//@skip-warning
Процедура ПриОбработкеРезультатовПроверокФормированияДокументовЭДО(РезультатыПроверок, ПараметрыОбработкиНаКлиенте) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОбработкеРезультатовПроверокФормированияДокументовЭДО(РезультатыПроверок, ПараметрыОбработкиНаКлиенте) 
```
</details>

## ПриПроверкеФормированияОтветовПоДокументамЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие возникает при формировании ответов по электронным документам. Данные ответов по электронным документам сформированы, но не записаны.
// На данном этапе можно отказаться от записи ответов по электронным документам.
// Событие может выполняться в фоновом задании, в связи с этим не следует помещать данные во временное хранилище.
//
// Параметры:
//  ДанныеДляПроверки - ТаблицаЗначений - сформированные данные электронных документов.
//    * Ключ - Число - ключ связи с данными для проверки. Используется для отказа от записи электронного документа
//                     при произвольной обработке результатов проверок.
//    * ТипДокумента - см. ОбменСКонтрагентами.ТипыДокументов()
//    * ОписаниеФайлаИнформацииОтправителя - Структура:
//      ** ДвоичныеДанные - ДвоичныеДанные - данные xml.
//      ** ИмяФайла - Строка - имя файла с расширением.
//      ** Формат - см. ОбменСКонтрагентами.ФорматыДокументов()
//    * ОписаниеФайлаИнформацииПолучателя - Структура:
//      ** ДвоичныеДанные - ДвоичныеДанные - данные xml.
//      ** ИмяФайла - Строка - имя файла с расширением.
//      ** Формат - см. ОбменСКонтрагентами.ФорматыДокументов()
//    * ОбъектыУчета - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументов
//    * Отказ - Булево - признак отказа от записи электронного документа при обработке результата по умолчанию.
//    * ПричинаОтказа - Строка - описание причины отказа для отображения пользователю при обработке результата по умолчанию.
//  СтандартнаяОбработка - Булево - признак обработки проверки по умолчанию.
//  РезультатыПроверок - Структура - результаты проверок для произвольной обработки.
//     Используется при нестандартной обработке (см. ПриОбработкеРезультатовПроверокФормированияДокументовЭДО).
//
//@skip-warning
Процедура ПриПроверкеФормированияОтветовПоДокументамЭДО(ДанныеДляПроверки, СтандартнаяОбработка, РезультатыПроверок) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриПроверкеФормированияОтветовПоДокументамЭДО(ДанныеДляПроверки, СтандартнаяОбработка, РезультатыПроверок) 
```
</details>

## ПриОбработкеРезультатовПроверокФормированияОтветовПоДокументамЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие возникает при нестандартной обработке результатов проверок данных сформированных ответов по электронным документам.
// Т.е. в процедуре см. ПриПроверкеФормированияОтветовПоДокументамЭДО флаг СтандартнаяОбработка установлен в Ложь.
//
// Параметры:
//  РезультатыПроверок - Структура - результаты проверок для произвольной обработки.
//  ПараметрыОбработкиНаКлиенте - Структура - параметры для передачи на клиент. Значения свойств должны сериализоваться.
//      См. ОбменСКонтрагентамиКлиентПереопределяемый.ПриОбработкеРезультатовПроверокФормированияОтветовПоДокументамЭДО
//
//@skip-warning
Процедура ПриОбработкеРезультатовПроверокФормированияОтветовПоДокументамЭДО(РезультатыПроверок, ПараметрыОбработкиНаКлиенте) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОбработкеРезультатовПроверокФормированияОтветовПоДокументамЭДО(РезультатыПроверок, ПараметрыОбработкиНаКлиенте) 
```
</details>

## ПослеФормированияЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие возникает после формирования электронного документа (в том числе входящего).
//
// Параметры:
//  ЭлектронныйДокумент	 - ДокументСсылка.ЭлектронныйДокументИсходящийЭДО - ссылка на электронный документ.
//                       - ДокументСсылка.ЭлектронныйДокументВходящийЭДО - ссылка на электронный документ.
//
//@skip-warning
Процедура ПослеФормированияЭлектронногоДокумента(ЭлектронныйДокумент) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПослеФормированияЭлектронногоДокумента(ЭлектронныйДокумент) 
```
</details>

## ПослеУтвержденияЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие возникает после утверждения электронного документа.
//
// Параметры:
//  ЭлектронныйДокумент	 - ДокументСсылка.ЭлектронныйДокументИсходящийЭДО - ссылка на электронный документ.
//                       - ДокументСсылка.ЭлектронныйДокументВходящийЭДО - ссылка на электронный документ.
//
Процедура ПослеУтвержденияЭлектронногоДокумента(ЭлектронныйДокумент) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПослеУтвержденияЭлектронногоДокумента(ЭлектронныйДокумент) 
```
</details>

## ПослеПодписанияЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие возникает после полного подписания электронного документа.
// Для документов, отправляемых контрагентам, событие возникает после полного подписания на стороне отправителя.
// Для документов, получаемых от контрагентов, событие возникает после полного подписания на стороне получателя.
//
// Параметры:
//  ЭлектронныйДокумент	 - ДокументСсылка.ЭлектронныйДокументИсходящийЭДО - ссылка на электронный документ.
//                       - ДокументСсылка.ЭлектронныйДокументВходящийЭДО - ссылка на электронный документ.
//
Процедура ПослеПодписанияЭлектронногоДокумента(ЭлектронныйДокумент) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПослеПодписанияЭлектронногоДокумента(ЭлектронныйДокумент) 
```
</details>

## ПослеПолученияОтветаОтКонтрагентаПоДокументу
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие возникает после успешного получения ответа (утверждение или отклонение) по электронному документу.
//
// Параметры:
//  ЭлектронныйДокумент - ДокументСсылка.ЭлектронныйДокументИсходящийЭДО - ссылка на электронный документ
//  ДокументУтвержден - Булево - Истина, если контрагент утвердил документ, Ложь - если отклонил.
Процедура ПослеПолученияОтветаОтКонтрагентаПоДокументу(ЭлектронныйДокумент, ДокументУтвержден) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПослеПолученияОтветаОтКонтрагентаПоДокументу(ЭлектронныйДокумент, ДокументУтвержден) 
```
</details>

## ПослеЗавершенияОбменаЭлектроннымДокументом
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие возникает после успешного завершения электронного документооборота.
//
// Параметры:
//  ЭлектронныйДокумент	 - ДокументСсылка.ЭлектронныйДокументИсходящийЭДО - ссылка на электронный документ.
//                       - ДокументСсылка.ЭлектронныйДокументВходящийЭДО - ссылка на электронный документ.
//
Процедура ПослеЗавершенияОбменаЭлектроннымДокументом(ЭлектронныйДокумент) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПослеЗавершенияОбменаЭлектроннымДокументом(ЭлектронныйДокумент) 
```
</details>

## ПослеАннулированияЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие возникает после после аннулирования электронного документа.
//
// Параметры:
//  ЭлектронныйДокумент	 - ДокументСсылка.ЭлектронныйДокументИсходящийЭДО - ссылка на электронный документ.
//                       - ДокументСсылка.ЭлектронныйДокументВходящийЭДО - ссылка на электронный документ.
Процедура ПослеАннулированияЭлектронногоДокумента(ЭлектронныйДокумент) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПослеАннулированияЭлектронногоДокумента(ЭлектронныйДокумент) 
```
</details>

## ПослеИзмененияОтраженияВУчете
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Событие возникает после изменения списка объектов учета, привязанных к электронному документу (при отражении в учете,
// подборе объекта учета, разрыве связи с объектом учета и т.д.).
//
// Параметры:
// 	ЭлектронныйДокумент     - ДокументСсылка.ЭлектронныйДокументИсходящийЭДО - ссылка на электронный документ.
//                          - ДокументСсылка.ЭлектронныйДокументВходящийЭДО - ссылка на электронный документ.
// 	ДобавленныеОбъектыУчета - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - набор объектов учета, добавленных
// 	                            в список связанных с электронным документом.
// 	УдаленныеОбъектыУчета   - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - набор объектов учета, удаленных
// 	                            из списка связанных с электронным документом.
//@skip-warning
Процедура ПослеИзмененияОтраженияВУчете(ЭлектронныйДокумент, ДобавленныеОбъектыУчета, УдаленныеОбъектыУчета) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПослеИзмененияОтраженияВУчете(ЭлектронныйДокумент, ДобавленныеОбъектыУчета, УдаленныеОбъектыУчета) 
```
</details>

## ПослеВозникновенииСобытияПоЭлектронномуСчетуФактуре
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Обработчик ключевых событий по электронному счету-фактуре, описанных в приказе от 10 ноября 2015 г. N 174н.:
// получение ПДО, ПДП, ИоП, ПДОИоП.
//
// Параметры:
//  ДокументыУчета - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - документы учета, привязанные к электронному счету-фактуре.
// 	Событие - Строка - идентификатор события. Возможные события:
// 	 * "ПолученПДО" - получено подтверждение даты отправки.
// 	 * "ПолученПДП" - получено подтверждение даты получения.
// 	 * "ПолученИоП" - получено извещение о получении электронного счета-фактуры.
// 	 * "ПолученИоППДО" - получено подтверждение даты отправки извещения о получении электронного счета-фактуры.
// 	СостояниеОбработки - Структура:
//	 * ПДППолучен - Булево - Истина, если по документу получен ПДП
//	 * ДатаПоступленияСФОператоруОтПродавца - Дата - дата поступления файла счета-фактуры Оператору ЭДО от продавца,
//     указанная в подтверждении (ПДП) этого Оператора ЭДО
//   * ПДОПолучен - Булево - Истина, если по документу получен ПДО
//	 * ДатаОтправкиСФПокупателюОператором - Дата - дата направления покупателю Оператором ЭДО файла счета-фактуры продавца,
//     указанная в подтверждении (ПДОЭСФ) Оператора ЭДО
//   * ИоППолучен - Булево - Истина, если по документу получено извещение о его получении покупателем.
//	 * ИоППДОПолучен - Булево - Истина, если по документу получено подтверждение даты отправки извещения о получении.
Процедура ПослеВозникновенииСобытияПоЭлектронномуСчетуФактуре(ДокументыУчета, Событие, СостояниеОбработки) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПослеВозникновенииСобытияПоЭлектронномуСчетуФактуре(ДокументыУчета, Событие, СостояниеОбработки) 
```
</details>

## ПолучитьОтветственногоПоЭД
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Используется для простановки ответственного при создании / получении электронного документа.
//
// Параметры:
//  Контрагент - ОпределяемыйТип.КонтрагентБЭД - ссылка на контрагента электронного документа.
//  Организация - ОпределяемыйТип.Организация - организация электронного документа.
//  ДоговорКонтрагента - ОпределяемыйТип.ДоговорСКонтрагентомЭДО - договор электронного документа. Может быть не указан.
//  ОтветственныйПоЭД - СправочникСсылка.Пользователи - ответственное за документ лицо. Выходной параметр.
//
Процедура ПолучитьОтветственногоПоЭД(Контрагент, Организация, ДоговорКонтрагента, ОтветственныйПоЭД) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПолучитьОтветственногоПоЭД(Контрагент, Организация, ДоговорКонтрагента, ОтветственныйПоЭД) 
```
</details>

## ОпределитьДокументЯвляетсяСчетомФактурой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет является ли документ информационной базы счет-фактурой.
//
// Параметры:
//  ДокументСсылка - ДокументСсылка - документ информационной базы.
//  Результат - Булево - Истина, если документ является счет-фактурой.
//
Процедура ОпределитьДокументЯвляетсяСчетомФактурой(ДокументСсылка, Результат) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ОпределитьДокументЯвляетсяСчетомФактурой(ДокументСсылка, Результат) 
```
</details>

## ПриПолученииОписанияОснованияЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает описание объекта учета, являющегося основанием электронного документа.
//
// Параметры:
//  ОснованиеОбъект - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - объект или ссылка на основание электронного документа.
//  Описание - Структура - данные, описывающие основание электронного документа:
//   * Вид - Строка - представление вида объекта. По умолчанию синоним объекта метаданных.
//   * Организация - ОпределяемыйТип.Организация - организация.
//   * Контрагент - ОпределяемыйТип.КонтрагентБЭД - контрагент.
//   * Дата - Дата - дата.
//   * Номер - Строка - номер.
//   * СуммаДокумента - Число - сумма документа.
//  СтандартнаяОбработка - Булево - признак формирования описания по умолчанию.
//                                  Если Ложь, то используются данные из параметра Описание. По умолчанию Истина.
//
Процедура ПриПолученииОписанияОснованияЭлектронногоДокумента(ОснованиеОбъект, Описание, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриПолученииОписанияОснованияЭлектронногоДокумента(ОснованиеОбъект, Описание, СтандартнаяОбработка) 
```
</details>

## СсылкаНаОбъектПоИННКПП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Ищет элемента справочника, хранящего контрагентов или организаций по реквизитам ИНН и КПП.
//
// Параметры:
//  ТипОбъекта - Строка - строковый идентификатор сущности. Возможные значения:
//						"Организации",
//    					"Контрагенты".
//  ИНН - Строка - ИНН.
//  КПП - Строка - КПП.
//  Ссылка - ОпределяемыйТип.Организация, ОпределяемыйТип.КонтрагентБЭД - ссылка на найденный объект.
//  ДатаСведений - Дата - дата сведений о ИНН/КПП объекта.
//               - Неопределено - дата сведений не определена.
//
Процедура СсылкаНаОбъектПоИННКПП(ТипОбъекта, ИНН, КПП, Ссылка, ДатаСведений = Неопределено) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.СсылкаНаОбъектПоИННКПП(ТипОбъекта, ИНН, КПП, Ссылка, ДатаСведений);
```
</details>

## СоздатьКонтрагентаПоРеквизитам
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Создает контрагента в информационной базе по реквизитам.
//
// Параметры:
//   РеквизитыКонтрагента - Структура - реквизиты необходимые для создания контрагента.
//    * ИНН - Строка - ИНН.
//    * КПП - Строка - КПП.
//    * Наименование - Строка - наименование контрагента.
//   Контрагент - ОпределяемыйТип.КонтрагентБЭД - ссылка на созданного контрагента.
//   Отказ - Булево - признак ошибки.
//
Процедура СоздатьКонтрагентаПоРеквизитам(Знач РеквизитыКонтрагента, Контрагент, Отказ = Ложь) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.СоздатьКонтрагентаПоРеквизитам(РеквизитыКонтрагента, Контрагент, Отказ);
```
</details>

## ЗаполнитьРеквизитыКонтрагента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет реквизиты контрагента переданными данными.
//
// Параметры:
//  СтруктураРеквизитов - структура - реквизитов контрагента, которые нужно заполнить. Содержит ключи:
//    * Контрагент - ОпределяемыйТип.КонтрагентБЭД - если указан, требуется заполнить данные этого контрагента.
//                                                   В противном случае необходимо создать нового контрагента.
//    * ИНН_КПП - Строка - ИНН и КПП, разделенные знаком "_".
//    * ОКПО - Строка - ОКПО.
//    * Наименование - Строка - наименование контрагента.
//    * ЮрАдресПредставление - Строка - строковое представление юридического адреса контрагента.
//    * ЮрАдресЗначенияПолей - Строка - перечисление значений элементов адреса, разделенных переносом строки. Название
//                                      адресного элемента и его значение разделяются знаком "=". Возможные адресные элементы:
//      - Индекс
//      - НаселенныйПункт
//      - Страна
//      - Регион
//      - Район
//      - Город
//      - Улица
//      - Дом
//      - Корпус
//      - Квартира
//    * ФактАдресПредставление - Строка - строковое представление фактического адреса контрагента.
//    * ФактАдресЗначенияПолей - Строка - перечисление значений элементов адреса, разделенных переносом строки. Название
//                                      адресного элемента и его значение разделяются знаком "=". Возможные адресные элементы:
//      - Индекс
//      - НаселенныйПункт
//      - Страна
//      - Регион
//      - Район
//      - Город
//      - Улица
//      - Дом
//      - Корпус
//      - Квартира
//    * Телефон - Строка - телефон контрагента.
//    * БИК - Строка - БИК банка.
//    * КорреспондентскийСчет - строка - номер корреспондентского счета.
//    * Банк - Строка - Название банка.
//    * РасчетныйСчет - Строка - номер расчетного счета.
//  КонтрагентСсылка    - ОпределяемыйТип.КонтрагентБЭД - ссылка на контрагента. В данном параметре необходимо вернуть
//                                                        ссылку на контрагента, у которого были заполнены данные.
//                                                        Выходной параметр.
//
Процедура ЗаполнитьРеквизитыКонтрагента(СтруктураРеквизитов, КонтрагентСсылка) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьРеквизитыКонтрагента(СтруктураРеквизитов, КонтрагентСсылка) 
```
</details>

## ПолучитьРеквизитыОрганизацииДляВыгрузкиВФайл
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает реквизиты элемента справочника "Организации", для выгрузки в xml-файл.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - элемент справочника организации;
//  СтруктураВозврата - Структура - перечень реквизитов организации:
//   * Наименование - Строка - наименование организации.
//   * НаименованиеПолное - Строка - полное наименование организации.
//   * ИНН - Строка -ИНН организации.
//   * КПП - Строка - КПП организации.
//   * ОКПО - Строка - ОКПО организации.
//   * ДолжностьРуководителя - Строка - должность руководителя организации.
//   * Руководитель - Строка - Ф.И.О. руководителя организации.
//   * СвидетельствоДата - Дата - дата свидетельства о регистрации.
//   * СвидетельствоНомер - Строка - номер свидетельства о регистрации.
//   * ЮридическийАдрес - Строка - представление адреса организации.
//   * ЗначенияПолейЮрАдрес - Строка - значения адресных элементов, разделенные переносом строки. Значение от имени
//                                     адресного элемента отделяется знаком "=".
//   * ФактическийАдрес - Строка - представление фактического адреса.
//   * ЗначенияПолейФактАдрес - Строка - значения адресных элементов, разделенные переносом строки. Значение от имени
//                                     адресного элемента отделяется знаком "=".
//   * Телефон - Строка - телефон организации.
//
Процедура ПолучитьРеквизитыОрганизацииДляВыгрузкиВФайл(Организация, СтруктураВозврата) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПолучитьРеквизитыОрганизацииДляВыгрузкиВФайл(Организация, СтруктураВозврата) 
```
</details>

## ЗаполнитьРегистрационныеДанныеОрганизации
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Процедура заполняет данные для заполнения заявки на получение уникального идентификатора абонента, добавления
// сертификата абонента
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - ссылка на элемент справочника Организации;
//  ДанныеОрганизации - см. ИнтеграцияЭДО.НоваяСтруктураДанныхОрганизации
//
Процедура ЗаполнитьРегистрационныеДанныеОрганизации(Организация, ДанныеОрганизации) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЗаполнитьРегистрационныеДанныеОрганизации(Организация, ДанныеОрганизации) 
```
</details>

## ДанныеСвидетельстваОРегистрацииИП
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает данные свидетельства о регистрации ИП по ссылке на контрагента или организацию.
//
// Параметры:
//  ИП - ОпределяемыйТип.Организация - организация
//     - ОпределяемыйТип.КонтрагентБЭД - контрагент
//  Сведения - Строка - в этот параметр необходимо поместить сведения о регистрации индивидуального предпринимателя.
//                      Выходной параметр.
//
Процедура ДанныеСвидетельстваОРегистрацииИП(ИП, Сведения) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ДанныеСвидетельстваОРегистрацииИП(ИП, Сведения) 
```
</details>

## АдресЭлектроннойПочтыКонтрагента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает адрес электронной почты контрагента.
//
// Параметры:
//  Контрагент - ОпределяемыйТип.КонтрагентБЭД - ссылка на элемент справочника контрагенты, адрес которого надо получить.
//  АдресЭП - Строка - адрес электронной почты.
//
Процедура АдресЭлектроннойПочтыКонтрагента(Контрагент, АдресЭП) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.АдресЭлектроннойПочтыКонтрагента(Контрагент, АдресЭП) 
```
</details>

## ПолучитьБанковскиеСчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает банковские счета организации для выгрузки сведений о ней.
//
// Параметры:
//  Организация - ОпределяемыйТип.Организация - ссылка на организацию.
//  Таблица - ТаблицаЗначений - таблица с перечнем банковских счетов. Содержит колонки:
//    * БанковскийСчет - ЛюбаяСсылка - ссылка на банковский счет.
//
Процедура ПолучитьБанковскиеСчета(Организация, Таблица) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПолучитьБанковскиеСчета(Организация, Таблица) 
```
</details>

## ПолучитьБанковскиеРеквизиты
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает банковские реквизиты по переданным счетам для выгрузки сведений об организации.
//
// Параметры:
//  МассивСчетов - Массив - список ссылок на банковские счета организации.
//  Таблица - ТаблицаЗначений - перечень банковских реквизитов. Должна содержать следующие колонки:
//    * Ссылка - ЛюбаяСсылка - ссылка на банковский счет.
//    * РасчетныйСчет - Строка - номер расчетного счета.
//    * КорреспондентскийСчет - Строка - номер корреспондентского счета.
//    * БИК - Строка - БИК банка.
//    * Банк - Строка - наименование банка.
//    * БанкДляРасчетов - Строка - наименование банка для расчетов.
//    * БанкДляРасчетовБИК - Строка - БИК банка для расчетов.
//    * БанкДляРасчетовКоррСчет - Строка - Строка - корреспондентский счет банка для расчетов.
//
Процедура ПолучитьБанковскиеРеквизиты(МассивСчетов, Таблица) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПолучитьБанковскиеРеквизиты(МассивСчетов, Таблица) 
```
</details>

## ЭтоФизЛицо
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет, является ли переданная организация или контрагент физ. лицом.
//
// Параметры:
//  ДанныеКонтрагента - ОпределяемыйТип.Организация - ссылка на организацию.
//                    - ОпределяемыйТип.КонтрагентБЭД - ссылка на контрагента.
//  ПризнакФизЛица - Булево - Истина если это физическое лицо. Выходной параметр.
//
Процедура ЭтоФизЛицо(ДанныеКонтрагента, ПризнакФизЛица) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ЭтоФизЛицо(ДанныеКонтрагента, ПризнакФизЛица) 
```
</details>

## СведенияФизЛицаПользователя
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает сведения физического лица по переданному пользователю ИБ и организации.
//
// Параметры:
//  Пользователь - ОпределяемыйТип.Пользователь - пользователь ИБ.
//  Организация - ОпределяемыйТип.Организация - организация.
//  СведенияФизЛица - Структура - данные физического лица:
//   * ИмяПолное - Строка - полное имя физического лица пользователя, неапример "Иванов Иван Иванович" .
//   * Должность - Строка - занимаемая должность.
//
Процедура СведенияФизЛицаПользователя(Знач Пользователь, Знач Организация, СведенияФизЛица) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.СведенияФизЛицаПользователя(Пользователь, Организация, СведенияФизЛица) 
```
</details>

## ПолучитьНомерДатаДоговораДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет соответствие выгружаемым документам дату и номер основания (договора).
//
// Параметры:
//  МассивСсылок - Массив Из ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - массив ссылок на учетные документы
//                 (в качестве возможных значений следует принимать те типы документов, на основании которых в данном
//                 прикладном решении формируется электронный документ вида «Акт приемки-сдачи работ (услуг).
//  ВозвращаемоеСоответствие - Соответствие - в случае, если требуемые реквизиты у договора не заполнены
//                             или при невозможности получения данных реквизитов, нужно помещать пустые значения указанных типов.
//                             Соответствие со следующими свойствами:
//                             * Ключ - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - ссылка на выгружаемый учетный документ.
//                             * Значение - Структура:
//                               ** НомерДоговора - Строка;
//                               ** ДатаДоговора - Дата.
//
Процедура ПолучитьНомерДатаДоговораДокументов(МассивСсылок, ВозвращаемоеСоответствие) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПолучитьНомерДатаДоговораДокументов(МассивСсылок, ВозвращаемоеСоответствие) 
```
</details>

## ПриОпределенииПрикладныхТиповЭлектронныхДокументов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет прикладные типы электронных документов.
//
// Параметры:
//  ТипыЭлектронныхДокументов - Массив Из ОпределяемыйТип.ПрикладныеТипыЭлектронныхДокументовЭДО - используемые прикладные
//                              типы электронных документов.
//
Процедура ПриОпределенииПрикладныхТиповЭлектронныхДокументов(ТипыЭлектронныхДокументов) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОпределенииПрикладныхТиповЭлектронныхДокументов(ТипыЭлектронныхДокументов) 
```
</details>

## ПриОпределенииСведенийОПрикладныхФорматах
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет сведения о прикладных форматах электронных документов.
//
// Параметры:
//  ТаблицаФорматов - ТаблицаЗначений - Таблица сведений о прикладных форматах.
//     * ПрикладнойТипДокумента      - ОпределяемыйТип.ПрикладныеТипыЭлектронныхДокументовЭДО - Ссылка на прикладной тип электронного документа.
//     * ИдентификаторФормата        - Строка - Текстовый идентификатор формата,
//          используется для идентификации формата в программном коде библиотеки.
//     * ПредставлениеФормата        - Строка - Пользовательское представление для вывода пользователю.
//     * Отключен                    - Булево - Если указано "Да", то формат не используется.
//     * ДатаНачалаДействия          - Дата - Дата, начиная с которой формат вступает в силу.
//     * ДатаОкончанияДействия       - Дата - Дата, после которой формат не должен использоваться.
//     * УсловиеВыводаПредупреждения - Строка - Задает условие вывода предупреждения для входящих документов.
//          Возможные значения:
//          ""ДатаФормированияЭлектронногоДокумента"" - предупреждение выводится только в том случае,
//          если электронный документ сформирован вне периода действия формата.
//          Пустая строка - предупреждение выводится в любом случае.
//     * ТекстПредупрежденияДляВходящегоДокумента - Строка - Содержит текст предупреждения,
//          который будет выводиться в форме визуализации входящего документа, сформированного по данному формату.
//          Используется для утративших силу форматов и для других предупреждений.
//          Может содержать в тексте символы ""%"", которые будут заменены на параметры из колонки ""ПараметрыПредупрежденияДляВходящегоДокумента"".
//          Если не задано, предупреждение выводиться не будет. Локализуется.
//
Процедура ПриОпределенииСведенийОПрикладныхФорматах(ТаблицаФорматов) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОпределенииСведенийОПрикладныхФорматах(ТаблицаФорматов) 
```
</details>

## ПриОпределенииНастроекРегламентаЭДО
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет настройки регламента электронного документооборота для прикладных типов электронных документов.
//
// Параметры:
//  Настройки - Структура -
//     * ТребуетсяИзвещениеОПолучении - Булево - По данному признаку, на стороне получателя определяется необходимость
//                                      отправки извещения о получении.
//     * ТребуетсяОтветнаяПодпись     - Булево - По данному признаку, на стороне получателя определяется, требуется
//                                      ответное подписание документа.
//     * РедактироватьПодпись         - Булево - Признак редактирования параметра "Подписывать документ" в форме
//                                      настроек регламента ЭДО.
//     * РедактироватьИзвещение       - Булево - Признак редактирования параметра "Ожидать извещение о получении" в
//                                      форме настроек регламента ЭДО.
//     * РедактироватьОтветнуюПодпись - Булево - Признак редактирования параметра "Ожидать ответную подпись" в форме
//                                      настроек регламента ЭДО.
//  ТипЭлектронногоДокумента - ОпределяемыйТип.ПрикладныеТипыЭлектронныхДокументовЭДО - Ссылка на прикладной тип
//                             электронного документа.
//  ВерсияФормата            - Строка - Текстовый идентификатор формата соответствующего прикладного вида электронного
//                             документа. См. ПриОпределенииСведенийОПрикладныхФорматах
//  СтандартнаяОбработка     - Булево - Признак использования настроек регламента по умолчанию.
//                             Если Ложь, то используются данные из параметра Настройки. По умолчанию Истина.
//
Процедура ПриОпределенииНастроекРегламентаЭДО(Настройки, ТипЭлектронногоДокумента, ВерсияФормата, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОпределенииНастроекРегламентаЭДО(Настройки, ТипЭлектронногоДокумента, ВерсияФормата, СтандартнаяОбработка) 
```
</details>

## ПриОпределенииТиповУчетныхДокументовПоПрикладномуТипуЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет соответствие списка учетных документов прикладному типу электронного документа.
//
// Параметры:
//  ТипЭлектронногоДокумента - ОпределяемыйТип.ПрикладныеТипыЭлектронныхДокументовЭДО - прикладной тип электронного документа.
//  ТипыУчетныхДокументов    - СписокЗначений - список ссылок на объекты учета. В качестве ключа задается пустая ссылка
//                             объекта, в качестве представления представление объекта учета, которое может быть показано пользователю.
//
Процедура ПриОпределенииТиповУчетныхДокументовПоПрикладномуТипуЭлектронногоДокумента(ТипЭлектронногоДокумента, ТипыУчетныхДокументов) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОпределенииТиповУчетныхДокументовПоПрикладномуТипуЭлектронногоДокумента(ТипЭлектронногоДокумента, ТипыУчетныхДокументов) 
```
</details>

## ПриОпределенииСоответствияИсходящихПрикладныхТиповДокументамУчета
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет соответствие прикладных типов исходящих электронных документов и представлений документов информационной базы,
// на основании которых они формируются.
//
// Параметры:
//  СоответствиеТиповДокументам - Соответствие - перечень типов электронных документов.
//    - Соответствие - с свойствами:
//    * Ключ             - ОпределяемыйТип.ПрикладныеТипыЭлектронныхДокументовЭДО - прикладной тип электронного документа.
//    * Значение         - Строка - представление документа информационной базы (хозяйственной операции).
//
Процедура ПриОпределенииСоответствияИсходящихПрикладныхТиповДокументамУчета(СоответствиеТиповДокументам) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОпределенииСоответствияИсходящихПрикладныхТиповДокументамУчета(СоответствиеТиповДокументам) 
```
</details>

## ПриОпределенииСпособовОбработкиПрикладногоТипаЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Возвращает идентификаторы способов отражения в учете, доступных при загрузке электронного документа.
//
// Параметры:
//  ТипЭлектронногоДокумента - ОпределяемыйТип.ПрикладныеТипыЭлектронныхДокументовЭДО - прикладной тип электронного документа.
//  СпособыОбработки         - СписокЗначений Из Строка - список способов отражения в учете. В качестве значения задается строковый
//                             идентификатор, который будет передан в переопределяемый методы создания учетных документов
//                             по данным электронных. В качестве представления - представление способа отражения, которое
//                             может быть отображено пользователю.
//                             Выходной параметр.
//
Процедура ПриОпределенииСпособовОбработкиПрикладногоТипаЭлектронногоДокумента(ТипЭлектронногоДокумента, СпособыОбработки) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОпределенииСпособовОбработкиПрикладногоТипаЭлектронногоДокумента(ТипЭлектронногоДокумента, СпособыОбработки) 
```
</details>

## ПриОпределенииСоставаКомандЭДООснованияПрикладногоЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для распределения объектов, к которым подключаются команды ЭДО, по группам.
//
// Параметры:
//  СоставКомандЭДО - Структура - структура состава команд ЭДО. Для каждого из ключей указывается массив полных имен
//                    объектов метаданных, к которым подключаются команды ЭДО.
//    Исходящие    - Массив Из Строка - объекты для команд работы с исходящими документами.
//    Входящие     - Массив Из Строка - объекты для команд работы со входящими документами.
//    БезПодписи   - Массив Из Строка - объекты для команд выполнения ЭДО без подписи.
//    Интеркампани - Массив Из Строка - объекты для команд обмена между организациями в рамках одной базы.
//
// Пример:
//  СоставКомандЭДО.Исходящие.Добавить("Документ.ТранспортнаяНакладная");
//	СоставКомандЭДО.Исходящие.Добавить("Документ.Извещение");
//
Процедура ПриОпределенииСоставаКомандЭДООснованияПрикладногоЭлектронногоДокумента(СоставКомандЭДО) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОпределенииСоставаКомандЭДООснованияПрикладногоЭлектронногоДокумента(СоставКомандЭДО) 
```
</details>

## ПриПолученииОписанияОснованияПрикладногоЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Получает описание объекта учета, являющегося основанием прикладного электронного документа.
//
// Параметры:
//  ОснованиеОбъект - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - объект или ссылка на основание электронного документа.
//  Описание - Структура - данные, описывающие основание электронного документа:
//   * Вид - Строка - представление вида объекта. По умолчанию синоним объекта метаданных.
//   * Организация - ОпределяемыйТип.Организация - организация.
//   * Контрагент - ОпределяемыйТип.КонтрагентБЭД - контрагент.
//   * Дата - Дата - дата.
//   * Номер - Строка - номер.
//   * СуммаДокумента - Число - сумма документа.
//  СтандартнаяОбработка - Булево - признак формирования описания по умолчанию.
//                                  Если Ложь, то используются данные из параметра Описание. По умолчанию Истина.
//
//
Процедура ПриПолученииОписанияОснованияПрикладногоЭлектронногоДокумента(ОснованиеОбъект, Описание, СтандартнаяОбработка) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриПолученииОписанияОснованияПрикладногоЭлектронногоДокумента(ОснованиеОбъект, Описание, СтандартнаяОбработка) 
```
</details>

## ПриОпределенииПараметровПрикладногоЭлектронногоДокументаПоИсточнику
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Предназначена для получения параметров ЭДО по ссылке на объект учета
//
// Параметры:
//  Источник  - Объект, ЛюбаяСсылка - документ или справочник источника.
//  Параметры - Структура - параметры источника, необходимые для определения настроек обмена электронными документами:
//    * ПрикладнойТипДокумента - ОпределяемыйТип.ПрикладныеТипыЭлектронныхДокументовЭДО - Ссылка на прикладной тип электронного документа.
//    * Входящий               - Булево - Признак того, что электронный документ является входящим.
//    * Организация            - ОпределяемыйТип.Организация - организация документа.
//    * Контрагент             - ОпределяемыйТип.КонтрагентБЭД - контрагент документа.
//    * ДоговорКонтрагента     - ОпределяемыйТип.ДоговорСКонтрагентомЭДО - договор контрагента.
//
Процедура ПриОпределенииПараметровПрикладногоЭлектронногоДокументаПоИсточнику(Источник, Параметры) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОпределенииПараметровПрикладногоЭлектронногоДокументаПоИсточнику(Источник, Параметры) 
```
</details>

## ПриОпределенииПараметровФайлаПрикладногоЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет параметры прикладного электронного документа по данным файла.
//
// Параметры:
//  ДанныеФайла     - ДвоичныеДанные - Данные файла прикладного электронного документа.
//  РасширениеФайла - Строка - Расширение файла без точки.
//  Параметры       - Структура - Параметры прикладного электронного документа.
//     * ТипЭлектронногоДокумента         - ОпределяемыйТип.ПрикладныеТипыЭлектронныхДокументовЭДО - прикладной тип
//                                          электронного документа.
//     * НаименованиеДокументаОтправителя - Строка - Наименование документа по данным отправителя.
//     * НомерДокументаОтправителя        - Строка - Номер документа по данным отправителя.
//     * ДатаДокументаОтправителя         - Дата  - Дата документа по данным отправителя.
//     * СуммаДокумента                   - Число - Сумма документа по данным отправителя
//     * Отправитель                      - см. ФорматыЭДО.НовоеОписаниеУчастникаЭДО
//     * Получатель                       - см. ФорматыЭДО.НовоеОписаниеУчастникаЭДО
//
Процедура ПриОпределенииПараметровФайлаПрикладногоЭлектронногоДокумента(ДанныеФайла, РасширениеФайла, Параметры) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОпределенииПараметровФайлаПрикладногоЭлектронногоДокумента(ДанныеФайла, РасширениеФайла, Параметры) 
```
</details>

## ПриФормированииФайлаПрикладногоЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирует файл прикладного электронного документа.
//
// Параметры:
//  ПараметрыФормирования - Структура - данные для формирования файла электронного документа.
//     * СсылкаНаОбъект           - ОпределяемыйТип.ОснованияЭлектронныхДокументовЭДО - объект, по которому необходимо
//                                  сформировать электронный документ.
//     * ТипЭлектронногоДокумента - ОпределяемыйТип.ПрикладныеТипыЭлектронныхДокументовЭДО - тип формируемого электронного
//                                  документа.
//  РезультатФормирования - Структура - данные, которые необходимо заполнить по результатам формирования файла
//                          электронного документа.
//     * ДанныеФайла                      - ДвоичныеДанные - файл электронного документа.
//     * ИмяФайла                         - Строка - Имя файла без расширения.
//     * Расширение                       - Строка - Расширение файла (без точки вначале).
//     * НаименованиеДокументаОтправителя - Строка - наименование электронного документа в информационной базе.
//     * НомерДокументаОтправителя        - Строка - номер электронного документа в информационной базе.
//     * ДатаДокументаОтправителя         - Строка - дата электронного документа в информационной базе.
//     * СуммаДокумента                   - Число - сумма электронного документа в информационной базе.
//  Отказ - Булево - если нужно отказаться от создания электронного документа, необходимо установить значение в Истина.
//                   После этого дальнейшие действия по формированию документа производиться не будут, поэтому
//                   нужно сформировать сообщения пользователю при необходимости самостоятельно.
//
Процедура ПриФормированииФайлаПрикладногоЭлектронногоДокумента(ПараметрыФормирования, РезультатФормирования, Отказ) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриФормированииФайлаПрикладногоЭлектронногоДокумента(ПараметрыФормирования, РезультатФормирования, Отказ) 
```
</details>

## ПриЗаполненииТабличногоДокументаИзФайлаПрикладногоЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Формирование представления прикладного электронного документа по данным файла.
//
// Параметры:
//  ТабличныйДокумент   - ТабличныйДокумент - Визуализация прикладного электронного документа.
//  ДанныеФайла         - ДвоичныеДанные - Данные файла прикладного электронного документа.
//  ПараметрыЗаполнения - Структура - Дополнительные параметры для формирования табличного документа.
//     * ВыводитьБанковскиеРеквизиты     - Булево - Значение настройки "Отображать банковские реквизиты",
//            установленной в форме просмотра электронного документа.
//            Если Истина, то в представлении участника ЭДО следует выводить банковские реквизиты.
//     * СкрыватьДопДанные               - Булево - Инвертированное значение настройки "Отображать дополнительную информацию",
//            установленной в форме просмотра электронного документа.
//            Если Ложь, то в табличном документе следует отображать дополнительную информацию, если она есть.
//     * ВыводитьПостраничныйРазделитель - Булево - Признак необходимости выводить постраничный разделитель.
//            Принимает значение Истина при выводе представления электронного документа на печать.
//     * ЭлектронныеПодписи              - Массив Из см. ЭлектроннаяПодпись.УстановленныеПодписи - Список установленных подписей.
//        ** ОтветнаяПодпись       - Булево - Признак ответной подписи.
//
Процедура ПриЗаполненииТабличногоДокументаИзФайлаПрикладногоЭлектронногоДокумента(ТабличныйДокумент, ДанныеФайла, ПараметрыЗаполнения) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриЗаполненииТабличногоДокументаИзФайлаПрикладногоЭлектронногоДокумента(ТабличныйДокумент, ДанныеФайла, ПараметрыЗаполнения) 
```
</details>

## ПриОпределенииИспользованияСопоставленияНоменклатурыКонтрагентов
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Определяет необходимость использования механизма сопоставления номенклатуры контрагентов для прикладного типа
// электронного документа.
//
// Параметры:
//  ТипЭлектронногоДокумента - ОпределяемыйТип.ПрикладныеТипыЭлектронныхДокументовЭДО - прикладной тип электронного документа.
//  Использовать             - Булево - Признак использования сопоставления номенклатуры контрагентов. По умолчанию Ложь.
//
Процедура ПриОпределенииИспользованияСопоставленияНоменклатурыКонтрагентов(ТипЭлектронногоДокумента, Использовать) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОпределенииИспользованияСопоставленияНоменклатурыКонтрагентов(ТипЭлектронногоДокумента, Использовать) 
```
</details>

## ПриЗаполненииИнформацииОТовареИзФайлаПрикладногоЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполнение информации о товаре прикладного электронного документа по данным в файла.
// Выполняется при использовании сопоставления номенклатуры контрагентов.
//
// Параметры:
//  ДанныеФайла       - ДвоичныеДанные - Данные файла прикладного электронного документа.
//  РасширениеФайла   - Строка - Расширение файла без точки.
//  ИнформациюОТоваре - ТаблицаЗначений - Таблица товаров.
//     * ИД                                    - Строка - Идентификатор товара по данным поставщика.
//     * Наименование                          - Строка - Наименование номенклатуры.
//     * НаименованиеХарактеристики            - Строка - Наименование характеристики.
//     * КодТовара                             - Строка - Код товара.
//     * Артикул                               - Строка - Артикул.
//     * БазоваяЕдиницаКод                     - Строка - Код единицы измерения.
//     * БазоваяЕдиницаНаименование            - Строка - Наименование единицы измерения.
//     * БазоваяЕдиницаНаименованиеПолное      - Строка - Полное наименование единицы измерения.
//     * БазоваяЕдиницаМеждународноеСокращение - Строка - Международное сокращение единицы измерения.
//     * Описание                              - Строка - Произвольное описание товара.
//     * Сопоставление                         - Структура - Параметры сопоставления номенклатуры.
//                                               Заполняется, если необходимо переопределить стандартный механизм.
//        ** Идентификатор    - Строка - Идентификатор товара.
//        ** Наименование     - Строка - Наименование номенклатуры.
//        ** Характеристика   - Строка - Наименование характеристики.
//        ** ЕдиницаИзмерения - Строка - Наименование единицы измерения.
//        ** Артикул          - Строка - Артикул.
//
Процедура ПриЗаполненииИнформацииОТовареИзФайлаПрикладногоЭлектронногоДокумента(ДанныеФайла, РасширениеФайла, ИнформациюОТоваре) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриЗаполненииИнформацииОТовареИзФайлаПрикладногоЭлектронногоДокумента(ДанныеФайла, РасширениеФайла, ИнформациюОТоваре) 
```
</details>

## ПриОтраженииВУчетеПрикладногоЭлектронногоДокументаСНоменклатурой
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняется при отражении в учете прикладного электронного документа, содержащего информацию для сопоставления номенклатуры.
// Позволяет определить необходимость сопоставления номенклатуры для указанного способа обработки электронных документов,
// а также отказаться от отражения в учете, если сопоставление не выполнено.
// Если в электронном документе не передана информация для сопоставления,
// то отражение в учете будет продолжено независимо от настроек.
// Выполняется при использовании сопоставления номенклатуры контрагентов.
//
// Параметры:
//  Документ - Структура - данные электронного документа (только чтение):
//   * СпособОбработки - Строка - способ отражения в учете электронного документа.
//                       См. ПриОпределенииСпособовОбработкиПрикладногоТипаЭлектронногоДокумента.
//  Настройки - Структура - настройки сопоставления номенклатуры (для изменения):
//   * ОтражатьТолькоСопоставленные - Булево - признак разрешения отражать в учете только документы с сопоставленной номенклатурой. По умолчанию Истина.
//                                             Если в электронном документе не передана информация для сопоставления,
//                                             то отражение в учете будет продолжено независимо от настроек.
//
Процедура ПриОтраженииВУчетеПрикладногоЭлектронногоДокументаСНоменклатурой(Знач Документ, Настройки) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриОтраженииВУчетеПрикладногоЭлектронногоДокументаСНоменклатурой(Документ, Настройки) 
```
</details>

## ПриСозданииОбъектовУчетаИзФайлаПрикладногоЭлектронногоДокумента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Выполняется при создании или при повторном заполнении документа учета по данным файла электронного документа.
//
// Параметры:
//  ПараметрыФайлаЭлектронногоДокумента - Структура - Параметры
//     * ДанныеФайла     - ДвоичныеДанные - Данные файла прикладного электронного документа.
//     * СпособОбработки - Строка - Способ отражения в учете электронного документа.
//                         См. ПриОпределенииСпособовОбработкиПрикладногоТипаЭлектронногоДокумента.
//     * Входящий        - Булево - Признак того, что электронный документ является входящим.
//  СсылкиНаОбъекты - Массив - Документы информационной базы, созданные ранее по электронному документу.
//
Процедура ПриСозданииОбъектовУчетаИзФайлаПрикладногоЭлектронногоДокумента(ПараметрыФайлаЭлектронногоДокумента, СсылкиНаОбъекты) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.ПриСозданииОбъектовУчетаИзФайлаПрикладногоЭлектронногоДокумента(ПараметрыФайлаЭлектронногоДокумента, СсылкиНаОбъекты) 
```
</details>

## СуммаПрописью
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Заполняет сумму прописью.
//
// Параметры:
//  СуммаЧислом - Число - преобразуемая сумма.
//  КодВалюты   - Число - код используемой валюты.
//  Результат   - Строка - сумма прописью. Выходной параметр.
//
Процедура СуммаПрописью(СуммаЧислом, КодВалюты, Результат) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.СуммаПрописью(СуммаЧислом, КодВалюты, Результат) 
```
</details>

## УстановитьИменаСвязейПараметровВыбораДоговорКонтрагента
<details style="margin: 1em 0; padding: 0.5em; border: 1px solid #ccc; border-radius: 6px;">

<summary style="font-weight: bold; cursor: pointer;">Описание, пример вызова</summary>

```bsl

// Задает имена связей параметров выбора для полей форм библиотеки, в которых выбирается договор контрагента.
//
// Параметры:
//  ИмяСвязиПоОрганизации  - Строка - Имя связи параметров выбора для связанного поля "Организация",
//                                    если значение не будет установлено, то связь параметров выбора не будет установлена.
//  ИмяСвязиПоКонтрагенту  - Строка - Имя связи параметров выбора для связанного поля "Контрагент",
//                                    если значение не будет установлено, то связь параметров выбора не будет установлена.
//
Процедура УстановитьИменаСвязейПараметровВыбораДоговорКонтрагента(ИмяСвязиПоОрганизации, ИмяСвязиПоКонтрагенту) Экспорт
```

Пример вызова
```bsl
ОбменСКонтрагентамиПереопределяемый.УстановитьИменаСвязейПараметровВыбораДоговорКонтрагента(ИмяСвязиПоОрганизации, ИмяСвязиПоКонтрагенту) 
```
</details>

---

© 2024, **ООО 1С-Софт**  
Все права защищены. Эта программа и сопроводительные материалы предоставляются  
в соответствии с условиями лицензии [Attribution 4.0 International (CC BY 4.0)](https://creativecommons.org/licenses/by/4.0/legalcode).

---
